{
 "cells": [
  {
   "attachments": {},
   "cell_type": "markdown",
   "id": "e2641694",
   "metadata": {},
   "source": [
    "# Reading an NWB File\n",
    "After downloading an NWB file, you *may* want to view the data inside. You can do basic reading of the file with **[PyNWB](https://github.com/NeurodataWithoutBorders/pynwb)**. This is a package designed to utilize, modify, and process NWB files. The basic read functionality of PyNWB is shown below."
   ]
  },
  {
   "attachments": {},
   "cell_type": "markdown",
   "id": "5d21aa90",
   "metadata": {},
   "source": [
    "### Environment Setup\n",
    "⚠️**Note: If running on a new environment, run this cell once and then restart the kernel**⚠️"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "id": "8a22c703",
   "metadata": {},
   "outputs": [],
   "source": [
    "import warnings\n",
    "warnings.filterwarnings('ignore')\n",
    "\n",
    "try:\n",
    "    from databook_utils.dandi_utils import dandi_stream_open\n",
    "except:\n",
    "    !git clone https://github.com/AllenInstitute/openscope_databook.git\n",
    "    %cd openscope_databook\n",
    "    %pip install -e .\n",
    "    %cd ./docs/basics"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "id": "d76f08a6",
   "metadata": {},
   "outputs": [],
   "source": [
    "import pandas as pd\n",
    "\n",
    "from dandi import dandiapi\n",
    "from pynwb import NWBHDF5IO"
   ]
  },
  {
   "attachments": {},
   "cell_type": "markdown",
   "id": "4687824b",
   "metadata": {},
   "source": [
    "### Downloading an NWB File\n",
    "To read an NWB File, it must first be downloaded. `dandiset_id` and `dandi_filepath` may be changed to select a different file off of DANDI. If the file of interest is already downloaded, you don't need to run the download cell again. When trying to download an embargoed file, refer to the code from the [Downloading an NWB File](./download_nwb.ipynb) notebook."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "id": "7fbd4d6c",
   "metadata": {},
   "outputs": [],
   "source": [
    "dandiset_id = \"000021\"\n",
    "dandi_filepath = \"sub-723627600/sub-723627600_ses-742951821.nwb\"\n",
    "download_loc = \".\""
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "id": "9da13c50",
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "sub-723627600_ses-742951821.nwb\n",
      "./sub-723627600_ses-742951821.nwb\n"
     ]
    }
   ],
   "source": [
    "filename = dandi_filepath.split(\"/\")[-1]\n",
    "filepath = f\"{download_loc}/{filename}\"\n",
    "\n",
    "print(filename)\n",
    "print(filepath)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "id": "da61049a",
   "metadata": {},
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "A newer version (0.62.2) of dandi/dandi-cli is available. You are using 0.61.2\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Downloaded file to ./sub-723627600_ses-742951821.nwb\n"
     ]
    }
   ],
   "source": [
    "client = dandiapi.DandiAPIClient()\n",
    "my_dandiset = client.get_dandiset(dandiset_id)\n",
    "file = my_dandiset.get_asset_by_path(dandi_filepath)\n",
    "# this may take awhile, especially if the file to download is large\n",
    "file.download(filepath)\n",
    "\n",
    "print(f\"Downloaded file to {filepath}\")"
   ]
  },
  {
   "attachments": {},
   "cell_type": "markdown",
   "id": "0b6b0571",
   "metadata": {},
   "source": [
    "### Reading an NWB File\n",
    "You can read in a NWB file with **PyNWB**'s `NWBHDF5IO` method to retrieve an io object. You can use the `.read` method to actually read it in. From there, you can see the raw data of the NWB file and can print the fields you are interested in. "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 11,
   "id": "7628e758",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "        <style>\n",
       "            .container-fields {\n",
       "                font-family: \"Open Sans\", Arial, sans-serif;\n",
       "            }\n",
       "            .container-fields .field-value {\n",
       "                color: #00788E;\n",
       "            }\n",
       "            .container-fields details > summary {\n",
       "                cursor: pointer;\n",
       "                display: list-item;\n",
       "            }\n",
       "            .container-fields details > summary:hover {\n",
       "                color: #0A6EAA;\n",
       "            }\n",
       "        </style>\n",
       "        \n",
       "        <script>\n",
       "            function copyToClipboard(text) {\n",
       "                navigator.clipboard.writeText(text).then(function() {\n",
       "                    console.log('Copied to clipboard: ' + text);\n",
       "                }, function(err) {\n",
       "                    console.error('Could not copy text: ', err);\n",
       "                });\n",
       "            }\n",
       "\n",
       "            document.addEventListener('DOMContentLoaded', function() {\n",
       "                let fieldKeys = document.querySelectorAll('.container-fields .field-key');\n",
       "                fieldKeys.forEach(function(fieldKey) {\n",
       "                    fieldKey.addEventListener('click', function() {\n",
       "                        let accessCode = fieldKey.getAttribute('title').replace('Access code: ', '');\n",
       "                        copyToClipboard(accessCode);\n",
       "                    });\n",
       "                });\n",
       "            });\n",
       "        </script>\n",
       "        <div class='container-wrap'><div class='container-header'><div class='xr-obj-type'><h3>root (NWBFile)</h3></div></div><div style=\"margin-left: 0px;\" class=\"container-fields\"><span class=\"field-key\" title=\".session_description\">session_description: </span><span class=\"field-value\">Data and metadata for an Ecephys session</span></div><div style=\"margin-left: 0px;\" class=\"container-fields\"><span class=\"field-key\" title=\".identifier\">identifier: </span><span class=\"field-value\">742951821</span></div><details><summary style=\"display: list-item; margin-left: 0px;\" class=\"container-fields field-key\" title=\".session_start_time\"><b>session_start_time</b></summary><span class=\"field-key\">2018-10-26 12:47:04-07:00</span></details><details><summary style=\"display: list-item; margin-left: 0px;\" class=\"container-fields field-key\" title=\".timestamps_reference_time\"><b>timestamps_reference_time</b></summary><span class=\"field-key\">2018-10-26 12:47:04-07:00</span></details><details><summary style=\"display: list-item; margin-left: 0px;\" class=\"container-fields field-key\" title=\".file_create_date\"><b>file_create_date</b></summary><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".file_create_date[0]\"><b>0</b></summary><span class=\"field-key\">2020-05-26 00:53:26.959556-07:00</span></details></details><details><summary style=\"display: list-item; margin-left: 0px;\" class=\"container-fields field-key\" title=\".acquisition\"><b>acquisition</b></summary><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".acquisition['raw_running_wheel_rotation']\"><b>raw_running_wheel_rotation</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".acquisition['raw_running_wheel_rotation'].resolution\">resolution: </span><span class=\"field-value\">-1.0</span></div><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".acquisition['raw_running_wheel_rotation'].comments\">comments: </span><span class=\"field-value\">no comments</span></div><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".acquisition['raw_running_wheel_rotation'].description\">description: </span><span class=\"field-value\">no description</span></div><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".acquisition['raw_running_wheel_rotation'].conversion\">conversion: </span><span class=\"field-value\">1.0</span></div><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".acquisition['raw_running_wheel_rotation'].offset\">offset: </span><span class=\"field-value\">0.0</span></div><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".acquisition['raw_running_wheel_rotation'].unit\">unit: </span><span class=\"field-value\">radians</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".acquisition['raw_running_wheel_rotation'].data\"><b>data</b></summary></details><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".acquisition['raw_running_wheel_rotation'].timestamps\"><b>timestamps</b></summary></details><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".acquisition['raw_running_wheel_rotation'].timestamps_unit\">timestamps_unit: </span><span class=\"field-value\">seconds</span></div><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".acquisition['raw_running_wheel_rotation'].interval\">interval: </span><span class=\"field-value\">1</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".acquisition['raw_running_wheel_rotation'].timestamp_link\"><b>timestamp_link</b></summary><div style=\"margin-left: 60px;\" class=\"container-fields\"><span class=\"field-key\" title=\".acquisition['raw_running_wheel_rotation'].timestamp_link[0]\">0: </span><span class=\"field-value\">acquisition/running_wheel_signal_voltage/timestamps</span></div><div style=\"margin-left: 60px;\" class=\"container-fields\"><span class=\"field-key\" title=\".acquisition['raw_running_wheel_rotation'].timestamp_link[0][1]\">1: </span><span class=\"field-value\">acquisition/running_wheel_supply_voltage/timestamps</span></div></details></details><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".acquisition['running_wheel_signal_voltage']\"><b>running_wheel_signal_voltage</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".acquisition['running_wheel_signal_voltage'].resolution\">resolution: </span><span class=\"field-value\">-1.0</span></div><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".acquisition['running_wheel_signal_voltage'].comments\">comments: </span><span class=\"field-value\">no comments</span></div><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".acquisition['running_wheel_signal_voltage'].description\">description: </span><span class=\"field-value\">no description</span></div><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".acquisition['running_wheel_signal_voltage'].conversion\">conversion: </span><span class=\"field-value\">1.0</span></div><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".acquisition['running_wheel_signal_voltage'].offset\">offset: </span><span class=\"field-value\">0.0</span></div><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".acquisition['running_wheel_signal_voltage'].unit\">unit: </span><span class=\"field-value\">V</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".acquisition['running_wheel_signal_voltage'].data\"><b>data</b></summary></details><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".acquisition['running_wheel_signal_voltage'].timestamps\"><b>timestamps (link to acquisition/raw_running_wheel_rotation/timestamps)</b></summary></details><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".acquisition['running_wheel_signal_voltage'].timestamps_unit\">timestamps_unit: </span><span class=\"field-value\">seconds</span></div><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".acquisition['running_wheel_signal_voltage'].interval\">interval: </span><span class=\"field-value\">1</span></div></details><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".acquisition['running_wheel_supply_voltage']\"><b>running_wheel_supply_voltage</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".acquisition['running_wheel_supply_voltage'].resolution\">resolution: </span><span class=\"field-value\">-1.0</span></div><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".acquisition['running_wheel_supply_voltage'].comments\">comments: </span><span class=\"field-value\">no comments</span></div><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".acquisition['running_wheel_supply_voltage'].description\">description: </span><span class=\"field-value\">no description</span></div><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".acquisition['running_wheel_supply_voltage'].conversion\">conversion: </span><span class=\"field-value\">1.0</span></div><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".acquisition['running_wheel_supply_voltage'].offset\">offset: </span><span class=\"field-value\">0.0</span></div><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".acquisition['running_wheel_supply_voltage'].unit\">unit: </span><span class=\"field-value\">V</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".acquisition['running_wheel_supply_voltage'].data\"><b>data</b></summary></details><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".acquisition['running_wheel_supply_voltage'].timestamps\"><b>timestamps (link to acquisition/raw_running_wheel_rotation/timestamps)</b></summary></details><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".acquisition['running_wheel_supply_voltage'].timestamps_unit\">timestamps_unit: </span><span class=\"field-value\">seconds</span></div><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".acquisition['running_wheel_supply_voltage'].interval\">interval: </span><span class=\"field-value\">1</span></div></details></details><details><summary style=\"display: list-item; margin-left: 0px;\" class=\"container-fields field-key\" title=\".processing\"><b>processing</b></summary><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".processing['eye_tracking']\"><b>eye_tracking</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['eye_tracking'].description\">description: </span><span class=\"field-value\">Eye tracking processing module</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".processing['eye_tracking'].data_interfaces\"><b>data_interfaces</b></summary><details><summary style=\"display: list-item; margin-left: 60px;\" class=\"container-fields field-key\" title=\".processing['eye_tracking'].data_interfaces['cr_ellipse_fits']\"><b>cr_ellipse_fits</b></summary><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['eye_tracking'].data_interfaces['cr_ellipse_fits']\">description: </span><span class=\"field-value\"></span></div><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['eye_tracking'].data_interfaces['cr_ellipse_fits']\"><b>table</b></summary><table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>center_x</th>\n",
       "      <th>center_y</th>\n",
       "      <th>height</th>\n",
       "      <th>phi</th>\n",
       "      <th>width</th>\n",
       "      <th>timestamps</th>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>id</th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>327.339200</td>\n",
       "      <td>220.528876</td>\n",
       "      <td>7.122461</td>\n",
       "      <td>-0.046604</td>\n",
       "      <td>8.540818</td>\n",
       "      <td>3.15554</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>327.225841</td>\n",
       "      <td>220.183568</td>\n",
       "      <td>7.286199</td>\n",
       "      <td>-0.186530</td>\n",
       "      <td>8.163864</td>\n",
       "      <td>3.17849</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>327.171088</td>\n",
       "      <td>220.285960</td>\n",
       "      <td>7.290239</td>\n",
       "      <td>-0.267194</td>\n",
       "      <td>8.074097</td>\n",
       "      <td>3.18553</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>327.097132</td>\n",
       "      <td>220.502671</td>\n",
       "      <td>7.239620</td>\n",
       "      <td>-0.006504</td>\n",
       "      <td>8.026307</td>\n",
       "      <td>3.21892</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table><p>... and 288127 more rows.</p></details></details><details><summary style=\"display: list-item; margin-left: 60px;\" class=\"container-fields field-key\" title=\".processing['eye_tracking'].data_interfaces['eye_ellipse_fits']\"><b>eye_ellipse_fits</b></summary><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['eye_tracking'].data_interfaces['eye_ellipse_fits']\">description: </span><span class=\"field-value\"></span></div><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['eye_tracking'].data_interfaces['eye_ellipse_fits']\"><b>table</b></summary><table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>center_x</th>\n",
       "      <th>center_y</th>\n",
       "      <th>height</th>\n",
       "      <th>phi</th>\n",
       "      <th>width</th>\n",
       "      <th>timestamps</th>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>id</th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>310.748365</td>\n",
       "      <td>207.967287</td>\n",
       "      <td>124.601937</td>\n",
       "      <td>0.080571</td>\n",
       "      <td>158.078800</td>\n",
       "      <td>3.15554</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>311.049063</td>\n",
       "      <td>208.004817</td>\n",
       "      <td>124.397462</td>\n",
       "      <td>0.078970</td>\n",
       "      <td>157.795426</td>\n",
       "      <td>3.17849</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>311.266888</td>\n",
       "      <td>208.144224</td>\n",
       "      <td>124.609645</td>\n",
       "      <td>0.089244</td>\n",
       "      <td>157.970495</td>\n",
       "      <td>3.18553</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>311.164458</td>\n",
       "      <td>208.152664</td>\n",
       "      <td>124.450363</td>\n",
       "      <td>0.091454</td>\n",
       "      <td>157.778064</td>\n",
       "      <td>3.21892</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table><p>... and 288127 more rows.</p></details></details><details><summary style=\"display: list-item; margin-left: 60px;\" class=\"container-fields field-key\" title=\".processing['eye_tracking'].data_interfaces['pupil_ellipse_fits']\"><b>pupil_ellipse_fits</b></summary><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['eye_tracking'].data_interfaces['pupil_ellipse_fits']\">description: </span><span class=\"field-value\"></span></div><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['eye_tracking'].data_interfaces['pupil_ellipse_fits']\"><b>table</b></summary><table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>center_x</th>\n",
       "      <th>center_y</th>\n",
       "      <th>height</th>\n",
       "      <th>phi</th>\n",
       "      <th>width</th>\n",
       "      <th>timestamps</th>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>id</th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>327.890593</td>\n",
       "      <td>192.698878</td>\n",
       "      <td>38.936052</td>\n",
       "      <td>-0.301362</td>\n",
       "      <td>42.041979</td>\n",
       "      <td>3.15554</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>NaN</td>\n",
       "      <td>NaN</td>\n",
       "      <td>NaN</td>\n",
       "      <td>NaN</td>\n",
       "      <td>NaN</td>\n",
       "      <td>3.17849</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>NaN</td>\n",
       "      <td>NaN</td>\n",
       "      <td>NaN</td>\n",
       "      <td>NaN</td>\n",
       "      <td>NaN</td>\n",
       "      <td>3.18553</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>329.518794</td>\n",
       "      <td>194.347578</td>\n",
       "      <td>41.306612</td>\n",
       "      <td>0.356213</td>\n",
       "      <td>45.434569</td>\n",
       "      <td>3.21892</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table><p>... and 288127 more rows.</p></details></details></details></details><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".processing['eye_tracking_rig_metadata']\"><b>eye_tracking_rig_metadata</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['eye_tracking_rig_metadata'].description\">description: </span><span class=\"field-value\">Eye tracking rig metadata module</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".processing['eye_tracking_rig_metadata'].data_interfaces\"><b>data_interfaces</b></summary><details><summary style=\"display: list-item; margin-left: 60px;\" class=\"container-fields field-key\" title=\".processing['eye_tracking_rig_metadata'].data_interfaces['eye_tracking_rig_metadata']\"><b>eye_tracking_rig_metadata</b></summary><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['eye_tracking_rig_metadata'].data_interfaces['eye_tracking_rig_metadata'].equipment\">equipment: </span><span class=\"field-value\">NP.1</span></div><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['eye_tracking_rig_metadata'].data_interfaces['eye_tracking_rig_metadata'].monitor_position\"><b>monitor_position</b></summary></details><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['eye_tracking_rig_metadata'].data_interfaces['eye_tracking_rig_metadata'].monitor_position__unit\">monitor_position__unit: </span><span class=\"field-value\">mm</span></div><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['eye_tracking_rig_metadata'].data_interfaces['eye_tracking_rig_metadata'].camera_position\"><b>camera_position</b></summary></details><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['eye_tracking_rig_metadata'].data_interfaces['eye_tracking_rig_metadata'].camera_position__unit\">camera_position__unit: </span><span class=\"field-value\">mm</span></div><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['eye_tracking_rig_metadata'].data_interfaces['eye_tracking_rig_metadata'].led_position\"><b>led_position</b></summary></details><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['eye_tracking_rig_metadata'].data_interfaces['eye_tracking_rig_metadata'].led_position__unit\">led_position__unit: </span><span class=\"field-value\">mm</span></div><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['eye_tracking_rig_metadata'].data_interfaces['eye_tracking_rig_metadata'].monitor_rotation\"><b>monitor_rotation</b></summary></details><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['eye_tracking_rig_metadata'].data_interfaces['eye_tracking_rig_metadata'].monitor_rotation__unit\">monitor_rotation__unit: </span><span class=\"field-value\">deg</span></div><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['eye_tracking_rig_metadata'].data_interfaces['eye_tracking_rig_metadata'].camera_rotation\"><b>camera_rotation</b></summary></details><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['eye_tracking_rig_metadata'].data_interfaces['eye_tracking_rig_metadata'].camera_rotation__unit\">camera_rotation__unit: </span><span class=\"field-value\">deg</span></div></details></details></details><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".processing['filtered_gaze_mapping']\"><b>filtered_gaze_mapping</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].description\">description: </span><span class=\"field-value\">Gaze mapping processing module filtered outputs</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces\"><b>data_interfaces</b></summary><details><summary style=\"display: list-item; margin-left: 60px;\" class=\"container-fields field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['eye_area']\"><b>eye_area</b></summary><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['eye_area'].resolution\">resolution: </span><span class=\"field-value\">-1.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['eye_area'].comments\">comments: </span><span class=\"field-value\">no comments</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['eye_area'].description\">description: </span><span class=\"field-value\">no description</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['eye_area'].conversion\">conversion: </span><span class=\"field-value\">1.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['eye_area'].offset\">offset: </span><span class=\"field-value\">0.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['eye_area'].unit\">unit: </span><span class=\"field-value\">Pixels ^ 2</span></div><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['eye_area'].data\"><b>data</b></summary></details><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['eye_area'].timestamps\"><b>timestamps</b></summary></details><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['eye_area'].timestamps_unit\">timestamps_unit: </span><span class=\"field-value\">seconds</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['eye_area'].interval\">interval: </span><span class=\"field-value\">1</span></div></details><details><summary style=\"display: list-item; margin-left: 60px;\" class=\"container-fields field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['pupil_area']\"><b>pupil_area</b></summary><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['pupil_area'].resolution\">resolution: </span><span class=\"field-value\">-1.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['pupil_area'].comments\">comments: </span><span class=\"field-value\">no comments</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['pupil_area'].description\">description: </span><span class=\"field-value\">no description</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['pupil_area'].conversion\">conversion: </span><span class=\"field-value\">1.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['pupil_area'].offset\">offset: </span><span class=\"field-value\">0.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['pupil_area'].unit\">unit: </span><span class=\"field-value\">Pixels ^ 2</span></div><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['pupil_area'].data\"><b>data</b></summary></details><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['pupil_area'].timestamps\"><b>timestamps</b></summary></details><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['pupil_area'].timestamps_unit\">timestamps_unit: </span><span class=\"field-value\">seconds</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['pupil_area'].interval\">interval: </span><span class=\"field-value\">1</span></div></details><details><summary style=\"display: list-item; margin-left: 60px;\" class=\"container-fields field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['screen_coordinates']\"><b>screen_coordinates</b></summary><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['screen_coordinates'].resolution\">resolution: </span><span class=\"field-value\">-1.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['screen_coordinates'].comments\">comments: </span><span class=\"field-value\">no comments</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['screen_coordinates'].description\">description: </span><span class=\"field-value\">no description</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['screen_coordinates'].conversion\">conversion: </span><span class=\"field-value\">1.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['screen_coordinates'].offset\">offset: </span><span class=\"field-value\">0.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['screen_coordinates'].unit\">unit: </span><span class=\"field-value\">Centimeters</span></div><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['screen_coordinates'].data\"><b>data</b></summary></details><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['screen_coordinates'].timestamps\"><b>timestamps</b></summary></details><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['screen_coordinates'].timestamps_unit\">timestamps_unit: </span><span class=\"field-value\">seconds</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['screen_coordinates'].interval\">interval: </span><span class=\"field-value\">1</span></div></details><details><summary style=\"display: list-item; margin-left: 60px;\" class=\"container-fields field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['screen_coordinates_spherical']\"><b>screen_coordinates_spherical</b></summary><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['screen_coordinates_spherical'].resolution\">resolution: </span><span class=\"field-value\">-1.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['screen_coordinates_spherical'].comments\">comments: </span><span class=\"field-value\">no comments</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['screen_coordinates_spherical'].description\">description: </span><span class=\"field-value\">no description</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['screen_coordinates_spherical'].conversion\">conversion: </span><span class=\"field-value\">1.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['screen_coordinates_spherical'].offset\">offset: </span><span class=\"field-value\">0.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['screen_coordinates_spherical'].unit\">unit: </span><span class=\"field-value\">Degrees</span></div><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['screen_coordinates_spherical'].data\"><b>data</b></summary></details><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['screen_coordinates_spherical'].timestamps\"><b>timestamps</b></summary></details><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['screen_coordinates_spherical'].timestamps_unit\">timestamps_unit: </span><span class=\"field-value\">seconds</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['filtered_gaze_mapping'].data_interfaces['screen_coordinates_spherical'].interval\">interval: </span><span class=\"field-value\">1</span></div></details></details></details><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".processing['optotagging']\"><b>optotagging</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['optotagging'].description\">description: </span><span class=\"field-value\">optogenetic stimulution data</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".processing['optotagging'].data_interfaces\"><b>data_interfaces</b></summary><details><summary style=\"display: list-item; margin-left: 60px;\" class=\"container-fields field-key\" title=\".processing['optotagging'].data_interfaces['optotagging']\"><b>optotagging</b></summary><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['optotagging'].data_interfaces['optotagging'].resolution\">resolution: </span><span class=\"field-value\">-1.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['optotagging'].data_interfaces['optotagging'].comments\">comments: </span><span class=\"field-value\">no comments</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['optotagging'].data_interfaces['optotagging'].description\">description: </span><span class=\"field-value\">no description</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['optotagging'].data_interfaces['optotagging'].conversion\">conversion: </span><span class=\"field-value\">1.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['optotagging'].data_interfaces['optotagging'].offset\">offset: </span><span class=\"field-value\">0.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['optotagging'].data_interfaces['optotagging'].unit\">unit: </span><span class=\"field-value\">seconds</span></div><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['optotagging'].data_interfaces['optotagging'].data\"><b>data</b></summary></details><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['optotagging'].data_interfaces['optotagging'].timestamps\"><b>timestamps</b></summary></details><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['optotagging'].data_interfaces['optotagging'].timestamps_unit\">timestamps_unit: </span><span class=\"field-value\">seconds</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['optotagging'].data_interfaces['optotagging'].interval\">interval: </span><span class=\"field-value\">1</span></div></details><details><summary style=\"display: list-item; margin-left: 60px;\" class=\"container-fields field-key\" title=\".processing['optotagging'].data_interfaces['optogenetic_stimulation']\"><b>optogenetic_stimulation</b></summary><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['optotagging'].data_interfaces['optogenetic_stimulation']\">description: </span><span class=\"field-value\"></span></div><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['optotagging'].data_interfaces['optogenetic_stimulation']\"><b>table</b></summary><table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>start_time</th>\n",
       "      <th>condition</th>\n",
       "      <th>level</th>\n",
       "      <th>stop_time</th>\n",
       "      <th>stimulus_name</th>\n",
       "      <th>duration</th>\n",
       "      <th>tags</th>\n",
       "      <th>timeseries</th>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>id</th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>9225.19538</td>\n",
       "      <td>a single square pulse</td>\n",
       "      <td>2.5</td>\n",
       "      <td>9225.20038</td>\n",
       "      <td>pulse</td>\n",
       "      <td>0.005</td>\n",
       "      <td>[optical_stimulation]</td>\n",
       "      <td>[(0, 1, optotagging pynwb.base.TimeSeries at 0x1601617791104\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (180,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (180,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: seconds\\n)]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>9227.05495</td>\n",
       "      <td>a single square pulse</td>\n",
       "      <td>1.0</td>\n",
       "      <td>9227.05995</td>\n",
       "      <td>pulse</td>\n",
       "      <td>0.005</td>\n",
       "      <td>[optical_stimulation]</td>\n",
       "      <td>[(1, 1, optotagging pynwb.base.TimeSeries at 0x1601617791104\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (180,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (180,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: seconds\\n)]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>9228.82508</td>\n",
       "      <td>half-period of a cosine wave</td>\n",
       "      <td>2.5</td>\n",
       "      <td>9229.82508</td>\n",
       "      <td>raised_cosine</td>\n",
       "      <td>1.000</td>\n",
       "      <td>[optical_stimulation]</td>\n",
       "      <td>[(2, 1, optotagging pynwb.base.TimeSeries at 0x1601617791104\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (180,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (180,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: seconds\\n)]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>9230.66016</td>\n",
       "      <td>2.5 ms pulses at 10 Hz</td>\n",
       "      <td>2.5</td>\n",
       "      <td>9231.66016</td>\n",
       "      <td>fast_pulses</td>\n",
       "      <td>1.000</td>\n",
       "      <td>[optical_stimulation]</td>\n",
       "      <td>[(3, 1, optotagging pynwb.base.TimeSeries at 0x1601617791104\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (180,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (180,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: seconds\\n)]</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table><p>... and 176 more rows.</p></details></details></details></details><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".processing['raw_gaze_mapping']\"><b>raw_gaze_mapping</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].description\">description: </span><span class=\"field-value\">Gaze mapping processing module raw outputs</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces\"><b>data_interfaces</b></summary><details><summary style=\"display: list-item; margin-left: 60px;\" class=\"container-fields field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['eye_area']\"><b>eye_area</b></summary><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['eye_area'].resolution\">resolution: </span><span class=\"field-value\">-1.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['eye_area'].comments\">comments: </span><span class=\"field-value\">no comments</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['eye_area'].description\">description: </span><span class=\"field-value\">no description</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['eye_area'].conversion\">conversion: </span><span class=\"field-value\">1.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['eye_area'].offset\">offset: </span><span class=\"field-value\">0.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['eye_area'].unit\">unit: </span><span class=\"field-value\">Pixels ^ 2</span></div><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['eye_area'].data\"><b>data</b></summary></details><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['eye_area'].timestamps\"><b>timestamps</b></summary></details><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['eye_area'].timestamps_unit\">timestamps_unit: </span><span class=\"field-value\">seconds</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['eye_area'].interval\">interval: </span><span class=\"field-value\">1</span></div></details><details><summary style=\"display: list-item; margin-left: 60px;\" class=\"container-fields field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['pupil_area']\"><b>pupil_area</b></summary><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['pupil_area'].resolution\">resolution: </span><span class=\"field-value\">-1.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['pupil_area'].comments\">comments: </span><span class=\"field-value\">no comments</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['pupil_area'].description\">description: </span><span class=\"field-value\">no description</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['pupil_area'].conversion\">conversion: </span><span class=\"field-value\">1.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['pupil_area'].offset\">offset: </span><span class=\"field-value\">0.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['pupil_area'].unit\">unit: </span><span class=\"field-value\">Pixels ^ 2</span></div><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['pupil_area'].data\"><b>data</b></summary></details><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['pupil_area'].timestamps\"><b>timestamps</b></summary></details><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['pupil_area'].timestamps_unit\">timestamps_unit: </span><span class=\"field-value\">seconds</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['pupil_area'].interval\">interval: </span><span class=\"field-value\">1</span></div></details><details><summary style=\"display: list-item; margin-left: 60px;\" class=\"container-fields field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['screen_coordinates']\"><b>screen_coordinates</b></summary><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['screen_coordinates'].resolution\">resolution: </span><span class=\"field-value\">-1.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['screen_coordinates'].comments\">comments: </span><span class=\"field-value\">no comments</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['screen_coordinates'].description\">description: </span><span class=\"field-value\">no description</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['screen_coordinates'].conversion\">conversion: </span><span class=\"field-value\">1.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['screen_coordinates'].offset\">offset: </span><span class=\"field-value\">0.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['screen_coordinates'].unit\">unit: </span><span class=\"field-value\">Centimeters</span></div><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['screen_coordinates'].data\"><b>data</b></summary></details><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['screen_coordinates'].timestamps\"><b>timestamps</b></summary></details><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['screen_coordinates'].timestamps_unit\">timestamps_unit: </span><span class=\"field-value\">seconds</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['screen_coordinates'].interval\">interval: </span><span class=\"field-value\">1</span></div></details><details><summary style=\"display: list-item; margin-left: 60px;\" class=\"container-fields field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['screen_coordinates_spherical']\"><b>screen_coordinates_spherical</b></summary><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['screen_coordinates_spherical'].resolution\">resolution: </span><span class=\"field-value\">-1.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['screen_coordinates_spherical'].comments\">comments: </span><span class=\"field-value\">no comments</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['screen_coordinates_spherical'].description\">description: </span><span class=\"field-value\">no description</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['screen_coordinates_spherical'].conversion\">conversion: </span><span class=\"field-value\">1.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['screen_coordinates_spherical'].offset\">offset: </span><span class=\"field-value\">0.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['screen_coordinates_spherical'].unit\">unit: </span><span class=\"field-value\">Degrees</span></div><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['screen_coordinates_spherical'].data\"><b>data</b></summary></details><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['screen_coordinates_spherical'].timestamps\"><b>timestamps</b></summary></details><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['screen_coordinates_spherical'].timestamps_unit\">timestamps_unit: </span><span class=\"field-value\">seconds</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['raw_gaze_mapping'].data_interfaces['screen_coordinates_spherical'].interval\">interval: </span><span class=\"field-value\">1</span></div></details></details></details><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".processing['running']\"><b>running</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['running'].description\">description: </span><span class=\"field-value\">running speed data</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".processing['running'].data_interfaces\"><b>data_interfaces</b></summary><details><summary style=\"display: list-item; margin-left: 60px;\" class=\"container-fields field-key\" title=\".processing['running'].data_interfaces['running_speed']\"><b>running_speed</b></summary><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['running'].data_interfaces['running_speed'].resolution\">resolution: </span><span class=\"field-value\">-1.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['running'].data_interfaces['running_speed'].comments\">comments: </span><span class=\"field-value\">no comments</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['running'].data_interfaces['running_speed'].description\">description: </span><span class=\"field-value\">no description</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['running'].data_interfaces['running_speed'].conversion\">conversion: </span><span class=\"field-value\">1.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['running'].data_interfaces['running_speed'].offset\">offset: </span><span class=\"field-value\">0.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['running'].data_interfaces['running_speed'].unit\">unit: </span><span class=\"field-value\">cm/s</span></div><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['running'].data_interfaces['running_speed'].data\"><b>data</b></summary></details><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['running'].data_interfaces['running_speed'].timestamps\"><b>timestamps</b></summary></details><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['running'].data_interfaces['running_speed'].timestamps_unit\">timestamps_unit: </span><span class=\"field-value\">seconds</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['running'].data_interfaces['running_speed'].interval\">interval: </span><span class=\"field-value\">1</span></div><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['running'].data_interfaces['running_speed'].timestamp_link\"><b>timestamp_link</b></summary><div style=\"margin-left: 100px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['running'].data_interfaces['running_speed'].timestamp_link[0]\">0: </span><span class=\"field-value\">processing/running/running_wheel_rotation/timestamps</span></div></details></details><details><summary style=\"display: list-item; margin-left: 60px;\" class=\"container-fields field-key\" title=\".processing['running'].data_interfaces['running_speed_end_times']\"><b>running_speed_end_times</b></summary><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['running'].data_interfaces['running_speed_end_times'].resolution\">resolution: </span><span class=\"field-value\">-1.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['running'].data_interfaces['running_speed_end_times'].comments\">comments: </span><span class=\"field-value\">no comments</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['running'].data_interfaces['running_speed_end_times'].description\">description: </span><span class=\"field-value\">no description</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['running'].data_interfaces['running_speed_end_times'].conversion\">conversion: </span><span class=\"field-value\">1.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['running'].data_interfaces['running_speed_end_times'].offset\">offset: </span><span class=\"field-value\">0.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['running'].data_interfaces['running_speed_end_times'].unit\">unit: </span><span class=\"field-value\">cm/s</span></div><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['running'].data_interfaces['running_speed_end_times'].data\"><b>data</b></summary></details><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['running'].data_interfaces['running_speed_end_times'].timestamps\"><b>timestamps</b></summary></details><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['running'].data_interfaces['running_speed_end_times'].timestamps_unit\">timestamps_unit: </span><span class=\"field-value\">seconds</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['running'].data_interfaces['running_speed_end_times'].interval\">interval: </span><span class=\"field-value\">1</span></div></details><details><summary style=\"display: list-item; margin-left: 60px;\" class=\"container-fields field-key\" title=\".processing['running'].data_interfaces['running_wheel_rotation']\"><b>running_wheel_rotation</b></summary><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['running'].data_interfaces['running_wheel_rotation'].resolution\">resolution: </span><span class=\"field-value\">-1.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['running'].data_interfaces['running_wheel_rotation'].comments\">comments: </span><span class=\"field-value\">no comments</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['running'].data_interfaces['running_wheel_rotation'].description\">description: </span><span class=\"field-value\">no description</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['running'].data_interfaces['running_wheel_rotation'].conversion\">conversion: </span><span class=\"field-value\">1.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['running'].data_interfaces['running_wheel_rotation'].offset\">offset: </span><span class=\"field-value\">0.0</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['running'].data_interfaces['running_wheel_rotation'].unit\">unit: </span><span class=\"field-value\">radians</span></div><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['running'].data_interfaces['running_wheel_rotation'].data\"><b>data</b></summary></details><details><summary style=\"display: list-item; margin-left: 80px;\" class=\"container-fields field-key\" title=\".processing['running'].data_interfaces['running_wheel_rotation'].timestamps\"><b>timestamps (link to processing/running/running_speed/timestamps)</b></summary></details><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['running'].data_interfaces['running_wheel_rotation'].timestamps_unit\">timestamps_unit: </span><span class=\"field-value\">seconds</span></div><div style=\"margin-left: 80px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['running'].data_interfaces['running_wheel_rotation'].interval\">interval: </span><span class=\"field-value\">1</span></div></details></details></details><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".processing['stimulus']\"><b>stimulus</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".processing['stimulus'].description\">description: </span><span class=\"field-value\">Stimulus Times processing</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".processing['stimulus'].data_interfaces\"><b>data_interfaces</b></summary><details><summary style=\"display: list-item; margin-left: 60px;\" class=\"container-fields field-key\" title=\".processing['stimulus'].data_interfaces['timestamps']\"><b>timestamps (link to processing/stimulus/timestamps/timestamps)</b></summary></details></details></details></details><details><summary style=\"display: list-item; margin-left: 0px;\" class=\"container-fields field-key\" title=\".epoch_tags\"><b>epoch_tags</b></summary><span class=\"field-key\">set()</span></details><details><summary style=\"display: list-item; margin-left: 0px;\" class=\"container-fields field-key\" title=\".electrodes\"><b>electrodes</b></summary><div style=\"margin-left: 20px;\" class=\"container-fields\"><span class=\"field-key\" title=\".electrodes\">description: </span><span class=\"field-value\">metadata about extracellular electrodes</span></div><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".electrodes\"><b>table</b></summary><table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>x</th>\n",
       "      <th>y</th>\n",
       "      <th>z</th>\n",
       "      <th>imp</th>\n",
       "      <th>location</th>\n",
       "      <th>filtering</th>\n",
       "      <th>group</th>\n",
       "      <th>group_name</th>\n",
       "      <th>probe_vertical_position</th>\n",
       "      <th>probe_horizontal_position</th>\n",
       "      <th>probe_id</th>\n",
       "      <th>local_index</th>\n",
       "      <th>valid_data</th>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>id</th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>850180720</th>\n",
       "      <td>NaN</td>\n",
       "      <td>NaN</td>\n",
       "      <td>NaN</td>\n",
       "      <td>NaN</td>\n",
       "      <td></td>\n",
       "      <td>AP band: 500 Hz high-pass; LFP band: 1000 Hz low-pass</td>\n",
       "      <td>probeE abc.EcephysElectrodeGroup at 0x1601617800992\\nFields:\\n  description: Ecephys Electrode Group\\n  device: probeE abc.EcephysProbe at 0x1601617789856\\nFields:\\n  probe_id: 769322720\\n  sampling_rate: 30000.0018391686\\n\\n  has_lfp_data: True\\n  lfp_sampling_rate: 1250.000076632025\\n  location: See electrode locations\\n  probe_id: 769322720\\n</td>\n",
       "      <td>probeE</td>\n",
       "      <td>3160</td>\n",
       "      <td>27</td>\n",
       "      <td>769322720</td>\n",
       "      <td>315</td>\n",
       "      <td>True</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>850180714</th>\n",
       "      <td>NaN</td>\n",
       "      <td>NaN</td>\n",
       "      <td>NaN</td>\n",
       "      <td>NaN</td>\n",
       "      <td></td>\n",
       "      <td>AP band: 500 Hz high-pass; LFP band: 1000 Hz low-pass</td>\n",
       "      <td>probeE abc.EcephysElectrodeGroup at 0x1601617800992\\nFields:\\n  description: Ecephys Electrode Group\\n  device: probeE abc.EcephysProbe at 0x1601617789856\\nFields:\\n  probe_id: 769322720\\n  sampling_rate: 30000.0018391686\\n\\n  has_lfp_data: True\\n  lfp_sampling_rate: 1250.000076632025\\n  location: See electrode locations\\n  probe_id: 769322720\\n</td>\n",
       "      <td>probeE</td>\n",
       "      <td>3140</td>\n",
       "      <td>43</td>\n",
       "      <td>769322720</td>\n",
       "      <td>312</td>\n",
       "      <td>True</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>850180154</th>\n",
       "      <td>NaN</td>\n",
       "      <td>NaN</td>\n",
       "      <td>NaN</td>\n",
       "      <td>NaN</td>\n",
       "      <td>VISal</td>\n",
       "      <td>AP band: 500 Hz high-pass; LFP band: 1000 Hz low-pass</td>\n",
       "      <td>probeE abc.EcephysElectrodeGroup at 0x1601617800992\\nFields:\\n  description: Ecephys Electrode Group\\n  device: probeE abc.EcephysProbe at 0x1601617789856\\nFields:\\n  probe_id: 769322720\\n  sampling_rate: 30000.0018391686\\n\\n  has_lfp_data: True\\n  lfp_sampling_rate: 1250.000076632025\\n  location: See electrode locations\\n  probe_id: 769322720\\n</td>\n",
       "      <td>probeE</td>\n",
       "      <td>340</td>\n",
       "      <td>43</td>\n",
       "      <td>769322720</td>\n",
       "      <td>32</td>\n",
       "      <td>True</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>850180600</th>\n",
       "      <td>NaN</td>\n",
       "      <td>NaN</td>\n",
       "      <td>NaN</td>\n",
       "      <td>NaN</td>\n",
       "      <td></td>\n",
       "      <td>AP band: 500 Hz high-pass; LFP band: 1000 Hz low-pass</td>\n",
       "      <td>probeE abc.EcephysElectrodeGroup at 0x1601617800992\\nFields:\\n  description: Ecephys Electrode Group\\n  device: probeE abc.EcephysProbe at 0x1601617789856\\nFields:\\n  probe_id: 769322720\\n  sampling_rate: 30000.0018391686\\n\\n  has_lfp_data: True\\n  lfp_sampling_rate: 1250.000076632025\\n  location: See electrode locations\\n  probe_id: 769322720\\n</td>\n",
       "      <td>probeE</td>\n",
       "      <td>2560</td>\n",
       "      <td>27</td>\n",
       "      <td>769322720</td>\n",
       "      <td>255</td>\n",
       "      <td>True</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table><p>... and 2300 more rows.</p></details></details><details><summary style=\"display: list-item; margin-left: 0px;\" class=\"container-fields field-key\" title=\".electrode_groups\"><b>electrode_groups</b></summary><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeA']\"><b>probeA</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".electrode_groups['probeA'].description\">description: </span><span class=\"field-value\">Ecephys Electrode Group</span></div><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".electrode_groups['probeA'].location\">location: </span><span class=\"field-value\">See electrode locations</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeA'].device\"><b>device</b></summary><div style=\"margin-left: 60px;\" class=\"container-fields\"><span class=\"field-key\" title=\".electrode_groups['probeA'].device.sampling_rate\">sampling_rate: </span><span class=\"field-value\">29999.970280708</span></div><details><summary style=\"display: list-item; margin-left: 60px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeA'].device.probe_id\"><b>probe_id</b></summary><span class=\"field-key\">769322712</span></details></details><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeA'].has_lfp_data\"><b>has_lfp_data</b></summary><span class=\"field-key\">True</span></details><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeA'].probe_id\"><b>probe_id</b></summary><span class=\"field-key\">769322712</span></details><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".electrode_groups['probeA'].lfp_sampling_rate\">lfp_sampling_rate: </span><span class=\"field-value\">1249.99876169617</span></div></details><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeB']\"><b>probeB</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".electrode_groups['probeB'].description\">description: </span><span class=\"field-value\">Ecephys Electrode Group</span></div><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".electrode_groups['probeB'].location\">location: </span><span class=\"field-value\">See electrode locations</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeB'].device\"><b>device</b></summary><div style=\"margin-left: 60px;\" class=\"container-fields\"><span class=\"field-key\" title=\".electrode_groups['probeB'].device.sampling_rate\">sampling_rate: </span><span class=\"field-value\">29999.9198310558</span></div><details><summary style=\"display: list-item; margin-left: 60px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeB'].device.probe_id\"><b>probe_id</b></summary><span class=\"field-key\">769322714</span></details></details><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeB'].has_lfp_data\"><b>has_lfp_data</b></summary><span class=\"field-key\">True</span></details><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeB'].probe_id\"><b>probe_id</b></summary><span class=\"field-key\">769322714</span></details><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".electrode_groups['probeB'].lfp_sampling_rate\">lfp_sampling_rate: </span><span class=\"field-value\">1249.996659627325</span></div></details><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeC']\"><b>probeC</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".electrode_groups['probeC'].description\">description: </span><span class=\"field-value\">Ecephys Electrode Group</span></div><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".electrode_groups['probeC'].location\">location: </span><span class=\"field-value\">See electrode locations</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeC'].device\"><b>device</b></summary><div style=\"margin-left: 60px;\" class=\"container-fields\"><span class=\"field-key\" title=\".electrode_groups['probeC'].device.sampling_rate\">sampling_rate: </span><span class=\"field-value\">29999.9989851737</span></div><details><summary style=\"display: list-item; margin-left: 60px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeC'].device.probe_id\"><b>probe_id</b></summary><span class=\"field-key\">769322716</span></details></details><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeC'].has_lfp_data\"><b>has_lfp_data</b></summary><span class=\"field-key\">True</span></details><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeC'].probe_id\"><b>probe_id</b></summary><span class=\"field-key\">769322716</span></details><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".electrode_groups['probeC'].lfp_sampling_rate\">lfp_sampling_rate: </span><span class=\"field-value\">1249.99995771557</span></div></details><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeD']\"><b>probeD</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".electrode_groups['probeD'].description\">description: </span><span class=\"field-value\">Ecephys Electrode Group</span></div><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".electrode_groups['probeD'].location\">location: </span><span class=\"field-value\">See electrode locations</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeD'].device\"><b>device</b></summary><div style=\"margin-left: 60px;\" class=\"container-fields\"><span class=\"field-key\" title=\".electrode_groups['probeD'].device.sampling_rate\">sampling_rate: </span><span class=\"field-value\">29999.9256599708</span></div><details><summary style=\"display: list-item; margin-left: 60px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeD'].device.probe_id\"><b>probe_id</b></summary><span class=\"field-key\">769322718</span></details></details><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeD'].has_lfp_data\"><b>has_lfp_data</b></summary><span class=\"field-key\">True</span></details><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeD'].probe_id\"><b>probe_id</b></summary><span class=\"field-key\">769322718</span></details><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".electrode_groups['probeD'].lfp_sampling_rate\">lfp_sampling_rate: </span><span class=\"field-value\">1249.996902498785</span></div></details><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeE']\"><b>probeE</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".electrode_groups['probeE'].description\">description: </span><span class=\"field-value\">Ecephys Electrode Group</span></div><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".electrode_groups['probeE'].location\">location: </span><span class=\"field-value\">See electrode locations</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeE'].device\"><b>device</b></summary><div style=\"margin-left: 60px;\" class=\"container-fields\"><span class=\"field-key\" title=\".electrode_groups['probeE'].device.sampling_rate\">sampling_rate: </span><span class=\"field-value\">30000.0018391686</span></div><details><summary style=\"display: list-item; margin-left: 60px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeE'].device.probe_id\"><b>probe_id</b></summary><span class=\"field-key\">769322720</span></details></details><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeE'].has_lfp_data\"><b>has_lfp_data</b></summary><span class=\"field-key\">True</span></details><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeE'].probe_id\"><b>probe_id</b></summary><span class=\"field-key\">769322720</span></details><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".electrode_groups['probeE'].lfp_sampling_rate\">lfp_sampling_rate: </span><span class=\"field-value\">1250.000076632025</span></div></details><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeF']\"><b>probeF</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".electrode_groups['probeF'].description\">description: </span><span class=\"field-value\">Ecephys Electrode Group</span></div><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".electrode_groups['probeF'].location\">location: </span><span class=\"field-value\">See electrode locations</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeF'].device\"><b>device</b></summary><div style=\"margin-left: 60px;\" class=\"container-fields\"><span class=\"field-key\" title=\".electrode_groups['probeF'].device.sampling_rate\">sampling_rate: </span><span class=\"field-value\">30000.042175479</span></div><details><summary style=\"display: list-item; margin-left: 60px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeF'].device.probe_id\"><b>probe_id</b></summary><span class=\"field-key\">769322722</span></details></details><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeF'].has_lfp_data\"><b>has_lfp_data</b></summary><span class=\"field-key\">True</span></details><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".electrode_groups['probeF'].probe_id\"><b>probe_id</b></summary><span class=\"field-key\">769322722</span></details><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".electrode_groups['probeF'].lfp_sampling_rate\">lfp_sampling_rate: </span><span class=\"field-value\">1250.001757311625</span></div></details></details><details><summary style=\"display: list-item; margin-left: 0px;\" class=\"container-fields field-key\" title=\".devices\"><b>devices</b></summary><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".devices['probeA']\"><b>probeA</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".devices['probeA'].sampling_rate\">sampling_rate: </span><span class=\"field-value\">29999.970280708</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".devices['probeA'].probe_id\"><b>probe_id</b></summary><span class=\"field-key\">769322712</span></details></details><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".devices['probeB']\"><b>probeB</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".devices['probeB'].sampling_rate\">sampling_rate: </span><span class=\"field-value\">29999.9198310558</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".devices['probeB'].probe_id\"><b>probe_id</b></summary><span class=\"field-key\">769322714</span></details></details><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".devices['probeC']\"><b>probeC</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".devices['probeC'].sampling_rate\">sampling_rate: </span><span class=\"field-value\">29999.9989851737</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".devices['probeC'].probe_id\"><b>probe_id</b></summary><span class=\"field-key\">769322716</span></details></details><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".devices['probeD']\"><b>probeD</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".devices['probeD'].sampling_rate\">sampling_rate: </span><span class=\"field-value\">29999.9256599708</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".devices['probeD'].probe_id\"><b>probe_id</b></summary><span class=\"field-key\">769322718</span></details></details><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".devices['probeE']\"><b>probeE</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".devices['probeE'].sampling_rate\">sampling_rate: </span><span class=\"field-value\">30000.0018391686</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".devices['probeE'].probe_id\"><b>probe_id</b></summary><span class=\"field-key\">769322720</span></details></details><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".devices['probeF']\"><b>probeF</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".devices['probeF'].sampling_rate\">sampling_rate: </span><span class=\"field-value\">30000.042175479</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".devices['probeF'].probe_id\"><b>probe_id</b></summary><span class=\"field-key\">769322722</span></details></details></details><details><summary style=\"display: list-item; margin-left: 0px;\" class=\"container-fields field-key\" title=\".intervals\"><b>intervals</b></summary><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".intervals['drifting_gratings_presentations']\"><b>drifting_gratings_presentations</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".intervals['drifting_gratings_presentations']\">description: </span><span class=\"field-value\">Presentation times and stimuli details for 'drifting_gratings' stimuli</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".intervals['drifting_gratings_presentations']\"><b>table</b></summary><table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>start_time</th>\n",
       "      <th>stop_time</th>\n",
       "      <th>stimulus_name</th>\n",
       "      <th>stimulus_block</th>\n",
       "      <th>temporal_frequency</th>\n",
       "      <th>color</th>\n",
       "      <th>mask</th>\n",
       "      <th>opacity</th>\n",
       "      <th>phase</th>\n",
       "      <th>size</th>\n",
       "      <th>units</th>\n",
       "      <th>stimulus_index</th>\n",
       "      <th>orientation</th>\n",
       "      <th>spatial_frequency</th>\n",
       "      <th>contrast</th>\n",
       "      <th>tags</th>\n",
       "      <th>timeseries</th>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>id</th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>1586.006904</td>\n",
       "      <td>1588.008574</td>\n",
       "      <td>drifting_gratings</td>\n",
       "      <td>2.0</td>\n",
       "      <td>15.0</td>\n",
       "      <td>[1.0, 1.0, 1.0]</td>\n",
       "      <td>None</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[10617.96666667, 10617.96666667]</td>\n",
       "      <td>[250.0, 250.0]</td>\n",
       "      <td>deg</td>\n",
       "      <td>2.0</td>\n",
       "      <td>315.0</td>\n",
       "      <td>0.04</td>\n",
       "      <td>0.8</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(3798, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>1589.009416</td>\n",
       "      <td>1591.011096</td>\n",
       "      <td>drifting_gratings</td>\n",
       "      <td>2.0</td>\n",
       "      <td>4.0</td>\n",
       "      <td>[1.0, 1.0, 1.0]</td>\n",
       "      <td>None</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[10617.96666667, 10617.96666667]</td>\n",
       "      <td>[250.0, 250.0]</td>\n",
       "      <td>deg</td>\n",
       "      <td>2.0</td>\n",
       "      <td>135.0</td>\n",
       "      <td>0.04</td>\n",
       "      <td>0.8</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(3799, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>1592.011914</td>\n",
       "      <td>1594.013594</td>\n",
       "      <td>drifting_gratings</td>\n",
       "      <td>2.0</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[1.0, 1.0, 1.0]</td>\n",
       "      <td>None</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[10617.96666667, 10617.96666667]</td>\n",
       "      <td>[250.0, 250.0]</td>\n",
       "      <td>deg</td>\n",
       "      <td>2.0</td>\n",
       "      <td>225.0</td>\n",
       "      <td>0.04</td>\n",
       "      <td>0.8</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(3800, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>1595.014426</td>\n",
       "      <td>1597.016106</td>\n",
       "      <td>drifting_gratings</td>\n",
       "      <td>2.0</td>\n",
       "      <td>8.0</td>\n",
       "      <td>[1.0, 1.0, 1.0]</td>\n",
       "      <td>None</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[10617.96666667, 10617.96666667]</td>\n",
       "      <td>[250.0, 250.0]</td>\n",
       "      <td>deg</td>\n",
       "      <td>2.0</td>\n",
       "      <td>180.0</td>\n",
       "      <td>0.04</td>\n",
       "      <td>0.8</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(3801, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table><p>... and 626 more rows.</p></details></details><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".intervals['flashes_presentations']\"><b>flashes_presentations</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".intervals['flashes_presentations']\">description: </span><span class=\"field-value\">Presentation times and stimuli details for 'flashes' stimuli</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".intervals['flashes_presentations']\"><b>table</b></summary><table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>start_time</th>\n",
       "      <th>stop_time</th>\n",
       "      <th>stimulus_name</th>\n",
       "      <th>stimulus_block</th>\n",
       "      <th>color</th>\n",
       "      <th>mask</th>\n",
       "      <th>opacity</th>\n",
       "      <th>phase</th>\n",
       "      <th>size</th>\n",
       "      <th>units</th>\n",
       "      <th>stimulus_index</th>\n",
       "      <th>orientation</th>\n",
       "      <th>spatial_frequency</th>\n",
       "      <th>contrast</th>\n",
       "      <th>tags</th>\n",
       "      <th>timeseries</th>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>id</th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>1285.739454</td>\n",
       "      <td>1285.989662</td>\n",
       "      <td>flashes</td>\n",
       "      <td>1.0</td>\n",
       "      <td>1.0</td>\n",
       "      <td>None</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[0.0, 0.0]</td>\n",
       "      <td>[300.0, 300.0]</td>\n",
       "      <td>deg</td>\n",
       "      <td>1.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>[0.0, 0.0]</td>\n",
       "      <td>0.8</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(3647, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>1287.741164</td>\n",
       "      <td>1287.991365</td>\n",
       "      <td>flashes</td>\n",
       "      <td>1.0</td>\n",
       "      <td>1.0</td>\n",
       "      <td>None</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[0.0, 0.0]</td>\n",
       "      <td>[300.0, 300.0]</td>\n",
       "      <td>deg</td>\n",
       "      <td>1.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>[0.0, 0.0]</td>\n",
       "      <td>0.8</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(3648, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>1289.742814</td>\n",
       "      <td>1289.993017</td>\n",
       "      <td>flashes</td>\n",
       "      <td>1.0</td>\n",
       "      <td>1.0</td>\n",
       "      <td>None</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[0.0, 0.0]</td>\n",
       "      <td>[300.0, 300.0]</td>\n",
       "      <td>deg</td>\n",
       "      <td>1.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>[0.0, 0.0]</td>\n",
       "      <td>0.8</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(3649, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>1291.744504</td>\n",
       "      <td>1291.994702</td>\n",
       "      <td>flashes</td>\n",
       "      <td>1.0</td>\n",
       "      <td>1.0</td>\n",
       "      <td>None</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[0.0, 0.0]</td>\n",
       "      <td>[300.0, 300.0]</td>\n",
       "      <td>deg</td>\n",
       "      <td>1.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>[0.0, 0.0]</td>\n",
       "      <td>0.8</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(3650, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table><p>... and 146 more rows.</p></details></details><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".intervals['gabors_presentations']\"><b>gabors_presentations</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".intervals['gabors_presentations']\">description: </span><span class=\"field-value\">Presentation times and stimuli details for 'gabors' stimuli</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".intervals['gabors_presentations']\"><b>table</b></summary><table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>start_time</th>\n",
       "      <th>stop_time</th>\n",
       "      <th>stimulus_name</th>\n",
       "      <th>stimulus_block</th>\n",
       "      <th>temporal_frequency</th>\n",
       "      <th>x_position</th>\n",
       "      <th>y_position</th>\n",
       "      <th>color</th>\n",
       "      <th>mask</th>\n",
       "      <th>opacity</th>\n",
       "      <th>phase</th>\n",
       "      <th>size</th>\n",
       "      <th>units</th>\n",
       "      <th>stimulus_index</th>\n",
       "      <th>orientation</th>\n",
       "      <th>spatial_frequency</th>\n",
       "      <th>contrast</th>\n",
       "      <th>tags</th>\n",
       "      <th>timeseries</th>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>id</th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>84.753134</td>\n",
       "      <td>84.986652</td>\n",
       "      <td>gabors</td>\n",
       "      <td>0.0</td>\n",
       "      <td>4.0</td>\n",
       "      <td>40.0</td>\n",
       "      <td>10.0</td>\n",
       "      <td>[1.0, 1.0, 1.0]</td>\n",
       "      <td>circle</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[3644.93333333, 3644.93333333]</td>\n",
       "      <td>[20.0, 20.0]</td>\n",
       "      <td>deg</td>\n",
       "      <td>0.0</td>\n",
       "      <td>45.0</td>\n",
       "      <td>0.08</td>\n",
       "      <td>0.8</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(1, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>84.986652</td>\n",
       "      <td>85.236850</td>\n",
       "      <td>gabors</td>\n",
       "      <td>0.0</td>\n",
       "      <td>4.0</td>\n",
       "      <td>40.0</td>\n",
       "      <td>-40.0</td>\n",
       "      <td>[1.0, 1.0, 1.0]</td>\n",
       "      <td>circle</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[3644.93333333, 3644.93333333]</td>\n",
       "      <td>[20.0, 20.0]</td>\n",
       "      <td>deg</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.08</td>\n",
       "      <td>0.8</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(2, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>85.236850</td>\n",
       "      <td>85.487048</td>\n",
       "      <td>gabors</td>\n",
       "      <td>0.0</td>\n",
       "      <td>4.0</td>\n",
       "      <td>-20.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>[1.0, 1.0, 1.0]</td>\n",
       "      <td>circle</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[3644.93333333, 3644.93333333]</td>\n",
       "      <td>[20.0, 20.0]</td>\n",
       "      <td>deg</td>\n",
       "      <td>0.0</td>\n",
       "      <td>90.0</td>\n",
       "      <td>0.08</td>\n",
       "      <td>0.8</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(3, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>85.487048</td>\n",
       "      <td>85.737246</td>\n",
       "      <td>gabors</td>\n",
       "      <td>0.0</td>\n",
       "      <td>4.0</td>\n",
       "      <td>30.0</td>\n",
       "      <td>-40.0</td>\n",
       "      <td>[1.0, 1.0, 1.0]</td>\n",
       "      <td>circle</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[3644.93333333, 3644.93333333]</td>\n",
       "      <td>[20.0, 20.0]</td>\n",
       "      <td>deg</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.08</td>\n",
       "      <td>0.8</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(4, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table><p>... and 3641 more rows.</p></details></details><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".intervals['invalid_times']\"><b>invalid_times</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".intervals['invalid_times']\">description: </span><span class=\"field-value\">experimental intervals</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".intervals['invalid_times']\"><b>table</b></summary><table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>start_time</th>\n",
       "      <th>stop_time</th>\n",
       "      <th>tags</th>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>id</th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>996.94</td>\n",
       "      <td>1129.13</td>\n",
       "      <td>[EcephysProbe, 769322716, probeC]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>3167.80</td>\n",
       "      <td>3226.30</td>\n",
       "      <td>[EcephysProbe, 769322716, probeC]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>4122.34</td>\n",
       "      <td>4185.04</td>\n",
       "      <td>[EcephysProbe, 769322716, probeC]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>5867.62</td>\n",
       "      <td>6115.02</td>\n",
       "      <td>[EcephysProbe, 769322716, probeC]</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table><p>... and 3 more rows.</p></details></details><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".intervals['natural_movie_one_presentations']\"><b>natural_movie_one_presentations</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".intervals['natural_movie_one_presentations']\">description: </span><span class=\"field-value\">Presentation times and stimuli details for 'natural_movie_one' stimuli</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".intervals['natural_movie_one_presentations']\"><b>table</b></summary><table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>start_time</th>\n",
       "      <th>stop_time</th>\n",
       "      <th>stimulus_name</th>\n",
       "      <th>stimulus_block</th>\n",
       "      <th>color</th>\n",
       "      <th>opacity</th>\n",
       "      <th>size</th>\n",
       "      <th>units</th>\n",
       "      <th>stimulus_index</th>\n",
       "      <th>orientation</th>\n",
       "      <th>frame</th>\n",
       "      <th>contrast</th>\n",
       "      <th>tags</th>\n",
       "      <th>timeseries</th>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>id</th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>2847.060224</td>\n",
       "      <td>2847.093585</td>\n",
       "      <td>natural_movie_one</td>\n",
       "      <td>4.0</td>\n",
       "      <td>[1.0, 1.0, 1.0]</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[1920.0, 1080.0]</td>\n",
       "      <td>pix</td>\n",
       "      <td>3.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(22000, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>2847.093585</td>\n",
       "      <td>2847.126945</td>\n",
       "      <td>natural_movie_one</td>\n",
       "      <td>4.0</td>\n",
       "      <td>[1.0, 1.0, 1.0]</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[1920.0, 1080.0]</td>\n",
       "      <td>pix</td>\n",
       "      <td>3.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>1.0</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(22001, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>2847.126945</td>\n",
       "      <td>2847.160306</td>\n",
       "      <td>natural_movie_one</td>\n",
       "      <td>4.0</td>\n",
       "      <td>[1.0, 1.0, 1.0]</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[1920.0, 1080.0]</td>\n",
       "      <td>pix</td>\n",
       "      <td>3.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>2.0</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(22002, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>2847.160306</td>\n",
       "      <td>2847.193667</td>\n",
       "      <td>natural_movie_one</td>\n",
       "      <td>4.0</td>\n",
       "      <td>[1.0, 1.0, 1.0]</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[1920.0, 1080.0]</td>\n",
       "      <td>pix</td>\n",
       "      <td>3.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>3.0</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(22003, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table><p>... and 17996 more rows.</p></details></details><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".intervals['natural_movie_three_presentations']\"><b>natural_movie_three_presentations</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".intervals['natural_movie_three_presentations']\">description: </span><span class=\"field-value\">Presentation times and stimuli details for 'natural_movie_three' stimuli</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".intervals['natural_movie_three_presentations']\"><b>table</b></summary><table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>start_time</th>\n",
       "      <th>stop_time</th>\n",
       "      <th>stimulus_name</th>\n",
       "      <th>stimulus_block</th>\n",
       "      <th>color</th>\n",
       "      <th>opacity</th>\n",
       "      <th>size</th>\n",
       "      <th>units</th>\n",
       "      <th>stimulus_index</th>\n",
       "      <th>orientation</th>\n",
       "      <th>frame</th>\n",
       "      <th>contrast</th>\n",
       "      <th>tags</th>\n",
       "      <th>timeseries</th>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>id</th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>2216.533564</td>\n",
       "      <td>2216.566925</td>\n",
       "      <td>natural_movie_three</td>\n",
       "      <td>3.0</td>\n",
       "      <td>[1.0, 1.0, 1.0]</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[1920.0, 1080.0]</td>\n",
       "      <td>pix</td>\n",
       "      <td>4.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(3999, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>2216.566925</td>\n",
       "      <td>2216.600287</td>\n",
       "      <td>natural_movie_three</td>\n",
       "      <td>3.0</td>\n",
       "      <td>[1.0, 1.0, 1.0]</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[1920.0, 1080.0]</td>\n",
       "      <td>pix</td>\n",
       "      <td>4.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>1.0</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(4000, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>2216.600287</td>\n",
       "      <td>2216.633648</td>\n",
       "      <td>natural_movie_three</td>\n",
       "      <td>3.0</td>\n",
       "      <td>[1.0, 1.0, 1.0]</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[1920.0, 1080.0]</td>\n",
       "      <td>pix</td>\n",
       "      <td>4.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>2.0</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(4001, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>2216.633648</td>\n",
       "      <td>2216.667010</td>\n",
       "      <td>natural_movie_three</td>\n",
       "      <td>3.0</td>\n",
       "      <td>[1.0, 1.0, 1.0]</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[1920.0, 1080.0]</td>\n",
       "      <td>pix</td>\n",
       "      <td>4.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>3.0</td>\n",
       "      <td>1.0</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(4002, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table><p>... and 35996 more rows.</p></details></details><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".intervals['natural_scenes_presentations']\"><b>natural_scenes_presentations</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".intervals['natural_scenes_presentations']\">description: </span><span class=\"field-value\">Presentation times and stimuli details for 'natural_scenes' stimuli</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".intervals['natural_scenes_presentations']\"><b>table</b></summary><table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>start_time</th>\n",
       "      <th>stop_time</th>\n",
       "      <th>stimulus_name</th>\n",
       "      <th>stimulus_block</th>\n",
       "      <th>stimulus_index</th>\n",
       "      <th>frame</th>\n",
       "      <th>tags</th>\n",
       "      <th>timeseries</th>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>id</th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>5909.618224</td>\n",
       "      <td>5909.868445</td>\n",
       "      <td>natural_scenes</td>\n",
       "      <td>9.0</td>\n",
       "      <td>5.0</td>\n",
       "      <td>104.0</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(51355, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>5909.868445</td>\n",
       "      <td>5910.118665</td>\n",
       "      <td>natural_scenes</td>\n",
       "      <td>9.0</td>\n",
       "      <td>5.0</td>\n",
       "      <td>66.0</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(51356, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>5910.118665</td>\n",
       "      <td>5910.368886</td>\n",
       "      <td>natural_scenes</td>\n",
       "      <td>9.0</td>\n",
       "      <td>5.0</td>\n",
       "      <td>36.0</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(51357, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>5910.368886</td>\n",
       "      <td>5910.619106</td>\n",
       "      <td>natural_scenes</td>\n",
       "      <td>9.0</td>\n",
       "      <td>5.0</td>\n",
       "      <td>61.0</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(51358, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table><p>... and 5946 more rows.</p></details></details><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".intervals['spontaneous_presentations']\"><b>spontaneous_presentations</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".intervals['spontaneous_presentations']\">description: </span><span class=\"field-value\">Presentation times and stimuli details for 'spontaneous' stimuli</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".intervals['spontaneous_presentations']\"><b>table</b></summary><table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>start_time</th>\n",
       "      <th>stop_time</th>\n",
       "      <th>stimulus_name</th>\n",
       "      <th>tags</th>\n",
       "      <th>timeseries</th>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>id</th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>24.686364</td>\n",
       "      <td>84.753134</td>\n",
       "      <td>spontaneous</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(0, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>996.748081</td>\n",
       "      <td>1285.739454</td>\n",
       "      <td>spontaneous</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(3646, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>1584.255460</td>\n",
       "      <td>1586.006904</td>\n",
       "      <td>spontaneous</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(3797, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>2185.507656</td>\n",
       "      <td>2216.533564</td>\n",
       "      <td>spontaneous</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(3998, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table><p>... and 11 more rows.</p></details></details><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".intervals['static_gratings_presentations']\"><b>static_gratings_presentations</b></summary><div style=\"margin-left: 40px;\" class=\"container-fields\"><span class=\"field-key\" title=\".intervals['static_gratings_presentations']\">description: </span><span class=\"field-value\">Presentation times and stimuli details for 'static_gratings' stimuli</span></div><details><summary style=\"display: list-item; margin-left: 40px;\" class=\"container-fields field-key\" title=\".intervals['static_gratings_presentations']\"><b>table</b></summary><table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>start_time</th>\n",
       "      <th>stop_time</th>\n",
       "      <th>stimulus_name</th>\n",
       "      <th>stimulus_block</th>\n",
       "      <th>color</th>\n",
       "      <th>mask</th>\n",
       "      <th>opacity</th>\n",
       "      <th>phase</th>\n",
       "      <th>size</th>\n",
       "      <th>units</th>\n",
       "      <th>stimulus_index</th>\n",
       "      <th>orientation</th>\n",
       "      <th>spatial_frequency</th>\n",
       "      <th>contrast</th>\n",
       "      <th>tags</th>\n",
       "      <th>timeseries</th>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>id</th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>5399.191914</td>\n",
       "      <td>5399.442125</td>\n",
       "      <td>static_gratings</td>\n",
       "      <td>8.0</td>\n",
       "      <td>[1.0, 1.0, 1.0]</td>\n",
       "      <td>None</td>\n",
       "      <td>1.0</td>\n",
       "      <td>0.5</td>\n",
       "      <td>[250.0, 250.0]</td>\n",
       "      <td>deg</td>\n",
       "      <td>6.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.08</td>\n",
       "      <td>0.8</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(49434, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>5399.442125</td>\n",
       "      <td>5399.692335</td>\n",
       "      <td>static_gratings</td>\n",
       "      <td>8.0</td>\n",
       "      <td>[1.0, 1.0, 1.0]</td>\n",
       "      <td>None</td>\n",
       "      <td>1.0</td>\n",
       "      <td>0.5</td>\n",
       "      <td>[250.0, 250.0]</td>\n",
       "      <td>deg</td>\n",
       "      <td>6.0</td>\n",
       "      <td>60.0</td>\n",
       "      <td>0.02</td>\n",
       "      <td>0.8</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(49435, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>5399.692335</td>\n",
       "      <td>5399.942546</td>\n",
       "      <td>static_gratings</td>\n",
       "      <td>8.0</td>\n",
       "      <td>[1.0, 1.0, 1.0]</td>\n",
       "      <td>None</td>\n",
       "      <td>1.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>[250.0, 250.0]</td>\n",
       "      <td>deg</td>\n",
       "      <td>6.0</td>\n",
       "      <td>90.0</td>\n",
       "      <td>0.16</td>\n",
       "      <td>0.8</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(49436, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>5399.942546</td>\n",
       "      <td>5400.192756</td>\n",
       "      <td>static_gratings</td>\n",
       "      <td>8.0</td>\n",
       "      <td>[1.0, 1.0, 1.0]</td>\n",
       "      <td>None</td>\n",
       "      <td>1.0</td>\n",
       "      <td>0.75</td>\n",
       "      <td>[250.0, 250.0]</td>\n",
       "      <td>deg</td>\n",
       "      <td>6.0</td>\n",
       "      <td>120.0</td>\n",
       "      <td>0.08</td>\n",
       "      <td>0.8</td>\n",
       "      <td>[stimulus_time_interval]</td>\n",
       "      <td>[(49437, 1, timestamps pynwb.base.TimeSeries at 0x1601617792880\\nFields:\\n  comments: no comments\\n  conversion: 1.0\\n  data: &lt;HDF5 dataset \"data\": shape (70390,), type \"&lt;f8\"&gt;\\n  description: no description\\n  interval: 1\\n  offset: 0.0\\n  resolution: -1.0\\n  timestamps: &lt;HDF5 dataset \"timestamps\": shape (70390,), type \"&lt;f8\"&gt;\\n  timestamps_unit: seconds\\n  unit: s\\n)]</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table><p>... and 5996 more rows.</p></details></details></details><details><summary style=\"display: list-item; margin-left: 0px;\" class=\"container-fields field-key\" title=\".subject\"><b>subject</b></summary><div style=\"margin-left: 20px;\" class=\"container-fields\"><span class=\"field-key\" title=\".subject.age\">age: </span><span class=\"field-value\">P120D</span></div><div style=\"margin-left: 20px;\" class=\"container-fields\"><span class=\"field-key\" title=\".subject.genotype\">genotype: </span><span class=\"field-value\">wt/wt</span></div><div style=\"margin-left: 20px;\" class=\"container-fields\"><span class=\"field-key\" title=\".subject.sex\">sex: </span><span class=\"field-value\">M</span></div><div style=\"margin-left: 20px;\" class=\"container-fields\"><span class=\"field-key\" title=\".subject.species\">species: </span><span class=\"field-value\">Mus musculus</span></div><div style=\"margin-left: 20px;\" class=\"container-fields\"><span class=\"field-key\" title=\".subject.subject_id\">subject_id: </span><span class=\"field-value\">723627600</span></div><div style=\"margin-left: 20px;\" class=\"container-fields\"><span class=\"field-key\" title=\".subject.specimen_name\">specimen_name: </span><span class=\"field-value\">C57BL/6J-404571</span></div><div style=\"margin-left: 20px;\" class=\"container-fields\"><span class=\"field-key\" title=\".subject.age_in_days\">age_in_days: </span><span class=\"field-value\">120.0</span></div></details><details><summary style=\"display: list-item; margin-left: 0px;\" class=\"container-fields field-key\" title=\".invalid_times\"><b>invalid_times</b></summary><div style=\"margin-left: 20px;\" class=\"container-fields\"><span class=\"field-key\" title=\".invalid_times\">description: </span><span class=\"field-value\">experimental intervals</span></div><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".invalid_times\"><b>table</b></summary><table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>start_time</th>\n",
       "      <th>stop_time</th>\n",
       "      <th>tags</th>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>id</th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>996.94</td>\n",
       "      <td>1129.13</td>\n",
       "      <td>[EcephysProbe, 769322716, probeC]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>3167.80</td>\n",
       "      <td>3226.30</td>\n",
       "      <td>[EcephysProbe, 769322716, probeC]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>4122.34</td>\n",
       "      <td>4185.04</td>\n",
       "      <td>[EcephysProbe, 769322716, probeC]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>5867.62</td>\n",
       "      <td>6115.02</td>\n",
       "      <td>[EcephysProbe, 769322716, probeC]</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table><p>... and 3 more rows.</p></details></details><details><summary style=\"display: list-item; margin-left: 0px;\" class=\"container-fields field-key\" title=\".units\"><b>units</b></summary><div style=\"margin-left: 20px;\" class=\"container-fields\"><span class=\"field-key\" title=\".units\">description: </span><span class=\"field-value\"></span></div><div style=\"margin-left: 20px;\" class=\"container-fields\"><span class=\"field-key\" title=\".units\">waveform_unit: </span><span class=\"field-value\">volts</span></div><details><summary style=\"display: list-item; margin-left: 20px;\" class=\"container-fields field-key\" title=\".units\"><b>table</b></summary><table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>snr</th>\n",
       "      <th>recovery_slope</th>\n",
       "      <th>cumulative_drift</th>\n",
       "      <th>waveform_halfwidth</th>\n",
       "      <th>cluster_id</th>\n",
       "      <th>amplitude_cutoff</th>\n",
       "      <th>l_ratio</th>\n",
       "      <th>isi_violations</th>\n",
       "      <th>d_prime</th>\n",
       "      <th>quality</th>\n",
       "      <th>velocity_below</th>\n",
       "      <th>spread</th>\n",
       "      <th>repolarization_slope</th>\n",
       "      <th>amplitude</th>\n",
       "      <th>peak_channel_id</th>\n",
       "      <th>PT_ratio</th>\n",
       "      <th>local_index</th>\n",
       "      <th>silhouette_score</th>\n",
       "      <th>presence_ratio</th>\n",
       "      <th>velocity_above</th>\n",
       "      <th>firing_rate</th>\n",
       "      <th>isolation_distance</th>\n",
       "      <th>max_drift</th>\n",
       "      <th>nn_miss_rate</th>\n",
       "      <th>waveform_duration</th>\n",
       "      <th>nn_hit_rate</th>\n",
       "      <th>spike_times</th>\n",
       "      <th>spike_amplitudes</th>\n",
       "      <th>waveform_mean</th>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>id</th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>950961498</th>\n",
       "      <td>1.841796</td>\n",
       "      <td>-0.019077</td>\n",
       "      <td>271.43</td>\n",
       "      <td>0.206030</td>\n",
       "      <td>71</td>\n",
       "      <td>0.500000</td>\n",
       "      <td>0.034664</td>\n",
       "      <td>0.891168</td>\n",
       "      <td>2.686974</td>\n",
       "      <td>good</td>\n",
       "      <td>0.392438</td>\n",
       "      <td>110.0</td>\n",
       "      <td>0.328248</td>\n",
       "      <td>88.432305</td>\n",
       "      <td>850180154</td>\n",
       "      <td>0.418521</td>\n",
       "      <td>71</td>\n",
       "      <td>0.082570</td>\n",
       "      <td>0.99</td>\n",
       "      <td>0.480737</td>\n",
       "      <td>2.793710</td>\n",
       "      <td>41.556254</td>\n",
       "      <td>33.20</td>\n",
       "      <td>0.005581</td>\n",
       "      <td>0.439531</td>\n",
       "      <td>0.770202</td>\n",
       "      <td>[3.9744092642121345, 4.549875895599463, 5.759175821462583, 5.993375807104808, 6.206975794009929, 6.7112090964309274, 8.192109005643442, 8.691908975002896, 8.793608968768115, 8.83200896641398, 9.160642279600244, 11.537542133882928, 11.684675458196162, 11.845242115019191, 11.879775446235437, 12.154208762744465, 12.212875425814536, 13.693608668370603, 16.667208486072226, 22.354641470733963, 22.815141442502725, 23.10650809130698, 24.21087469026977, 24.312841350685307, 25.090874636320827, 25.43620794848329, 25.509541277320878, 25.561341274145246, 27.74087447386095, 28.369641101980687, 28.764874411083998, 30.626407630294885, 33.03534081594708, 33.558607450534566, 35.55980732784977, 38.41997381917216, 38.92894045463631, 42.095073593867895, 42.32287357990247, 44.54390677707399, 46.429139994831935, 47.78693991159117, 47.91770657024111, 48.05983989486087, 48.203239886069646, 48.31127321277993, 48.371006542451276, 48.85647317935611, 49.12490649623297, 49.32307315075091, 49.366206481439924, 49.4438398100139, 49.52783980486423, 49.65577313035453, 49.67600646244745, 51.56107301354894, 51.63700634222713, 52.6079396160368, 52.94190626222944, 53.41463956658156, 54.209172851205544, 54.21310618429774, 55.582206100364225, 55.90780608040311, 58.191572607062064, 59.389605866949225, 61.040405765745916, 61.10867242822745, 62.21000569404287, 64.34340556325347, 64.3551055625362, 64.58243888193272, 67.31967204745828, 68.21757199241196, 68.30390532045259, 69.720038566969, 70.2288052024454, 73.34697167795095, 74.40390494648832, 74.41933827887551, 75.70163820026333, 76.22697150139078, 76.23313816767939, 77.7615047406486, 78.16140471613248, 78.8190380091492, 81.64980450227398, 83.8021377036572, 85.8272375795072, 85.8553709111158, 85.87553757654614, 85.9832709032748, 86.00277090207935, 86.39783754452621, 86.48177087271395, 86.49183753876348, 87.03720417199611, 87.33027082069614, 87.59483747114339, 87.60137080407618, ...]</td>\n",
       "      <td>[0.00013284615614484466, 7.155759550312513e-05, 8.939943098470118e-05, 7.700851469753486e-05, 0.00011095208067655804, 9.029365072009522e-05, 8.262158543266691e-05, 8.201934636005223e-05, 8.435827603210274e-05, 7.879183893772323e-05, 0.00012424104360240826, 8.367359035809769e-05, 0.00011329268580875535, 7.306773723566603e-05, 7.532981786636207e-05, 7.770834297726059e-05, 9.337571677809022e-05, 9.52366706717469e-05, 8.349757184608462e-05, 7.536622739235519e-05, 7.499669323338691e-05, 7.157744082084876e-05, 0.0001384765399681603, 0.00011126323393442632, 7.626311263252822e-05, 7.405363129613772e-05, 7.310098623456404e-05, 7.392093992966326e-05, 8.219016713774625e-05, 9.068488970369246e-05, 8.235546651268378e-05, 8.438568630624676e-05, 7.359906753471943e-05, 9.099812459386434e-05, 8.207673087008007e-05, 7.481388403062735e-05, 7.818505581410435e-05, 8.274541716897118e-05, 8.553733033889243e-05, 7.184991252722183e-05, 7.71532135283947e-05, 9.735940252046095e-05, 8.028737116549925e-05, 7.27007353062378e-05, 7.465030454091626e-05, 8.40476495287503e-05, 7.185674129660803e-05, 0.00010400483594937854, 8.58037348486733e-05, 8.690314768053053e-05, 7.21146669626157e-05, 8.449791675032244e-05, 8.8653971801735e-05, 7.819305232844135e-05, 9.380924209107427e-05, 7.747330892015253e-05, 8.172117791832164e-05, 7.767286637794012e-05, 7.397117834830741e-05, 9.688393358584738e-05, 0.00011307559948382587, 8.161699476010254e-05, 7.789803806736589e-05, 7.655647681921667e-05, 0.00012593963017638432, 0.00012080442098372697, 8.95851912820375e-05, 0.00010246469459519402, 7.431080808223131e-05, 7.308432048325537e-05, 8.04817181960879e-05, 7.52960801915879e-05, 8.793181039982523e-05, 9.55367938169821e-05, 7.192441973223475e-05, 8.520961287275467e-05, 7.736682835067153e-05, 0.00010337142951016944, 9.119279529289045e-05, 7.923456024219482e-05, 7.716320282487599e-05, 0.0001475585874728387, 8.667410466273527e-05, 9.012526062890204e-05, 7.577208857359722e-05, 8.53640725282576e-05, 7.363364928600695e-05, 7.722007961970784e-05, 9.804772470455734e-05, 0.00014067602566162954, 0.00014623343811840015, 7.27040354550118e-05, 7.461201646869796e-05, 8.768985872317168e-05, 0.00011900161317289211, 9.228231402486564e-05, 8.262751935402015e-05, 9.591619669007262e-05, 8.757532452139415e-05, 0.00010145337669628265, ...]</td>\n",
       "      <td>[[0.0, -0.05772000000002819, -1.8382649999999927, -1.4301300000000055, -1.9246500000000069, -1.3884000000000114, 0.17550000000004218, -2.342924999999987, -0.031589999999997787, 2.563469999999988, 4.5567599999999935, 1.9246499999999678, -0.06357000000003055, -0.44011499999998804, -0.4143750000000175, 1.4467049999999801, -4.864275000000024, 0.3047849999999741, -0.2759249999999831, -0.007994999999990426, 0.4705350000000088, -0.24940499999998522, -1.8642000000000394, -0.372645000000027, -1.683240000000037, -2.761785000000021, 1.8696600000000068, -2.6096850000000025, -2.117505000000005, -0.22561500000002255, 1.6120650000000225, -3.9834599999999547, -1.79985000000001, -2.0022599999999535, -0.46565999999999974, -0.7778549999999953, -2.4948300000000323, -1.9314749999999812, -2.5714650000000425, -2.3698350000000232, -1.8667349999999772, -2.588820000000002, -1.3737750000000055, 1.4059499999999723, -1.109939999999991, 0.6319949999999892, 3.303884999999994, 0.5017349999999503, -4.025774999999996, -3.058185000000048, 0.7897500000000015, 0.5066099999999771, 2.122964999999997, -3.7812450000000446, -1.5410850000000345, 0.40364999999998474, -4.19561999999998, -1.3002599999999909, -2.9171999999999834, 0.9531599999999614, -2.6122200000000184, -2.6820299999999904, -0.36933000000000504, -1.9082700000000017, -5.020080000000053, -0.5910450000000473, -1.56487499999999, 1.820324999999979, -1.7288700000000574, 3.0562349999999654, 1.7070300000000032, -2.1584550000000355, -0.3601650000000234, -1.4045850000000755, -2.795910000000024, -3.9869699999999995, -0.7244250000000356, -4.889625000000006, -3.4727549999999887, 1.7261399999999796, -4.806944999999995, -0.09028500000002992], [0.0, 0.3254550000000047, -1.0295999999999976, -0.24453000000000058, 0.12148500000000251, -0.030419999999998115, 0.7918950000000025, 1.2052950000000053, 0.8697000000000066, 1.5032549999999962, 0.8145150000000005, 0.16575000000000095, 0.8174399999999946, 0.09691500000000497, 0.0017550000000023935, 1.6805099999999942, 1.0826399999999992, 2.5909649999999966, 2.2370400000000035, 1.427790000000003, 2.2826700000000026, 0.8882250000000043, 0.8999250000000036, 0.969929999999994, 0.6333599999999993, 1.1655149999999996, 0.9662249999999966, 1.0266749999999987, 0.31511999999999984, 0.29464499999999516, 0.3420300000000025, 0.3812249999999975, -0.48243000000000213, -0.5302049999999974, -0.09067499999999429, -0.2999100000000041, -0.9398999999999966, -0.17998499999998918, 0.4352400000000025, -0.5539949999999969, 0.18856500000000276, -0.30458999999999925, 0.8178300000000012, 0.31511999999999807, 1.2965549999999948, 1.4940899999999977, 1.7425199999999976, 1.297919999999999, 0.9726599999999945, 0.7515300000000003, 1.2924600000000024, 1.201004999999998, 0.8755500000000018, 0.4935449999999988, -0.40150499999999756, -0.5674499999999978, -0.8215350000000035, -1.5459600000000004, -0.117779999999998, -0.9256649999999964, 0.0664950000000033, -0.7922849999999935, -0.2866499999999985, -0.11075999999999908, -0.02320499999999459, 0.7610850000000027, -0.5185049999999984, 0.5754449999999953, 1.2924599999999988, 1.2366900000000025, 1.8480150000000042, 1.4714699999999952, 0.7513350000000014, 1.6725150000000073, 1.3642199999999964, 1.0104900000000003, 0.4340700000000024, 1.989390000000005, 0.2845050000000038, 0.2788500000000016, -0.21372000000000346, 0.17549999999999955], [0.0, 0.2710499999999847, 1.1647349999999914, 1.414335000000003, -0.5040750000000198, 1.9394700000000054, -2.419560000000013, -0.20904000000001943, -1.189500000000013, -1.3718250000000207, -4.352010000000014, -1.2649650000000072, -2.1184800000000195, -1.373970000000007, -1.1526450000000033, -0.5114850000000271, 0.6725549999999672, 0.8230949999999932, 1.2971399999999829, -1.013610000000039, -1.2146550000000254, -1.4431950000000153, 2.1065849999999955, -1.1924250000000054, 0.24862499999998633, -1.4603550000000247, -0.9166949999999936, -3.0800250000000062, -1.6101150000000288, -3.6322650000000083, -1.638975000000018, -0.8186100000000156, -2.7678300000000107, -3.4165950000000116, -4.348110000000005, -2.7069900000000047, -3.9770250000000127, -3.954210000000006, -2.6087100000000056, -1.812915000000027, -0.22639500000000012, -1.8213000000000168, 0.44947499999999074, -0.6534450000000156, -0.0705900000000117, 0.5651099999999669, -1.4492400000000103, -0.8439600000000134, 1.2435149999999826, 1.6415099999999985, -1.9033950000000228, -0.5614049999999953, -0.5138250000000024, -0.7523100000000262, 0.851564999999967, -2.604615000000022, -1.9923150000000085, -2.6239200000000054, -0.8160750000000192, -4.014075000000011, 0.7983299999999787, -1.996800000000034, -2.599545000000008, -3.826095000000013, -0.4087200000000166, -1.9076850000000025, -1.3478400000000281, -4.008420000000007, -1.0313550000000067, -1.9211400000000083, 0.9159149999999912, -0.33852000000002214, -0.9958650000000073, -1.1731200000000044, 1.3761149999999773, -1.4527499999999982, 0.004874999999985974, -0.8472750000000389, -1.65691500000003, -3.23934000000002, -1.8733650000000068, -1.8218849999999946], [0.0, -0.7704450000000005, -0.6140550000000076, -0.8002799999999937, -0.7361249999999835, -0.08092500000002012, -0.4874999999999954, -0.034709999999998686, 0.12440999999999924, -0.5368349999999964, -0.522989999999993, -0.32116499999999526, -0.7840950000000078, 0.1253850000000032, -0.43680000000001407, -0.12343500000000773, 0.39565499999999965, 1.0438350000000014, 1.5539550000000055, 0.5957250000000105, 0.8041799999999952, 0.6975150000000117, 1.0455900000000007, 0.5450250000000114, 1.0321350000000056, -0.4586399999999937, -0.5883149999999873, -0.20319000000001175, -0.6472049999999907, -0.46507499999999347, -0.4451849999999844, -0.5619899999999962, -1.37669999999998, -0.9512100000000014, -0.7714199999999867, -1.3094250000000027, -0.552240000000026, -0.8905649999999952, -1.2493649999999796, -1.1542050000000064, -0.5812950000000079, -1.2489750000000015, -0.7101900000000168, 0.20982000000001655, 0.09477000000001112, -0.20084999999999198, -0.4564950000000074, -0.09866999999998072, -0.8505900000000022, -0.6489599999999953, -0.052259999999991535, -0.5639400000000094, -0.7435349999999907, -1.2226499999999891, -1.7436900000000115, -1.0044450000000182, -1.4769299999999994, -0.7589400000000026, -0.792675000000008, -0.5460000000000154, -0.4666349999999948, -0.6302400000000024, -0.827579999999994, -0.6518849999999894, -1.0516349999999886, -0.06532500000000852, -0.753675000000003, -1.184820000000002, -0.6840599999999952, 0.41846999999999923, 0.18486000000000402, 0.5331299999999963, 0.12382499999998942, 0.12811500000001708, 0.1177800000000051, -0.11349000000000942, -0.22853999999997932, 0.5276699999999988, -0.38980499999999196, -0.4935449999999957, -0.11855999999999689, 0.08755499999999294], [0.0, -0.4492799999999768, -0.3129749999999909, -1.400684999999994, -1.168049999999985, -0.3753749999999876, -0.70277999999999, 0.04368000000000016, -0.1296749999999811, -0.6366749999999879, 0.08697000000000266, -0.6592950000000073, -0.43329000000001017, -0.5635499999999922, -0.2061150000000076, 0.38258999999999865, 0.7002449999999918, 1.5278250000000053, 1.540890000000008, 1.9599450000000118, 1.983345000000023, 1.5208050000000153, 1.2021750000000182, 0.4734600000000082, 0.4377750000000056, 0.38454000000002075, -0.3170700000000153, -0.5438549999999971, -0.15794999999999604, -0.43153499999999845, -0.8035949999999996, -0.9471149999999859, -1.6686150000000062, -1.88603999999998, -1.7994599999999998, -1.7647500000000065, -1.3390649999999962, -1.5416699999999857, -1.5748199999999724, -1.9035900000000119, -1.0662599999999838, -1.2281100000000134, -0.9789000000000048, -0.5842199999999931, -0.6871799999999961, -0.5395649999999943, 0.3176550000000091, -0.46390499999998625, -0.3127799999999876, -0.48516000000000226, -0.2714399999999788, -0.33286499999999286, -0.22736999999999163, -0.7409999999999766, -0.7086299999999923, -1.2364949999999926, -1.2575549999999893, -1.8224699999999885, -1.4293499999999693, -0.9586199999999927, -0.4549349999999954, -0.19636499999999657, -0.639404999999984, -1.2986999999999895, -0.9194249999999915, -1.269449999999983, 0.04972499999999691, -0.5280600000000035, -0.2332199999999922, -0.17647499999998928, 0.049335000000017004, 0.12538500000001385, 0.5666700000000056, -0.1788150000000126, -0.04133999999998217, 0.04426499999999933, -0.7384649999999748, -0.07975499999999336, -0.345539999999982, 0.021645000000008352, 0.5331300000000141, -0.6282899999999945], [0.0, -0.4793100000000017, -0.06668999999999947, 0.06454499999999919, 0.4568849999999993, -0.299130000000001, 0.011894999999999656, 0.019109999999998406, 0.69537, 0.7918949999999997, 0.6639749999999994, 0.42607499999999876, 0.6690449999999992, 0.7583549999999994, 0.8297250000000002, 0.344175, 0.6122999999999995, 0.873795, 1.4026349999999999, 1.7017649999999986, 1.5995850000000003, 0.7255949999999993, 0.7058999999999993, 0.5071949999999998, 1.094925, 1.1768249999999991, 1.6093349999999993, 1.1781899999999994, 1.1506949999999994, 0.9722699999999999, 0.8788649999999999, 0.3431999999999993, -0.35021999999999887, -0.4781399999999991, -0.4056000000000006, -0.0011699999999994493, -0.5809050000000009, -0.7877999999999998, -0.5075849999999988, -0.4118399999999989, -0.47911499999999996, -0.3498300000000001, 0.10627499999999956, 0.977145, 0.9652499999999996, 0.7915049999999995, 0.6702149999999998, 0.2811899999999996, 0.40189500000000067, 0.24745499999999987, 0.14078999999999964, 0.7158450000000001, 0.4401149999999987, 0.3554849999999997, 0.9348299999999996, 0.03353999999999813, 0.31804499999999913, 0.10900499999999924, 0.2597400000000002, -0.07254000000000072, 0.030614999999999726, 0.20806499999999872, -0.21781500000000076, -0.06981000000000015, 0.4348499999999994, 0.3110249999999998, 0.21391499999999952, -0.19870499999999858, 0.7273499999999995, 1.17, 1.08615, 0.9272249999999996, 1.261649999999999, 1.162395, 0.9632999999999996, 1.1894999999999993, 1.0572899999999996, 0.5828549999999995, 0.3026399999999996, 0.3689399999999994, 0.5744699999999994, 0.6204900000000001], [0.0, -0.8211449999999996, -0.33832499999999754, -1.0574850000000007, 0.36562500000000675, 0.20748000000000122, -0.09067499999999917, -0.17939999999999667, 0.24355500000000063, -0.4910099999999886, -0.6241950000000029, -0.2228849999999971, -0.335205000000002, 0.8283600000000066, 0.7439250000000053, 0.6366750000000012, 1.4053650000000042, 0.49452000000000673, 1.6984500000000002, 1.9938750000000005, 2.3793900000000017, 1.5128099999999973, 1.5978300000000023, 0.4488900000000031, 0.6879599999999932, -0.009554999999994429, 0.9170850000000046, -0.4498649999999893, 0.16009500000000187, 0.28001999999999505, -0.35548499999999983, -0.902655000000002, -1.2934350000000014, -1.1992499999999948, -0.8511749999999969, -0.09028499999999262, -0.5403449999999985, 0.03431999999999835, -1.1315849999999905, 0.43211999999999673, 0.8917350000000015, 1.0988249999999988, -0.028860000000001662, 0.4069649999999978, 1.3139100000000012, 0.9886499999999994, -0.1234350000000024, 0.849225000000001, 0.6505199999999975, 1.339650000000003, 0.7801950000000035, 1.4199900000000047, 1.2456600000000004, 0.6345300000000007, 1.2889500000000034, 0.616005000000003, 0.38376000000000854, -0.4670249999999978, 0.29483999999999533, 0.181350000000001, -0.3367650000000033, 0.17725500000000327, -0.3821999999999939, -0.24940499999999144, -0.19226999999999528, 1.1567400000000032, 0.9939149999999977, 1.9439550000000074, 1.4357850000000036, 2.0221500000000043, 2.2822800000000014, 1.3357500000000044, 0.8209500000000016, 1.8936450000000034, 2.1533850000000005, 1.1499150000000036, 0.05596500000000049, 0.8946600000000009, 0.8923200000000038, -0.32701500000000294, -0.16048500000000043, 0.7766850000000058], [0.0, -0.5058299999999996, -0.5163599999999873, -0.7638149999999984, -1.2772499999999827, 0.04173000000000737, -0.27904499999999466, 0.9293700000000076, 0.0015600000000075553, 1.3745550000000062, 0.7511399999999986, 0.09379500000000185, 0.19948499999999303, -0.06259500000000084, 1.6376100000000076, 0.7121399999999998, 0.3966300000000018, 1.0873200000000098, 0.567840000000003, 1.0557300000000032, 0.6858150000000016, 0.7708350000000097, 1.2033450000000006, 1.2041249999999986, 1.3813800000000063, 2.5855050000000075, 1.8172050000000048, 1.7684550000000065, 0.909870000000006, 1.2329849999999993, 0.3402750000000099, -0.24784499999999543, -0.15541500000000497, -0.5237700000000016, -0.16555499999999235, -0.23965499999999285, -1.106819999999999, -1.1635649999999949, -0.9340499999999965, -1.0494900000000014, 0.08170500000000658, -0.10022999999999982, -0.6323849999999975, -0.36133499999998975, 0.6986850000000029, 0.7025849999999991, 1.5286050000000113, 0.8431800000000003, -0.06181499999999218, 1.6943549999999998, 0.9576450000000012, 0.9398999999999997, 1.031355000000005, 0.3675750000000022, -0.1536599999999977, 0.5040749999999949, -0.24472499999999808, -0.5393699999999866, -0.8525399999999896, -0.41554499999999894, -0.3299399999999926, -0.17900999999999723, -0.0448499999999914, 0.09399000000000779, 0.22308000000000305, -0.03392999999999535, 1.3439400000000052, 0.27768000000000725, 1.2345450000000069, 1.4441700000000086, 0.8759400000000017, 1.6461900000000025, 1.0843950000000167, 2.336100000000002, 0.8006699999999993, 1.6210350000000027, 2.220270000000006, 1.5767700000000087, 0.5970900000000023, 1.0970700000000093, 0.19753500000000201, 0.5354700000000117], [0.0, -0.205919999999999, 0.5887049999999938, -0.4812600000000078, 0.22776000000000352, -0.23556000000000665, -0.805739999999993, 0.7209150000000015, 0.6635849999999941, 0.9003149999999991, 1.2191400000000012, 0.7277399999999883, -0.7681050000000216, 0.5931899999999999, 0.7343700000000037, 0.7833149999999929, 0.6442800000000002, 1.248194999999992, 0.5910450000000225, 2.0262449999999905, 2.1875100000000067, 2.037360000000003, 1.7585100000000065, 1.4673750000000005, 1.7417400000000036, 1.3735799999999951, 0.6776249999999759, 1.1025299999999962, 1.1893050000000187, 1.2986999999999753, 0.9163049999999817, 0.6869849999999964, -0.7636199999999853, -0.544244999999993, -0.2310749999999988, -0.5926049999999936, -0.8273850000000085, -0.17998499999999673, 0.09028500000001571, 0.49373999999999896, 0.9426299999999994, 0.45863999999999905, 1.2850499999999876, 0.9878700000000062, 1.358370000000006, 1.9792500000000004, 1.2193349999999938, 1.570920000000008, 1.2949950000000001, 1.643460000000001, 2.234895000000005, 2.3435100000000073, 1.9287449999999922, 1.4968200000000067, 0.9242999999999917, 0.20104499999998815, -0.015990000000007498, 0.25369499999999867, -0.35451000000000654, -0.4763850000000005, 0.7961849999999941, 0.6581249999999965, 1.0274549999999945, 0.5563349999999883, 0.6904949999999968, 0.7827300000000008, 1.3749449999999932, 2.485665000000001, 2.2918349999999883, 2.2270949999999843, 2.206815000000004, 2.2091550000000133, 1.263794999999993, 1.8092100000000002, 0.772980000000004, 1.3291200000000085, 1.4921399999999938, 1.1914500000000015, 1.2398100000000039, 0.5268899999999928, 1.2567749999999993, 2.053739999999996], [0.0, 0.28391999999999973, 0.5678400000000039, 0.26071500000000336, 1.160250000000001, 1.4591849999999966, 1.6370249999999995, 1.1218349999999981, 1.081275000000001, 0.9993750000000006, 1.3123500000000026, 1.2676949999999994, 0.9857250000000048, 1.0019099999999983, 1.4016600000000001, 0.8975849999999985, 1.237274999999995, 0.7441199999999997, 1.3573950000000052, 2.2370400000000004, 1.981785, 1.8039450000000015, 1.7152199999999986, 2.2103249999999983, 2.247375, 1.8616649999999986, 1.9726199999999996, 1.8521099999999984, 2.2664850000000003, 1.923284999999999, 1.7616299999999994, 1.5291899999999976, 1.3960049999999984, 0.6386249999999976, 0.8449350000000035, 0.3504150000000017, 0.5042699999999973, 0.7300799999999992, 0.31999500000000136, 1.1308049999999996, 1.1982750000000038, 1.0167299999999964, 0.9984000000000015, 1.356224999999998, 1.77684, 1.6873350000000014, 2.0853299999999986, 2.272529999999998, 2.9920799999999987, 2.8021499999999984, 3.0107999999999997, 2.033069999999999, 1.9886099999999995, 2.476110000000002, 2.5880399999999995, 1.8585449999999994, 2.069924999999998, 1.6933799999999999, 1.5880799999999993, 2.2292400000000003, 2.070315000000001, 2.445105, 2.1044399999999994, 2.218514999999999, 2.3314199999999987, 2.49756, 3.0771000000000006, 1.8835050000000035, 2.6892449999999997, 3.4877699999999994, 2.715765000000001, 2.6670149999999984, 2.448225, 1.9841250000000001, 1.7171699999999936, 2.4532950000000007, 1.9053449999999983, 2.1173099999999994, 2.165669999999998, 2.1465599999999987, 2.221635000000001, 1.9925100000000038], [0.0, 0.1862250000000012, -0.9857249999999942, -0.5032950000000067, -0.3047849999999963, -0.027300000000010094, -0.024179999999998536, 0.45805500000000077, -0.13552499999999768, -0.20221500000000514, -0.052260000000005746, -0.47657999999999756, -0.6292650000000055, -1.0563150000000014, -0.43465500000000024, -0.3309149999999965, 0.3878550000000063, 0.554385000000007, 0.9359999999999999, 1.3677299999999937, 1.9004700000000048, 1.9874400000000065, 1.725360000000003, 1.294019999999997, 1.4041950000000067, 0.49451999999999074, 0.41554500000000605, 0.1920749999999929, 0.525525000000008, 0.9804600000000008, 0.7213050000000001, 0.45278999999999403, 0.0936000000000039, -0.1384500000000024, -0.09945000000000803, -0.2862599999999995, -0.015210000000003276, 0.2735849999999971, -0.11953499999999373, 0.2353650000000016, 0.33734999999999093, 1.1292450000000072, 0.7725899999999957, 1.0726950000000084, 1.018094999999997, 0.5672549999999905, 0.3003, 0.9627150000000038, 1.3928849999999997, 0.5966999999999985, 0.8162700000000092, 1.0859550000000073, 1.174094999999996, 0.38629500000000405, 0.7222800000000111, 0.7012200000000002, 0.1715999999999953, 0.2150849999999931, -0.26793000000000067, 0.482040000000004, 0.49822500000000236, 0.8511749999999942, 0.22931999999999597, 0.4810649999999974, 0.5532150000000007, 0.8285550000000006, 1.294409999999992, 1.2540449999999987, 1.859325000000002, 1.7661149999999974, 2.3273250000000045, 2.2971000000000013, 1.3936650000000004, 1.1945699999999961, 0.44206499999999327, 0.47151000000001275, 0.4067699999999892, 0.3180449999999988, 0.48535499999999665, -0.4227600000000109, -0.7774650000000083, -0.7903350000000122], [0.0, 0.6450599999999937, 0.45844499999999755, 0.265589999999996, 0.6491550000000039, 0.9178649999999955, 0.5966999999999913, 0.9385349999999892, 1.0847849999999823, 0.3001049999999701, 0.7565999999999988, 0.27046499999999085, 0.37186499999999967, 1.268669999999993, 1.206269999999984, 0.9223499999999962, 1.5436200000000007, 2.3452649999999924, 2.1648899999999998, 2.6079300000000067, 2.8737149999999883, 3.1989750000000026, 2.645565000000005, 2.4554399999999905, 1.8296850000000084, 2.4336000000000197, 1.3016250000000156, 1.1832599999999829, 1.1592750000000027, 0.7606949999999948, 0.8841299999999883, 0.28099500000000077, 0.45434999999995895, 0.2657849999999833, 0.0288599999999839, 0.1088099999999983, -0.04543499999999767, 0.6514950000000077, -0.14176500000001013, 1.0533899999999772, 1.0054199999999849, 0.7844849999999788, 0.7265700000000024, 0.8182199999999646, 0.914355000000004, 0.3812250000000148, 0.08989499999999495, 0.6801599999999901, 0.6737250000000046, 1.4018549999999834, 1.827929999999995, 1.3166399999999925, 1.3478400000000015, 0.5071950000000136, 0.6039150000000042, 0.4888649999999899, 1.0504649999999955, 0.8802299999999867, 1.5834000000000206, 1.879800000000012, 1.8407999999999838, 1.679340000000007, 1.528995000000009, 2.1270600000000073, 1.1157899999999898, 1.6916249999999966, 1.8552300000000024, 1.7768400000000089, 2.5129650000000012, 1.6290300000000002, 2.7580800000000067, 1.9562400000000117, 1.800824999999982, 1.7423249999999868, 2.050424999999988, 0.9149400000000014, 2.3058749999999897, 1.29167999999998, 2.4000600000000016, 1.4788799999999842, 1.5287999999999986, 0.9711000000000016], [0.0, 0.3831750000000007, -0.10490999999999939, -0.4720949999999998, -0.7591349999999994, -0.4843799999999987, -0.8716499999999993, 0.28879500000000013, -0.11563499999999971, -1.1072099999999985, -0.8622899999999998, -0.9662249999999992, -1.9888049999999997, -1.3632449999999992, -1.0771799999999991, -0.409499999999998, -1.0303799999999994, -1.7764499999999996, -0.8796449999999996, -1.4002949999999992, -0.21586499999999909, -0.09437999999999847, -0.0007799999999984486, 0.6557849999999994, 0.35177999999999776, 1.0173150000000002, 0.33774000000000015, 0.4426500000000029, 1.3517399999999997, 1.5506399999999998, 1.4104350000000003, 2.13096, 2.426774999999994, 1.7733300000000043, 1.0925849999999995, 1.8433349999999995, 1.4030250000000006, 0.782924999999999, 0.5645250000000037, 0.39058499999999996, 1.4759550000000001, 2.2218300000000033, 1.6300050000000035, 1.8797999999999961, 2.034629999999998, 2.5238849999999964, 2.2206600000000067, 2.8464150000000004, 2.345069999999997, 3.2966700000000015, 2.4636299999999975, 2.450369999999996, 2.82087, 2.6383500000000044, 2.078699999999997, 1.9788599999999972, 1.5071550000000016, 0.669045000000001, 0.834405000000001, 1.6362449999999973, 1.7711849999999993, 0.9073350000000018, 1.0992150000000003, 0.4161299999999999, 1.0723050000000016, 1.807260000000001, 2.9092050000000036, 2.0420399999999974, 2.9357250000000015, 3.0380999999999956, 3.3787649999999996, 2.9236349999999955, 3.440579999999996, 3.3089549999999956, 1.8792150000000023, 2.0523750000000023, 1.8690749999999985, 2.1100949999999985, 2.6237250000000003, 1.9704749999999984, 1.6477500000000036, 0.8792550000000023], [0.0, 0.3199950000000005, 0.19421999999999606, 0.5450250000000025, 0.7569899999999978, 0.9260550000000021, 1.9817850000000017, 2.5125750000000013, 2.4236549999999997, 1.435590000000004, 1.3271699999999957, 0.5148000000000037, 0.7248150000000035, 0.3744000000000014, 0.28723500000000257, 0.5325450000000052, 0.5224050000000071, 0.8172450000000073, 0.7776600000000022, 0.9609600000000094, 1.082835000000002, 1.5151499999999993, 2.060174999999999, 2.127255, 1.98393, 2.064465000000001, 1.8517200000000003, 2.160209999999998, 3.1718699999999997, 3.49245, 3.4382400000000013, 3.1028399999999996, 2.331420000000001, 2.2883249999999986, 1.754025, 1.2103650000000052, 1.4096549999999985, 1.0395450000000008, 1.1536200000000014, 1.2704249999999973, 1.830464999999995, 2.31777, 2.2719449999999988, 2.6445899999999973, 2.6044199999999984, 3.0189900000000005, 2.9792099999999984, 3.3789599999999997, 3.6069149999999994, 3.793335, 3.6542999999999983, 3.8432549999999996, 2.9657549999999997, 2.950545, 2.3068499999999985, 1.8129149999999994, 1.0713299999999992, 0.8238749999999979, 0.9022650000000039, 0.976950000000004, 1.442220000000002, 1.187745000000001, 1.5701400000000016, 2.1455850000000023, 1.9474649999999993, 2.3392200000000005, 3.1174649999999953, 4.028115, 3.9019500000000003, 3.9434849999999995, 3.516045, 3.2291999999999987, 3.153344999999998, 2.752035000000001, 2.99676, 2.8990649999999976, 3.0291299999999994, 3.158999999999999, 2.682810000000001, 2.8920449999999986, 2.766659999999998, 1.9975799999999992], [0.0, -0.12616499999999142, -0.15716999999999626, -0.10373999999999084, -0.16048499999998977, 0.3956550000000085, -0.07234499999999455, -0.6298500000000016, -0.18817499999999798, -1.5564899999999962, -1.4888250000000025, -1.1584950000000007, -1.8285149999999928, -1.9712549999999962, -1.6695899999999972, -1.5438150000000017, -0.9514049999999981, -0.8457149999999971, -0.2622749999999967, 0.0709800000000067, 0.23458500000000537, 1.043250000000004, 0.6762600000000014, 0.8691150000000043, 0.778635000000004, 0.48945000000000816, 1.1280750000000013, 1.7785950000000037, 2.032485000000004, 2.4729900000000047, 2.4570000000000034, 2.706405000000004, 1.884870000000006, 2.271165000000005, 1.9271850000000057, 1.8597150000000053, 1.070550000000006, 1.3182000000000058, 2.162550000000003, 2.288130000000004, 2.485860000000006, 2.1732750000000043, 1.5334800000000046, 1.9149000000000056, 1.9847100000000037, 2.300610000000005, 2.4047400000000048, 2.8705950000000047, 2.7652950000000036, 2.7631500000000058, 2.6564850000000035, 2.825160000000005, 2.2159800000000054, 2.5404600000000044, 2.421705000000006, 2.3797800000000056, 2.1483150000000046, 1.158885000000005, 1.409265000000003, 0.6066450000000025, 0.9311250000000029, 0.17745000000000433, 0.5553600000000012, 1.0426650000000057, 1.704690000000006, 2.0285850000000023, 2.0570550000000045, 2.267070000000003, 3.038295000000005, 3.2600100000000047, 3.6989550000000047, 3.955575000000005, 3.4764600000000043, 2.842515000000004, 2.7202500000000054, 2.3136750000000035, 2.232165000000006, 2.143245000000003, 2.320890000000004, 2.0785050000000034, 1.8214950000000028, 1.193400000000009], [0.0, -0.08989500000000014, -0.1647750000000001, -0.6581250000000012, -0.2560349999999999, 0.20923500000000061, 0.5450249999999989, 0.5614049999999988, 0.38044500000000075, 0.0967200000000002, -0.14722499999999925, -0.6550050000000007, -0.9244950000000006, -0.9365849999999981, -1.7427150000000018, -1.2452700000000014, -1.5091050000000006, -1.4901900000000006, -0.4843800000000006, -0.2199599999999994, 0.04933500000000077, -0.23029499999999894, 0.09574500000000108, 0.12148500000000029, 0.36464999999999964, 0.8622899999999984, 1.3026000000000009, 0.9459449999999988, 1.5432300000000003, 2.5712700000000024, 1.8507449999999976, 2.209544999999998, 2.2023300000000003, 1.9328400000000021, 1.7626050000000035, 0.6846450000000004, 0.4096950000000002, 0.8447399999999993, 0.5690100000000001, 0.9459449999999989, 1.3603199999999993, 1.4545049999999993, 1.7912699999999984, 2.304314999999998, 2.218905000000003, 2.463825, 3.1233149999999994, 2.821260000000003, 3.1474949999999993, 3.3945600000000025, 3.341324999999995, 3.484065000000001, 3.0408299999999957, 2.715765, 2.101515, 1.1405549999999998, 1.000545, 1.2579450000000003, 0.19285500000000047, -0.3576300000000002, -0.14332499999999884, -0.0945749999999986, 0.5097300000000002, 0.5902650000000007, 1.849380000000001, 2.0478899999999984, 2.151045000000001, 2.4634349999999996, 3.339764999999999, 2.9641949999999997, 3.678284999999998, 3.306615000000001, 2.4375000000000027, 2.6748150000000006, 3.3036899999999965, 2.3932350000000024, 2.500679999999999, 2.394599999999999, 2.5238849999999986, 1.9523400000000004, 1.879995000000001, 1.342379999999999], [0.0, -0.6516900000000048, -0.42373500000001485, -0.5177250000000013, -0.05070000000000263, -0.6318000000000064, -0.6789900000000078, 0.031979999999991904, -0.8743800000000084, -1.2175800000000105, -1.0570950000000172, -1.9384950000000059, -2.886000000000011, -3.0903600000000067, -3.9364650000000063, -4.420650000000009, -3.9249600000000093, -3.081975000000008, -2.6611650000000067, -2.293005000000009, -1.8333900000000094, -1.098435000000003, -0.23731500000000683, 0.06766500000000697, 0.9303450000000009, 1.2312299999999965, 1.389960000000011, 2.421119999999984, 3.696615000000005, 4.918290000000006, 5.973629999999984, 5.392335000000003, 5.551845, 4.779254999999976, 2.8598699999999972, 2.7247350000000043, 3.5710349999999966, 2.7056250000000013, 1.9152899999999917, 2.234114999999992, 3.6523499999999984, 2.397134999999995, 2.4499799999999947, 3.205605000000002, 4.01134499999999, 4.453409999999996, 4.718024999999976, 4.045859999999989, 4.701839999999997, 4.692479999999987, 5.388240000000007, 5.701995000000014, 2.9836949999999867, 4.621500000000003, 3.1006949999999875, 3.2486999999999835, 2.2327499999999905, 1.4872650000000043, 2.9834999999999887, 1.7212649999999776, 0.9155249999999899, 0.9878699999999956, 0.9432149999999933, 2.0172750000000015, 2.564639999999981, 1.8197399999999835, 3.2808750000000053, 4.309304999999993, 3.914625000000001, 5.172959999999996, 5.8306949999999915, 5.039774999999986, 4.376970000000002, 4.6080450000000095, 4.674540000000002, 3.6886200000000073, 3.1794749999999965, 2.126279999999994, 2.4612899999999964, 2.044574999999991, 1.4018549999999976, 1.7977049999999952], [0.0, 0.6355050000000086, 0.9863099999999978, 0.7318350000000002, 0.3582150000000004, 0.04309499999999389, 1.2752999999999983, 1.3807950000000022, 0.840255, 1.15206, 1.5085199999999968, 0.7911149999999973, 0.19636500000000146, -0.03509999999999769, -0.7259850000000001, -0.9829949999999967, -1.077959999999996, -0.532154999999999, -0.20143500000000003, -0.3777149999999989, 0.5822700000000016, 0.849614999999996, 0.9008999999999956, 1.0762049999999967, 1.7471999999999974, 2.5546950000000006, 2.1705450000000006, 2.818919999999998, 4.362540000000001, 4.251974999999999, 4.653089999999999, 4.5187349999999995, 3.320069999999999, 3.0751499999999994, 2.9132999999999996, 2.5562549999999975, 2.4841049999999996, 2.6350349999999985, 2.576144999999998, 2.2957349999999987, 2.6730599999999978, 3.051944999999999, 2.5453349999999983, 2.8087799999999996, 2.838225, 2.905499999999999, 3.680625, 3.6901799999999993, 3.502784999999999, 3.953234999999999, 3.8038649999999983, 4.2322799999999985, 3.92574, 3.6513749999999985, 3.444479999999999, 2.737409999999999, 1.5449849999999992, 1.2948000000000026, 1.1711699999999952, 1.2772499999999951, 1.2573599999999958, 1.5777450000000002, 1.8515249999999992, 2.1063899999999967, 2.4860549999999986, 3.2042399999999978, 3.5345699999999987, 4.534334999999999, 4.620719999999999, 4.761704999999997, 4.507424999999998, 4.341479999999999, 3.8050349999999993, 3.5727899999999977, 3.907214999999999, 3.5548499999999987, 3.412304999999999, 3.5819549999999984, 3.6297299999999995, 3.117464999999998, 2.45505, 2.247960000000001], [0.0, 0.018915000000009563, -0.36718499999999743, -1.2284999999999884, -1.825979999999999, -0.33657000000000004, -1.4277900000000012, -1.399514999999997, -2.2867649999999964, -2.6126099999999957, -2.4741599999999995, -2.5960350000000005, -3.804449999999997, -4.096949999999994, -4.246514999999999, -3.796454999999997, -3.5029799999999973, -2.909789999999998, -2.303144999999995, -2.425799999999998, -2.5876499999999973, -2.1286199999999913, -1.1625899999999971, -0.36250499999999164, 0.6033299999999961, 1.4075100000000038, 2.2893000000000034, 2.307630000000006, 3.088800000000008, 3.483480000000001, 4.234425000000015, 3.6814049999999936, 3.5665500000000128, 4.363125000000008, 3.932175000000007, 3.398460000000015, 3.9054600000000006, 3.385395000000014, 2.553914999999999, 2.789085000000001, 3.200924999999997, 2.8707900000000013, 2.8668900000000086, 2.9729700000000028, 3.4000200000000005, 3.7640849999999917, 3.519165000000009, 4.615455000000007, 4.531800000000016, 4.282200000000009, 4.132830000000005, 3.6934949999999978, 2.938650000000001, 3.16446000000001, 3.126629999999996, 3.214379999999996, 2.628795, 2.689245000000003, 3.1716750000000067, 2.802150000000003, 1.9927050000000062, 1.8776550000000043, 2.0855250000000067, 1.8068700000000062, 2.366130000000001, 2.427945000000004, 3.3744750000000048, 3.189809999999997, 3.7650599999999974, 3.4885500000000045, 4.360590000000022, 3.817515000000008, 3.5860500000000117, 3.6262199999999973, 3.680039999999999, 3.244215000000003, 2.0709000000000097, 1.6781700000000033, 1.5886650000000007, 1.1848200000000073, 1.7583150000000023, 1.635660000000004], [0.0, -0.15249000000000057, -0.22970999999999975, -0.26578500000000105, 0.007604999999999418, -0.028080000000000105, 0.14234999999999953, -0.3816150000000004, -0.4929600000000015, -0.19500000000000062, -0.27651000000000026, -0.9609600000000018, -1.2682800000000007, -1.6596450000000007, -2.4802049999999976, -2.8388100000000023, -2.963999999999999, -2.486639999999999, -2.038334999999999, -1.9675499999999988, -1.5087150000000016, -1.1477700000000006, -0.023790000000001754, 0.43758000000000086, 1.3579799999999986, 1.2792, 2.4098100000000047, 3.0496050000000015, 3.9397800000000007, 4.611944999999996, 4.836389999999988, 4.751565, 4.306379999999994, 4.081350000000002, 4.070430000000008, 3.2124300000000003, 3.439409999999997, 4.147455000000003, 3.4070399999999967, 3.1810349999999974, 3.7480949999999966, 3.4760700000000035, 2.9577599999999986, 3.0164550000000037, 3.5462699999999945, 3.5002499999999976, 3.532229999999994, 3.4331700000000023, 3.752775000000004, 4.291754999999998, 4.548764999999999, 4.779840000000002, 4.361954999999998, 4.225650000000006, 3.6236849999999947, 3.0509700000000013, 2.9708249999999956, 2.5819949999999956, 2.413904999999999, 2.271944999999999, 2.1019050000000017, 2.394210000000002, 2.3653500000000034, 2.461290000000001, 3.030299999999991, 2.8996499999999994, 3.5593350000000035, 3.421274999999998, 3.691154999999992, 3.690179999999997, 3.892199999999998, 3.9044849999999993, 3.5944350000000007, 3.3348900000000006, 2.978039999999999, 3.1545149999999973, 2.7871349999999944, 2.9035499999999974, 2.4934650000000027, 2.3156250000000003, 1.761824999999999, 1.719314999999999], [0.0, -0.7177950000000008, -0.6448650000000022, -0.5976750000000015, -0.5153849999999993, -0.55185, -0.17237999999999964, -0.8667750000000012, -1.1095499999999996, -1.4043900000000025, -1.3800149999999993, -2.150265000000002, -2.9090100000000017, -3.754919999999997, -5.00292, -5.675670000000002, -5.709990000000001, -5.738655000000005, -5.194604999999999, -4.826640000000003, -4.303065000000002, -3.6535200000000043, -2.4298950000000032, -0.895830000000001, 0.8024249999999991, 1.7466149999999967, 3.933734999999998, 4.797974999999996, 5.346120000000001, 5.78721, 6.0278399999999905, 6.41004, 6.280169999999998, 6.13392, 6.129435000000001, 5.530785, 5.256225000000001, 5.034705000000001, 4.781009999999997, 4.715099999999998, 4.794854999999995, 4.493190000000003, 4.320224999999999, 3.6782850000000007, 4.1390699999999985, 4.539014999999994, 4.297214999999997, 4.4810999999999925, 5.347680000000004, 5.389605000000001, 5.344950000000001, 5.480279999999997, 4.570020000000003, 4.099679999999996, 3.952844999999999, 3.6886199999999967, 3.551339999999996, 3.5940449999999995, 3.0759299999999987, 3.0451199999999954, 2.2545899999999994, 2.2134449999999997, 2.8684499999999997, 3.1822049999999993, 3.923204999999998, 3.4468199999999958, 3.503174999999999, 3.9025350000000034, 3.969029999999997, 4.082715, 4.366049999999998, 4.336409999999996, 4.255484999999998, 3.7874850000000038, 3.4144499999999987, 2.855190000000001, 2.1904350000000004, 2.1026849999999984, 2.045354999999998, 2.164499999999997, 1.890329999999999, 1.9550699999999999], [0.0, -0.1731600000000006, 0.0419250000000006, -0.17628000000000005, -0.5555550000000001, -0.5961149999999997, -0.36250500000000063, -0.054990000000000094, -0.5325450000000007, -0.33422999999999925, -0.5331300000000003, -1.0093200000000018, -1.7052750000000003, -2.7089399999999997, -3.35283, -4.390619999999995, -4.590299999999997, -4.2112199999999955, -3.6950549999999995, -3.285360000000001, -2.6919749999999993, -1.9759349999999996, -1.3593449999999985, -0.23497500000000077, 0.7858499999999999, 1.4024400000000026, 3.4054799999999976, 3.4739250000000004, 4.180605000000002, 5.0368500000000065, 5.408519999999997, 5.171010000000002, 4.895864999999996, 5.193629999999993, 4.404074999999991, 4.898789999999998, 4.728750000000002, 4.736745000000004, 4.586399999999999, 3.566159999999997, 3.159389999999999, 3.759600000000002, 3.463980000000003, 3.261569999999999, 3.249284999999996, 2.7112799999999995, 3.131115000000001, 3.773834999999996, 3.2176949999999955, 3.624659999999998, 4.317300000000007, 3.5835149999999945, 4.057754999999994, 3.6484499999999933, 3.6934950000000004, 2.6826149999999975, 2.6958749999999987, 2.272725000000001, 2.4835199999999986, 1.9930950000000014, 1.647749999999999, 2.0744100000000003, 2.2606350000000006, 2.6215799999999962, 2.1578699999999986, 2.819699999999999, 2.885999999999999, 2.9363099999999998, 2.9628299999999963, 2.908034999999998, 3.33177, 2.7801149999999972, 2.5250549999999996, 2.5741950000000005, 2.1235500000000007, 2.8017599999999963, 2.3206949999999966, 2.150070000000001, 2.106194999999999, 1.4127750000000006, 1.5681900000000006, 0.9258599999999995], [0.0, 0.22815000000000207, 0.10803000000000118, -0.5436600000000009, -0.47833500000000084, -0.2205449999999991, -0.3433950000000019, -0.7177949999999993, -0.9527700000000034, -1.1481600000000005, -1.5360150000000004, -3.0640350000000005, -3.5920950000000005, -4.840680000000001, -6.898124999999999, -7.877804999999997, -8.198190000000002, -7.850700000000003, -7.379579999999997, -6.1280699999999975, -5.5227900000000005, -4.0920749999999995, -1.9845149999999987, -0.32038499999999503, 1.9956300000000042, 3.9526500000000024, 5.842395000000002, 6.622590000000008, 7.686510000000032, 8.266050000000037, 8.822190000000013, 8.516040000000004, 8.291985000000006, 8.439794999999997, 8.034584999999998, 7.831395000000029, 7.3189350000000015, 6.855810000000011, 6.344520000000008, 6.295185, 5.99722500000002, 5.941259999999998, 5.659290000000002, 5.365620000000012, 5.622629999999985, 5.213910000000007, 4.715684999999995, 4.858814999999998, 4.893915, 5.189339999999998, 5.25681, 5.4286049999999975, 5.2226850000000145, 4.4850000000000065, 5.1840750000000035, 4.861545000000007, 4.631835000000013, 4.162469999999992, 3.735420000000016, 3.6905699999999997, 3.8672399999999967, 3.8227799999999914, 3.8863500000000015, 4.365075000000006, 4.7388899999999925, 4.452044999999998, 4.423965000000004, 4.385550000000007, 4.408949999999997, 4.710809999999999, 3.986970000000006, 3.9245699999999935, 4.405829999999996, 3.658784999999996, 3.4817249999999977, 2.4174150000000014, 2.3318100000000013, 2.507115, 2.4766950000000016, 2.9996850000000044, 2.80956, 2.9131049999999994], [0.0, -0.3424199999999846, -0.5095349999999712, -0.4186649999999954, -1.0424699999999962, -0.9205949999999863, -0.4902299999999773, -0.5027099999999844, -0.7086299999999799, -1.2310349999999914, -1.0990199999999781, -1.84353000000001, -3.738539999999995, -4.952024999999992, -5.362304999999985, -6.69844500000001, -7.841924999999975, -7.723949999999981, -7.325174999999998, -6.211335000000005, -5.073704999999983, -4.150184999999992, -2.7436499999999757, -0.8273849999999783, 1.206075000000002, 3.023865000000006, 4.837560000000019, 5.902845000000018, 6.900660000000019, 7.935525000000018, 7.804290000000017, 7.8146250000000155, 7.927920000000018, 6.817590000000013, 7.572435000000017, 7.120620000000014, 6.489405000000009, 6.631560000000017, 6.353490000000016, 5.878665000000011, 6.220110000000022, 5.271045000000019, 4.54584000000002, 4.677075000000018, 4.799145000000019, 4.639050000000022, 4.511325000000012, 4.919655000000015, 4.828785000000009, 5.822505000000016, 5.389800000000021, 5.211180000000015, 4.889040000000008, 4.039425000000021, 4.517955000000006, 4.4440500000000265, 3.777735000000014, 3.789630000000021, 3.519165000000016, 2.483130000000001, 3.4622250000000196, 3.3056400000000075, 3.3218250000000147, 3.2095050000000036, 3.4489650000000083, 3.479775000000026, 3.614325000000017, 3.5178000000000162, 3.8808900000000097, 4.60161000000002, 4.270695000000022, 3.8658750000000186, 3.147300000000021, 3.75316500000001, 3.163485000000012, 3.056040000000017, 2.177760000000024, 2.2204650000000097, 2.395380000000019, 2.617290000000022, 2.083185000000009, 2.3037300000000265], [0.0, -0.38493000000000066, -0.17627999999999844, -0.6368700000000036, -0.39721500000000454, -0.45922499999999555, -0.5452199999999996, -0.967785000000001, -0.6124949999999965, -1.207635000000006, -1.3269749999999894, -1.7899050000000036, -3.3955349999999944, -4.897814999999997, -7.436520000000027, -9.785490000000006, -12.128415000000007, -13.532610000000012, -13.929630000000017, -13.016835000000022, -11.70546000000001, -9.314759999999982, -6.517290000000011, -3.572594999999997, -0.8041799999999855, 1.8950100000000045, 5.144295000000005, 7.245225000000007, 8.866065000000003, 9.967425000000002, 10.570755000000002, 10.924875000000005, 11.183640000000006, 11.234145000000005, 10.878075, 10.272990000000005, 10.223460000000008, 10.233795, 9.703980000000001, 8.910914999999996, 8.001630000000004, 7.281495000000003, 6.903195000000004, 6.286995000000004, 6.355830000000004, 5.918250000000004, 6.189105000000004, 5.640375000000004, 5.473650000000005, 5.592990000000005, 5.779800000000004, 5.8234800000000035, 5.604885000000003, 5.731830000000006, 5.447520000000004, 5.0783850000000035, 5.0196900000000015, 4.745520000000003, 4.3674150000000065, 3.886350000000002, 3.853785000000005, 3.8572950000000024, 3.994380000000005, 3.447210000000004, 4.1687100000000035, 4.274790000000002, 4.316715000000004, 3.4846500000000082, 3.596580000000002, 4.3605900000000055, 4.036695000000002, 4.181580000000003, 3.5427600000000044, 2.6592150000000068, 3.1118100000000046, 2.84349000000001, 2.989740000000003, 2.518035000000011, 2.3013900000000014, 2.57049000000001, 2.51940000000001, 2.2423050000000018], [0.0, 0.26812499999999595, 0.1928549999999909, -1.0186799999999963, -1.4104350000000156, -1.5736500000000042, -1.3494000000000028, -2.1229650000000397, -1.8209099999999978, -0.7486050000000137, -1.650285000000009, -1.8133050000000086, -2.6069550000000152, -3.2949150000000156, -4.8514050000000175, -6.318195000000021, -7.621185000000025, -7.714980000000011, -8.20072500000001, -7.508280000000024, -6.898515000000021, -5.814509999999991, -4.712175000000016, -3.9561600000000077, -2.4267750000000223, -1.0155600000000131, 0.8786699999999978, 2.6908049999999974, 3.9109200000000026, 5.416709999999995, 5.922929999999994, 6.253649999999993, 6.382740000000001, 6.491354999999997, 6.485895000000003, 6.92601, 6.989384999999999, 6.371234999999997, 5.884709999999993, 6.061379999999994, 6.185399999999997, 5.068634999999994, 5.046599999999997, 4.409144999999991, 4.5064499999999965, 4.722704999999994, 4.432544999999997, 3.886544999999999, 3.7443899999999983, 3.826679999999996, 3.9329549999999953, 4.207514999999991, 4.457114999999993, 4.922969999999994, 4.586205, 4.6125299999999925, 3.8491049999999953, 3.7445850000000007, 4.014269999999995, 2.572049999999992, 3.178109999999995, 2.832179999999994, 2.8990650000000002, 3.009824999999992, 2.829450000000005, 3.555044999999989, 2.886974999999997, 2.5231049999999877, 2.651999999999992, 2.6562900000000065, 3.2001449999999974, 2.901599999999992, 2.394014999999998, 2.507894999999997, 2.2270949999999985, 2.0090849999999882, 1.6496999999999975, 1.8899399999999957, 1.5527849999999699, 1.4693249999999942, 1.4800499999999772, 1.6924049999999777], [0.0, 0.3506099999999748, -0.03958500000000775, 0.46097999999999395, 0.10042499999999244, 0.007410000000017902, 0.01169999999998339, -0.08502000000002141, -0.754844999999996, -1.356810000000019, -1.7680650000000018, -3.4004100000000186, -5.508750000000028, -8.947770000000023, -12.943320000000035, -17.287724999999973, -20.010899999999953, -21.784035000000006, -22.93433999999998, -22.276994999999953, -18.99748500000003, -15.009150000000012, -9.98536500000002, -3.8912249999999915, 1.1056500000000113, 6.544200000000002, 10.37867999999999, 14.080559999999991, 15.88255499999999, 16.916834999999985, 17.801744999999986, 18.31166999999999, 18.202664999999985, 18.583499999999994, 17.261009999999995, 16.91761499999999, 16.43186999999999, 15.585374999999988, 14.928224999999994, 13.477034999999992, 12.30157499999999, 11.003069999999983, 10.65089999999999, 10.484564999999991, 9.40036499999999, 9.15739499999999, 9.501764999999988, 9.508589999999987, 8.963369999999994, 8.689979999999993, 8.298419999999997, 7.636394999999994, 8.29627499999998, 7.582574999999988, 7.4466599999999925, 7.758854999999987, 6.924644999999996, 6.870434999999988, 6.923474999999992, 5.720129999999993, 5.137860000000002, 5.632574999999986, 5.689124999999989, 6.11149499999999, 5.904404999999995, 5.560814999999987, 5.105489999999996, 5.135519999999978, 5.448104999999989, 5.739435, 6.254624999999986, 6.105059999999996, 5.645054999999994, 5.267144999999992, 4.9830299999999905, 4.605314999999981, 4.28102999999998, 4.500599999999977, 4.306379999999997, 4.824884999999989, 4.633395, 4.57742999999998], [0.0, 0.30810000000000315, 1.5800849999999969, 1.6561349999999777, 0.03490500000000196, -0.40189500000004585, 0.05245500000003034, 0.2950349999999915, 0.6415499999999597, -0.14936999999997624, -0.5779800000000606, -0.5606249999999946, -2.5644450000000205, -3.873869999999968, -7.351694999999957, -9.49864499999999, -12.636974999999957, -13.566345000000027, -14.450669999999938, -14.888444999999919, -13.405664999999999, -10.959975000000014, -7.9729650000000305, -4.881435000000032, -2.911155000000015, 0.5653049999999595, 3.8346750000000043, 6.101550000000032, 9.492210000000018, 11.12592, 11.42251499999998, 12.709905000000013, 13.155674999999963, 12.743639999999974, 13.674569999999978, 12.509054999999986, 12.453089999999978, 12.823589999999996, 11.857169999999964, 10.416315000000008, 9.707880000000035, 8.849489999999975, 8.816534999999998, 8.281065000000005, 7.427939999999985, 7.986614999999954, 7.3924499999999895, 7.201154999999957, 7.489169999999945, 7.465379999999996, 7.577700000000021, 7.611630000000012, 8.066175000000001, 7.842900000000029, 7.249904999999977, 7.116524999999996, 7.012784999999994, 6.2511150000000555, 6.371039999999972, 4.823324999999976, 4.598100000000059, 4.539405000000045, 4.168710000000054, 4.815720000000056, 4.768139999999988, 4.8488699999999625, 4.915559999999999, 3.9967200000000247, 4.2775199999999955, 4.707495000000009, 5.410080000000015, 4.1104049999999575, 3.7369800000000097, 3.470804999999956, 3.8069850000000187, 2.9398200000000045, 3.3005700000000004, 2.56873499999994, 2.0839649999999423, 2.2590749999999815, 2.279550000000029, 3.326894999999979], [0.0, 0.46195500000000206, 0.25954500000000236, 0.4180800000000015, 0.3981900000000019, 0.20104500000000114, -0.1598999999999987, -0.7677150000000005, -0.9993749999999998, -0.8189999999999974, -1.3501799999999982, -2.669354999999996, -5.039189999999997, -8.011574999999999, -12.074205000000006, -17.44664999999999, -23.403705000000027, -29.471130000000006, -34.50135000000001, -35.99446499999998, -34.038809999999984, -29.25428999999999, -21.963045000000022, -13.560300000000014, -5.672354999999988, 2.3926499999999997, 7.285394999999996, 12.175410000000015, 16.218540000000008, 18.828225, 21.06039000000007, 22.892415000000014, 24.031020000000055, 24.192870000000052, 23.68918500000005, 23.913435000000035, 23.21104500000007, 23.247510000000034, 21.71286000000006, 19.671210000000045, 18.29080500000002, 17.300790000000017, 16.007160000000002, 15.33714000000001, 13.717080000000024, 13.20208500000001, 13.060320000000017, 12.381525000000023, 12.345839999999997, 12.270375000000003, 11.329304999999996, 10.93618500000001, 10.902060000000011, 10.428600000000003, 9.986535000000002, 10.49587499999999, 9.930179999999993, 10.030020000000011, 9.463154999999997, 8.245574999999999, 7.423650000000002, 7.691774999999997, 7.435349999999993, 7.533630000000002, 7.264140000000002, 6.619274999999995, 6.7791749999999995, 6.362265000000006, 6.643259999999999, 7.332780000000005, 7.027605000000001, 6.419985000000003, 5.666114999999996, 5.1265499999999955, 4.373265, 4.474664999999999, 4.707299999999999, 5.438940000000003, 5.602739999999998, 6.125145000000003, 5.14293, 4.720365000000004], [0.0, 0.5705700000000062, -0.10705499999999724, -0.5344950000000059, -0.5635499999999958, -1.325024999999993, -1.2885599999999968, -1.6023149999999955, -0.5978699999999995, -0.7879949999999862, -0.9122099999999964, -1.7119050000000016, -2.7124500000000005, -3.5339850000000013, -6.1216349999999995, -8.361209999999978, -9.833265000000022, -10.754640000000013, -11.793015000000036, -12.72316500000002, -13.529880000000041, -13.908180000000012, -12.146550000000023, -10.443615000000019, -8.827454999999997, -5.667674999999996, -2.9940299999999933, 1.3421850000000024, 4.215705000000007, 6.460740000000003, 8.367645000000005, 10.157550000000006, 11.002875000000005, 12.713220000000003, 12.573795000000004, 12.532260000000008, 12.944100000000002, 12.87039, 12.041250000000002, 11.663535000000003, 10.92136500000001, 9.828975000000005, 8.912280000000006, 8.756670000000003, 7.7836200000000035, 7.676175000000003, 7.078110000000004, 7.4895600000000035, 7.276035000000004, 7.393815000000004, 6.7581150000000045, 7.075185000000006, 6.508710000000004, 6.038565000000005, 6.611280000000005, 6.140355000000003, 6.493500000000005, 6.168435000000002, 6.045780000000005, 5.661630000000004, 5.936775, 5.024370000000001, 4.695015000000003, 4.876560000000005, 4.5095700000000045, 4.7207550000000005, 4.1648099999999975, 3.2467500000000005, 4.0792050000000035, 4.505085000000008, 4.140045000000001, 3.1757700000000044, 3.1434000000000033, 2.585115000000008, 3.2524049999999987, 3.0769050000000027, 3.2032650000000107, 2.7994200000000085, 3.448185000000005, 2.1227700000000045, 2.37861000000001, 2.228655000000005], [0.0, 0.4795050000000014, 0.13493999999999318, 0.6004050000000074, 0.5649149999999867, 0.6891299999999969, 1.3757249999999868, 1.3831350000000047, 0.9016800000000167, 0.5493150000000071, 0.07858499999999857, -1.1226150000000077, -3.102645, -5.132009999999999, -8.695829999999997, -14.544269999999994, -21.963239999999992, -31.382714999999997, -43.63749, -49.326030000000074, -48.80947500000006, -42.134234999999975, -31.74444, -19.592624999999988, -6.950969999999999, 3.694860000000004, 12.136410000000009, 18.851040000000022, 23.723114999999996, 25.872015000000008, 26.681069999999973, 27.72120000000002, 28.393365000000014, 28.75742999999999, 28.550535000000057, 29.45865000000003, 27.195480000000043, 26.543985000000088, 24.86484000000004, 24.117015000000055, 22.41661500000003, 20.95275000000007, 19.794060000000005, 19.437600000000035, 17.81617500000003, 16.656510000000026, 16.06566000000002, 15.377115000000007, 13.708109999999994, 12.599925000000006, 13.510769999999969, 13.291395000000005, 12.464984999999984, 13.042575, 12.60460500000001, 11.783655000000003, 11.387025000000037, 11.11753500000001, 9.861929999999997, 9.902100000000004, 9.517950000000031, 9.136724999999995, 9.041760000000004, 8.609445000000012, 8.912085000000019, 9.046635000000002, 8.859239999999968, 8.710844999999996, 9.00978000000001, 7.984275000000007, 7.653944999999997, 7.078499999999991, 6.519045000000013, 6.942, 6.4231049999999925, 6.710924999999994, 6.762210000000003, 6.577350000000001, 6.459180000000021, 6.665685000000007, 7.077525000000001, 6.2645700000000115], [0.0, 0.4984199999999963, 0.6355049999999953, 0.5584799999999968, 0.4044299999999965, -0.10471500000000278, 0.18719999999999715, 0.7515299999999954, 0.06980999999999549, -0.18583500000000752, -0.7230600000000034, -0.5222100000000038, -1.725750000000001, -3.2496750000000065, -5.321550000000016, -8.118045000000008, -12.222014999999988, -17.984070000000035, -25.67175000000003, -31.135650000000037, -34.637849999999986, -34.28372999999996, -30.920954999999974, -24.866010000000045, -17.53011000000003, -9.724065000000005, -1.2879749999999963, 5.453369999999998, 10.804949999999998, 14.943629999999992, 17.55955500000001, 19.492590000000007, 20.745660000000022, 20.690670000000026, 21.17739000000003, 21.06819000000002, 20.975175000000014, 20.586150000000025, 20.170994999999998, 19.475039999999993, 18.400395000000003, 16.852484999999984, 15.925650000000003, 15.203175000000002, 13.672425000000002, 13.337415000000007, 12.348375000000013, 11.646179999999996, 11.34568499999999, 11.074830000000004, 10.97031, 10.771410000000001, 10.040940000000004, 10.257390000000008, 10.324470000000005, 10.292684999999992, 10.062195000000013, 9.580154999999994, 8.704799999999995, 8.55699, 7.403954999999992, 7.270574999999994, 7.120229999999996, 6.950774999999991, 7.149284999999989, 7.160399999999998, 7.021754999999997, 6.1623899999999985, 6.1623899999999985, 6.281729999999994, 5.862089999999999, 5.489249999999998, 4.880459999999993, 4.831124999999997, 4.672199999999996, 4.6872149999999975, 4.828004999999996, 4.861154999999995, 4.6384649999999965, 4.448534999999995, 4.380869999999995, 3.7258649999999953], [0.0, 0.2718299999999987, 0.21040500000000106, 0.18817499999999487, 0.6095699999999984, 0.3355949999999961, 0.2899649999999969, 0.6230249999999988, 0.9597899999999986, 0.9276150000000007, 0.5159700000000034, 0.24979499999999932, -0.22932000000000308, -0.9124050000000001, -3.7030500000000015, -7.65277500000002, -18.213000000000044, -33.621509999999965, -49.80767999999995, -58.49453999999998, -58.84943999999996, -52.69036500000002, -40.293825000000105, -27.125280000000014, -13.671255000000002, -2.094495000000004, 7.091370000000003, 14.23968000000001, 19.678814999999993, 23.85064500000006, 26.398125000000032, 28.096574999999987, 28.610010000000003, 29.582864999999977, 28.696395000000017, 29.401125000000032, 28.456544999999995, 28.581734999999984, 27.68453999999999, 26.391494999999974, 24.81336000000003, 23.46883500000003, 21.61614000000001, 20.187570000000004, 19.366815000000017, 17.18632499999999, 16.545165000000022, 15.827370000000013, 14.684865000000013, 13.820430000000012, 13.058369999999988, 13.489904999999993, 12.916994999999996, 13.25415000000001, 12.648285000000005, 11.786579999999997, 10.959195, 10.810410000000001, 10.409880000000001, 9.785099999999998, 8.83428, 8.718839999999997, 8.775000000000002, 8.516819999999987, 7.668374999999999, 7.1091149999999965, 7.400444999999991, 7.768215000000007, 8.125260000000003, 7.4862449999999985, 7.008494999999993, 6.7707899999999945, 6.294794999999995, 6.715019999999993, 6.597434999999997, 6.475754999999994, 6.076394999999996, 6.436754999999999, 6.227324999999999, 5.805539999999997, 6.149519999999999, 5.539755000000001], [0.0, 0.11056499999998781, -0.7076550000000132, -0.4763850000000067, 0.239069999999991, 0.27104999999999535, -0.021645000000005687, -0.20046000000000852, 0.10471499999998546, 0.2778749999999901, -0.38278500000001525, -0.5984550000000199, -1.7101500000000183, -2.8432950000000012, -2.5829700000000013, -3.5538750000000157, -6.176625000000005, -10.163790000000015, -14.666145000000016, -19.798350000000028, -23.743785000000045, -26.060190000000055, -27.096419999999988, -24.76734000000001, -20.942805000000043, -14.235195000000049, -7.503990000000009, -1.302600000000008, 4.1135249999999886, 7.830614999999989, 11.29693499999999, 12.895934999999984, 14.004314999999995, 14.896634999999996, 15.127514999999992, 15.767699999999998, 16.082039999999992, 16.373955, 16.367715000000004, 16.430114999999986, 15.885089999999991, 14.588730000000002, 13.777919999999995, 12.881894999999993, 11.979629999999991, 11.989184999999981, 11.660999999999994, 11.579489999999982, 11.277044999999987, 10.817039999999988, 10.64777999999999, 10.280204999999986, 10.351379999999988, 9.61057499999999, 9.584249999999992, 9.196589999999986, 9.146864999999986, 9.002954999999993, 8.393579999999993, 8.458124999999994, 8.388704999999995, 7.488389999999989, 7.415654999999991, 7.130759999999991, 7.41818999999999, 7.013759999999991, 6.538934999999991, 6.228494999999991, 6.308249999999991, 6.271394999999989, 6.389759999999991, 6.053384999999991, 5.46311999999999, 5.689904999999991, 4.945394999999991, 4.327049999999993, 4.328024999999991, 3.9411449999999877, 4.577234999999991, 4.42084499999999, 3.93880499999999, 4.243004999999988], [0.0, -0.33617999999999615, 0.24667500000000198, -0.03041999999999634, 0.19480500000000323, 0.8275800000000038, -0.08657999999999433, 0.651105000000002, 0.22795500000000235, 0.40677000000000296, 0.3983850000000029, -0.5959200000000018, -0.4771649999999976, -0.5520449999999948, -0.8730149999999979, -4.610774999999998, -12.352080000000008, -23.924745000000037, -37.561875000000015, -44.71681499999995, -46.22728499999996, -40.60446000000005, -32.71105500000003, -22.687470000000012, -12.301965000000004, -3.6234899999999968, 4.469400000000004, 10.358205000000005, 15.202004999999998, 18.712005000000012, 20.97303000000001, 21.58962000000004, 21.918195000000054, 23.005905000000055, 24.197940000000038, 23.841480000000047, 23.62327500000002, 23.754120000000043, 22.739145000000036, 21.506940000000007, 20.291505000000036, 18.702060000000003, 16.96441500000001, 17.030910000000013, 15.162615000000017, 14.565525000000003, 13.627965000000012, 12.932984999999999, 12.506130000000002, 12.529335, 12.492674999999991, 12.601289999999988, 11.506950000000016, 11.622194999999996, 11.279580000000003, 10.32720000000001, 10.556715000000015, 10.034115000000007, 10.113480000000003, 10.065900000000005, 9.344205000000002, 9.140625, 8.738729999999999, 8.244989999999996, 8.746334999999998, 7.469670000000003, 8.223345000000002, 7.540844999999995, 7.702110000000003, 7.768410000000003, 7.329075000000006, 6.983925000000001, 6.969494999999999, 7.049445000000005, 6.366749999999998, 6.249165000000003, 5.970705000000002, 6.180915000000003, 6.366750000000002, 7.013955000000002, 6.658470000000004, 4.967430000000002], [0.0, 0.5397599999999998, 0.35431499999999966, 0.6210750000000018, 0.1407899999999992, 0.5159699999999996, 1.2111449999999997, 1.0910250000000015, 0.890369999999997, 1.0239449999999983, 0.9937200000000013, 0.7495800000000001, -0.10881000000000032, -0.04894499999999982, 0.3640650000000006, -1.6385849999999984, -6.091799999999998, -12.624105, -19.804005000000018, -26.369850000000017, -28.868385000000032, -28.931565000000003, -26.155154999999993, -20.620860000000018, -14.084459999999996, -7.434764999999998, -0.508365, 4.960995, 8.897460000000008, 12.81813, 13.959855000000012, 15.281954999999998, 16.320720000000016, 16.83493499999999, 17.032664999999987, 17.129970000000014, 17.19978000000003, 17.061135, 16.292445000000008, 15.215264999999995, 14.469780000000014, 13.673789999999991, 13.731704999999996, 12.679095000000016, 12.838020000000022, 11.55043500000001, 10.401885000000014, 10.917075000000011, 11.164334999999989, 11.311170000000008, 10.981425000000014, 10.306725000000013, 9.69579000000001, 9.606089999999996, 9.446775000000006, 9.156225000000013, 8.419515000000008, 8.225684999999997, 8.061885000000002, 8.271120000000012, 7.535970000000006, 6.801600000000006, 7.464990000000005, 6.462494999999999, 6.646770000000006, 7.144409999999998, 6.389370000000011, 6.116760000000003, 6.485310000000004, 6.365190000000011, 5.802225000000003, 6.010875000000002, 5.757960000000004, 4.8539400000000015, 4.782569999999994, 4.198935000000004, 4.118789999999999, 4.526730000000001, 4.799925, 4.049174999999993, 4.620330000000004, 4.144334999999999], [0.0, -0.7222800000000014, 0.11699999999999378, 1.0652849999999798, -0.24882000000000737, -0.7612799999999993, -0.7445100000000267, 0.3108300000000046, -0.7805850000000127, -1.4348100000000201, -0.6489600000000078, 0.3911699999999847, 0.21956999999999205, 0.6048899999999975, 0.4451849999999773, -0.006825000000006298, 2.010059999999971, 1.8082349999999927, 2.800784999999994, 3.2871149999999734, 4.479539999999979, 3.9926249999999808, 4.2609449999999836, 2.5765349999999874, 1.6578899999999894, 1.0962899999999856, 0.266369999999986, -0.42705000000000837, -0.9800700000000173, -2.468505000000011, -1.811160000000001, -2.310360000000019, -1.7154150000000072, -2.6880750000000155, -2.4018150000000063, -2.1407100000000234, -1.444755000000006, -2.525250000000012, -1.3427700000000158, -0.9968400000000202, -0.9582300000000092, -0.9324899999999925, -0.6290700000000307, -0.4594200000000068, -0.8182200000000144, -0.6052800000000111, -1.085760000000013, -0.9751950000000065, -1.8152550000000094, -0.7862400000000012, -1.677195000000001, -1.6775850000000077, -0.8301150000000082, -0.4483050000000226, -0.48594000000002247, 0.76108499999998, 0.8560499999999642, 0.8665799999999866, 1.7481749999999892, 1.7282849999999872, 0.4802849999999861, 2.0535450000000015, 1.5995849999999745, 1.0972650000000055, 0.5013449999999882, 1.008149999999981, 1.193985000000005, 0.47716499999999584, -0.684060000000013, -0.670410000000004, -0.91221, -1.4281800000000047, -1.742325000000017, -0.8386950000000173, -0.6934200000000192, -0.14859000000001465, 0.5458049999999695, 1.5804749999999999, -0.15951000000000626, 0.45610500000000087, 2.058224999999995, 1.6364400000000003], [0.0, 0.5001750000000003, 0.8868599999999994, 1.1001899999999996, 0.7060949999999995, 1.3074749999999997, 1.589444999999999, 1.2618449999999997, 1.0366199999999988, 1.59783, 1.521975, 1.5024749999999991, 1.2386399999999984, 0.9207900000000002, 0.7478249999999993, 0.39779999999999993, -1.5627299999999984, -3.705194999999998, -7.381335000000001, -9.439950000000014, -11.655930000000001, -12.793950000000024, -12.705225000000013, -11.598405000000007, -9.346155000000017, -6.444750000000005, -3.2157449999999974, -0.23283000000000031, 2.6531700000000003, 5.288010000000004, 6.890130000000006, 8.122140000000009, 9.404850000000003, 9.597120000000011, 10.316670000000013, 10.84746000000002, 10.853505000000009, 10.81548, 10.568805000000015, 10.19616000000001, 9.906390000000005, 9.958065000000001, 9.306765000000006, 8.691149999999997, 8.796839999999996, 8.675159999999998, 8.346000000000004, 8.562254999999993, 8.822384999999993, 8.492055000000008, 8.68686, 8.446229999999996, 8.582534999999996, 8.504534999999994, 8.034000000000002, 7.801560000000002, 7.6560899999999945, 7.613775000000001, 7.120424999999996, 6.8792100000000085, 6.976904999999992, 7.146945000000003, 7.201349999999998, 7.224360000000004, 7.027605000000008, 6.544200000000006, 6.3811799999999925, 6.102524999999995, 6.227909999999991, 5.959979999999993, 5.634135000000001, 5.571344999999993, 5.228729999999992, 5.061809999999998, 5.281379999999997, 5.049719999999994, 4.8779249999999985, 4.4382, 4.429620000000003, 4.215510000000002, 4.089344999999999, 3.8853749999999962], [0.0, 0.6204899999999931, 0.0930149999999994, 0.5625749999999972, 0.4174949999999953, -0.010725000000000762, 0.8517600000000005, 1.079519999999988, 1.8129149999999932, 1.527825, 1.277445000000002, 1.6259099999999966, 1.56994499999999, 2.283644999999999, 2.430869999999995, 1.981784999999995, 0.7031699999999965, -2.1362250000000014, -5.9570550000000075, -9.036690000000021, -12.133679999999998, -13.706550000000032, -12.604215000000028, -11.640525000000029, -8.915205000000025, -5.879639999999998, -2.4347699999999985, 0.8139299999999903, 3.6492299999999975, 5.892510000000008, 7.200959999999998, 8.662484999999998, 9.557144999999997, 9.799334999999997, 9.968399999999997, 10.340849999999998, 10.877879999999998, 10.887629999999996, 10.787594999999998, 10.104509999999998, 9.590489999999997, 9.226619999999997, 8.38656, 8.271314999999996, 8.018009999999997, 8.087234999999998, 7.998509999999995, 7.815795, 7.763729999999999, 8.003384999999998, 7.441979999999999, 7.1596199999999985, 6.451574999999998, 6.206264999999998, 6.37962, 6.201389999999998, 6.754799999999999, 6.819929999999999, 6.857954999999997, 7.976474999999999, 7.417994999999994, 7.316009999999995, 7.027799999999999, 7.052565, 6.794385, 6.7093649999999965, 7.043984999999999, 6.832604999999998, 6.542054999999998, 6.378839999999997, 6.545174999999995, 6.417254999999998, 6.234929999999997, 5.859359999999996, 5.682299999999997, 4.9167299999999985, 4.609799999999995, 5.207279999999993, 5.115630000000002, 4.872465000000002, 4.521464999999989, 4.589910000000004], [0.0, 0.22483500000000323, 0.11797499999999328, 0.4847699999999966, 0.5623800000000001, 1.2062699999999928, 1.0902449999999977, 1.014779999999997, 1.3501799999999986, 1.292849999999997, 1.3882049999999988, 1.3741649999999983, 1.639949999999995, 1.3234649999999957, 1.5822299999999996, 0.9751949999999994, -0.82446000000001, -4.131269999999998, -7.606755000000013, -10.033920000000027, -11.101350000000018, -12.65589000000007, -11.979240000000054, -10.631400000000045, -8.419710000000034, -5.4299700000000195, -1.8078449999999968, 1.5525899999999968, 4.366634999999997, 6.717164999999994, 7.749104999999998, 9.306179999999998, 10.02202499999999, 10.644854999999994, 10.414559999999996, 10.731825000000008, 10.225409999999997, 10.395060000000008, 10.056734999999989, 9.832094999999999, 8.873669999999997, 8.895899999999996, 8.523059999999994, 8.868209999999996, 8.592089999999995, 8.467289999999997, 7.706594999999995, 7.412729999999994, 7.977254999999996, 7.388354999999998, 7.369829999999995, 7.356374999999996, 7.093514999999995, 7.0851299999999995, 7.214999999999999, 7.189649999999995, 7.179899999999995, 7.618064999999996, 6.914309999999997, 7.347209999999993, 7.159424999999998, 7.141094999999998, 6.9897749999999945, 6.4796549999999975, 6.271979999999997, 6.695909999999997, 5.841419999999997, 5.959004999999994, 5.915714999999997, 5.897969999999997, 5.837324999999993, 6.053969999999998, 5.274359999999996, 4.869344999999997, 5.086964999999997, 5.014229999999997, 5.205719999999996, 4.414409999999997, 3.9407549999999967, 4.104944999999996, 3.849299999999997, 3.980534999999996], [0.0, -0.22678499999999957, -0.06532499999999608, 0.26539500000000293, 0.25935000000000086, 1.0143899999999961, 1.2754949999999994, 1.6690050000000007, 1.605045, 1.9334249999999984, 1.969110000000001, 1.6588650000000005, 1.4077050000000004, 1.6612049999999998, 2.2467900000000007, 2.3990849999999977, 0.9905999999999993, -0.6331649999999982, -3.842669999999986, -5.896214999999989, -7.542794999999996, -8.981895000000007, -9.999015000000009, -9.967620000000002, -8.843835, -5.553599999999983, -2.3048999999999973, 0.654809999999999, 2.5634699999999992, 4.181385000000001, 5.647590000000001, 6.746804999999999, 7.501065000000005, 8.404304999999999, 7.575555000000001, 8.421075, 8.373495, 8.530275, 7.729410000000005, 6.956819999999997, 6.63078, 6.899099999999999, 6.4985700000000035, 6.781125000000002, 7.237815, 5.852924999999999, 5.881005000000003, 6.105645, 5.907525000000004, 5.062395, 5.439915000000001, 5.69322, 5.7086250000000005, 5.900310000000001, 5.598839999999999, 5.701604999999999, 5.844150000000001, 5.725004999999999, 5.8394699999999995, 6.222060000000002, 6.20139, 6.425445, 6.293430000000001, 5.838884999999999, 5.745675, 6.141915000000001, 5.76966, 5.7250049999999995, 5.537024999999999, 5.136105, 4.731480000000001, 4.825665000000002, 5.089109999999998, 4.805580000000001, 4.471935, 3.85008, 3.7461449999999994, 3.086849999999999, 3.329625, 3.81693, 3.2516250000000007, 3.150809999999999], [0.0, 1.2011999999999967, 1.3285349999999956, 1.2468299999999957, 1.6407299999999974, 1.8823349999999954, 1.322489999999995, 1.8889649999999973, 1.5369899999999963, 1.2965549999999972, 2.154164999999996, 1.950389999999996, 2.200184999999996, 2.329079999999996, 1.241954999999995, 2.061539999999995, 1.1971049999999965, 0.8968049999999985, -0.12655499999999886, -0.9213750000000034, -1.9687200000000011, -3.1508100000000026, -4.3921800000000095, -4.6080450000000095, -3.91326000000001, -2.0849400000000085, -1.7431049999999964, -0.8371350000000013, -0.05830500000000516, 1.2610649999999952, 2.1820499999999963, 3.475094999999996, 4.477394999999998, 5.624384999999998, 6.154784999999998, 6.238049999999996, 5.788379999999996, 5.442059999999996, 4.592834999999996, 5.285474999999995, 5.589089999999997, 5.918834999999994, 5.543264999999996, 5.604299999999997, 4.8987899999999955, 5.5151849999999945, 5.360159999999993, 5.634329999999992, 5.520060000000001, 5.626725, 5.905769999999994, 6.334770000000001, 5.755814999999998, 5.854875000000002, 5.862284999999999, 6.4876499999999995, 6.030179999999991, 5.881589999999999, 5.848634999999995, 6.004244999999999, 5.8447349999999965, 5.272604999999994, 5.371664999999994, 5.432504999999997, 5.896994999999993, 5.539559999999989, 5.562375000000001, 4.780034999999996, 4.397054999999995, 5.095739999999994, 5.132594999999997, 5.264025, 4.685849999999997, 4.904054999999993, 4.996289999999996, 4.340114999999997, 4.384574999999996, 4.248269999999995, 3.6445499999999957, 3.957524999999996, 3.4115249999999966, 3.5230649999999977], [0.0, 0.18856499999998988, 0.048750000000026716, -0.21839999999995996, 0.6399900000000187, 0.6764550000000042, 1.2257699999999723, 0.9804600000000434, 1.0580700000000505, 1.5354300000000265, 0.9145499999999984, 1.7665049999999738, 1.9618949999999877, 2.276430000000026, 1.666665000000009, 1.6729050000000178, 1.3599300000000305, 0.9582300000000146, 0.6633900000000139, -0.6727500000000006, -0.7289099999999848, -2.5615199999999305, -3.349709999999952, -2.6824199999999294, -2.2296300000000215, -2.151044999999982, -0.45844499999999044, 0.5465850000000358, 1.527630000000002, 1.1276850000000067, 1.98061500000005, 1.3774800000000162, 2.929680000000044, 3.0386850000000543, 3.7535550000000306, 4.775940000000038, 3.564599999999995, 4.155060000000002, 3.159000000000024, 5.113095000000101, 4.775745000000057, 4.272254999999998, 2.9413800000000236, 4.457114999999998, 3.2978400000000043, 2.7245400000000366, 3.5176050000000103, 4.582305000000066, 3.770325000000007, 4.714320000000022, 3.7215750000000227, 3.511365000000044, 2.738190000000003, 2.86435500000006, 2.7584700000000666, 3.0398549999999993, 2.9238300000000095, 3.7202100000000087, 3.9739050000000056, 3.3772050000000142, 4.40485500000004, 4.221165000000035, 3.5300850000000352, 3.220619999999979, 4.2523649999999975, 3.5363249999999944, 3.735810000000022, 4.069650000000035, 3.922619999999995, 2.5839450000000177, 3.6777000000000086, 3.0449250000000134, 3.341520000000042, 3.910140000000034, 3.560895000000013, 2.282669999999996, 1.3648050000000254, 1.503060000000037, 2.1652800000000063, 1.2975300000000196, 1.6984499999999798, 1.3922999999999988], [0.0, 0.06824999999999992, 0.7644000000000004, 0.9276149999999979, 1.0529999999999988, 1.5020850000000006, 1.2189449999999993, 1.8854549999999983, 1.9275749999999996, 1.3129350000000004, 1.7245799999999998, 1.5623399999999985, 1.7949749999999984, 2.196479999999999, 2.5628849999999996, 2.277795, 2.2569299999999988, 2.5474799999999993, 1.320734999999999, 1.0387650000000013, -0.4438200000000032, -2.525250000000004, -4.401735000000007, -4.652114999999997, -3.798404999999997, -3.250650000000004, -2.032094999999999, -0.49237500000000534, 0.7088249999999989, 1.2899249999999984, 2.4413999999999993, 3.227055, 3.8292150000000005, 4.272644999999999, 4.908149999999999, 5.060445, 5.133374999999999, 5.343975000000005, 4.54155, 4.550519999999999, 4.653479999999998, 3.9783899999999996, 4.527120000000002, 4.905225, 4.811819999999998, 5.093984999999998, 4.886114999999997, 4.802265, 4.998629999999999, 5.35548, 4.976789999999995, 5.452589999999997, 5.204160000000001, 4.92102, 4.781985000000001, 4.70613, 5.034900000000001, 5.155799999999999, 4.854915, 4.392569999999998, 4.993365000000001, 5.196359999999998, 5.116019999999995, 4.951635000000001, 4.7798399999999965, 5.070779999999999, 4.736549999999996, 5.029634999999999, 5.245304999999998, 5.316089999999997, 4.765604999999995, 4.711199999999999, 4.7102249999999986, 4.671809999999999, 4.7377199999999995, 4.874024999999996, 4.309694999999998, 4.0920749999999995, 3.9432899999999993, 3.925740000000001, 3.5195549999999995, 3.4037250000000006], [0.0, -0.22717499999999458, -0.3030299999999988, 0.32253000000000753, 0.5532150000000007, 0.1343550000000011, 0.2164500000000027, 1.5502500000000055, 0.6758700000000024, 0.7476300000000009, 0.7872150000000078, 1.6292250000000008, 1.5239250000000046, 2.081040000000012, 1.5611700000000077, 1.960530000000003, 1.5393300000000005, 1.1241750000000108, 0.9436050000000007, 0.5210400000000011, -0.5450250000000016, -1.361099999999995, -3.291600000000002, -4.808894999999999, -4.893719999999998, -4.790369999999999, -3.1609499999999975, -1.7733299999999983, -0.5902649999999978, 0.8012550000000109, 1.3187850000000099, 2.5088700000000053, 3.1416450000000253, 2.900820000000012, 3.548414999999995, 3.0622800000000066, 3.5505600000000133, 3.768375000000008, 3.7135800000000128, 3.661125000000002, 3.2358299999999893, 3.8857650000000135, 3.9364649999999983, 4.063019999999986, 3.5413949999999907, 2.985645000000007, 4.2022500000000065, 3.2976449999999957, 4.262310000000008, 3.7576500000000124, 3.9561599999999952, 4.165199999999995, 4.45848, 3.825315, 3.8104950000000013, 3.266444999999994, 4.332509999999985, 2.9546399999999977, 3.4011900000000086, 3.8508599999999973, 3.604964999999998, 3.8352600000000034, 3.8799150000000093, 4.796610000000008, 4.551689999999999, 3.293355000000009, 3.412890000000008, 3.647475000000007, 4.076670000000007, 3.7151399999999946, 2.889509999999998, 3.8842049999999997, 3.9011699999999916, 3.3625799999999977, 3.6730199999999957, 3.5254050000000063, 3.8791349999999927, 3.3161700000000174, 2.8095599999999976, 2.7093299999999942, 2.082795000000014, 2.0671950000000097], [0.0, 0.8677500000000022, 1.0249200000000003, 1.273155000000004, 0.6169800000000025, 0.7183800000000022, 1.3663650000000005, 1.148355, 1.420964999999998, 1.5420599999999993, 2.1019050000000004, 1.5510300000000004, 1.9402500000000016, 1.9930949999999998, 1.9008599999999984, 1.5547350000000004, 1.7080050000000049, 2.1606000000000045, 1.840604999999996, 1.8185699999999998, 0.8305050000000032, -0.2887949999999989, -0.7909199999999987, -1.3696799999999991, -1.2109499999999986, -1.0235549999999978, -0.3299399999999989, -0.3972149999999979, 0.19948500000000213, 0.3588000000000011, 1.2731549999999987, 1.360515000000003, 1.3965900000000007, 1.8445049999999998, 2.1356399999999978, 2.313284999999998, 2.678910000000006, 1.9503900000000005, 2.1818549999999997, 1.7758649999999983, 2.4999000000000007, 2.2510800000000004, 2.7668549999999974, 2.895164999999999, 2.84193, 2.973359999999993, 3.1307249999999986, 3.432975000000004, 3.378959999999998, 3.321045000000002, 3.353415000000006, 3.3148050000000056, 3.4811400000000057, 3.5376900000000115, 3.5918999999999977, 3.3138300000000034, 3.2135999999999965, 2.617679999999998, 3.3417149999999958, 3.2171099999999995, 3.226859999999998, 3.140669999999998, 3.5723999999999987, 3.023475, 3.1164900000000046, 2.791425000000001, 3.0291300000000025, 3.124875000000005, 3.149640000000001, 3.482309999999997, 3.7338600000000013, 3.2291999999999956, 3.3619949999999963, 3.611985000000001, 3.2151600000000005, 3.207750000000001, 2.73858, 2.7818700000000014, 2.5332450000000017, 2.254395000000002, 1.8665399999999988, 1.7982899999999988], [0.0, -0.3114149999999982, -0.011699999999999378, -0.5013449999999997, 0.2065050000000006, 0.05986500000000028, -0.1903199999999996, 0.45512999999999915, 0.573494999999999, 1.2823200000000003, 1.2290849999999982, 1.1602499999999996, 1.405559999999999, 1.6151850000000008, 1.2472200000000004, 1.2222599999999986, 0.9989849999999976, 0.043095000000000994, 0.6202950000000005, 0.3759600000000003, 0.31434000000000073, 0.8271899999999999, 0.7222799999999991, 0.9594000000000062, -1.9589699999999992, -3.8937600000000017, -4.4539950000000035, -4.228184999999998, -3.111615, -1.4892149999999995, -0.3238949999999994, 0.004290000000001237, 1.5395249999999976, 2.17932, 2.210519999999997, 2.1997950000000013, 1.9289400000000008, 2.1500699999999973, 1.5718949999999974, 2.0010899999999987, 1.884675, 2.412540000000001, 1.7384249999999968, 2.5646400000000016, 2.4404249999999994, 2.370810000000002, 2.213444999999996, 2.6837849999999985, 2.437304999999995, 2.6956799999999994, 2.3023649999999956, 2.749499999999993, 2.6182649999999983, 2.656290000000004, 2.318549999999992, 2.46948, 2.2520549999999973, 1.6674449999999976, 2.2265099999999975, 2.8033199999999967, 2.8990649999999984, 1.7785949999999984, 2.432234999999996, 2.2083750000000015, 2.2107149999999964, 2.5714649999999972, 2.2549800000000007, 2.3359049999999986, 2.0753849999999936, 2.002649999999995, 1.8238349999999928, 2.2382099999999996, 2.4006449999999973, 1.6916250000000002, 2.082209999999996, 2.064074999999994, 2.1292049999999962, 2.0003099999999994, 1.917435000000005, 1.4759550000000008, 0.9652500000000046, 0.7718099999999959], [0.0, 1.0126350000000026, 1.2698400000000003, 1.6450200000000008, 0.8347949999999997, 1.915290000000001, 0.8923199999999997, 1.6937700000000013, 1.7275050000000003, 2.737605000000002, 1.6374150000000018, 1.8117450000000026, 2.3136750000000013, 2.457585000000002, 1.1583000000000012, 1.8074550000000011, 1.9149000000000023, 2.6777400000000005, 1.2733500000000015, 1.3985399999999992, 0.8006700000000008, 0.3471000000000033, -1.4363699999999968, -1.4297399999999982, -2.201744999999998, -1.8797999999999984, 0.34495499999999923, 0.20436000000000099, 0.7731749999999974, 2.085720000000001, 2.255175000000001, 2.6853450000000016, 2.5539150000000013, 3.358485000000001, 4.623060000000003, 4.222920000000001, 3.672240000000002, 3.587024999999999, 4.1423849999999955, 3.5564100000000023, 2.889510000000002, 2.934750000000001, 3.8243399999999994, 3.6970050000000025, 4.127175000000002, 3.7455600000000002, 3.0384900000000017, 3.7603799999999996, 3.638699999999999, 5.282744999999997, 5.180565000000001, 4.876364999999999, 4.483635000000005, 4.54857, 4.048980000000001, 3.861975, 3.458520000000002, 3.7947000000000015, 2.579070000000001, 3.786900000000001, 3.863145000000001, 3.3555600000000014, 3.5452950000000025, 3.3315750000000017, 3.67458, 4.046834999999999, 3.9694200000000013, 4.439370000000003, 3.392025000000003, 4.628324999999999, 4.9580699999999975, 5.285085, 4.391205000000003, 4.742399999999998, 3.556410000000003, 3.2461650000000004, 4.1745600000000005, 3.9532350000000003, 3.3567299999999993, 3.095040000000002, 2.5106250000000023, 3.5913150000000016], [0.0, 0.3119999999999976, -0.17316000000000997, -0.39507000000000847, -0.6091800000000047, -0.44440500000000416, -0.36114000000000157, 0.059084999999997834, 0.585584999999992, 0.9950850000000093, 0.5709599999999933, 0.800084999999978, 1.4584049999999937, 1.4654249999999909, 1.7639700000000058, 1.1984699999999942, 1.5984149999999886, 1.5061799999999979, 0.8002799999999954, 1.316249999999994, 0.8312849999999905, 0.7573800000000048, 0.3412499999999934, -0.19012500000000543, -0.39058500000000596, -1.3057200000000018, -1.6933800000000065, -1.7906850000000043, -1.9143149999999993, -1.4379300000000006, -0.7501650000000124, -0.8958300000000046, -1.2333750000000059, -0.6897149999999934, 0.14761499999999828, 0.12401999999999891, 0.4471349999999994, 0.4089149999999977, 0.3779099999999964, 0.5391749999999984, 0.751920000000001, 0.8422049999999857, 0.16223999999999617, 0.49295999999999207, 0.8416199999999989, 0.9531599999999969, 0.9855300000000122, 0.4231499999999997, 0.7809750000000006, 0.9149400000000076, 0.8700899999999967, 0.7597200000000006, 1.2218699999999947, 1.5323099999999936, 0.7199399999999967, 0.8856900000000065, 0.9202049999999993, 0.7252050000000132, 1.0896600000000038, 1.783469999999996, 1.8333900000000112, 1.8341700000000074, 1.2327900000000014, 1.238834999999991, 1.888770000000009, 1.4500199999999897, 1.5637049999999952, 1.3548600000000022, 1.3880099999999995, 1.4439749999999885, 1.9749599999999923, 1.9815900000000033, 1.6847999999999956, 1.5445950000000028, 1.6407299999999951, 2.0800650000000127, 2.1763949999999905, 0.9213749999999932, 0.7454850000000066, 0.585975000000003, 0.7747349999999944, 0.09750000000000014], [0.0, 0.2802149999999992, -0.797940000000005, -0.7517250000000084, -0.11895000000001676, -0.647985000000002, -1.0822500000000028, -0.9541350000000008, -0.5598450000000037, -0.5134350000000119, 0.2911349999999846, 0.851564999999991, 0.37361999999999007, 0.5982599999999918, 0.5268899999999901, 1.0081500000000005, -0.42295500000000263, 0.43874999999999176, 0.6446699999999952, 0.3529499999999919, 0.35665499999998573, -0.106665000000012, -0.1567799999999986, -1.9858800000000052, -1.6124550000000104, -0.42958500000000743, -1.3780650000000083, -0.5284500000000083, -1.4424150000000147, -1.6890900000000126, -1.2086100000000073, -0.7737600000000135, -0.21469500000000163, 0.10295999999998795, 0.593969999999997, 0.007214999999997751, -0.10666500000001644, 0.5536049999999912, 1.0401299999999836, 0.050894999999992585, 0.5699849999999875, 0.6331649999999902, -0.03276000000000234, -0.42685500000000864, 0.019889999999995744, 0.032174999999996956, 0.20611500000000493, 0.13045499999999155, 0.9584249999999992, 0.053234999999992816, 0.25037999999998295, 1.3246349999999945, 0.9371699999999858, 0.26344499999998483, 0.5725199999999973, 1.5093000000000032, 1.9135349999999933, 1.6814849999999906, 1.632149999999986, 1.289924999999993, 1.075424999999984, 0.6780149999999923, 0.4991999999999903, 0.1624349999999959, -0.13260000000001604, 1.2390299999999819, -0.02106000000001007, -0.19539000000000506, 0.46312499999999446, 0.9059699999999946, 1.0155599999999971, 1.8181800000000008, 1.2616499999999915, 0.9820199999999959, 0.23672999999999522, 0.9584249999999948, 1.4238899999999974, 0.6189299999999944, 0.9369749999999915, 0.07721999999998275, 0.3476849999999905, 0.29717999999999645], [0.0, -0.1762799999999931, -0.4779449999999992, -0.7404149999999996, -0.6815249999999926, -0.7696649999999865, -0.6667049999999959, -0.3211649999999979, -0.5752499999999978, -0.14702999999999378, -0.5446349999999898, 0.4568850000000033, 0.37615500000000246, 0.5588700000000015, 0.7160400000000031, 0.6772350000000076, 1.125540000000008, 0.4982250000000068, 0.822510000000003, 0.9467250000000016, 0.4313400000000147, -0.1934399999999803, -0.620099999999991, -0.5171399999999968, -1.004640000000001, -1.0102949999999788, -1.7594849999999953, -2.110485000000007, -1.9162649999999966, -2.3737349999999955, -2.7179099999999954, -1.0485149999999974, -1.2444900000000017, -1.1138399999999846, -1.301040000000003, -0.5288399999999873, -1.309815000000003, -0.3999449999999962, -0.811980000000001, -0.38999999999998014, 0.23829000000001344, -0.32233500000000337, -0.06785999999998715, 0.2291250000000069, 0.49023000000001193, -0.5350799999999944, -0.33812999999999693, 0.2156700000000047, -0.11641499999999727, 0.12168000000000134, -0.37244999999999084, -0.3679650000000043, -0.48262499999999076, 0.49315500000001045, 0.4742400000000062, 0.2330250000000218, 0.41106000000001064, 0.5268900000000132, 0.38590500000000194, 0.20436000000001098, 0.17725499999999972, 0.059865000000012714, 0.1538549999999974, -0.13142999999999372, 0.29640000000001, 0.844545000000017, 0.797355000000004, 0.4063799999999995, 0.9112350000000147, 0.17901000000001321, 0.2145000000000028, 0.25545000000002016, 0.3621150000000046, 1.0021050000000047, 0.37713000000001173, -0.12109499999998707, 0.6805500000000064, 0.09399000000001134, 0.39331500000001185, -0.14468999999999, -0.24647999999999204, -0.5836349999999824], [0.0, 1.0058100000000003, 0.07741499999999801, 0.09593999999999636, 0.22502999999999695, 0.20553, 0.5988449999999972, 0.6489599999999989, 1.2899249999999958, 0.9806549999999987, 1.2795899999999993, 1.6073850000000003, 1.968525, 2.1722999999999963, 2.425604999999998, 1.6011450000000003, 0.9753900000000013, 1.6680299999999955, 1.6126499999999995, 1.8854549999999968, 1.6493099999999972, 0.9580349999999971, -0.06240000000000201, -0.0793650000000019, -0.31882500000000147, 0.21547499999999853, -0.37713000000000285, -0.9453600000000012, -0.6579300000000008, -0.6780150000000017, -0.41925000000000123, -0.20416500000000126, 0.1942199999999965, 0.6696299999999957, 1.0808849999999972, 0.6688499999999964, 0.882179999999996, 1.0691849999999974, 1.34062499999999, 0.5834399999999991, -0.10607999999999951, 0.792284999999997, 0.9129899999999989, 1.3511549999999954, 0.970124999999999, 0.8960249999999967, 0.6093749999999982, 0.5569199999999963, 1.177799999999995, 1.0373999999999994, 0.33013499999999896, 0.7347599999999983, 0.7643999999999997, 0.748799999999997, 1.2704250000000008, 1.0110749999999933, 1.3078649999999978, 0.9449699999999988, 0.9753899999999951, 1.1637599999999968, 1.3688999999999978, 1.0570949999999955, 1.2643799999999974, 0.9699299999999935, 0.9617399999999967, 1.0902449999999977, 0.8262149999999986, 1.0331100000000002, 1.1222249999999923, 1.4541149999999914, 2.1787349999999996, 2.3700299999999985, 1.0212149999999967, 1.570529999999998, 2.0621250000000035, 1.7473949999999951, 1.4858999999999951, 1.2273299999999994, 0.6066450000000025, 0.9568649999999996, 0.46390499999999957, 0.2757299999999969], [0.0, -0.1093949999999797, 0.335010000000004, -0.3119999999999852, 0.4543500000000016, -0.5986499999999904, 0.8911500000000121, 0.624195000000018, 0.17900999999999456, 0.5216250000000091, 1.314885000000018, 1.4186250000000111, 1.477320000000013, 1.8852600000000166, 1.6278600000000072, 2.081040000000012, 1.6588650000000058, 2.174054999999999, 2.6726700000000143, 2.4868349999999992, 2.1151650000000277, 2.108340000000002, 1.504815000000006, 1.0087350000000175, 0.018525000000000347, 0.213720000000027, -1.212899999999987, -0.8841299999999936, -1.5075449999999888, -0.9398999999999837, -1.375334999999998, -0.9675899999999826, -0.8917349999999944, -0.06103499999999862, 0.045630000000011606, -0.785849999999984, -1.358369999999991, -0.6667049999999985, -0.8537099999999898, -0.17335499999998305, -0.6255599999999983, 0.3484650000000151, -0.23926499999999606, -0.9371699999999876, -0.7392450000000022, -0.2716349999999963, -0.10939499999997793, -0.9118199999999934, 0.11388000000002307, -0.3014699999999948, 0.8289450000000134, 0.9005100000000112, 0.3314999999999966, 0.9726600000000065, 0.4529850000000071, -0.25194000000000116, 0.8502000000000152, 0.7014150000000061, 0.5013450000000201, 0.35782500000000006, -0.0023399999999842436, 0.8359650000000052, 1.0984350000000145, 0.8392800000000076, 0.44635500000002004, 0.5148000000000135, 0.3116099999999964, 1.2503400000000173, 1.1776050000000247, 0.7010250000000102, 1.3341900000000155, 0.8981700000000199, 0.8180250000000395, 1.387230000000022, 1.5845700000000011, 1.7739150000000024, 0.7704450000000129, 0.9256649999999897, 0.44128500000001303, 0.8991450000000079, 1.1499150000000018, 0.8498100000000104], [0.0, 0.5247449999999996, -0.04114500000000004, -0.5797350000000002, 0.3777149999999995, 0.45746999999999977, 0.10100999999999936, -1.00035, -1.0391549999999996, -0.44518499999999983, 0.2757299999999995, 0.6532499999999991, 0.9338549999999998, 0.8386950000000001, 0.49373999999999946, -0.01872000000000032, 0.8447399999999989, 0.5606249999999984, 1.0504649999999984, 0.45006000000000085, 0.6977099999999995, 0.44225999999999993, -0.2634450000000002, -0.6906900000000004, -0.1209000000000002, -0.3478800000000005, -0.522990000000001, -1.122615000000001, -0.919815000000001, -1.2236249999999997, -1.2571650000000003, -1.8593250000000012, -0.8441550000000001, -0.6912749999999998, -0.8080800000000005, -0.6171750000000004, -0.5797349999999999, -0.2950350000000006, -0.02691000000000056, -0.09886500000000029, 0.044264999999999485, -0.15463500000000002, -0.8776950000000003, -1.106625, -0.5489250000000007, -0.7199399999999996, -0.9402899999999998, -0.39721500000000026, -0.501539999999999, -0.38531999999999966, -0.6275100000000012, 0.02183999999999954, 0.15755999999999976, -0.1560000000000006, -0.4015050000000013, -0.3685500000000005, -0.27709500000000026, 0.7074599999999994, 0.4003349999999993, 0.003509999999999, 0.6165899999999993, 1.051634999999998, -0.07702500000000027, 0.24413999999999947, 0.3385199999999996, 0.29054999999999925, 0.35704499999999956, 0.2228849999999999, -0.486720000000001, -0.33462000000000064, 0.20962499999999895, -0.6723600000000005, -0.3603600000000004, -0.16477500000000056, 0.009359999999999535, 0.2045549999999997, 0.1916849999999996, -0.3471000000000001, -0.02086500000000055, -0.2880150000000006, -0.13533000000000034, -0.0830700000000008], [0.0, 0.21761999999996817, -0.7263749999999973, -0.14215500000001668, -0.6940050000000326, -0.07195500000001687, -0.47151000000007315, -0.7096049999999678, -0.9258600000000143, -1.2066599999999994, -0.0491400000000084, 1.039349999999942, 0.7131150000000801, 1.3306800000000436, 0.7185750000000013, 1.061580000000042, 1.5642899999999784, 1.7473950000000116, 1.6307849999999746, 1.0262849999999943, 1.2889499999999998, 0.9800700000000333, 0.7727849999999918, -0.7478249999999278, -0.5963100000000381, -0.25974000000000785, -0.47736000000003287, -0.6635850000000616, -0.5294250000000105, -0.4330950000000584, -1.2207000000000932, -0.31278000000005335, 0.010529999999981499, -0.36562500000002984, -0.3445649999999745, -0.0776100000000639, -0.3090750000000355, -0.8396699999999768, -0.9083100000000357, -0.30810000000002447, -0.7583550000000656, -0.21254999999999313, -1.0826400000000191, -0.17608499999999339, -0.03334500000006102, -0.5656950000000336, -0.4227600000000109, -1.2671100000000663, -1.0317450000000221, -0.8494200000000802, -0.7530899999999932, -0.5128500000000287, -0.5809050000000369, 0.46565999999998553, 0.0659099999999242, 0.01813500000005064, -0.415350000000025, -0.07156499999996413, -0.29581500000008276, -1.0284300000000783, -0.8697000000000301, -1.0475399999999695, 0.13182000000004734, -0.6737250000000046, -0.25525500000013324, 0.8470799999999699, 0.1372800000000609, -0.1696500000000185, 0.7694699999999344, -1.0071750000000108, 0.9537449999998984, 0.6509099999999535, 0.61327500000003, -0.021255000000081736, 0.14741999999998256, 0.9865049999999513, -0.3355950000000547, 0.3120000000000118, -0.26987999999996504, -0.09243000000000023, -0.9629100000000506, -0.515385000000002], [0.0, 0.1556100000000007, 0.23302500000000026, 0.10627500000000023, 0.6971250000000004, 0.8950500000000001, 0.7294950000000003, 0.40501500000000007, 0.73242, 0.38512500000000044, 0.375375, 0.9418500000000016, 0.4960800000000004, 0.9876750000000003, 1.7676749999999999, 1.2651600000000005, 0.8626800000000003, 1.4390999999999998, 2.1912150000000015, 1.1085750000000005, 1.626885000000002, 2.056275, 0.9779250000000004, 0.08073000000000002, 0.3738150000000001, -0.36074999999999946, -1.303185000000002, -0.3248699999999989, -1.4835599999999984, -1.059045, -1.7791799999999998, -0.8149050000000002, -1.4636700000000005, -0.45883500000000044, -0.6992700000000016, -0.39565499999999953, -1.129245, -0.5442450000000003, -0.4077450000000009, 0.14098500000000147, -1.0481249999999984, -0.2326349999999986, -0.917475000000002, -0.9492599999999982, -0.3211649999999995, -0.7265699999999993, -0.6659249999999994, -1.2179699999999998, -0.9572550000000024, -0.09867000000000059, -0.08306999999999987, 0.012285000000000657, 0.42841500000000016, -0.5902650000000005, -1.0740600000000016, -0.992549999999998, -0.4481099999999977, 0.09204000000000034, -0.4315349999999989, -0.47716499999999984, -0.9683699999999977, -1.2963600000000017, 0.1875900000000001, 0.05752499999999999, -0.1630199999999996, -0.302640000000001, -0.41690999999999945, 0.40872000000000047, 0.49335000000000023, 0.22113000000000038, 0.687375, 0.35841000000000034, -0.1429349999999996, 0.9258600000000021, 1.0409100000000011, 0.6460350000000004, 0.4518150000000004, 0.36699000000000037, 0.6052800000000004, 0.38844000000000034, 0.33579000000000037, 0.9555000000000013], [0.0, 0.16087499999999721, 0.6456449999999985, -0.0672750000000013, -0.05713500000000038, -0.14157000000000108, -0.34846500000000113, -0.1792050000000004, -0.3408600000000013, 0.6828899999999987, 0.8090549999999994, 0.2991299999999981, 0.8024249999999984, 0.5807099999999987, 0.7944299999999982, 0.17744999999999833, 1.390545, 1.2462449999999956, 1.2306450000000018, 1.8150599999999955, 1.0970699999999978, 0.9816299999999982, 1.286219999999998, 0.8605350000000007, 0.4364099999999991, -0.4490850000000012, -0.9365850000000014, -1.769235000000002, -1.8043350000000022, -1.4026350000000016, -1.3474500000000011, -2.140320000000001, -1.5678000000000012, -1.1337300000000012, -1.3386750000000012, -1.4905800000000016, -1.505205000000001, -1.5851550000000014, -1.3439400000000008, -1.1783850000000013, -1.412580000000001, -0.7059000000000002, -0.8439600000000012, -0.9652500000000009, -1.1058450000000015, -0.7850700000000016, -1.2988950000000008, -1.2981150000000015, -0.8833500000000011, -1.4954550000000009, -1.145625000000001, -0.9987900000000012, -1.4248650000000014, -1.0075650000000012, -0.8371350000000013, -0.29269500000000126, -0.7813650000000013, -0.8628750000000012, -0.6959550000000013, -1.254435000000001, -0.5241600000000014, -0.8691150000000012, -0.7942350000000009, -0.9303450000000011, -1.2507300000000012, -1.538745000000001, -0.8952450000000012, -0.8628750000000008, -0.9677850000000016, -0.7597200000000015, -1.0159500000000015, -1.1421150000000007, -0.5602350000000008, -0.772200000000001, -0.5280600000000015, 0.24082500000000184, 0.09691499999999875, 0.0992549999999981, -0.28918500000000136, -0.4492800000000027, -0.3414450000000019, -0.38395500000000116], [0.0, -0.17062499999999714, 1.1062349999999959, 1.1885249999999976, 0.9422399999999973, 1.083029999999999, 0.9159149999999983, -0.5553599999999972, 0.32175000000000065, 0.5929950000000002, 0.3919499999999978, 1.0894649999999992, 1.963454999999998, 0.3094649999999963, 1.0106849999999952, 0.7154549999999977, 1.2429300000000003, 0.4796999999999989, 0.24140999999999702, 0.2663700000000051, 0.3211649999999997, 0.9383400000000006, -0.15931499999999854, 0.1290899999999957, 0.1318200000000025, 0.3872700000000022, -0.3995549999999932, -0.7324200000000007, -1.3238549999999951, -1.1035049999999997, 0.07468500000000144, -0.12792000000000137, 0.2685149999999976, 0.3617250000000021, -0.25096499999999855, 0.0643499999999988, -0.8211450000000036, -0.4551299999999996, -0.6382349999999986, -0.5762250000000027, -1.6771950000000078, -0.2827500000000005, -0.03354000000000079, -0.45454500000000264, -0.7854599999999983, 0.12674999999999947, 0.008580000000001586, -0.12148500000000118, -0.16672500000000356, -0.21645000000000403, -0.7792200000000036, -0.09535499999999741, -0.22113000000000316, -0.04991999999999841, 0.3972149999999952, -0.6819150000000005, -0.26285999999999854, -0.4601999999999986, 0.46331999999999907, -1.072500000000003, -0.6916650000000018, -0.05752500000000005, -0.7874099999999946, -0.239849999999997, 0.2872350000000021, -0.27182999999999646, 0.18466499999999808, -0.48886499999999566, -0.31219500000000044, 0.6838649999999977, 0.5192849999999982, -0.15015000000000134, 0.6768449999999966, -1.0791300000000006, -2.0531550000000096, 0.14936999999999667, 0.3582149999999973, 0.6327749999999952, -0.8560499999999975, -0.7511399999999999, 0.07624500000000012, -0.11465999999999887], [0.0, -0.25544999999999973, -0.5530200000000014, -0.8168550000000017, -0.41866500000000006, -0.14078999999999997, -0.09750000000000081, 0.20923499999999984, 0.2326349999999996, -0.15658499999999953, -0.13669500000000046, 0.36406499999999964, 0.21859499999999887, 0.2622749999999987, 0.08365499999999926, 0.16964999999999875, 0.38473499999999927, 0.40618499999999935, 0.7659599999999996, 1.4016599999999992, 1.2228449999999995, 0.8954399999999998, 0.9114299999999997, 0.49159499999999956, 0.26597999999999977, 0.04952999999999996, -0.6249750000000007, -1.0500750000000016, -1.9221149999999996, -1.2786149999999996, -1.7731349999999997, -1.148355000000002, -0.9619350000000011, -1.4535299999999995, -1.1189099999999985, -1.1967150000000009, -1.3256099999999977, -1.1752649999999998, -1.1097450000000013, -0.9053850000000034, -1.2010050000000005, -0.5481450000000003, -1.7005950000000027, -1.2554100000000037, -0.9455549999999986, -0.8679449999999995, -1.255410000000001, -1.5744299999999989, -0.9122100000000002, -1.141140000000003, -1.1639550000000025, -1.577550000000003, -1.3831349999999987, -1.1727300000000025, -0.9042149999999998, -0.9469199999999989, -1.3080600000000009, -0.9933300000000016, -1.065675, -1.3503749999999999, -1.642874999999999, -1.2940200000000026, -1.0245299999999988, -0.9024600000000012, -0.7780499999999981, -0.9985950000000035, -0.3968250000000002, -0.6971249999999989, -0.5493150000000033, -0.7232549999999991, -0.7411949999999998, -0.25915500000000247, -0.36835500000000043, -0.8611200000000001, -1.0719150000000013, -0.24004499999999962, 0.030224999999999613, -0.7166249999999996, -0.5727149999999988, -0.778245000000001, -0.5368350000000015, -0.7181850000000021], [0.0, 0.024764999999998594, 0.04738499999999668, 0.7043399999999984, 0.15619499999999498, 0.03665999999999858, 0.7142849999999994, 0.45746999999999627, 0.495495, 0.4576649999999933, 0.1637999999999975, 0.7604999999999968, 1.2846599999999988, 0.4709249999999958, 0.0077999999999915914, 0.5812949999999972, 1.5305550000000032, 1.2489749999999917, 1.798485000000003, 2.0679749999999983, 1.8207150000000003, 1.3388700000000036, 1.8146699999999973, 1.214070000000003, 1.3404300000000031, 0.4660499999999983, -0.22035000000000338, -0.22366499999999867, -0.7269599999999992, -1.4888250000000056, -0.7119450000000036, -1.1232000000000006, -0.9036300000000077, -0.4486949999999972, -0.7874100000000039, -0.5935800000000064, -0.6860100000000031, -0.8320650000000089, -1.155375000000018, -0.9326850000000091, -0.907139999999993, -0.7665449999999963, -0.28762500000000024, -0.38434499999999705, -0.908504999999999, -1.411020000000005, -1.631174999999999, -0.9956700000000032, -1.0964850000000004, -0.6279000000000048, -1.068209999999996, -0.9360000000000035, -0.8024250000000119, -0.7876049999999992, -1.199445000000006, -0.4761900000000061, -0.7146750000000086, -1.2805650000000028, -1.3242450000000137, -1.3267800000000145, -1.0190700000000081, -0.5736900000000089, -0.9231300000000031, -1.5642900000000086, -1.1563500000000078, -0.7137000000000038, -0.19617000000000662, -0.8796450000000062, -0.9287849999999986, -0.8599500000000013, -0.8246550000000052, -0.3071249999999992, -0.4013100000000023, 0.20182500000000658, 0.02729999999999677, -0.09437999999999391, 0.08014499999999813, -0.4463550000000023, 0.009749999999999481, 0.04524000000000239, -0.22522499999999912, -0.7544550000000054], [0.0, -0.5304, -0.4022849999999998, -0.2729999999999997, -0.42607499999999954, 0.33208500000000046, 0.20904000000000045, 0.0505049999999999, -0.3640649999999994, 0.21040500000000004, 0.524745, 0.5565299999999997, 0.3788850000000007, 0.7445100000000009, 0.8784750000000001, 0.5407350000000002, 0.6015750000000001, 0.6813300000000001, 0.2031900000000002, 0.44538000000000033, 0.3597750000000003, -0.18602999999999978, -0.21859499999999862, -0.40403999999999884, -0.12343499999999977, 0.4588350000000001, -0.4925700000000002, -0.502514999999999, -0.24862499999999974, -0.6087900000000007, -0.4777500000000008, -0.585975, -0.017939999999999845, -0.27026999999999946, 0.38688000000000017, 0.28723500000000035, 0.8147099999999987, 0.54132, -0.0984750000000005, 0.3868800000000002, 0.3617250000000002, 0.9083100000000002, 0.7558200000000005, 0.33072, 0.4034550000000003, 0.0206700000000003, -0.41457000000000044, -0.2170349999999989, -0.04796999999999929, 0.18427500000000008, -0.3293550000000002, 0.10373999999999975, -0.5575049999999985, -0.44089500000000015, -0.3274049999999994, -0.3773249999999999, 0.24959999999999943, -0.2297100000000001, -1.000155, -0.22561500000000004, -0.3564599999999999, -1.187745000000001, -0.7909199999999993, -0.7708349999999992, -0.6041099999999993, -0.9094800000000018, -0.5690099999999999, -0.5738850000000003, -0.20845499999999975, -0.10666499999999937, 0.6167850000000006, 0.17667000000000047, -0.3406649999999989, 0.5198699999999998, 0.5036850000000002, 0.13552499999999984, 0.15093000000000018, -0.3038100000000007, -0.20630999999999958, -0.40793999999999964, -0.4654650000000007, -0.04777499999999987], [0.0, 0.02008500000000013, 0.14468999999999932, 0.2825550000000008, 0.28041000000000205, 0.6612450000000014, 0.36055499999999885, 0.5771999999999999, 0.3404700000000007, 0.4178849999999996, 0.24472500000000075, 0.5688149999999994, 0.28548000000000195, 0.41164500000000137, 0.5081700000000033, 0.7868250000000039, 0.4574699999999998, 0.9270299999999998, 0.5559450000000017, 1.0763999999999974, 1.0861499999999982, 1.1282699999999948, 0.7402200000000021, 0.84903, 0.5682300000000025, 0.37732499999999636, 0.11017499999999925, 0.09418500000000041, 0.11856, 0.14196000000000075, -0.5487299999999995, -0.08346000000000031, -0.5658899999999991, -0.6891299999999978, -0.09574500000000041, -0.04952999999999852, -0.589289999999999, -0.40150500000000156, -0.3160949999999978, -0.5155800000000019, -0.5933849999999987, -0.6060600000000003, -0.09418500000000085, -0.15346500000000152, 0.5575050000000035, 0.05733000000000055, -0.6456450000000002, -0.8135399999999988, -0.75231, -0.913574999999999, -0.9736349999999994, -0.9537449999999993, -1.1118899999999994, -0.8913450000000002, -0.8956349999999985, -0.3281849999999997, 0.09340500000000218, -0.18992999999999793, -0.3190199999999994, -0.22717499999999768, -0.09477000000000002, -0.5050499999999998, -0.22229999999999994, -0.567645, -0.4568850000000009, -0.40169999999999817, -0.7111649999999983, -0.7528949999999988, -0.5879249999999987, -0.36621000000000103, -0.8392799999999988, -0.23906999999999834, -0.23263499999999815, -0.03978000000000104, 0.10764000000000151, -0.10861499999999813, -0.3412500000000003, -0.45707999999999727, 0.031199999999999672, -0.0271050000000006, -0.26968500000000084, -0.3964349999999981], [0.0, -0.8751599999999979, -0.2519400000000034, -0.1084200000000064, -0.023985000000006362, -0.38824500000000084, -0.22873500000000302, -0.9404849999999971, -1.1475750000000002, -0.3642599999999998, -0.06513000000000657, -0.5300100000000061, -0.17764500000000982, -0.32623500000000494, -0.6411600000000064, -0.14020500000000213, -0.18252000000000468, -0.5309850000000065, -0.7002450000000042, -0.29620500000000405, 0.4947149999999958, -0.34788000000000396, 0.015989999999995508, -0.10803000000000429, -0.6807450000000008, -0.424515000000004, -0.46488000000000174, -0.6756750000000067, -0.10335000000000472, -0.1733550000000048, -0.7010250000000036, -0.06981000000000304, -0.4611750000000039, -0.45376499999999975, -0.4399200000000074, -0.7205250000000039, -0.5124600000000052, -0.5820750000000019, -0.7725900000000001, -0.9804599999999968, -0.9498450000000065, -1.7770350000000041, -1.9338150000000018, -1.7514899999999987, -0.17764500000000272, -1.018095000000001, -1.1559599999999968, -0.8470800000000054, -0.37420499999999945, -0.9009000000000023, -0.8808150000000028, -1.533284999999998, -1.6514549999999986, -1.194375000000003, -1.107015, -0.7640100000000016, -0.7505549999999994, -1.0352550000000011, -1.5405000000000033, -0.9833849999999984, -1.488630000000001, -1.6348800000000043, -1.0372050000000006, -0.8408400000000045, -0.8511750000000027, -0.05538000000000043, -0.6682649999999981, -0.5680350000000001, -1.0611900000000007, -0.7039500000000047, -1.1423100000000033, -0.8211449999999987, -0.815685000000006, -0.5339100000000077, -0.6290700000000027, -1.1152049999999978, -0.3166800000000056, -0.9623250000000039, -0.6604650000000034, -0.9003150000000009, -1.3166399999999943, -1.8558150000000007], [0.0, -0.08482500000000748, -0.3716699999999955, -0.05362499999999493, 0.6160050000000004, 0.5918249999999974, 0.2889900000000001, 0.13182000000000205, 0.15112500000000484, 0.04601999999999684, 0.7532849999999902, 0.21313499999999763, 1.8491850000000003, 1.1349000000000062, 0.08638499999999727, 0.1132950000000097, 1.0955100000000098, 1.0134150000000073, 1.213484999999996, 0.7599150000000083, 1.2889500000000016, 0.8135400000000059, 0.8390849999999963, 0.9816300000000053, 0.6128850000000119, 0.6842549999999994, 1.0840049999999959, 0.8215349999999937, 1.286805000000002, 1.3517399999999995, -0.08931000000000289, -0.2049449999999986, -0.46293000000000006, -0.9250800000000012, 0.0419249999999991, 0.39857999999999993, 0.5116799999999992, -0.0015600000000031145, -0.5344949999999988, 0.6963449999999956, 0.2078699999999989, 0.29172000000000775, -0.23068499999999847, -0.3607499999999968, -1.011075000000007, -0.39234000000001146, -0.4993950000000096, -0.15853499999999965, 0.0007799999999935636, -0.14098500000000502, 0.6091800000000074, 0.40092000000000017, 0.1673100000000023, -0.2279550000000059, -0.03724499999999331, -0.3238949999999985, -0.0341249999999933, -0.26773499999999206, 0.11972999999999612, 0.3970199999999968, -0.1392300000000004, -0.09983999999999416, -1.387035, -0.973440000000009, -0.28177499999999167, -0.6294599999999981, -0.3266250000000097, -0.5633550000000023, -0.6628050000000032, -0.17959499999999817, 0.6959549999999961, 0.925079999999995, -0.05752500000000005, 0.4960800000000045, 0.5998199999999985, -0.10608000000000217, -0.01599000000000661, -0.11543999999999865, 0.39585000000000026, 0.34885499999999503, -0.6460350000000092, -1.1093550000000025], [0.0, -0.6093749999999929, -0.8847150000000035, -0.4617599999999946, -0.326429999999986, 0.2868450000000049, 0.2205450000000191, -0.25388999999999307, 0.021840000000016957, 0.055965000000011145, 0.41496000000000777, 0.0766350000000191, -0.3646499999999886, -0.8463000000000003, 0.011115000000014419, -0.5760300000000012, -0.3827849999999966, -0.21839999999998838, -0.10295999999998884, 0.1521000000000079, -0.05245499999998238, -0.29386499999999316, -0.57681, -0.2733899999999956, -0.36913499999998933, -0.17296499999998716, -0.9556949999999995, -0.6201000000000008, -0.4065749999999859, -0.4221750000000011, -0.3523649999999936, -0.7183800000000042, -0.37128000000000405, -0.662609999999999, -1.5130049999999917, -1.2171899999999924, -1.023164999999989, -1.3827449999999963, -1.5982199999999995, -0.8897849999999972, -1.1035050000000028, -1.1192999999999964, -1.0721099999999932, -0.9143549999999943, -0.842594999999994, -0.6823049999999817, -0.48164999999997704, -1.042860000000001, -0.5834399999999906, -0.5666699999999807, -0.5777849999999969, -1.08927, -1.1565449999999906, -1.2086099999999966, -0.981239999999997, -0.507974999999993, -0.76966499999999, -1.6202549999999922, -1.3090349999999917, -0.9872850000000009, -1.2312299999999876, -1.462110000000008, -1.211144999999993, -1.1815049999999898, -0.7138949999999911, -0.7762949999999824, -0.15989999999998794, -0.22502999999999496, -0.7673250000000023, -0.7768800000000002, -0.3981899999999925, -1.1294400000000069, -0.8554649999999908, -1.0492949999999945, -1.163954999999997, -0.7174049999999959, -0.3929249999999911, -1.4229149999999997, -0.7129200000000067, -0.34261499999999856, 0.07254000000001071, -0.6589049999999954], [0.0, -0.47092499999999893, -0.8289449999999983, -0.35334000000000154, 0.06103499999999418, -0.42529499999999887, -0.19441500000000023, 0.014819999999997169, 0.005654999999995081, -0.19811999999999985, 0.07409999999999917, 0.055964999999998266, -0.6522749999999977, -0.5734950000000003, -0.8221199999999982, -0.6200999999999999, -0.6756749999999996, -0.40403999999999796, -0.6565649999999961, -0.23302500000000226, -0.1889549999999991, 0.06649499999999797, -0.4596149999999959, -0.37576499999999813, -0.5116799999999992, -0.38395500000000027, -0.7796100000000017, -0.3956550000000014, -0.5434649999999981, -0.27728999999999626, -0.579345000000004, -0.8595599999999988, -0.6475949999999995, -0.6546149999999966, -0.7337849999999979, -1.0990199999999999, -0.5547749999999998, -0.8634600000000008, -0.5413199999999971, -0.7743450000000034, -0.7064850000000007, -0.48301499999999953, -0.38649000000000067, -1.202954999999997, -1.2056850000000017, -1.3924949999999976, -1.4197949999999988, -1.2366899999999976, -1.4467049999999984, -0.9687600000000014, -1.3899599999999999, -1.1251499999999988, -1.2673050000000017, -1.5925649999999982, -1.1035049999999957, -0.37908000000000186, -0.5709599999999981, -0.7279350000000004, -1.1335349999999997, -1.434225, -1.3544699999999974, -1.5332849999999951, -1.2752999999999965, -1.1475750000000002, -0.754650000000002, -1.4463149999999976, -1.5406949999999993, -1.2226500000000011, -0.659490000000003, -0.5970900000000028, -0.7043399999999993, -1.1395799999999974, -1.2405899999999948, -1.1590799999999963, -1.461914999999998, -0.9127950000000005, -0.9572549999999986, -0.9572550000000009, -1.0691849999999956, -1.564484999999999, -0.7343700000000046, -1.134900000000004], [0.0, 0.14468999999999888, 0.6633900000000001, 0.4256849999999961, 1.1483549999999956, 1.214459999999999, 1.2985049999999978, 1.6118699999999966, 1.6730999999999994, 0.9365849999999987, 1.6194749999999964, 0.822509999999999, 0.5335200000000015, 0.1803749999999953, 0.5929949999999962, 0.7355399999999976, -0.15054000000000123, -0.11134499999999559, 0.5970899999999961, 0.407354999999995, 0.6273150000000034, -0.10218000000000194, -0.9814350000000003, 1.2577500000000068, -0.08267999999999764, 1.0313550000000054, 0.8907599999999976, 0.5112899999999985, -0.1809599999999989, -0.25116000000000316, 0.6446699999999983, 0.7113599999999987, 0.5680349999999987, 1.0914150000000014, 0.860534999999996, 0.7901400000000027, 0.7277399999999994, 1.2614549999999958, -0.19402499999999856, -0.1868099999999986, 0.009749999999997705, -0.5900699999999999, -0.41457000000000166, 0.3962399999999988, 0.4857450000000041, 0.017355000000002896, -0.06961500000000198, 0.3094649999999999, 0.5961149999999984, 0.656759999999998, 1.023945000000003, 0.8609249999999955, -0.36523500000000153, 0.3047849999999981, -0.6850349999999998, -0.1086149999999999, -0.1907100000000015, -0.3199949999999978, -1.6116750000000004, -0.8156849999999995, -0.3547049999999996, 0.00935999999999737, -0.10998000000000197, 0.6571499999999979, -0.09496499999999708, 0.12460500000000385, -0.11505000000000054, 0.5927999999999969, 1.1440650000000003, 0.5358599999999973, 0.6085950000000033, -0.042510000000000936, 0.30342000000000224, 0.239460000000002, 0.3586050000000003, -0.09691500000000319, 0.3757649999999977, 1.1994450000000003, 0.6282899999999998, 0.4839900000000008, -0.6039150000000015, -0.04758000000000173], [0.0, 0.2109900000000009, 0.1916850000000021, 0.317265000000001, 0.6278999999999983, 0.28820999999999963, 0.42802499999999744, -0.04874999999999918, 0.3143400000000012, 0.21021000000000067, 0.3966299999999976, 0.5272799999999986, 0.3855150000000005, 0.24570000000000092, 0.022229999999998418, 0.27923999999999904, 0.0649349999999993, -0.04309499999999966, 0.33169499999999874, -0.07195500000000221, 0.16341000000000006, 0.30536999999999703, 0.568814999999997, 0.7657649999999989, 0.6992700000000001, 0.4603949999999981, 0.03470999999999713, 0.026520000000000987, 0.33266999999999824, 0.32915999999999923, 0.04640999999999851, -0.19656000000000007, -0.0471900000000014, -0.20923500000000006, -0.15015000000000223, -0.322919999999999, -0.18193499999999885, -0.14117999999999875, -0.3915600000000006, -0.3535350000000028, -0.5249400000000004, -0.5908500000000017, -0.2412149999999995, -0.30420000000000247, -0.18583499999999753, -0.18330000000000046, 0.07936500000000168, -0.29211000000000253, -0.21625499999999764, -0.1187550000000015, 0.0473850000000009, -0.19753499999999935, -0.1829099999999979, -0.4301699999999984, -0.03666000000000169, -0.3995549999999999, -0.32194500000000237, -0.10705500000000345, -0.24453000000000036, -0.22229999999999972, -0.8872500000000012, -0.8219249999999996, -0.6622199999999996, -0.19578000000000073, -0.19344000000000228, -0.30478499999999964, -0.08287499999999937, -0.11973000000000167, -0.34358999999999895, -0.20045999999999653, -0.07156500000000277, -0.4395300000000004, -0.09594000000000258, -0.4543499999999987, -0.14878499999999906, -0.5389799999999998, -0.48886499999999944, 0.024180000000001645, -0.2310749999999986, -0.33929999999999816, 0.1267499999999997, 0.37050000000000005], [0.0, 0.02593499999999871, -0.2129399999999957, -0.05986499999999895, 0.04894500000000557, 0.38922000000000345, 0.08560500000000282, -0.20981999999999967, 0.1638000000000046, -0.011114999999996655, 0.3488550000000097, 0.5641349999999994, 0.25447499999999934, 0.11368500000000736, -0.020084999999995468, -0.6000150000000009, -0.4098899999999981, -0.3155099999999984, -1.2226499999999962, -1.230059999999995, -0.6333599999999966, -0.7174049999999963, -0.8804250000000002, -0.760694999999993, -0.30615000000000014, -0.7055099999999959, -0.744314999999999, -0.4637099999999985, 0.18739500000000797, -0.14117999999999897, 0.08112000000000164, 0.13533000000000195, -0.06805499999999576, 0.13825500000000357, 0.129674999999998, -0.3704999999999963, -0.5978699999999977, -0.060449999999999005, -0.9274199999999975, -0.40072499999999867, -0.04172999999999716, -0.10978499999999869, -0.758549999999997, 0.1454700000000022, -0.0914550000000025, 0.5220149999999988, -0.2733899999999956, -0.31901999999999786, 0.12090000000000467, -0.01091999999999782, -0.15307499999999852, -0.3077099999999988, -0.35977499999999685, -0.3274050000000015, -0.23672999999999567, -0.10510499999999379, -0.0015599999999995617, -0.8702849999999942, -0.7993049999999968, -0.8363549999999975, -1.0637249999999954, -1.5063749999999954, -0.7515299999999954, -1.3373099999999947, -0.7484099999999967, -0.6971249999999976, -0.8634599999999977, -0.4937399999999945, -0.2626649999999935, -0.5058299999999973, -0.22249499999999944, 0.2932800000000051, 0.08833500000000427, -0.20358000000000054, -0.16106999999999516, -0.06337499999999752, -0.4660500000000001, -0.34534499999999513, -0.690884999999998, -1.0216049999999983, -0.9482849999999967, -1.3788449999999957], [0.0, 0.663975, 0.4270500000000004, 0.6062550000000001, 0.20747999999999966, 0.2460899999999998, 0.7879949999999999, 0.2223000000000006, 0.7127250000000004, 0.9285900000000001, 0.34183499999999956, 0.598845, 0.5711549999999999, 0.74997, 0.4670249999999999, 0.7273500000000004, 0.27280500000000063, 0.29308500000000126, 0.46917, 0.4738500000000001, 0.694005, 0.7293000000000004, 0.2527200000000004, -0.018525000000000458, 0.104715, 0.465855, 0.8386949999999997, 0.9902099999999999, 0.030810000000000115, -0.019890000000000185, 0.24160499999999863, -0.05460000000000065, 0.014624999999999777, 0.5892899999999996, 0.4896450000000001, 0.5214300000000004, 0.2302949999999997, 0.06337500000000007, 0.9779249999999998, 0.5680350000000001, -0.062009999999999676, 0.024375000000000036, 0.19032000000000027, 0.6867900000000006, -0.07117499999999954, -0.2349750000000006, -0.36016500000000073, 0.27826500000000065, -0.06239999999999957, -0.13318500000000055, 0.05225999999999964, 0.31336499999999967, 0.18797999999999937, 0.2866500000000002, -0.08345999999999965, -0.18524999999999858, -0.15365999999999924, 0.4635150000000001, 0.012479999999999492, -0.14722499999999972, -0.5456099999999975, -0.2763150000000014, -0.14527500000000182, 0.6797700000000007, -0.10900500000000113, 0.9504300000000001, -0.03529500000000119, -0.38454000000000166, -0.5073900000000007, -0.3001050000000014, 0.5206500000000001, 0.3981900000000004, 0.26481, -0.13786499999999946, -0.32565000000000044, -0.027690000000002213, -0.18895499999999843, -0.14157000000000042, 0.20202000000000087, 0.4547399999999999, 0.31161000000000016, 0.4276350000000002], [0.0, 0.3821999999999994, 0.8361599999999993, 0.6762600000000012, 0.25973999999999986, 0.24394500000000002, 0.0491400000000001, -0.11583000000000036, 0.0906749999999994, 0.5227950000000001, 0.17023500000000003, 0.2166450000000001, 0.4787249999999997, 0.34475999999999934, 0.35606999999999955, 0.29171999999999965, 0.548535, -0.03295499999999996, 0.3272099999999998, 0.4434299999999996, -0.24959999999999993, -0.3825900000000004, -0.49783499999999936, -0.17082000000000003, 0.2166450000000001, -0.20904000000000003, -0.43602000000000024, 0.09165000000000006, 0.27826500000000026, -0.00546000000000002, -0.19695000000000007, -0.2277600000000003, 0.28158000000000016, -0.0625950000000004, -0.01560000000000035, -0.2068950000000007, -0.13591500000000037, -0.1400100000000002, -0.24257999999999996, -0.19227000000000039, -0.24472500000000036, -0.42315000000000047, -0.5935799999999996, -0.4666349999999997, -0.596895, -0.2852850000000002, 0.01969499999999967, 0.005459999999999868, 0.03295499999999969, 0.43523999999999935, 0.00448499999999992, 0.4486949999999991, -0.1589250000000002, -0.7601099999999996, -0.13786500000000032, -0.9192300000000007, -0.9449700000000001, -0.8952450000000014, -0.5834400000000002, -0.2774850000000002, -0.8279699999999981, -1.0886850000000012, -0.5887050000000007, -0.8065200000000019, -0.7774649999999999, -0.35509499999999994, -0.21099000000000012, -0.33735000000000037, -0.39273000000000075, -0.5360550000000007, -0.5990400000000002, -0.6637800000000007, 0.1265549999999997, -0.036660000000000054, 0.046214999999999784, -0.5235750000000008, -0.5867550000000006, -0.4701450000000005, -0.08424000000000022, -0.6614400000000005, -1.0073700000000008, -0.8948549999999993], [0.0, 0.07761000000001061, 0.05596500000000759, -0.14936999999999223, -0.2137200000000039, -0.1815449999999803, -0.3332549999999852, -0.09145499999999629, -0.11504999999999121, -0.03197999999999368, -0.5099249999999973, -0.15502499999999841, 0.1912949999999931, -0.08501999999999299, -0.3562649999999916, -0.31979999999999187, -0.19051500000001198, -0.5372250000000047, 0.07955999999999719, -0.7780500000000004, -0.5463899999999917, -0.9886500000000051, -0.5849999999999937, -1.0134149999999806, -0.6378450000000004, -0.679574999999998, -0.4679999999999911, -0.48691499999998733, -0.27202499999998864, 0.2737800000000057, 0.22288500000000688, -0.24570000000000114, -0.08170500000000303, -0.4414799999999932, -0.2419949999999904, 0.09535500000000319, -1.2101700000000033, -0.5362499999999972, -1.1407499999999917, -0.45532500000001086, -0.5690099999999969, -0.4266599999999876, -0.96505499999998, -0.8032050000000073, -0.03470999999999691, 0.09925500000001186, -0.48984000000000805, -0.33403500000000363, -0.23029499999999814, 0.19675499999999957, -0.3582150000000084, -0.5173350000000134, -0.6050849999999901, -0.6091800000000074, -0.795404999999981, -1.016729999999999, -1.0606050000000042, -0.9734399999999859, -0.5323499999999921, -0.2384849999999865, -0.8591700000000007, -0.8535150000000034, -0.8108100000000018, -0.3894149999999943, -0.7035599999999871, -0.5996249999999961, 0.09067500000000628, -0.03646499999999797, -0.4756050000000016, -0.20767500000000716, -0.196755000000012, -0.1953900000000086, -0.24901500000000532, -0.26637000000000377, -0.39877499999998633, -0.11309999999999754, -0.5752499999999934, -0.5668650000000017, -0.8966099999999955, -0.7987199999999888, -0.6577349999999864, -0.669239999999995], [0.0, 1.9618949999999558, -0.3024450000000982, 1.2261599999999433, -0.581490000000116, 1.3749449999999541, 1.0668449999999439, 1.4431949999999958, 0.6296549999999996, 0.8074949999999461, -0.3373500000000078, -0.3159000000001271, 1.1204700000000258, 1.1551799999999517, 1.131389999999918, 1.676609999999954, 0.2747549999999137, 1.0225799999999055, 0.4054049999998952, 0.9921599999999486, 0.5307899999999464, 0.14800499999991956, 0.08150999999999442, 0.3326699999999079, 0.5918249999999716, 0.6881549999999308, 0.7300799999999157, 0.9223499999998594, -0.5116800000000339, 0.009554999999942027, 0.34553999999995, -0.2640300000001119, -0.323505000000047, 0.025739999999984775, -0.8301149999999566, -0.588120000000032, -0.6017700000000801, 0.4976400000000112, -1.5541500000001065, -0.10705500000007362, -1.4724449999999933, -0.9172800000000478, -1.9930950000000038, -1.244295000000001, -1.2834900000000644, -0.8170500000001013, -0.7320300000001438, -1.2963600000000355, -0.5875350000000168, -0.6631950000000586, -0.6025500000001003, -0.05908500000013106, -0.2671500000000364, -0.19500000000009265, -0.8650200000000225, -1.0617750000001465, -0.665925000000108, -0.6643650000001031, -0.36991500000008415, -1.3343850000000188, -0.060450000000074056, -0.16419000000001915, -1.3127400000000549, 0.3381299999999712, -0.6883500000000637, 0.7450949999999139, -0.3492450000000389, -0.3880500000001277, -0.4898400000001075, 0.6401849999999811, 0.40735499999994573, -0.6236100000000206, 0.47950499999984686, 0.7513349999999335, -0.48516000000009285, 0.07663500000001022, 0.3252599999998935, -0.053040000000059706, 0.03860999999997006, -0.771420000000063, -0.7739550000000719, -0.6017700000000303], [0.0, -0.4775550000000033, -0.13630500000000456, 0.3562650000000005, -0.8067149999999987, -0.33286500000000174, -0.6824999999999992, -0.18330000000000268, -0.3424199999999944, -0.24297000000000324, -0.190515000000004, -0.30712500000000276, -0.9071400000000107, -0.12402000000000601, -0.13006499999999654, 0.045239999999995284, -0.15073500000000717, -0.6031349999999991, -0.5337150000000053, 0.2240550000000061, -0.23068500000000114, -0.8821799999999991, 0.03256499999999374, 0.2790449999999982, -0.21528000000000524, -0.3917550000000096, -0.44050500000000703, -0.9578400000000036, -1.2378600000000057, -0.6158100000000104, -0.6630000000000003, -0.8307000000000011, -0.4660500000000045, -0.4836000000000107, -0.01189500000000443, -0.5695950000000005, -0.7665450000000016, -0.663585000000003, -0.2782650000000091, -0.09555000000000113, -0.15112500000000395, -0.5173350000000019, -0.8110050000000069, -0.7840950000000051, -0.3264300000000073, -0.5830500000000081, -0.5229900000000107, 0.037050000000000693, -0.8977800000000071, -0.5304000000000055, -0.8299200000000084, -0.25466999999999995, -1.305135, -0.6787950000000018, -1.009125000000008, -0.3110250000000008, -0.7302750000000007, -0.8853000000000053, -0.7864350000000053, -0.4793100000000061, -0.8197800000000068, -1.133924999999997, -0.870480000000005, -0.6497400000000049, -1.0235550000000062, -0.6959550000000165, -0.5553600000000092, -0.6388200000000044, -0.9974250000000016, -1.0830300000000035, -0.3400800000000066, -0.38922000000000523, -0.18739500000001286, -0.961935000000004, -0.6862050000000055, -0.4430400000000123, -0.73203, -0.4703399999999984, -0.6980999999999948, -0.46136999999999784, -0.7209150000000051, -1.0914150000000147], [0.0, -0.13181999999999938, -0.4826250000000014, 0.3745950000000007, 0.015795000000001114, 0.8400600000000016, 0.5500949999999998, 1.2840750000000027, 0.7408049999999933, 0.606644999999999, 0.7503599999999992, 0.43329000000000084, 0.14059499999999536, 0.23907000000000034, 0.38375999999999655, 0.35470499999999516, 0.8739899999999992, 0.5118750000000012, 0.2973750000000006, 0.5114849999999986, 0.48125999999999625, 0.6319949999999968, 0.8849099999999988, 0.6015750000000057, 0.5965050000000018, 0.29113499999999704, 0.4362149999999967, -0.005655000000004851, 0.2250300000000025, -0.00682500000000319, -0.43914000000000275, -0.195975000000002, -0.4463550000000027, -0.02086500000000191, -0.48867000000000127, -0.15171000000000534, -0.5629650000000015, -0.7835099999999997, -0.7583550000000017, -0.48613499999999954, -0.08248500000000458, -0.5194800000000068, -0.19382999999999884, 0.02983499999999717, 0.1076399999999964, -0.30030000000000046, -0.27319500000000385, 0.10432500000000022, 0.508950000000004, 0.21683999999999815, 0.14137500000000003, -0.28469999999999906, 0.33949500000000343, -0.03880500000000442, 0.17764499999999916, 0.038219999999998144, -0.7458750000000043, -0.06473999999999913, -0.39643499999999765, -0.11778000000000244, 0.39838499999999755, 0.29269499999999793, 0.5848050000000002, 0.10607999999999729, 0.06785999999999914, 0.09359999999999769, -0.2730000000000028, -0.08131500000000091, 0.04797000000000695, -0.2597400000000025, -0.13182000000000116, -0.10393500000000166, 0.13338000000000028, 0.1838849999999974, 0.24199500000000196, 0.5653050000000008, 0.15990000000000304, 0.5752499999999956, 0.5124600000000026, 0.457665000000004, 0.6912749999999992, 0.2076750000000014], [0.0, -0.05421000000000009, -0.2642250000000005, -0.061814999999999176, -0.6643649999999997, -0.6185400000000005, -0.5103149999999983, 0.2031899999999997, -0.4783349999999995, -1.0007400000000015, -1.1107200000000013, -0.08638500000000099, -0.1251899999999998, 0.3744000000000001, 0.25116000000000016, 0.7708349999999999, 1.2339599999999995, 2.1996, 2.393429999999999, 2.4497850000000008, 2.523689999999999, 2.3622300000000003, 2.613584999999998, 2.332785000000001, 1.9248450000000001, 0.7854599999999999, 0.2985450000000002, -0.13006500000000193, -0.47209500000000004, -0.9430199999999989, -1.4439750000000011, -2.088255000000001, -1.7002050000000009, -2.02878, -2.0673899999999983, -1.6795350000000013, -1.4773200000000013, -0.4849650000000004, -0.5422950000000002, -0.9305399999999995, -0.5448299999999996, -0.24881999999999993, 0.15112500000000018, -0.6450599999999991, -1.1715599999999997, -1.0742549999999995, -1.004834999999998, -1.36617, -1.0502700000000011, -1.2675000000000018, -1.3111800000000005, -1.007955, -1.1232000000000004, -0.662024999999998, -0.24569999999999936, 0.3808350000000002, 0.5247449999999997, 0.8753550000000008, 0.6263400000000008, 0.6119099999999988, 0.9239099999999996, 1.4102400000000006, 0.8989499999999992, 0.8303100000000005, 0.5050500000000003, 0.3944849999999994, -0.1932450000000011, -0.4348500000000004, -0.9324900000000007, -0.6440849999999995, -1.300454999999999, -0.8802300000000005, -1.1686350000000008, -1.121054999999999, -0.6528599999999999, -0.17744999999999989, 0.3742050000000003, 1.1272949999999986, 0.45883499999999905, 0.8860800000000002, 1.4714700000000007, 1.633320000000001], [0.0, 0.03704999999999403, 0.21274499999999796, -0.029445000000004384, -0.25701000000000107, -0.17004000000000286, -0.35860499999999984, -0.44889000000000445, -0.26305499999999915, -0.49744499999999947, -0.32272500000000326, -0.3983850000000042, 0.05479499999999904, 0.7380749999999956, 0.8624849999999966, 1.6136249999999976, 2.3706149999999977, 3.530864999999998, 3.915599999999999, 4.079009999999998, 4.4286449999999995, 4.039424999999997, 3.9622049999999973, 3.211064999999997, 2.1740549999999974, 1.2606749999999995, 0.11660999999999788, -0.6971250000000055, -1.1813100000000003, -1.6711500000000035, -2.04906, -2.1752249999999966, -2.2005750000000015, -2.5790700000000113, -2.576730000000004, -2.361060000000002, -1.9133399999999972, -1.5488850000000003, -1.420575000000004, -1.1411400000000058, -0.8983650000000032, -0.3566550000000044, -0.42276000000000336, -0.9459450000000045, -1.332630000000003, -1.3078650000000045, -1.0011300000000047, -1.4899950000000022, -1.2550200000000005, -1.727504999999998, -1.611089999999999, -1.3456950000000032, -1.0832250000000019, -1.0372050000000033, -0.8291400000000051, -0.49705500000000225, -0.20319000000000642, 0.20884499999999906, 0.2293199999999982, 0.36503999999999626, 0.8478599999999985, 1.4624999999999972, 1.1249549999999975, 1.0009349999999984, 0.4791149999999984, -0.1799850000000034, 0.07916999999999796, -0.36484499999999986, -1.0414950000000016, -1.7111250000000027, -1.2903150000000028, -1.5342599999999993, -1.3263900000000057, -1.1542050000000028, -1.0262849999999992, -0.32740500000000106, 0.01033499999999865, 0.4902299999999975, 0.4445999999999972, 0.8749649999999971, 0.9658349999999989, 0.9315149999999983], [0.0, 0.4385550000000258, 0.40248000000005746, -0.40696499999998537, 0.04133999999999105, 0.6639750000000078, -0.1883699999999564, 0.1468350000000207, 0.9582300000000217, 1.253460000000043, 0.9129899999999829, 0.3313050000000253, 0.5434649999999834, 0.43894500000003944, 0.167895000000005, 0.20514000000002497, 0.43114499999998657, 0.6748950000000029, 0.7020000000000088, 0.6641700000000164, 0.3958499999999603, 0.32447999999999766, 0.24316499999995145, 0.643499999999996, 0.883935000000033, 0.879645, -0.1417650000000279, 0.1419599999999761, 0.27338999999997426, 0.4024799999999864, 0.10471500000000233, 0.2677349999999947, -0.6581250000000658, -0.26110499999999703, -0.17549999999999244, -0.43621500000002555, -0.4522049999999709, -1.0151699999999906, 0.12207000000000079, -0.40696500000001024, 0.21859500000000764, -0.41671500000002126, -0.3675749999999951, -0.17120999999999498, -0.22444500000003487, -0.03744000000003567, 0.20786999999998912, 0.834015000000047, 0.695565000000002, 0.5575049999999919, -0.11797500000000483, -0.7725900000000365, -0.13572000000001339, 0.12675000000001901, 0.294060000000016, 0.2646149999999885, -0.2156699999999958, 0.2141100000000158, 0.3660150000000293, 0.3233099999999922, 0.28723500000001323, -0.06707999999999359, 0.4527899999999683, -0.13689000000001528, 0.02925000000001532, 0.16633500000003565, 0.03470999999998625, -0.18057000000002077, 0.8708700000000071, 0.5777850000000129, 0.015989999999995064, 0.11309999999996734, -0.729299999999963, -0.7411950000000118, -0.27553500000002273, -0.6569550000000106, -0.29132999999999143, -0.3112199999999987, 0.08970000000000766, 0.035099999999982145, 0.5370299999999801, 0.2696849999999671], [0.0, -0.10763999999999929, 0.2542800000000003, 0.5456100000000008, 0.36055500000000174, 0.2390700000000009, 0.009944999999999649, 0.4662450000000008, 0.3812250000000008, 0.28762500000000124, 0.37771500000000047, 0.3135600000000004, 0.0444600000000005, 0.7470450000000006, 0.5370300000000005, 0.05109000000000119, 0.7977450000000004, 0.6626100000000003, 0.8059350000000005, 0.8864700000000004, 1.2616500000000008, 1.1189100000000003, 0.7926750000000005, 0.31746000000000063, -0.07663499999999956, 0.16399500000000022, -0.35528999999999944, 0.0007799999999995588, 0.34436999999999995, -0.3876600000000001, 0.3911699999999998, 0.3209700000000012, 0.12187499999999996, -0.05615999999999999, 0.32662499999999994, -0.34514999999999896, -0.7404150000000018, -0.5101200000000004, -0.6507149999999975, -0.5653049999999982, -0.6867899999999996, -0.6000150000000002, -0.39994499999999755, 0.0013650000000002827, -0.40442999999999873, -0.6979050000000016, -0.4980299999999991, -0.2534999999999974, 0.03821999999999903, -0.34788000000000086, 0.5522400000000002, -0.09535499999999897, -0.46273500000000034, -0.3554850000000007, -0.1959749999999978, -0.26695500000000094, -0.8340149999999997, -0.28996499999999914, -0.0551849999999976, -0.08228999999999975, -0.05577000000000054, -0.36620999999999904, -0.5734949999999979, -0.6544200000000009, -0.4003350000000008, -0.9083100000000002, 0.011700000000001598, 0.12324000000000057, -0.034514999999999185, 0.2542800000000007, -0.04055999999999904, -0.06239999999999957, 0.351780000000001, -0.050894999999999246, -0.00701999999999936, -0.47579999999999756, -0.041339999999999266, 0.18856500000000131, -0.24706499999999987, 0.2630549999999998, -0.20026499999999903, -0.4297799999999987], [0.0, -1.4537249999999977, -1.037204999999993, -1.0496849999999966, -0.7924800000000012, -1.868099999999993, -2.082599999999996, -2.1284250000000027, -1.1169599999999997, -1.0535850000000018, -0.8464950000000027, -1.708005, -0.9707099999999977, -0.5110949999999965, -0.674895000000002, -1.481024999999999, -1.0276499999999924, -0.4746299999999932, -1.2353249999999987, 0.8827649999999982, -0.5235749999999983, -0.23984999999999257, 0.06084000000000156, -0.8901749999999984, -1.0572899999999903, -1.237470000000001, -1.872779999999997, -1.9529250000000067, -1.8813600000000061, -2.132520000000002, -1.786005000000003, -2.7660750000000034, -2.109899999999997, -2.0061600000000004, -2.208569999999999, -3.3506850000000026, -1.8226650000000006, -2.0188350000000073, -2.5821900000000024, -2.997150000000002, -3.100890000000003, -2.6157300000000063, -0.5005650000000026, -2.0112299999999967, -2.414489999999997, -2.138760000000002, -1.8027750000000005, -2.9017950000000035, -1.7368650000000025, -2.846609999999999, -1.965795, -1.4975999999999994, -2.4324300000000028, -1.7103449999999896, -2.464215000000004, -2.1331050000000014, -2.4757200000000026, -1.8320250000000025, -2.30061, -2.4597299999999986, -2.1221849999999964, -2.009475000000002, -1.6810949999999956, -2.1703499999999982, -2.182245000000006, -1.732575000000005, -2.006939999999992, -2.7186900000000014, -2.1600149999999987, -2.840175000000004, -2.749110000000008, -1.9059299999999952, -1.133144999999999, -2.432039999999997, -1.4792700000000023, -1.1052600000000012, -2.4517350000000073, -1.271984999999992, -2.6800799999999967, -2.410979999999995, -1.4437799999999985, -1.12359], [0.0, 0.05050500000000011, 0.06747000000000009, -0.1989, -0.13279499999999972, -0.3080999999999995, -0.3108300000000003, 0.20104499999999983, -0.1285049999999999, -0.15190499999999985, -0.08853000000000032, 0.022229999999999944, -0.041145000000000057, -0.21274499999999966, -0.24628499999999967, -0.44889, 0.6064499999999997, 0.6908850000000002, 0.9588149999999992, 0.8377199999999995, 0.6321899999999999, 0.6074249999999998, 0.9281999999999996, 0.07507499999999999, 0.379470000000001, -0.09769499999999987, -0.32135999999999953, -0.40481999999999985, -0.6571500000000002, -0.69849, -0.7146749999999988, -1.4977950000000018, -1.1530349999999991, -1.083615, -1.7218500000000014, -1.2977249999999996, -1.2427350000000004, -0.9775350000000006, -0.6815250000000019, -0.9297599999999999, -1.1770200000000015, -1.1177399999999993, -0.5775899999999998, -0.7333949999999997, -1.0645050000000003, -0.36894000000000005, -0.603719999999999, -0.0941850000000001, -0.46039500000000033, -0.585195000000001, -0.7823399999999991, -0.16906500000000008, -0.4804799999999996, -0.4083299999999993, -0.5894849999999996, -0.6967350000000003, -0.7733700000000007, -1.0005449999999994, -0.5982599999999988, -0.8642399999999997, -0.4391400000000004, -1.0401299999999987, -1.0278449999999988, -0.8080800000000009, -0.2950349999999998, -0.6990750000000001, -0.9742199999999993, -0.6082050000000002, -0.3344250000000003, -0.3100499999999998, -0.7043400000000001, -0.7952099999999996, -0.6374549999999997, -0.5085599999999997, -0.7057050000000009, -0.20689500000000005, -0.5218199999999993, -0.30771000000000037, -0.7160399999999999, -0.5052450000000002, 0.0906750000000004, -0.20104500000000022], [0.0, -0.21469499999999797, -0.06707999999999847, -0.15209999999999835, -0.16438499999999756, -0.2644199999999979, -0.07019999999999915, -0.28489499999999746, 0.06181500000000162, -0.2464799999999966, -0.4484999999999979, -0.675479999999997, -0.6969299999999967, -0.6698249999999983, -0.49919999999999853, -0.29483999999999977, -0.26110499999999837, -0.16808999999999874, 0.08716500000000171, 0.22522500000000145, -0.18602999999999847, 0.02983500000000061, -0.3814199999999983, -0.048164999999999014, 0.3445650000000013, 0.27748500000000115, 0.15151500000000107, -0.0060449999999970805, -0.5313749999999988, -0.2923049999999976, -0.2809949999999972, -0.8326499999999983, -0.8579999999999965, -0.7285199999999987, -0.8548799999999979, -1.1167650000000002, -1.158299999999999, -1.1294399999999987, -1.0514399999999982, -0.6563700000000001, -0.8215349999999972, -1.1033099999999971, -0.5153849999999986, -0.46253999999999706, -0.48418499999999853, -0.33032999999999846, -0.38375999999999877, -0.5752499999999958, -0.8371349999999951, -0.6395999999999975, -0.7335899999999975, -0.6319949999999963, -0.9714899999999993, -0.6160049999999984, -0.8572199999999968, -0.7158449999999974, -0.4469399999999977, -0.7029749999999995, -0.8248499999999963, -0.758549999999997, -0.8503949999999987, -0.7261799999999985, -0.7082399999999967, -0.7277399999999976, -0.5044649999999988, -0.20903999999999923, -0.38258999999999843, -0.1255799999999997, -0.24628499999999853, -0.43250999999999706, -0.2667599999999992, -0.26929500000000006, -0.7027799999999984, -0.6138599999999999, -0.6774299999999966, -0.6548099999999986, -0.9057749999999993, -0.46916999999999676, -0.48340499999999875, -0.740219999999999, -0.4715099999999981, -0.3962399999999975], [0.0, -0.14527500000000515, -0.6296550000000121, -0.20923500000001294, 0.03627000000000358, 0.27338999999999825, -0.970710000000012, -1.1910600000000091, -0.7203300000000086, -0.3412500000000005, -0.9773399999999928, -1.356615000000013, -0.6185399999999968, -0.20767500000000183, -0.3693300000000068, 0.34261499999999145, -0.2258100000000125, -0.28314000000000217, -0.012090000000005041, 0.2960099999999981, 0.36757500000000043, 0.8693099999999996, -0.04309500000000721, -0.2769000000000066, 0.6676799999999963, -0.03217500000001117, -0.014820000000005606, -1.1415300000000093, -0.4430400000000061, -0.6963450000000027, -0.8925149999999986, -1.8669300000000009, -0.7289100000000053, -0.9356100000000058, -0.717990000000003, -0.7792199999999987, -1.2926549999999954, -0.49296000000000095, -0.7441200000000086, -1.6471650000000047, -1.2296700000000005, -0.4937400000000034, -1.1101350000000103, -1.3246349999999998, -0.6117150000000056, -0.09204000000000079, -0.37927500000000247, -0.972855000000016, 0.04718999999999607, -1.1809200000000155, -0.7261799999999967, 0.08268000000000253, -0.45610500000000265, -0.21528000000000969, -0.9122100000000035, -0.5789550000000103, -0.6522750000000102, -1.1040900000000073, -0.9087000000000112, -1.5676050000000084, -0.2092350000000085, -1.503060000000005, -0.7934550000000069, -1.6339050000000048, -1.2641850000000048, -1.1423100000000126, -0.4368000000000043, -1.7002050000000022, -1.7146349999999995, -0.35138999999999854, -0.6234150000000014, -0.7142850000000074, -0.8213400000000002, -0.006630000000006575, 0.2513549999999869, -0.7644000000000011, -1.4989650000000125, -0.6477900000000014, -0.7511400000000048, 0.0598649999999985, -0.8028150000000087, -0.7577700000000078], [0.0, -0.257594999999998, 0.47579999999999956, -0.08579999999999899, 1.1524499999999964, 0.4514249999999995, 0.17413500000000148, 0.539759999999994, 0.48067500000000507, 0.8915399999999973, 1.3470600000000017, 1.275105, 0.5060249999999966, 0.08424000000000031, 0.2825550000000039, -0.07780500000000501, -0.4656599999999944, 0.1076399999999973, 0.8654100000000033, 0.9285900000000016, 1.6017300000000017, 0.8839350000000064, 1.3256100000000037, 1.1893050000000045, 0.7667399999999951, 0.023789999999997313, 0.641549999999997, -0.6786000000000034, 0.6715799999999987, 0.37654500000000013, 0.4697549999999975, 0.3240899999999991, 0.2999099999999979, -0.10900500000000157, 0.19772999999999818, -0.9260550000000003, -0.7720049999999987, -0.005069999999995467, -0.39195, -1.0194599999999983, -0.8798399999999993, -1.2296699999999987, -0.9950850000000004, -0.889589999999997, 0.03178499999999662, -0.4603949999999979, -0.5616000000000003, 0.3933149999999985, 0.09652499999999797, -0.012479999999999158, -0.05479500000000126, -0.3340349999999983, -0.4923749999999987, -0.19772999999999996, -0.41535000000000144, -0.8620950000000027, -0.530400000000002, -0.936779999999998, -0.22736999999999918, -0.3001049999999994, -0.6123000000000043, -0.7316399999999992, -1.5633149999999958, 0.027299999999994107, -0.7957950000000005, -0.3993599999999997, -0.5518499999999973, -0.0434850000000071, 0.9746100000000038, 0.13884000000000363, -0.038220000000002585, 0.024569999999995318, -0.2663700000000011, 0.5951399999999962, -0.31707000000000063, -0.6887400000000019, -0.6499349999999966, 0.09515999999999991, -0.38083499999999937, -0.3767399999999963, 0.4229550000000062, -0.17803500000000394], [0.0, -0.3155100000000033, 0.015210000000009494, 0.6015750000000084, 0.14118000000000297, -0.6731399999999885, 0.385710000000012, 0.04270499999999444, 0.8012550000000127, -0.5064150000000005, 0.2527200000000054, 0.19012500000000987, -0.5610149999999896, -0.759524999999992, -0.5323499999999939, -1.6296149999999896, -1.8460649999999932, -1.5921749999999983, -1.173510000000002, -1.9431749999999992, -1.3903499999999989, -0.970709999999996, -0.9301499999999905, -0.8769149999999941, -1.4248650000000032, -1.2536549999999984, -0.5559449999999924, -0.3738150000000031, -0.17491499999998616, -0.06610499999998964, 0.6780150000000029, 0.7837050000000092, 0.5577000000000041, 0.40950000000000664, 0.49198500000000855, -0.5270849999999996, -0.745680000000001, -0.45532500000000553, 0.24102000000001134, -0.4545449999999933, -1.0354500000000062, -0.8708699999999974, -0.6998549999999906, -0.23341499999999016, -0.0005849999999893996, -0.10471499999999434, 0.01443000000000616, -0.8455199999999934, -0.008774999999991095, -0.22035000000000338, -0.49783499999999226, 0.1747200000000042, -0.3718649999999899, -0.6460349999999897, -0.3118049999999899, -0.35880000000000045, -0.1491749999999925, -1.4623049999999962, -0.7285199999999934, -0.10685999999999218, -1.5915899999999974, -0.7105799999999975, -0.34358999999999185, -0.41320499999999694, -0.3537299999999943, 0.025545000000003704, -0.6029399999999887, 0.5695950000000094, 0.07371000000000194, 0.009750000000001258, -0.7768799999999985, 0.8182200000000153, 0.26870999999999423, -0.24550500000000053, 0.14566500000001437, -0.42041999999999646, 0.371865000000013, 0.6651450000000141, -0.07215000000000682, 0.13689000000000995, -0.2989349999999904, 1.0619700000000103], [0.0, -0.38590499999999883, 0.055379999999997764, -0.14390999999999554, -0.1129050000000027, 0.2833350000000028, 0.007214999999998639, -0.5502899999999991, -0.48691499999999577, -0.5380050000000032, -0.26110500000000236, -0.1614600000000035, -0.17004000000000064, -0.2868449999999996, -0.4459649999999997, -0.3248699999999993, -0.40384499999999823, -0.04777499999999746, 0.06942000000000004, 0.34709999999999663, 0.1480049999999995, -0.0701999999999976, -0.23868000000000222, 0.16204499999999733, 0.3915600000000028, 0.3989699999999985, 0.18095999999999668, -0.23224499999999715, -0.3515849999999965, -0.7815600000000003, -0.470730000000001, -0.5069999999999988, -0.839865000000001, -0.7123349999999968, -0.48983999999999694, -0.6922499999999943, -0.7686899999999985, -1.0804949999999975, -0.8310899999999957, -0.46292999999999784, -0.6869850000000031, -1.052804999999997, -0.45337499999999364, -0.7901399999999965, -0.8217299999999987, -0.8141249999999962, -0.3285749999999976, -0.577395000000001, -0.7739549999999986, -0.7963799999999956, -0.737879999999997, -0.78234, -0.8815949999999981, -0.8041799999999975, -0.5017349999999978, -0.8946599999999969, -0.716429999999999, -0.9615449999999988, -0.8825699999999976, -0.5621849999999977, -0.8693099999999987, -0.9168899999999978, -0.9209849999999977, -0.3079049999999999, -0.4430399999999981, -0.6064500000000006, -0.769664999999998, -0.44791499999999873, -0.5380049999999992, -0.18447000000000147, -0.572909999999998, -0.656759999999998, -0.8373299999999992, -0.7817549999999986, -0.4537649999999993, -1.074644999999997, -0.6680699999999966, -0.08755499999999827, -0.8088599999999988, -0.35723999999999867, -0.8864699999999988, -0.9280049999999975], [0.0, 0.22932000000000308, -0.5830500000000018, -0.004094999999997739, -0.28840499999999736, 0.04094999999999693, -0.31219499999999734, 0.2891850000000069, 0.6140550000000111, -0.00428999999999391, 0.13903500000000868, 0.4576650000000093, -0.08950500000000261, -0.20806499999999417, 0.48165000000001257, 0.48438000000002646, 0.15892500000000886, 0.24336000000000446, 0.7359300000000122, 0.1961700000000235, 0.6532500000000105, 0.6364800000000148, 0.8810100000000034, 0.7825350000000029, 0.6752850000000148, -0.2950349999999897, -0.15872999999998783, -0.00467999999999158, -0.429974999999998, -0.9968400000000068, -0.6427199999999953, -0.3303299999999947, -0.5108999999999959, -1.0475400000000032, -0.700439999999996, -0.9890400000000028, -1.1729250000000047, -0.6399899999999947, -0.5122649999999966, -0.5836350000000019, -0.7043400000000091, -0.5331299999999946, -0.3728399999999983, -0.9170849999999913, -0.4432349999999863, -0.23497499999999683, -0.37088999999998506, -0.6138599999999981, -0.14975999999999878, -0.7796099999999964, -0.5610149999999958, -0.5760299999999985, -0.3759599999999903, -1.0438350000000085, -0.6844499999999965, -0.7712249999999976, -0.5713499999999998, -0.4570799999999968, -0.19187999999999406, -0.4120349999999924, -0.5908500000000068, 0.48340500000001185, -0.1575599999999966, 0.11856000000001643, -0.18349499999998642, -0.5208450000000067, 0.04309499999999744, 0.001560000000001338, -0.07351500000000044, -0.9241050000000053, -0.5407349999999891, -0.22054500000000132, -0.49939499999999093, -1.2704249999999924, -0.42587999999999493, -0.4210049999999974, -0.555359999999995, -0.2737799999999915, 0.12090000000000423, -0.5647200000000066, -0.20299500000000137, -0.39097499999997964], [0.0, 0.30966000000000005, 0.4602000000000013, -0.5300100000000056, 0.4609799999999993, 0.2981550000000013, -0.08755500000000627, -0.274170000000006, 0.22931999999999508, -0.1273350000000022, 0.12538499999999964, 0.5614050000000104, 0.43835999999999853, 0.2710499999999989, 0.22034999999999805, 0.10919999999999952, -0.48418500000000053, 0.037635000000004304, 0.2474549999999951, 0.13025999999999982, 0.7591350000000006, 0.41651999999999756, 0.3322799999999999, 0.6290700000000031, 0.8515650000000008, 0.5276699999999996, 0.3137549999999978, -0.06591000000000413, 0.22015500000000277, -0.2193750000000021, -0.1912950000000011, -0.41769000000000256, -0.2708550000000023, -0.34671000000000607, -0.08385000000000353, -0.882569999999999, -0.854685000000003, -1.20939, -0.4307550000000071, -0.5604300000000033, 0.01130999999999549, -0.9272250000000044, -0.6938100000000036, -0.8453250000000025, -0.3492450000000038, -0.6072300000000022, -0.6645600000000007, -1.0241400000000045, -0.5967000000000033, -0.608400000000004, -0.6830849999999979, -0.8371350000000031, -0.49393500000000223, -0.5461950000000053, -0.21586500000000086, -0.08443499999999915, -0.6142500000000051, -1.3053299999999992, -0.6319950000000008, -0.4323150000000009, -1.1103299999999998, -1.4609399999999941, -0.5335200000000047, -0.4970550000000018, 0.15463499999999986, -0.6292650000000037, -0.8002799999999981, -0.4180800000000078, -0.00429000000000368, -0.18408000000000202, 0.29581499999999483, -0.659295000000002, -0.6466200000000009, -0.2919150000000026, -0.5286450000000045, -0.5171400000000075, -0.769274999999999, 0.012675000000000658, -0.0625950000000044, -0.4219800000000018, -0.25369500000000356, -0.05167500000000569], [0.0, -0.12655499999998732, -0.4492799999999946, -0.27631499999999676, 0.22444500000001444, 0.1136850000000118, -0.2819699999999905, -0.43075499999999156, 0.2767050000000131, 0.2856750000000172, 0.08209500000000336, 0.045630000000007165, 0.06240000000001622, -0.41106, -0.6569549999999911, -0.19538999999998996, -0.5771999999999968, -0.34183499999997924, -0.38902499999998597, -0.49861499999999204, -0.010334999999989769, -0.4642949999999999, 0.35782500000000894, 0.002340000000002007, -0.3954599999999884, -0.29015999999998954, -0.3422249999999911, -0.07780499999999169, -0.15853499999999254, -0.6692399999999905, -0.5358599999999925, -0.623999999999997, -0.803789999999994, -1.1077949999999932, -0.9258599999999895, -0.8347949999999855, -1.0173149999999938, -1.3971749999999927, -1.2852449999999997, -1.0834199999999958, -1.2074399999999965, -1.2571650000000032, -1.1731199999999866, -0.9983999999999948, -1.1033099999999934, -1.7518799999999892, -1.0941449999999975, -1.1536199999999939, -1.1023349999999938, -0.9785099999999964, -0.6698249999999843, -0.9999599999999935, -1.1582999999999863, -1.0970699999999978, -1.1629799999999895, -1.2183599999999952, -1.6910399999999948, -1.1169599999999917, -1.1070149999999943, -1.4129699999999907, -1.4605499999999934, -1.3121549999999953, -1.1740949999999977, -1.1224199999999964, -0.9034350000000009, -0.9824099999999918, -1.187549999999999, -1.1446499999999915, -1.2103649999999986, -1.159469999999999, -1.3657799999999956, -0.929759999999999, -1.0241399999999956, -1.2908999999999962, -1.4964299999999922, -1.7934149999999986, -1.6658849999999914, -1.154009999999996, -1.023359999999994, -0.8207549999999966, -0.9539399999999958, -1.1300249999999927], [0.0, 0.7887749999999905, 0.5165549999999914, 0.18251999999999846, 0.09632999999998404, 0.5477549999999916, 0.6780150000000003, 0.7544550000000019, 0.4754099999999948, 0.35802000000000156, 0.7733699999999839, 0.23906999999998035, 0.292889999999991, 0.6858150000000016, 0.4180799999999927, 0.5567249999999984, -0.6875700000000053, 0.05245500000000902, 0.23048999999999786, -0.09281999999999435, 0.22873499999999325, 0.0830699999999922, 0.40852499999999203, 0.04777499999999435, 0.5530199999999983, 0.30127499999998975, 0.15736499999998266, 0.16184999999998873, 0.25681499999999424, 0.08228999999998976, 0.5422949999999833, -0.016770000000008167, 0.512459999999999, 0.2595449999999886, -0.009945000000008974, -0.08911500000000849, -0.9785100000000133, 0.07858500000000035, -0.427634999999996, -0.2521349999999991, -0.20182500000001014, -0.6787950000000134, -0.5109000000000012, -0.43192500000001743, -0.4157400000000049, -0.4685850000000027, -0.37362000000000073, -0.62673000000001, 0.42295499999999997, 0.47950499999999074, -0.25174500000000677, -0.5924100000000143, 0.028274999999990058, -0.2509650000000203, 0.9135750000000016, -0.04290000000000482, -0.3683550000000153, -0.8084700000000087, -1.0017150000000052, -0.500175000000004, -0.5046600000000083, -0.5647200000000145, 0.29405999999999466, -0.5019299999999989, 0.01950000000000429, -0.6819150000000018, -0.4783350000000022, -0.2965950000000035, 0.2597399999999883, 0.1988999999999823, 0.11992499999999318, -0.25330500000000455, 0.07390499999999811, -0.07000500000001075, 0.2051399999999841, -0.35529000000001076, 0.40715999999999397, -0.09594000000000236, -0.5670600000000192, -0.437385000000015, -0.5799300000000089, -0.6218550000000125], [0.0, -0.19733999999999519, 0.12050999999999323, 0.5929950000000028, 0.3303300000000018, 1.2585300000000004, 1.0217999999999972, 0.9059700000000053, 0.5536049999999983, 0.7930650000000057, 0.41847000000000456, 0.15755999999999926, -0.05927999999999489, -0.059865000000002055, -0.18817500000000376, -0.18895499999999466, -0.38941499999999873, -0.2486249999999961, -0.23731500000000239, -0.7493850000000029, -0.15892499999999643, -0.5421000000000067, 0.30849000000000704, -0.06415500000000662, -0.1134899999999961, -0.1673100000000005, 0.4342649999999919, 0.16867499999999236, 0.0542100000000012, 0.05537999999999421, 0.1415699999999971, -0.12089999999999801, 0.1444950000000036, 0.020864999999992584, -0.1936350000000049, -0.7080450000000038, -0.439530000000004, -0.5984550000000031, -0.4288050000000023, -0.47365500000000704, -0.5343000000000062, -0.16906500000000246, -0.6004050000000003, -0.5161650000000035, 0.06551999999999847, -0.07117500000000643, 0.06649499999999442, -0.4496699999999949, -0.2244450000000029, 0.032174999999997844, 0.14566500000000548, -0.5912400000000062, -0.29795999999999623, 0.160095000000001, -0.2517449999999961, 0.2495999999999956, -0.1306499999999966, 0.05537999999999421, 0.16048500000000487, -0.10666500000000756, -0.2533049999999957, -0.6708000000000052, -0.45649500000000387, -0.5998200000000091, 0.17667000000000588, -0.5021249999999995, -0.41281500000000193, -0.09008999999999467, -0.11934000000000466, -0.14663999999999877, 0.15541499999999875, -0.4964700000000031, -0.14859000000000044, -0.2729999999999988, -0.34515000000000473, -0.3432000000000004, 0.026325000000002596, -0.5251350000000015, -0.5140200000000013, -0.957645000000003, -0.7460699999999996, -0.6813300000000009], [0.0, 0.05850000000000444, -0.12226499999999918, -0.25291500000000067, -0.09164999999999468, 0.29503500000000393, 0.10042500000000176, -0.01462500000000011, 0.31414500000000434, -0.056159999999995325, 0.025740000000003427, 0.14527500000000648, -0.2345849999999965, -0.16243499999999678, -0.059864999999999835, -0.24979499999999177, -0.11738999999999367, -0.10978499999999825, -0.38239499999999804, -0.3650399999999969, -0.004484999999995853, 0.10978500000000446, 0.14508000000000276, 0.26793000000000555, 0.1220699999999999, -0.050114999999991916, 0.0386100000000007, 0.40443000000000007, 0.23575500000000016, -0.19850999999999708, -0.31628999999999685, -0.537614999999998, -0.4545450000000022, -0.4580549999999963, -0.37342499999999745, -0.003899999999991799, -0.5268899999999981, -0.5894849999999945, -0.41066999999999787, -0.7310550000000049, -0.5132400000000032, -0.4586399999999946, -0.5483399999999978, -0.4165199999999958, 0.08190000000000719, -0.4440149999999976, -0.23926499999999695, -0.3745949999999967, -0.21508499999999842, -0.655590000000001, -0.8032050000000046, -1.0931700000000033, -0.43153499999999223, -0.23965499999999906, -0.9755850000000024, -1.0701600000000022, -0.2470649999999983, -0.41496000000000155, -0.396045, -0.8519549999999949, -0.6871799999999961, -0.9262500000000022, -0.6197099999999978, -0.23614499999999872, -0.45005999999999613, -0.7197449999999961, -0.8053499999999971, -0.025544999999996598, -0.11212500000000158, 0.0967200000000088, -0.14293499999999426, -0.3096599999999974, -0.15638999999999736, -0.5812949999999972, -0.38687999999999434, -0.6169800000000008, -0.6027449999999952, -0.4132049999999987, -0.4724849999999954, -0.24706499999999654, -0.0676649999999972, -0.3090749999999973], [0.0, 0.2739750000000014, 0.19967999999999808, 0.25642500000000057, 0.10022999999999982, 0.07234500000000255, 0.5805149999999974, 0.09126000000000012, 0.2841150000000021, 0.6121050000000015, 0.6979050000000009, 0.31804500000000413, 0.49510500000000146, 0.5682299999999976, 0.8053499999999998, 0.1922700000000046, 0.15385499999999963, -0.21898500000000132, 0.04699500000000789, 0.27378000000000213, 0.09555000000000069, 0.13259999999999872, 0.31609499999999713, 0.2076750000000005, 0.29678999999999967, 0.07780500000000012, 0.13006499999999832, 0.18193499999999752, -0.09164999999999868, -0.2254199999999975, -0.14059499999999936, 0.4083299999999994, 0.4416749999999996, 0.1140750000000037, -0.03393000000000024, -0.14313000000000198, -0.16009499999999788, -0.5112899999999962, 0.06006000000000311, -0.19363500000000178, -0.05986499999999584, -0.2630549999999925, -0.05694000000000088, 0.18212999999999901, -0.23751000000000078, 0.08443499999999826, -0.08384999999999776, -0.019109999999997296, 0.14235000000000309, -0.07000499999999654, -0.20572500000000105, 0.038805000000001755, 0.05050499999999669, -0.14351999999999876, 0.0861900000000011, 0.11134500000000402, -0.3055650000000001, -0.5138249999999975, -0.2349750000000035, -0.14254499999999615, -0.28294499999999845, -0.3562649999999956, -0.10100999999999827, -0.595139999999998, -0.49900499999999903, -0.5075850000000046, -0.25642499999999924, -0.3451500000000025, 0.11056499999999891, -0.07604999999999551, -0.3742049999999919, -0.27885000000000026, -0.615809999999998, -0.08482499999999904, -0.2653949999999998, -0.5294249999999985, -0.1333799999999994, -0.08482499999999638, -0.08989500000000383, -0.08696999999999733, 0.10783499999999968, -0.24686999999999815], [0.0, -0.13006499999999832, 0.7388550000000151, 1.5982200000000155, 0.2595450000000099, 1.55492999999999, -0.05128500000000713, 0.5469750000000122, 1.0648950000000124, 0.4541549999999983, 2.1631349999999987, 0.7946250000000035, 0.16925999999999242, 1.0231649999999899, 0.48749999999999716, -0.67645499999999, 0.3022499999999919, -0.5998200000000047, -0.14429999999999055, -0.670215000000006, -0.569789999999994, 0.641159999999994, -0.9028499999999973, 0.47424000000001065, 0.14488500000001991, 0.1499549999999985, 0.4087200000000131, -0.11232000000001463, -0.4252949999999984, -0.3030300000000068, 0.7386599999999834, 1.1791649999999958, 0.037440000000012574, 0.8459100000000159, 1.7612400000000168, 0.9473100000000088, 0.5957250000000016, 0.2111850000000004, -0.03295500000000118, 0.28704000000000285, -0.019305000000002792, 0.6411600000000064, 0.07839000000000773, -0.4769699999999979, -0.6475949999999973, 0.4656600000000086, -0.059864999999996726, 0.4748249999999974, 0.9328800000000044, 0.10588500000000245, 0.46955999999999243, 0.049920000000010845, 0.9005099999999917, 0.01618499999999834, 0.12480000000001823, 0.16204499999999022, -0.267540000000011, 0.014625000000004107, -0.3233099999999922, -0.5058300000000067, -0.3164850000000001, 0.1292849999999941, 0.3151199999999932, 0.053235000000002586, -0.3320850000000064, 0.20923499999997475, 0.0822900000000093, 0.44187000000000154, 0.723839999999992, 0.588704999999976, 0.6300450000000097, 0.22230000000000594, 1.0054200000000044, 0.9420449999999967, 0.9036299999999855, 0.44966999999999935, 0.10997999999999841, 0.5498999999999938, 0.39857999999999016, 0.8043750000000003, 0.7605000000000146, 0.09574500000000619], [0.0, -0.48145499999999686, -0.7160399999999996, -0.4590299999999994, 0.12616499999999764, 0.11271000000000253, -0.17023500000000347, -0.354509999999995, -0.13298999999999328, 0.07332000000000871, 0.12051000000000212, 0.15561000000000025, 0.25330500000000367, -0.8180250000000031, 0.018330000000008617, -0.5848049999999994, -0.7487999999999984, -0.9057750000000055, -0.29035499999999814, -0.6331650000000035, -0.6604649999999985, -0.8866649999999998, -0.7289099999999955, -0.3611399999999936, -0.9814350000000003, -0.9320999999999993, 0.13357499999999511, 0.47287500000000726, 0.09613499999999853, -0.11602500000000049, 0.06415500000000218, -0.39526499999999576, -0.7669349999999993, 0.12304500000000473, 0.2244450000000091, -0.061425000000002505, -0.5198699999999965, -1.0900499999999949, -1.9102199999999963, -1.5381599999999973, -0.8412300000000004, -1.6200599999999992, -0.8020349999999965, -0.3827850000000028, -0.2977649999999983, -1.2138749999999967, -0.5354699999999966, -0.2460899999999997, -0.2997150000000053, -0.02106000000000119, -0.4163250000000023, -0.36465000000000014, -0.911429999999994, 0.1554150000000032, -0.3825900000000022, -0.9695399999999976, -0.9044100000000004, -0.6864000000000008, -1.4833649999999965, -1.170389999999998, -1.4254499999999983, -1.1592749999999987, -1.7557799999999988, -1.1750699999999998, -1.288949999999999, -0.21118500000000395, -0.12538500000000052, -0.429195000000008, -0.4796999999999949, -0.5764199999999979, -0.46117500000000167, -0.9913800000000004, -0.5961150000000028, 0.23321999999999932, -0.48262499999999875, -0.897974999999998, 0.41281500000000104, 0.11193000000000008, -0.8152949999999963, -0.5380049999999983, 0.18232500000000318, -0.8815949999999964], [0.0, 1.0908300000000093, 0.4514250000000004, 0.6532500000000088, 0.3905849999999962, -0.11485499999998794, 0.28119000000001293, 0.12129000000001255, -0.5881200000000106, 0.3223349999999776, -0.18505499999997, 0.584415000000007, 0.14839500000001493, 0.6951749999999866, 0.01033500000002796, 0.15424499999998176, 0.20572499999999927, -0.1191449999999925, 0.9851400000000297, 0.429585000000003, -0.013649999999994833, 0.009750000000012804, -0.06610499999999853, 0.13006500000000543, 0.20260500000001258, 0.12246000000002688, -0.10061999999999394, -0.5417100000000126, -0.5177250000000058, -0.3810300000000044, -0.08541000000001375, -0.27475499999998654, -0.10510499999998046, -0.35392500000000915, 0.5227949999999915, 0.2496000000000027, -0.24511499999999486, 0.6140550000000182, -1.4387099999999826, -1.6559399999999975, 0.05186999999999742, -0.12713999999999714, -0.09711000000000425, 0.18057000000000833, -1.049099999999985, -0.16809000000001362, -0.9744149999999969, 0.09301500000000118, -0.05908499999998895, 0.32096999999998843, -0.9272249999999786, -0.3693300000000015, 0.5929949999999913, 0.4915949999999949, -0.4999799999999901, 0.06415500000001728, -0.5383949999999764, -0.5105099999999965, -0.4451849999999933, 0.7768799999999967, 0.002534999999994625, 0.30361499999998465, -0.03237000000000023, -0.9088949999999834, -0.09438000000002056, -0.2928899999999821, 0.6327750000000041, 0.005655000000016841, -0.1210950000000004, 0.32662499999999817, -0.4678049999999807, -0.35080499999999404, -0.052454999999993035, -0.8236799999999853, -0.07916999999999597, -0.16048499999997823, -0.562965000000009, 0.011115000000014419, -0.25506000000000384, 0.33793499999999455, 0.1782300000000152, -0.5721299999999871], [0.0, 0.6940049999999935, 0.46546499999999824, 0.8307000000000011, 0.9408749999999952, 0.536054999999994, 0.9749999999999956, -0.09886500000000442, 0.7564049999999964, 0.6768449999999975, 0.8266049999999945, 1.0395449999999933, 0.4828199999999927, 0.5953350000000004, 1.376114999999991, 0.9572549999999973, 1.286804999999998, 1.7746949999999964, 0.9172799999999968, 0.8256299999999954, 1.6647149999999962, 1.0516349999999965, 0.8425949999999944, 0.8999249999999952, 0.48301500000000175, 0.4015049999999962, 0.5573099999999975, 0.14449499999999826, 0.0007799999999944518, 0.44303999999999855, 0.16204499999999689, -0.42002999999999924, -0.30264000000000335, -0.24414000000000158, -0.20494500000000304, -0.05304000000000153, -1.0032750000000006, -0.597870000000003, -0.7333950000000011, 0.15229499999999918, -0.5495100000000055, -0.9034350000000011, -0.32877000000000045, -0.17940000000000111, -0.7222800000000014, -0.39975000000000094, -0.017550000000000843, -0.7234500000000013, 0.05186999999999786, 0.06337499999999485, 0.539174999999998, 0.5838300000000038, 0.05791499999999372, -0.5670600000000059, -0.40891500000000347, -0.49725000000000064, 0.7127250000000003, -0.013845000000005658, -0.1056900000000005, -0.3554850000000034, -0.47697000000000234, -0.44050500000000437, -0.6844500000000036, -0.16204499999999955, -0.44869500000000295, 0.5875349999999955, -0.6977100000000034, 0.4717049999999978, 0.27495000000000047, 0.9730499999999935, 0.013844999999998553, -0.19324500000000233, 0.1628249999999949, 0.553215000000002, -0.04036500000000265, -0.07644000000000695, 0.03665999999999725, -0.6626100000000035, 0.1355249999999968, -0.00429000000000368, 0.05908499999999828, 0.7271549999999976], [0.0, 0.30790499999999976, 0.16750500000000001, 0.24998999999999905, 0.2653949999999998, 0.8394749999999993, 0.3779100000000002, 0.06688500000000164, -0.3525600000000009, 0.002924999999998734, 0.18290999999999902, 0.5034900000000003, 0.34241999999999884, 0.7057050000000004, 0.2542799999999995, 0.2330250000000006, 0.24998999999999982, 0.5313749999999998, 0.7560149999999997, 1.1750699999999994, 0.9094799999999998, 0.7476299999999994, 0.8474699999999991, 0.21586499999999953, 0.2065049999999995, 0.8069099999999997, 0.23341499999999926, 0.040754999999998986, 0.28645499999999935, -0.06883499999999998, -0.25818000000000074, -0.21099, -0.2318550000000006, -0.3151200000000003, -0.17803499999999928, 0.1519050000000004, -0.5286450000000005, 0.06785999999999914, 0.1831050000000003, -0.43114499999999767, 0.09087000000000023, 0.23419499999999882, 0.2148899999999998, 0.24628499999999975, 0.01423499999999911, 0.22658999999999918, 0.2146950000000003, 0.103545, -0.20084999999999864, -0.3297450000000013, -0.07800000000000007, -0.39838500000000066, 0.08384999999999909, -0.516555000000001, -0.1074449999999989, 0.1283100000000008, -0.47657999999999956, 0.13162499999999921, 0.28762499999999935, -0.28274999999999917, -0.1472250000000006, -0.3353999999999986, 0.15014999999999956, 0.08072999999999952, -0.28353000000000006, -0.1376700000000004, -0.5422950000000009, -0.3535350000000004, -0.18232499999999918, -0.6056700000000015, -0.15970499999999888, -0.24940499999999832, -0.006240000000001356, 0.3697199999999984, 0.06376499999999852, 0.09164999999999912, -0.2199599999999977, 0.10783499999999768, 0.13337999999999917, -0.030224999999998614, 0.17939999999999845, 0.21878999999999982], [0.0, 0.2195699999999965, -0.4007249999999978, -0.22386000000000017, 0.619125000000003, 0.6074250000000045, -0.058889999999999, 1.1306100000000017, 0.5333250000000032, 1.1672700000000047, 0.902654999999994, 1.008930000000003, 1.0516349999999983, 1.498965, 1.0935599999999939, 0.7259850000000023, 0.9634949999999991, 0.5149950000000034, 0.4888650000000032, 0.07780499999999968, 0.7123350000000004, 0.6546150000000006, 0.253695000000004, 0.1390350000000029, 0.6684600000000023, 0.6571499999999979, 0.3381300000000014, 0.6247799999999906, 0.37518000000000207, 0.008580000000004695, -0.004875000000001961, 0.007800000000004914, 0.14878500000000372, -0.0698100000000017, -0.22112999999999428, 0.09204000000000345, -0.3104399999999998, 0.4734599999999993, -0.1559999999999988, -0.6029399999999963, -0.24998999999999683, -0.4525949999999974, -0.36035999999999824, -0.05343000000000009, 0.04524000000000905, 0.20045999999999964, 0.13825499999999735, 0.3170699999999984, 0.08404500000000636, 0.7162350000000055, 0.39429000000000247, 0.470729999999997, 0.2899649999999987, 0.5444399999999998, -0.07956000000000518, 0.026714999999997602, 0.11407500000000148, -0.4445999999999981, -0.4765799999999998, -0.20982000000000323, 0.17920500000000006, 0.32545499999999805, 0.1275300000000006, 0.2763150000000021, 0.2696849999999973, -0.23263499999999748, 0.2767050000000024, 0.6043049999999948, 1.0180950000000024, 0.8782800000000002, 0.9262499999999978, 1.1553749999999985, 0.8098350000000059, 0.5017350000000036, 0.6661199999999985, 1.138799999999998, 0.8156849999999993, 0.5625750000000043, 0.5873400000000037, -0.10783499999999746, 0.4701449999999996, 0.3804449999999999], [0.0, 0.6573449999999852, 0.8178299999999954, 0.8868599999999685, 0.6863999999999884, 0.6791849999999915, 0.8872499999999928, 1.2829049999999889, 1.1132550000000023, 0.5953349999999897, 0.5805149999999895, 0.41047499999999815, 0.9794849999999897, 1.15439999999999, 1.0455899999999918, 1.1366549999999904, 1.4944799999999923, 1.6766100000000073, 0.508364999999996, 0.5947499999999959, 1.4656199999999995, 1.4580150000000032, 0.8895899999999894, 0.5916299999999968, 1.0580699999999883, 1.0582649999999987, 0.4494749999999943, 0.6074249999999957, 0.7402200000000025, 0.3367649999999873, 0.6004049999999967, -0.20494500000001104, 0.1729649999999996, -0.059475000000023925, 0.09808499999999043, -0.14624999999999844, -0.48652500000002696, -0.4225650000000165, 0.49354499999999923, 0.03197999999997414, 0.25369499999997736, -0.09691500000001163, 0.08813999999998146, 0.42938999999998195, 0.09574499999999198, 0.4510349999999974, 0.17140499999998404, -0.07956000000000607, -0.32545500000001404, 0.16009499999998233, 0.1836899999999968, -0.09633000000002312, 0.36133499999999685, -0.06825000000001147, 0.45201000000000136, 0.21254999999998248, 0.35099999999999376, 0.7191599999999809, 0.6959549999999837, 0.011309999999992826, 0.24394499999998587, 0.3708899999999904, 0.18212999999999901, 0.28372499999997736, 0.35158499999999115, 0.4978349999999896, 0.6236099999999993, 0.4785300000000028, 0.5775899999999936, 1.0377900000000135, 0.3424200000000095, 0.6216599999999985, 0.2533049999999868, 0.26734499999999173, 0.7331999999999965, 0.38141999999999143, 0.5524349999999938, 0.7211099999999853, 0.3909749999999992, -0.01852500000001278, 0.9112350000000013, 0.5005649999999946], ...]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>950962279</th>\n",
       "      <td>0.840895</td>\n",
       "      <td>NaN</td>\n",
       "      <td>21.69</td>\n",
       "      <td>0.947739</td>\n",
       "      <td>150</td>\n",
       "      <td>0.014174</td>\n",
       "      <td>NaN</td>\n",
       "      <td>2299.182784</td>\n",
       "      <td>NaN</td>\n",
       "      <td>noise</td>\n",
       "      <td>0.160246</td>\n",
       "      <td>110.0</td>\n",
       "      <td>0.359335</td>\n",
       "      <td>900.086645</td>\n",
       "      <td>850180684</td>\n",
       "      <td>0.769004</td>\n",
       "      <td>149</td>\n",
       "      <td>-0.109312</td>\n",
       "      <td>0.16</td>\n",
       "      <td>0.686767</td>\n",
       "      <td>0.031516</td>\n",
       "      <td>NaN</td>\n",
       "      <td>67.96</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>1.167504</td>\n",
       "      <td>NaN</td>\n",
       "      <td>[508.11441169093075, 1028.0623131485363, 1034.5582127503012, 1034.5587127502706, 1072.781143740354, 1074.6238769607176, 1074.7187436215684, 1074.765176952055, 1075.9467102129538, 1076.2404101949483, 1076.6607101691816, 1076.7773101620335, 1076.7777768286714, 1077.6019434448122, 1078.0852767485144, 1078.253643404859, 1078.391076729767, 1078.5550100530504, 1079.2096766795823, 1080.0417432952386, 1080.9976765699678, 1081.7294098584418, 1111.0427413947032, 1111.0432413946726, 1112.1041079963022, 1112.1044079962837, 1112.1056413295414, 1112.1292079947634, 1113.3342745875527, 1114.390974522771, 1114.4145745213243, 3204.829213033828, 3208.256679490372, 3209.141846102773, 3210.3669126943364, 3211.908479266496, 3211.9088459331406, 3212.0297459257285, 3212.4119459022977, 3212.4128125689112, 3212.5193792290447, 3213.007945865759, 3223.042545250582, 3224.1034118522116, 3224.127445184072, 4178.209320026825, 4181.075519851111, 4181.075986517749, 4182.131919786348, 4182.156153118195, 4752.314651497609, 6108.039668384048, 6108.040168384017, 6111.272334852534, 6112.330968120968, 6112.353134786275, 6113.396468055646, 7416.876254811678, 7422.620021126219, 8166.580175517282, 8166.581008850564, 8166.583242183761, 8166.583675517068, 8166.585142183644, 8166.588942183412, 8172.7543084721065, 8491.040222292726, 8492.079688895668, 8492.080922228924, 9225.196543951484, 9231.26084357971, 9231.360843573579, 9231.460843567449, 9231.560843561318, 9238.074309828673, 9241.63367627713, 9241.732576271066, 9241.833109598238, 9242.231976240451, 9242.232409573757, 9242.33194290099, 9242.432409561496, 9242.432909561467, 9242.532442888698, 9245.544509370708, 9245.545076037339, 9245.545476037314, 9245.556176036658, 9253.11727557312, 9254.830042134785, 9256.676475354921, 9257.17647532427, 9257.276475318138, 9257.47600863924, 9257.576008633108, 9264.67167486477, 9268.345407972884, 9273.932740963683, 9273.933107630326, 9274.032740957551, ...]</td>\n",
       "      <td>[0.00019446292452144539, 0.00028776945509786836, 0.0001910601427272853, 0.0006515109306546342, 0.0004209706162889785, 0.0001760577509463769, 0.0004284175704827291, 0.0002904615003997955, 0.0002039476026557015, 0.00030102118885981006, 0.000492633870323081, 0.0002057065620944732, 0.0004600351833864843, 0.00020773869944622523, 0.0002917891312473346, 0.00024469619671642286, 0.00030356380860524604, 0.0002821246151717438, 0.00029272466516623596, 0.00026771068263709285, 0.00010451309422829866, 0.0001489497078092421, 0.00010736228587791564, 0.0005633265644099174, 0.00019695648899597276, 0.0005226352956545795, 0.00012423414484479285, 0.0001945292888018908, 0.0003076644902916381, 0.0005454437054979714, 0.000291038833546541, 0.0002618244738300199, 0.00038935796226737527, 0.0003605816319100579, 0.0002777358789259155, 0.0001369173411987428, 0.0002156215331040694, 0.00020813147115945964, 0.0001573541970382772, 0.00017317480437426333, 0.00024987104132466134, 0.00023066613815392981, 9.642412956884873e-05, 0.0002379841614117287, 0.00012391502665491398, 0.0005921967369041615, 0.0002957081546432476, 0.0006206879001524096, 0.0002819123875697708, 0.0005227350382335606, 0.0003897523503251086, 0.0002996337061878163, 0.0005538269154732151, 0.00026942604785238917, 0.00016553294728074167, 0.0003190929246881526, 0.0005134905520303751, 0.00012821652737579644, 0.0006035904905109422, 0.0003429725158470337, 0.0003327100464628375, 0.0004542514006041139, 0.00016076105892534717, 0.00023874411010152066, 0.00018895183317943915, 0.00042043835247622196, 0.0005738692106357008, 0.0005525871949352185, 0.0005251287659731167, 0.000763734137223037, 0.0007491731016463205, 0.0007458931463414123, 0.0008359579332522944, 0.0007477118006779883, 0.000716503734946393, 0.0015190010145568872, 0.0008838767413588223, 0.0012365061780315685, 0.0002005559940390484, 0.00034010148000768387, 0.00017944822969114728, 0.00033970520883014603, 0.0002342023389862424, 0.00033064633546902916, 0.0004248533268579937, 0.0006941199058482674, 0.0002927174465403185, 0.00024201592091327418, 0.00048027062387025687, 0.0004964724531180094, 0.001512940130695277, 0.0015207638657765883, 0.0015206380733736443, 0.0014818445499866736, 0.0015259162071031623, 0.00046620720270189314, 0.0002898004939630677, 0.0009608911941708596, 0.0006041192705520603, 0.0009706867439995172, ...]</td>\n",
       "      <td>[[0.0, -1.96475328947367, 4.27268092105264, 0.5279111842105451, 6.0687335526315564, 7.362532894736873, 14.594851973684172, 4.987894736842122, 9.745509868421053, -5.33171052631581, -48.53832236842112, -86.36254934210531, -130.47103618421062, -136.06253289473693, -108.06656250000003, -108.06912828947372, -83.78777960526321, -63.26018092105269, -46.79615131578954, -32.196167763157945, -36.079490131579, -31.793338815789518, -15.787944078947412, -28.77917763157898, -43.34067434210531, -37.39060855263163, -66.7887828947369, -94.52753289473688, -103.50202302631584, -140.09467105263164, -154.69593750000007, -165.5036842105264, -134.8380098684211, -103.04210526315796, -66.69962171052637, -61.69120065789479, -44.195082236842154, -47.319572368421106, -55.40052631578953, -81.60429276315796, -96.55514802631586, -116.480427631579, -130.38123355263167, -131.57432565789475, -133.84055921052635, -138.33518092105274, -154.8684868421053, -123.91608552631578, -115.36430921052636, -89.12782894736849, -20.986233552631653, -25.666233552631653, -46.51263157894741, -85.5357236842106, -110.03131578947375, -135.56925986842123, -175.94452302631584, -157.2937993421054, -161.49399671052635, -121.24958881578956, -123.58317434210534, -125.47480263157908, -120.93078947368426, -119.63506578947371, -146.64256578947374, -141.11649671052643, -125.94434210526316, -146.27694078947383, -121.65690789473696, -136.9252796052632, -149.18911184210532, -153.1763486842107, -149.42388157894746, -158.85572368421063, -168.2214967105264, -185.81575657894751, -192.38866776315786, -184.58032894736837, -181.37822368421058, -173.70715460526316, -178.65078947368428, -178.0471875000001], [0.0, 4.59212171052628, 3.937845394736838, 6.842960526315759, 1.8127302631578868, 2.789013157894729, 6.515180921052595, 3.8993585526315666, 9.887911184210497, 12.96108552631575, 16.945756578947368, 1.7633388157894618, -4.987894736842117, -4.572878289473693, 3.9057730263157797, 19.21648026315789, 28.364161184210538, 20.586611842105256, 22.600756578947355, 20.417269736842094, 16.720608552631568, 14.0079276315789, 23.18319078947372, 25.66110197368426, 28.65666118421057, 34.59518092105266, 35.98070723684212, 33.53166118421054, 32.64902960526315, 34.81199013157896, 26.834309210526293, 22.924687499999976, 22.982417763157862, 24.933059210526316, 33.50343749999998, 29.858733552631556, 27.30513157894736, 32.17435855263157, 39.2482401315789, 37.18021381578946, 45.46514802631576, 48.9552631578947, 45.49337171052631, 58.015065789473695, 57.500625, 51.78404605263154, 40.1186842105263, 40.678667763157875, 44.789062499999986, 40.978223684210455, 35.06600328947363, 32.06467105263155, 30.405246710526306, 25.258273026315777, 33.31613486842101, 31.48736842105263, 34.170542763157876, 34.12820723684208, 33.721529605263136, 34.846628289473664, 23.308914473684197, 18.234424342105257, 11.604424342105252, 9.42478618421052, 13.920049342105242, 11.445986842105247, 10.411332236842094, 5.7704605263158, 3.792878289473686, 0.4560690789473547, -0.7729440789473934, -1.7966940789473806, -1.5535855263157998, -2.7120394736842304, -6.025756578947381, 1.3912993421052402, -0.812072368421072, -4.645361842105273, -3.803141447368425, -9.72883223684212, -13.59932565789475, -12.549917763157907], [0.0, 5.010345394736859, 4.200838815789467, 13.038700657894779, 13.817417763157955, 11.855230263157964, 18.77452302631587, 19.40891447368427, 19.13758223684217, 1.7299835526315555, -7.037960526315825, -14.188174342105295, -29.66437500000003, -30.389851973684245, -35.65485197368424, -23.86120065789477, -14.100296052631613, -4.8320230263158415, 10.66855263157899, 14.075279605263198, 22.437828947368494, 23.326233552631663, 31.298141447368437, 35.604177631578956, 29.944046052631585, 18.758486842105285, 18.286381578947413, 14.139424342105258, 0.5850000000000009, -2.3528289473684296, -11.077154605263193, -6.891069078947414, -7.568437500000034, 5.340049342105189, 14.565986842105218, 32.246842105263084, 30.067203947368448, 32.474555921052676, 38.772286184210536, 39.77615131578951, 32.69970394736839, 23.44618421052627, 20.74889802631573, 15.984868421052603, 29.195476973684144, 32.10251644736839, 11.06817434210523, 26.196069078947296, 20.999062500000008, 31.525855263157872, 39.359210526315856, 38.52468750000002, 39.18024671052634, 38.51763157894742, 22.662976973684152, 27.643815789473663, 22.72327302631576, 14.108634868421028, 21.88105263157893, 18.117039473684173, 18.04648026315786, 16.557680921052594, 16.198470394736823, 5.038569078947347, -3.699868421052649, -0.6523519736842545, 5.320805921052596, 15.969473684210506, 14.527499999999925, 5.794194078947342, -0.24054276315794354, -5.932105263157929, -8.287500000000026, -5.170707236842137, -1.9237006578947913, -11.815460526315814, -14.650016447368456, -13.956611842105293, -12.515279605263185, -13.192006578947407, -11.349769736842127, -12.599309210526357], [0.0, -0.4509374999999949, 2.5741282894737054, 0.5574177631579147, 4.445230263157907, 2.7941447368421173, -1.558717105263149, -2.0718749999999986, 4.352220394736836, 19.188898026315858, 21.988174342105317, 21.05294407894742, 26.129358552631633, 34.30845394736848, 35.88320723684216, 32.40014802631584, 26.630970394736895, 7.822450657894787, 13.381875000000043, 18.414671052631633, 14.52108552631584, 16.646842105263207, 15.577549342105304, 8.883404605263198, 10.383750000000042, 21.27039473684216, 26.33718750000005, 20.32041118421059, 29.877335526315846, 25.586694078947424, 24.283914473684263, 29.706069078947422, 32.38411184210532, 32.78822368421058, 36.01149671052637, 35.09294407894742, 39.94549342105268, 50.338865131579, 54.14328947368429, 56.75333881578955, 50.461381578947424, 50.208651315789524, 57.38259868421056, 58.62636513157898, 46.66786184210532, 56.255575657894795, 59.5949506578948, 61.75726973684216, 63.20950657894741, 60.752121710526396, 56.57116776315796, 53.38574013157903, 53.68850328947376, 53.140707236842175, 56.544226973684275, 58.4948684210527, 57.8489309210527, 61.49491776315794, 62.205000000000055, 54.94958881578953, 64.84070723684216, 67.66050986842112, 58.40121710526321, 54.64297697368426, 51.95531250000003, 48.96873355263164, 46.81796052631583, 48.99759868421059, 41.864062500000045, 40.80567434210531, 41.39580592105268, 40.30662828947373, 38.55611842105269, 37.94032894736847, 36.7709703947369, 44.968026315789515, 35.17248355263163, 37.53429276315795, 47.016167763157945, 39.27710526315795, 41.749884868421105, 43.64343750000005], [0.0, -0.01796052631579048, 2.336792763157906, 3.642779605263165, 2.3695065789473775, 1.4644243421052643, 2.8743256578947443, 4.8121381578947435, 8.835296052631588, 6.118766447368427, 4.2771710526315845, -1.7171546052631523, -3.5106414473684113, -7.65375, -1.728059210526311, 1.7011184210526302, 9.011694078947375, 12.712845394736846, 13.992532894736843, 8.030279605263166, 4.4984703947368505, -5.172631578947391, -3.2617598684210654, -0.9794901315789604, 16.004753289473687, 20.400592105263165, 19.00672697368421, 29.625888157894746, 24.122911184210526, 22.505822368421054, 27.5136019736842, 27.474473684210523, 28.532861842105284, 28.30899671052633, 31.004358552631594, 21.00098684210528, 15.507631578947379, 9.036710526315794, 4.143750000000007, 0.987828947368425, 1.7639802631579018, 11.618536184210532, 25.89266447368421, 31.474539473684235, 29.353273026315783, 21.040756578947377, 6.242565789473689, 12.95723684210527, 13.827039473684223, 26.727828947368444, 33.64776315789479, 33.27700657894742, 30.62013157894741, 21.682845394736884, 14.19458881578949, 17.075970394736867, 16.27672697368423, 12.755180921052634, 14.786644736842117, 21.233832236842122, 14.628207236842119, 6.762779605263162, -1.3002138157894665, -1.9217763157894696, -7.066825657894731, -1.2822532894736813, 5.477960526315795, 6.428585526315795, 10.675608552631584, 9.498552631578953, 9.637746710526317, 7.991792763157898, 10.053404605263168, 10.350394736842107, 13.124654605263158, 9.836595394736847, 8.397187500000006, 9.701250000000007, 7.606282894736847, 6.36379934210527, -0.6799342105263131, -3.234819078947365], [0.0, -3.476644736842175, -5.006496710526399, -5.019967105263248, -5.443322368421136, -4.864736842105309, -8.632598684210613, -10.1675822368422, -6.562648026315827, -1.8435197368421399, 10.634555921052659, 11.253552631578977, 8.711496710526312, 19.168371710526333, 22.83296052631579, 21.038832236842094, 15.714819078947372, -2.97824013157895, -0.6003947368421265, -5.465773026315851, -5.146973684210579, -6.4536019736842505, -6.248980263157975, -9.712154605263265, -12.394687500000053, -11.941184210526373, -11.237516447368456, -9.25031250000005, -11.274078947368459, -2.8384046052631575, -7.1367434210525715, -0.2084703947368638, 4.522203947368396, 7.729440789473671, 13.222796052631587, 15.329309210526315, 15.154194078947366, 17.764243421052647, 16.5102138157895, 12.37351973684212, 9.487006578947373, 11.030970394736826, 9.477384868421048, 8.383075657894736, 6.699276315789483, 9.857763157894745, 0.652351973684226, 9.6762335526316, 14.413963815789458, 16.13432565789473, 8.64478618421056, 9.240690789473717, 11.621101973684233, 16.29340460526319, 18.1747697368421, 18.081118421052647, 21.402532894736847, 19.40314144736843, 20.88552631578947, 17.362697368421063, 15.812960526315802, 18.807236842105258, 21.011249999999993, 20.559029605263145, 19.112565789473667, 22.29478618421052, 25.738075657894733, 23.37049342105263, 18.156167763157924, 16.288914473684237, 16.776414473684223, 17.811710526315814, 19.060608552631578, 16.766151315789507, 17.869440789473703, 19.337072368421044, 20.990723684210533, 21.494259868421075, 25.263404605263155, 24.392319078947356, 26.752845394736827, 27.236496710526314], [0.0, 3.2752302631578916, 2.6600822368421064, 3.917960526315783, 3.5786348684210543, 7.219490131578938, 9.940509868421044, 6.986644736842099, 4.389424342105256, -4.874358552631584, -5.01419407894737, -7.752532894736849, -12.03996710526316, -16.504440789473687, -13.617927631578947, -6.367648026315788, -0.1276480263157893, 1.3342105263157902, 4.743503289473681, 5.368914473684207, 7.458108552631574, 16.179226973684198, 17.95667763157894, 13.929671052631566, 9.369621710526316, 5.8172861842105235, 6.230378289473684, 2.9962006578947364, -1.0083552631578951, 2.3393585526315803, -1.1873190789473689, -2.1469243421052635, -3.5523355263157885, 2.8826644736842097, 8.300328947368424, 16.269029605263153, 19.15490131578948, 22.93815789473686, 22.02794407894737, 24.74447368421053, 23.64118421052633, 20.287055921052644, 17.59810855263158, 6.948799342105262, 15.960493421052627, 15.744325657894738, 9.398486842105267, 17.424276315789466, 17.04582236842105, 21.471809210526335, 20.4833388157895, 17.54166118421053, 16.79629934210526, 15.63271381578947, 16.538437499999997, 22.187023026315796, 18.40761513157893, 25.13960526315791, 22.582796052631597, 21.18572368421053, 15.511480263157898, 19.4082730263158, 20.548125000000002, 15.137516447368414, 9.444029605263163, 5.261792763157894, 5.886562500000001, 5.565197368421054, 5.871809210526315, 5.935312499999996, 8.665953947368429, 6.286825657894735, 8.56652960526316, 6.46899671052632, 6.300937500000005, 6.754440789473683, 6.536990131578949, 5.381743421052631, 4.358634868421053, 4.628042763157895, 4.884621710526317, 3.577993421052632], [0.0, 0.33226973684211103, 0.6016776315789478, 0.7986019736842209, -1.264934210526313, 2.991710526315792, 6.837828947368422, 11.321546052631586, 13.02843749999995, 4.707582236842093, 2.880740131578939, -12.472944078947373, -22.904802631578942, -26.268552631578945, -23.92021381578948, -11.861003289473686, 1.268782894736848, 9.332417763157899, 14.11376644736842, 7.63450657894737, 7.1662499999999945, 7.0828618421052525, 11.723733552631586, 17.74949013157895, 25.36475328947368, 21.783552631578967, 18.75912828947369, 19.451891447368435, 9.424144736842102, 14.276694078947376, 12.280509868421035, 11.313207236842118, 14.662845394736834, 23.23065789473684, 28.11078947368421, 29.45013157894734, 23.124819078947358, 19.23636513157894, 12.318355263157923, 13.28373355263161, 20.950953947368408, 24.5321546052631, 24.058124999999993, 23.671332236842108, 35.43291118421054, 21.986250000000016, 12.905279605263168, 26.213388157894716, 25.16847039473682, 31.757417763157843, 29.741348684210497, 31.089671052631505, 32.604128289473636, 27.84458881578946, 23.695065789473663, 18.93488486842104, 13.392138157894756, 15.749457236842112, 16.74883223684211, 22.13827302631579, 11.778256578947364, 13.592911184210514, 8.853256578947374, 5.1014309210526285, -1.5272861842105243, -3.9205263157894716, -2.6716282894736647, -4.727467105263161, -2.3618092105262942, -4.190575657894726, -3.8377796052631403, -3.88909539473684, -4.726825657894725, -7.097615131578944, -3.7274506578947406, -8.225279605263157, -8.237467105263157, -8.758963815789471, -11.51975328947368, -10.31319078947368, -17.274177631578947, -16.63016447368421], [0.0, -1.919210526315819, 0.822976973684213, 5.179687499999986, 1.1199671052631572, 0.2771052631578925, 1.1590953947368234, 1.704967105263158, 2.680608552631554, 4.354144736842041, -2.3900328947368834, -0.2136019736842627, -0.9377960526316471, -0.590131578947414, 5.93146381578941, 8.037335526315726, 5.062302631578881, 4.406101973684162, 5.590855263157863, 8.247088815789429, 4.883980263157859, 8.585773026315739, 15.553174342105189, 13.442812499999926, 7.034111842105233, 8.630032894736782, 8.300970394736787, 5.708881578947313, 11.762861842105183, 3.129621710526248, 6.637697368420987, 3.9583717105262437, 7.735855263157816, 12.871282894736781, 14.448601973684152, 18.959259868420983, 22.344177631578876, 28.918371710526245, 29.895937499999924, 29.64577302631572, 23.271069078947296, 28.520032894736772, 27.302565789473615, 17.92460526315782, 21.582138157894665, 24.344851973684143, 15.213207236842042, 23.720082236842035, 25.161414473684143, 21.818190789473608, 18.040065789473623, 15.927779605263098, 19.799555921052555, 17.660328947368356, 21.32171052631572, 21.775855263157823, 24.579621710526247, 22.80088815789467, 22.921480263157825, 20.365953947368354, 22.677088815789403, 19.419819078947295, 20.457039473684148, 17.494194078947302, 12.76351973684204, 12.156069078947306, 9.61401315789465, 5.660773026315724, 4.680641447368334, 5.816644736842026, 5.511315789473613, 5.990476973684149, 6.436924342105193, 5.324013157894662, 4.5754440789473065, 5.037927631578885, 6.178421052631492, 5.476677631578887, 4.811496710526239, 4.685131578947296, 8.960378289473603, 5.850641447368368], [0.0, -2.226463815789483, -1.218108552631584, 1.4086184210526298, 3.2919078947368554, 4.242532894736872, 6.617171052631608, 11.030970394736894, 8.140608552631605, 1.6049013157894763, -4.145032894736852, -2.1924671052631606, -4.447796052631583, -13.248453947368423, -10.202861842105266, -4.220082236842117, -5.994325657894745, -6.960986842105269, -4.065493421052643, -1.5818092105263215, 4.8544736842105465, 11.369654605263193, 14.347894736842147, 14.6455263157895, 12.08101973684212, 9.217598684210547, 10.345263157894742, 10.333075657894746, 12.33503289473682, 10.131661184210532, 11.851381578947379, 2.409917763157896, -3.055213815789484, 0.6619736842105368, 5.054605263157875, 12.472944078947332, 13.281809210526305, 14.34148026315787, 8.233618421052622, 10.580032894736842, 12.62175986842107, 17.21901315789474, 18.16514802631578, 24.24157894736845, 22.61486842105263, 15.965625000000006, -5.493355263157897, 1.7197203947368251, -1.3560197368420965, 16.92138157894733, 19.940674342105222, 18.36912828947364, 22.367269736842058, 16.759095394736807, 15.439638157894738, 21.25756578947365, 15.26452302631579, 23.843240131578884, 26.01582236842103, 28.348125, 14.370345394736827, 9.494062499999995, 0.5811513157894836, -2.1238322368421034, -7.715328947368423, -2.1257565789473727, 1.3149671052631504, 5.849358552631568, 10.134868421052609, 10.877664473684199, 12.9258059210526, 13.165707236842088, 15.827072368421032, 17.279950657894677, 18.349884868421025, 13.222154605263146, 14.290164473684221, 15.018207236842112, 8.350361842105258, 5.725559210526313, 1.6613486842105019, 1.7902796052631658], [0.0, -0.8710855263157895, -0.799243421052632, -0.2931414473684244, -1.806315789473684, -2.3432072368421055, -2.8800986842105267, -4.845493421052632, -9.46455592105263, -17.29470394736842, -12.998930921052628, -10.816085526315787, -12.739144736842105, -9.302269736842112, -7.0732401315789515, -8.391414473684213, -7.1707401315789445, -7.537006578947368, -7.464523026315792, -7.316990131578949, -5.140559210526316, -5.078338815789474, -4.755690789473686, -5.905805921052631, -11.861644736842107, -16.041315789473696, -15.28761513157895, -14.42230263157895, -22.30055921052632, -23.039506578947364, -23.690575657894733, -22.008700657894757, -19.000312499999996, -12.581990131578952, -6.569062499999999, -0.9281743421052582, 2.475986842105257, 4.086019736842099, 3.8223848684210515, 1.574753289473684, -9.501759868421052, -11.126546052631577, -16.056069078947374, -19.630855263157905, -17.253009868421053, -14.094523026315796, -12.550559210526316, -7.827582236842105, -7.429884868421053, 6.383684210526319, 5.269490131578939, 4.8743585526315645, 5.096940789473674, 0.19307565789473635, -2.1270394736842118, -0.3880756578947362, -4.127713815789473, -4.811496710526317, -7.5684375000000035, -5.715296052631579, -1.1321546052631595, -3.756957236842106, -2.8127467105263166, -1.4887993421052652, -5.6780921052631586, -2.851875000000001, -1.7447368421052625, 1.551019736842107, 0.8479934210526312, 0.32777960526315875, -2.558092105263156, -4.3323355263157906, -3.432384868421053, -2.9731085526315795, -5.301562500000001, -7.455542763157897, -7.379851973684207, -6.0854111842105265, -7.589605263157896, -6.598569078947369, -5.267565789473684, -4.756973684210527], [0.0, -1.3124013157894714, 0.30981907894736693, 2.5144736842105306, 3.545921052631592, -1.8820065789473714, -1.1045723684210502, -0.48557565789473767, -4.630608552631579, -5.652434210526308, -11.123980263157879, 8.017450657894745, 21.337746710526318, 15.190756578947376, 16.877763157894748, 12.332467105263168, 1.5516611842105386, 1.0506907894736814, -0.10199013157894488, 1.457368421052637, -4.2463815789473776, -8.256710526315786, -11.513338815789478, -12.438947368421069, -3.7992927631579017, 2.5747697368421134, 5.0109868421052735, 14.415246710526322, 21.09720394736843, 18.972730263157906, 31.949210526315795, 29.022927631578963, 17.85404605263158, 15.524309210526322, 11.44791118421053, 9.909078947368428, 7.196398026315797, 4.271398026315797, 2.951299342105269, -1.0513322368421028, -6.567138157894733, -0.8550493421052527, 2.6587993421052696, 16.718684210526316, 14.156743421052647, 6.665921052631588, 1.5529440789473767, 6.526085526315798, 10.558865131578955, 25.66495065789476, 26.077401315789476, 25.895871710526322, 25.07546052631579, 18.839950657894747, 13.644226973684216, 21.55968750000002, 11.9495230263158, 17.260707236842105, 14.834111842105276, 22.808585526315802, 21.91697368421055, 14.735328947368426, 9.783996710526324, 4.585707236842113, 0.40603618421053866, 11.356825657894742, 21.454490131578964, 30.803585526315818, 35.80559210526316, 39.11802631578949, 43.322713815789456, 44.31310855263161, 49.3709210526316, 56.169621710526364, 53.89312500000002, 48.529983552631556, 48.09764802631579, 49.546036184210536, 42.54463815789477, 35.47588815789475, 34.90564144736843, 32.81837171052631], [0.0, -1.3277960526315788, 0.7222697368421043, 4.256003289473678, 7.340723684210528, 8.122648026315801, 7.331101973684217, 8.454276315789496, 11.710904605263181, 15.10672697368423, 13.034851973684214, 13.489638157894731, 10.757713815789485, 8.220148026315787, 12.377368421052632, 15.576907894736832, 14.088108552631594, 15.757154605263155, 15.23501644736845, 18.417878289473716, 28.280131578947397, 26.047253289473698, 27.79648026315791, 31.666973684210554, 33.55090460526316, 38.83835526315792, 40.2302960526316, 42.66074013157892, 45.192532894736864, 43.32271381578947, 35.35273026315789, 33.14550986842105, 32.22503289473683, 36.47654605263159, 36.246907894736836, 38.96792763157894, 35.47588815789474, 39.660049342105275, 47.74421052631576, 54.91559210526313, 45.562648026315784, 45.90710526315787, 42.18991776315791, 51.007894736842125, 53.474901315789516, 47.10853618421053, 31.82541118421055, 34.84598684210525, 34.41878289473684, 47.38050986842103, 45.426661184210495, 40.39707236842103, 36.599703947368376, 32.144851973684226, 30.652203947368385, 34.43353618421052, 34.058289473684205, 42.30152960526313, 33.97169407894739, 39.7177796052632, 41.00259868421054, 38.654259868421065, 25.89972039473683, 16.153569078947374, 9.15024671052631, 10.497286184210521, 13.4460197368421, 10.995690789473679, 11.363240131578934, 11.058552631578932, 11.396595394736826, 10.784013157894725, 13.291430921052623, 13.473601973684199, 13.273470394736838, 12.238174342105262, 11.780822368421052, 14.297220394736835, 7.6248848684210495, 10.35552631578947, 4.554276315789472, 0.618355263157895], [0.0, 1.1841118421052705, 1.9859210526315945, 2.715246710526319, 3.23674342105263, 4.77044407894738, 7.186134868421055, 8.055296052631581, 4.019950657894739, -5.223947368421055, -4.236759868421055, -3.9051315789473797, -4.451003289473693, -5.767894736842111, -2.32588815789474, -0.30340460526316804, 1.8730263157894669, 4.419572368421042, 6.545328947368434, 7.571644736842108, 10.03672697368422, 11.54027960526315, 12.392763157894743, 14.44282894736842, 14.542894736842099, 13.639736842105266, 11.023914473684213, 9.594128289473671, 8.259917763157878, 8.746776315789466, 9.131003289473663, 10.549884868421037, 12.143240131578947, 14.087467105263146, 15.006661184210488, 17.936151315789473, 17.239539473684204, 17.287006578947377, 13.324786184210508, 15.503141447368401, 18.10549342105263, 17.026578947368407, 14.435773026315784, 11.22917763157893, 11.880888157894733, 7.134177631578931, 3.6787006578947263, 14.715444078947352, 11.595444078947361, 20.30245065789469, 20.593026315789437, 19.304358552631577, 19.57825657894736, 15.485822368421063, 15.140082236842103, 16.508289473684187, 11.163108552631565, 9.008486842105258, 9.959111842105239, 9.009128289473685, 6.865411184210517, 2.641480263157888, -1.46057565789474, -2.8358388157894776, -6.334292763157901, 1.0853289473684171, 3.896151315789467, 2.146282894736835, 4.78263157894737, 4.205970394736839, 5.818569078947357, 5.0796217105263235, 5.266924342105263, 5.329786184210532, 4.186726973684207, 1.2341447368421008, -0.9698684210526345, -1.1174013157894773, -3.085361842105269, -3.631875000000007, -4.853832236842121, -5.923766447368425], [0.0, 1.2861019736842305, 4.343240131578973, 7.637072368421073, 9.030937500000032, 7.073240131578981, 11.708980263157923, 13.529407894736849, 8.60309210526318, 4.329128289473678, 5.247680921052632, 25.37758223684211, 29.838848684210546, 13.65833881578946, 14.864259868421033, 14.244621710526314, 11.315773026315778, 12.204819078947338, 12.613421052631551, 13.83922697368418, 20.20430921052629, 23.14085526315788, 24.10815789473685, 23.151759868421074, 20.770065789473705, 20.755312500000006, 24.26082236842108, 24.976677631578944, 36.402779605263156, 38.80371710526319, 41.345773026315804, 33.917812500000025, 26.007483552631555, 29.02100328947367, 29.92993421052629, 34.70422697368422, 34.00312499999999, 31.811940789473688, 28.592516447368425, 29.35327302631576, 36.170575657894766, 41.29317434210527, 35.298848684210554, 38.42526315789473, 37.83449013157897, 29.233322368421042, 20.033042763157876, 32.8061842105263, 27.87601973684209, 35.33348684210531, 37.76521381578948, 38.112236842105304, 41.35603618421055, 42.45996710526316, 49.232368421052655, 50.267664473684206, 49.06559210526309, 51.79046052631579, 53.15866776315792, 53.71608552631577, 45.79613486842105, 46.64541118421052, 33.24750000000001, 32.56949013157891, 22.408963815789424, 27.532845394736817, 33.64904605263157, 38.6234703947369, 45.9988322368421, 52.47039473684208, 57.12473684210521, 60.12606907894737, 61.34032894736845, 62.22039473684208, 62.979226973684234, 62.286463815789446, 59.135674342105204, 58.93041118421053, 51.418421052631594, 50.927072368421044, 45.105937499999996, 43.140542763157846], [0.0, -1.49649671052632, -2.6504605263157974, -0.5554934210526388, 1.585016447368421, 5.331710526315807, 5.083470394736859, 5.800608552631592, -2.2283881578947433, -21.17674342105265, -24.509062500000024, -23.405131578947387, -29.912615131578963, -26.931167763157895, -17.945773026315784, -14.27412828947369, -14.343404605263167, -20.306299342105277, -11.56657894736841, -5.978930921052643, -0.3431743421052702, 3.2386677631579, 3.322055921052641, 2.0866282894736914, -3.68832236842106, -10.349111842105266, -15.334440789473689, -18.436480263157904, -26.502680921052637, -27.915148026315794, -29.199325657894754, -25.383355263157895, -17.598750000000013, -9.50881578947369, -1.6773848684210573, 5.314391447368414, 8.211809210526308, 10.012351973684218, 11.299736842105268, 12.743634868421058, 8.771792763157887, 10.549243421052633, 3.9904440789473705, -5.850641447368428, 0.18986842105262625, -3.764654605263164, -8.60694078947369, 8.263124999999992, 10.40620065789474, 22.915065789473715, 21.44679276315796, 21.036266447368465, 21.9637993421053, 15.788585526315789, 20.148503289473698, 22.67067434210527, 23.428223684210533, 22.120953947368413, 17.44223684210527, 12.957236842105253, 11.598651315789485, 8.089292763157893, 7.60307565789473, 9.237483552631563, 6.0058717105263115, 9.407467105263162, 12.8244572368421, 13.147746710526324, 11.934769736842117, 9.976430921052625, 9.275328947368426, 8.002697368421046, 6.313766447368427, 6.0507730263157855, 7.243865131578949, 7.483124999999991, 5.222023026315788, 3.5568256578947297, 1.5189473684210455, -0.5638322368421096, 0.851200657894732, 0.3944901315789364], [0.0, 2.3149835526315856, 4.918618421052635, 3.6100657894736883, 5.290016447368422, 7.312499999999998, 8.30417763157896, 6.123256578947366, 0.7928289473684228, -9.293930921052633, -2.1629605263157887, -4.073832236842105, -10.993125000000003, -15.396661184210517, -13.522993421052629, -0.7690953947368407, 3.201463815789474, 4.694111842105267, 11.729506578947374, 12.811628289473676, 19.691151315789416, 25.405805921052576, 27.51873355263149, 21.963157894736796, 16.399884868421033, 9.019391447368424, 6.974457236842113, 6.325953947368419, -3.9750493421052604, -4.319506578947371, -4.083453947368423, -4.340674342105266, 2.0532730263157912, 12.626249999999997, 23.696348684210523, 33.72409539473685, 38.62603618421054, 41.815953947368435, 42.59595394736843, 43.60687500000003, 34.843421052631584, 30.833092105263155, 15.80205592105263, 9.426069078947368, 19.248552631578956, 19.53207236842105, 23.288388157894747, 27.717582236842112, 25.323059210526306, 30.569457236842112, 26.19350328947369, 26.25059210526316, 25.267253289473675, 19.118338815789475, 21.8675822368421, 23.29672697368419, 16.844407894736833, 18.813009868421062, 8.299687500000006, 16.15292763157894, 15.779605263157887, 16.58333881578947, 18.95156249999999, 19.340921052631582, 10.370921052631562, 4.879490131578952, -0.6780098684210527, 0.7152138157894724, 1.0744243421052637, -0.8479934210526338, -3.3817105263157865, -4.104621710526314, -4.494621710526313, -6.106578947368423, -10.139358552631581, -10.25481907894737, -10.097664473684205, -8.09185855263158, -7.671710526315791, -4.3432401315789475, -4.7242598684210515, -6.387532894736846], [0.0, -0.19179276315789373, -0.1706250000000038, 2.6511019736842085, 5.634473684210525, 9.111759868421043, 11.125263157894736, 10.66919407894735, 7.347779605263159, 4.627401315789489, -1.3104769736841977, 2.1430756578947436, 0.08082236842106205, -2.691513157894723, 1.0667269736842249, 4.262417763157905, 7.036036184210526, 6.166875000000005, 5.845509868421055, 8.96166118421053, 18.92782894736842, 25.949753289473698, 27.108207236842105, 23.81116776315789, 20.804062499999997, 23.281973684210545, 21.856677631578968, 20.31143092105263, 28.181348684210526, 24.104950657894744, 21.0837335526316, 19.90090460526317, 17.59105263157898, 21.21138157894736, 25.13319078947368, 30.21345394736847, 30.969078947368473, 25.37116776315794, 24.051069078947382, 26.673305921052645, 34.763240131578996, 39.48621710526317, 35.57723684210525, 39.7504934210526, 41.01222039473687, 23.815657894736862, 16.007960526315795, 23.62963815789477, 22.79511513157897, 28.56942434210535, 29.66501644736848, 27.91771381578956, 30.254506578947435, 29.591891447368447, 33.31485197368427, 34.295625000000044, 37.682467105263186, 34.762598684210545, 35.482302631579, 29.289769736842146, 26.014539473684245, 21.76046052631581, 11.88601973684213, 9.235559210526326, 6.080279605263173, 9.262500000000017, 17.197845394736845, 15.813601973684218, 17.987467105263164, 16.49289473684213, 18.19657894736843, 19.53656250000002, 20.05485197368421, 19.12988486842107, 21.4711677631579, 17.52690789473686, 14.884786184210547, 13.3510855263158, 10.163733552631584, 6.833980263157895, 5.166858552631589, 4.710789473684216], [0.0, -0.8274671052631533, 0.8428618421052612, 3.039819078947353, 7.579983552631582, 14.25809210526318, 17.449292763157928, 17.395411184210545, 14.453092105263131, 12.424835526315746, 2.2732894736842013, -14.217680921052649, -17.50509868421056, -13.607664473684238, -13.848207236842134, -1.3970723684210355, 9.009769736842088, 11.17914473684209, 10.770542763157863, 14.657072368421048, 36.18789473684206, 48.83210526315787, 48.7429440789474, 47.64157894736837, 43.13092105263152, 41.123832236842134, 41.350263157894744, 33.92871710526314, 35.80495065789467, 27.700904605263155, 22.836167763157903, 22.600756578947376, 24.95422697368418, 38.24052631578945, 42.65240131578939, 50.667927631578905, 50.87832236842098, 54.04129934210519, 59.826513157894695, 71.13266447368416, 65.80031249999995, 74.83317434210522, 66.69769736842112, 74.22444078947365, 78.53624999999998, 59.501940789473664, 54.51981907894729, 54.886085526315696, 52.827039473684124, 58.37876644736831, 57.74373355263144, 57.778371710526116, 55.76166118421037, 60.03690789473667, 59.39225328947359, 59.52182565789471, 67.90618421052626, 66.13001644736842, 58.97787828947362, 60.17610197368421, 49.06944078947362, 46.38819078947364, 31.92098684210525, 29.357121710526286, 16.518552631578906, 21.251792763157937, 27.115263157894724, 24.13253289473682, 22.776513157894748, 18.108059210526314, 16.445427631578923, 16.06055921052633, 14.37419407894734, 16.036825657894695, 15.471710526315789, 7.789736842105249, 8.94690789473681, 8.751907894736817, 2.407351973684186, -0.3713980263158341, -6.807680921052661, -7.550476973684251], [0.0, -1.8287664473684444, -3.2713815789473877, -2.1892598684210753, -4.066134868421095, -3.4099342105263233, -4.947483552631603, -4.8082894736842405, -2.4182565789473855, 4.998157894736842, 4.8531907894736825, 6.40228618421051, 12.422911184210516, 15.032319078947358, 15.485822368421054, 12.013026315789473, 3.643421052631581, -1.687006578947365, -6.334292763157933, -10.39273026315794, -6.663996710526366, -4.518996710526352, -5.756990131578984, -7.808338815789515, -5.7319736842105655, -2.169375000000006, -1.864687500000013, -3.4843421052631705, 5.432417763157872, 0.14368421052630964, 1.2707072368421066, 0.44195723684207167, -0.5984703947368573, 2.381694078947376, 3.309868421052645, 5.1296546052631555, 6.164309210526312, 6.655016447368428, 5.333634868421054, 5.89810855263158, 12.337598684210516, 16.480065789473677, 15.059259868421048, 12.347861842105251, 15.163815789473668, 6.812171052631584, 0.582434210526305, 6.797417763157906, 5.3086184210526355, 8.190000000000015, 8.385000000000012, 9.725625000000015, 11.272154605263164, 13.128503289473686, 16.38256578947368, 17.583996710526314, 23.317894736842096, 24.12932565789473, 25.095986842105255, 21.494259868421043, 20.983026315789466, 17.497401315789453, 16.868782894736835, 17.081743421052618, 11.82636513157894, 13.114391447368416, 16.40373355263157, 18.078552631578937, 16.92651315789473, 16.654539473684206, 18.97978618421051, 19.30435855263157, 19.278700657894724, 19.32424342105262, 21.648207236842097, 22.559703947368412, 20.495526315789466, 18.9547697368421, 22.085674342105253, 19.89256578947368, 22.258223684210517, 21.156858552631576], [0.0, -2.635707236842059, -5.678733552631492, -4.42855263157891, -8.246447368420995, -16.01116776315782, -16.022072368421014, -13.347236842105282, -6.944309210526306, 7.088634868420996, 9.927039473684118, 6.898124999999965, 20.661661184210494, 29.93570723684204, 32.497648026315716, 28.863207236842037, 17.210674342105214, 9.971299342105212, -9.753207236842108, -17.435180921052627, -11.632006578947333, -16.23374999999998, -17.25044407894739, -12.487697368421031, -5.833322368421086, -0.1962828947368962, -4.556200657894792, -9.441463815789497, 2.6511019736841774, 2.923075657894671, 10.34398026315781, 18.449950657894654, 26.236480263157823, 24.07929276315788, 20.578914473684172, 16.21258223684206, 16.213223684210483, 13.91620065789472, 19.871398026315745, 22.10748355263153, 25.911266447368384, 26.361562499999934, 23.2460526315789, 18.55129934210521, 29.307730263157826, 22.130575657894674, 29.155707236842037, 32.1249671052631, 29.62139802631576, 19.627006578947366, 20.186348684210536, 20.448059210526317, 15.918799342105245, 22.867598684210478, 23.88236842105257, 26.237763157894705, 39.49199013157887, 26.747072368420973, 31.524572368420994, 25.92088815789471, 26.69383223684204, 29.509786184210466, 34.754901315789425, 40.763338815789425, 39.15009868421048, 29.733651315789427, 25.03184210526313, 23.540476973684164, 19.946447368420998, 18.117039473684194, 20.030476973684173, 21.916973684210525, 21.108749999999972, 18.088815789473657, 25.29483552631575, 25.814407894736796, 23.287746710526264, 18.165148026315762, 23.63156249999993, 23.695065789473638, 22.565476973684163, 25.72973684210519], [0.0, 0.04297697368420117, 1.5048355263158193, -3.201463815789417, -3.350279605263104, -3.5882565789473375, -5.124523026315721, -5.422796052631519, -9.894325657894726, -14.390230263157896, 5.431776315789474, 11.366447368421024, 20.288980263157875, 21.714917763157878, 17.795032894736828, 15.757796052631564, 7.957796052631586, 4.885263157894769, 1.4907236842105576, -4.075115131578912, -7.588322368421018, -5.043700657894682, -5.606891447368362, -8.995016447368371, -9.83851973684206, -10.460082236842112, -6.433075657894747, -5.688996710526318, -6.330444078947394, -2.323322368421067, 4.6556249999999935, 8.018092105263154, 7.2906907894736825, 10.902039473684226, 12.077171052631584, 14.227944078947363, 14.004078947368422, 15.811677631578945, 10.150263157894742, 8.603733552631574, 12.589687499999986, 14.605756578947366, 13.8424342105263, 12.9739144736842, 12.540937500000002, 5.493996710526307, 9.863536184210531, 16.204884868421047, 13.873865131578945, 18.805312500000007, 19.316546052631587, 22.193437499999995, 23.572549342105248, 24.70726973684209, 27.566842105263145, 27.05753289473683, 27.09986842105262, 28.036381578947356, 27.384029605263144, 27.142203947368408, 27.115904605263143, 25.641858552631565, 24.090838815789464, 23.63092105263157, 20.845115131578936, 27.568766447368407, 35.466266447368405, 35.36491776315788, 35.77159539473683, 35.65356907894735, 35.78827302631578, 34.18465460526315, 34.35656249999998, 33.882532894736826, 34.64842105263157, 36.52529605263156, 33.61120065789473, 36.128240131578934, 34.507944078947354, 35.380953947368404, 35.0332894736842, 36.04356907894736], [0.0, -0.4233552631579016, 1.4734046052631555, 0.9487006578947437, -1.0577467105263132, -3.196973684210537, -5.517730263157887, -5.25409539473684, -11.993141447368423, -8.306743421052627, 6.5632894736842164, 7.664013157894733, 10.606332236842102, 13.669243421052627, 13.352368421052628, 11.832138157894736, 5.821776315789474, 5.259226973684205, 2.1199835526315773, -0.08723684210527338, -1.3573026315789463, -4.35991776315791, -5.374046052631581, -5.988552631578955, -9.54794407894736, -9.52036184210527, -6.449753289473698, -8.257351973684205, -8.85902960526316, -10.768618421052636, -3.6543256578947414, 1.458009868421044, 4.588273026315786, 10.366430921052624, 12.853963815789475, 11.914884868421055, 13.819342105263159, 15.424243421052626, 14.588437500000003, 10.090608552631574, 5.9731578947368345, 8.760888157894732, 3.77940789473684, -0.04875000000001606, 4.982121710526306, 0.473388157894739, 8.458125000000004, 15.018207236842104, 14.55059210526316, 20.179292763157893, 18.795049342105262, 20.443569078947366, 21.993305921052627, 18.08625, 19.59172697368421, 17.80786184210526, 17.548075657894735, 18.587861842105262, 17.659046052631577, 19.3415625, 21.77328947368421, 22.022171052631577, 20.021496710526314, 20.151069078947366, 17.523700657894736, 23.72842105263158, 27.867039473684212, 27.35067434210525, 28.23715460526315, 26.91449013157895, 25.565526315789477, 23.60013157894737, 23.882368421052636, 23.190888157894737, 21.764950657894737, 21.924671052631577, 22.640526315789472, 25.089572368421052, 23.083124999999995, 25.913832236842104, 26.24032894736842, 25.539868421052628], [0.0, -1.3310032894736636, 3.4561184210526115, 4.617138157894708, 2.5940131578947536, 3.6273848684210463, 1.8114473684210566, 8.639013157894727, 15.112500000000008, 16.80463815789474, 49.36001644736842, 57.72513157894736, 49.235575657894756, 43.390707236842104, 49.517812500000005, 42.74669407894737, 33.71190789473685, 20.933634868421073, 19.902828947368434, 19.408273026315804, 15.349194078947374, 23.6552960526316, 29.789457236842107, 27.565559210526317, 39.538174342105265, 47.43503289473685, 62.32623355263158, 72.58361842105266, 62.15432565789477, 60.37110197368422, 59.326184210526336, 53.11376644736845, 46.689671052631596, 35.16029605263158, 35.59134868421053, 38.216151315789475, 41.300871710526316, 54.99769736842106, 58.1888980263158, 57.40312500000002, 65.87472039473684, 71.4854605263158, 74.23406250000002, 61.63731907894737, 63.71560855263159, 55.2703125, 47.964868421052635, 51.152861842105274, 46.286842105263155, 39.488782894736836, 34.29305921052632, 29.85809210526316, 29.63743421052631, 39.128289473684205, 42.53309210526316, 47.20218750000001, 63.131891447368425, 65.04661184210528, 69.25707236842108, 75.76006578947371, 71.06980263157897, 54.32802631578946, 44.671036184210536, 47.424769736842116, 44.988552631578955, 43.03983552631579, 46.737138157894734, 48.002072368421054, 44.378536184210525, 43.053305921052626, 43.2136677631579, 44.20470394736842, 47.81605263157895, 47.62618421052633, 63.46159539473684, 64.24672697368419, 64.43595394736843, 68.49695723684212, 67.7233717105263, 66.92092105263157, 58.13501644736843, 60.45064144736844], [0.0, 4.119375000000003, 1.0147697368421023, 4.998799342105261, 7.893651315789476, 9.65699013157895, 10.70511513157895, 13.80266447368421, 17.345378289473672, 19.009292763157887, 19.236365131578964, 12.836644736842103, 1.901891447368416, 4.137976973684206, 0.568963815789477, 17.15935855263157, 29.4911842105263, 28.4000822368421, 26.639950657894747, 24.96962171052632, 28.739407894736836, 35.19685855263156, 41.55296052631578, 45.483108552631556, 46.79550986842102, 51.74684210526316, 47.154720394736856, 51.31194078947365, 46.076447368421036, 48.37026315789469, 42.00838815789478, 45.256036184210544, 44.58764802631581, 42.753108552631645, 50.42353618421057, 47.24837171052635, 53.156101973684265, 60.46475328947373, 70.38024671052635, 68.61434210526319, 68.19547697368424, 71.73113486842107, 73.46945723684213, 74.32707236842107, 60.631529605263154, 62.65786184210526, 48.692269736842135, 62.94394736842112, 67.3577467105264, 69.24039473684209, 68.13325657894741, 55.791167763157944, 55.53202302631584, 49.33371710526324, 48.470970394736916, 46.876973684210604, 47.65889802631579, 47.30738486842105, 45.43243421052631, 43.86409539473684, 32.41810855263159, 28.174292763157883, 18.15296052631578, 18.181184210526304, 18.392220394736842, 18.349884868421057, 21.82460526315787, 18.78863486842103, 15.769983552631576, 13.488355263157889, 11.087417763157887, 8.14509868421051, 8.417713815789458, 5.2072697368420995, 3.143733552631577, 0.4746710526315736, -0.11289473684210671, -2.6094078947368424, -0.7280427631578958, -8.356134868421055, -8.603092105263155, -8.215657894736847], [0.0, 2.937187500000009, 5.373404605263168, 7.5607401315789495, 9.622351973684214, 12.970065789473693, 16.489046052631572, 16.74819078947368, 16.550625000000007, 13.7744407894737, 5.171990131578944, 5.811513157894719, 13.856546052631579, 2.3406414473684123, 2.386825657894736, 14.186250000000001, 21.578930921052642, 22.897746710526278, 22.03115131578943, 20.144013157894697, 23.104292763157844, 31.86902960526305, 39.34766447368412, 36.82805921052617, 38.722253289473585, 39.29378289473674, 39.97820723684203, 37.26745065789469, 38.87940789473683, 37.77291118421055, 40.02567434210523, 33.579128289473715, 28.05690789473683, 23.045921052631577, 19.009292763157873, 27.04470394736837, 28.595082236842053, 30.396266447368383, 36.335427631578916, 34.871644736842086, 36.840888157894724, 44.67039473684207, 48.443388157894695, 38.63694078947367, 32.659934210526295, 31.268634868421024, 24.93370065789474, 27.045345394736856, 31.431562500000013, 29.887598684210538, 29.2365296052631, 28.82728618421048, 29.496957236842064, 29.359046052631534, 23.899687499999985, 28.877319078947366, 33.819029605263154, 36.09167763157895, 31.05952302631581, 26.158865131578928, 31.18396381578949, 35.22059210526313, 21.060000000000006, 17.572450657894738, 17.53075657894735, 22.191513157894754, 24.141513157894735, 27.645740131578954, 29.763799342105244, 31.670822368421057, 33.15513157894732, 33.17245065789471, 34.954391447368394, 34.50922697368419, 37.103881578947366, 39.91726973684212, 37.78766447368422, 36.30463815789474, 35.99802631578947, 35.57787828947369, 34.84277960526316, 32.67404605263158], [0.0, -0.23861842105261744, 1.6286348684210719, 3.1206414473684543, 4.2329111842105345, 9.558207236842128, 15.050279605263169, 19.831628289473635, 17.955394736842052, 12.146447368421049, 3.510641447368398, -10.365148026315792, -15.863634868421062, -17.623766447368432, -15.69236842105264, -8.016809210526318, -0.8601809210526401, 3.1649013157895016, 6.173289473684202, 8.20154605263159, 11.20351973684213, 23.00230263157887, 33.71190789473674, 33.445065789473595, 23.930476973684165, 26.86509868421046, 28.248700657894688, 27.689358552631525, 29.030624999999965, 29.97675986842099, 21.423059210526304, 18.906661184210513, 14.759062500000004, 18.27291118421053, 25.000411184210513, 28.93889802631582, 29.14416118421053, 29.289769736842146, 27.77082236842108, 25.960016447368375, 36.08654605263156, 43.141825657894714, 37.76906250000002, 39.451578947368375, 54.808470394736844, 43.417006578947365, 17.631463815789488, 25.80991776315787, 24.065822368421045, 27.9080921052632, 29.675921052631594, 27.00365131578949, 28.407779605263187, 30.15572368421055, 29.80549342105268, 33.409144736842116, 32.78886513157892, 37.41498355263158, 36.43485197368423, 41.31113486842104, 22.4371875, 21.002269736842116, 3.7633717105263127, -3.90384868421053, -4.139259868421059, -0.205904605263159, 1.0019407894736805, 1.2283717105263054, -1.047483552631574, -0.1943585526315772, -1.1404934210526285, -1.7832236842105242, 1.035937499999994, 2.9256414473684256, 4.751200657894733, -6.341348684210537, -5.284243421052636, -1.401562500000006, -5.30990131578948, -6.447187500000007, -17.89189144736843, -14.974588815789483], [0.0, -1.3290789473684015, -1.0449177631579403, -2.1725822368421177, -10.527434210526323, -19.10999999999993, -24.09340460526313, -25.752828947368457, -26.051743421052606, -27.742598684210506, -32.2096381578948, -16.063766447368522, 6.715953947368305, 9.41388157894724, 18.37746710526308, 16.36332236842088, 12.987384868420918, 3.237384868420918, -3.853815789473714, -11.31641447368412, -29.533519736842067, -54.62822368421055, -59.99072368421045, -57.32615131578942, -53.354950657894705, -51.0874342105262, -58.39544407894729, -58.15682565789487, -54.521101973684324, -58.212631578947594, -37.05769736842116, -22.95162828947379, -13.374177631578974, -7.715328947368533, -1.8980427631580312, 0.7492105263157072, -2.638273026315929, -10.582598684210623, -20.922730263157945, -41.672269736842196, -50.49217105263173, -41.1244736842105, -35.18338815789491, -37.74661184210537, -47.489555921052784, -48.39271381578956, -43.32463815789484, -19.340921052631685, -18.51281250000008, -7.780115131579009, -4.842286184210636, -1.1655098684211822, -0.9179111842106664, 4.775575657894677, -3.69986842105277, -12.27537828947375, -17.560263157894767, -35.35786184210532, -27.085756578947425, -21.990740131579045, -13.996381578947492, -11.990575657894837, -6.1405756578948, -2.0770065789473904, -11.382483552631612, -1.5458881578947654, 7.882105263157797, 13.674374999999912, 16.050937499999904, 19.854078947368336, 22.56162828947356, 23.257598684210443, 21.101052631578824, 26.20825657894732, 26.924753289473614, 28.736842105263058, 25.226200657894715, 27.246759868420945, 35.61379934210516, 30.933157894736752, 33.62787828947361, 33.686249999999895], [0.0, -0.26299342105265566, -1.28353618421054, 0.03271381578946375, -6.624226973684159, -8.111743421052587, -12.868075657894664, -13.849490131578904, -14.528782894736764, -16.15036184210517, -1.9615460526314976, 11.61148026315795, 11.177220394736871, 19.24598684210531, 23.356381578947435, 18.656496710526397, 16.169605263157912, 5.810230263157891, 1.4265789473684336, -6.959703947368347, -12.604440789473557, -16.76486842105257, -14.079128289473601, -16.258766447368316, -22.759194078947274, -27.01904605263151, -26.904226973684203, -23.144703947368384, -28.1903289473683, -17.50381578947359, -15.810394736842113, -11.986726973684128, -6.888503289473597, -0.010904605263135636, 3.6774177631579335, 7.894934210526358, 11.557598684210546, 14.86875000000007, 17.188865131579014, 9.592203947368468, 1.57731907894739, 2.2591776315790426, 0.980773026315866, -9.161792763157806, -19.33899671052623, -11.092549342105151, 2.823651315789519, 6.575476973684246, 7.515197368421113, 6.773042763157939, 6.279769736842134, 7.095690789473743, 10.68651315789478, 11.88986842105271, 14.315822368421117, 14.250394736842182, 16.16383223684216, 4.637664473684303, 14.204210526315855, 2.3861842105263733, 11.945032894736912, 21.662960526315864, 21.025361842105312, 26.869588815789538, 24.159473684210596, 23.804111842105332, 23.46414473684219, 23.287746710526378, 23.004868421052723, 24.76115131578956, 22.39998355263166, 22.058733552631647, 20.84511513157902, 18.923980263157965, 16.829013157894778, 22.6296217105264, 20.165180921052716, 19.76684210526321, 28.16787828947373, 29.11144736842111, 35.82419407894744, 34.24751644736848], [0.0, -1.9423026315789467, 0.46633223684210723, 2.553601973684213, 1.5657730263157914, -0.23669407894736594, -0.9275328947368413, 0.1558717105263181, 2.1764309210526336, 0.7479276315789496, -0.25465460526315464, 4.206611842105266, 14.338273026315791, 9.029654605263167, 9.61016447368421, 11.294605263157905, 10.036726973684209, 8.390773026315792, 6.3958717105263165, 6.449753289473688, 4.03342105263158, 0.5157236842105273, -1.3996381578947341, 1.098157894736844, 8.116875, 9.355509868421057, 8.308667763157896, 9.561414473684216, 12.493470394736843, 13.921973684210531, 19.61930921052633, 24.000394736842107, 24.691874999999985, 24.627088815789467, 20.466019736842078, 19.048421052631593, 12.715411184210522, 9.14319078947368, 7.476710526315792, 6.647319078947367, 12.706430921052638, 18.663552631578952, 18.366562499999997, 19.925921052631583, 23.509046052631597, 20.140164473684205, 8.767302631578952, 22.131217105263143, 25.7252467105263, 27.458437499999974, 20.96442434210524, 22.486578947368418, 25.242878289473655, 32.006299342105244, 37.35917763157893, 29.13838815789471, 32.82414473684208, 34.96337171052632, 29.492467105263174, 35.04611842105265, 28.59893092105263, 22.90865131578947, 19.26779605263158, 15.904687500000003, 15.60192434210528, 23.13379934210525, 29.263470394736814, 31.466200657894742, 33.935773026315815, 34.73245065789475, 39.45735197368423, 41.121907894736836, 41.782598684210555, 40.177055921052684, 43.652417763157885, 43.79610197368421, 43.887187499999996, 44.05396381578949, 39.867878289473666, 37.237944078947386, 33.577203947368425, 32.08199013157891], [0.0, 1.3502467105263083, 1.891628289473669, 2.479194078947355, 7.593453947368404, 11.544769736842097, 15.759720394736833, 19.15041118421057, 20.60521381578947, 20.255625000000023, 7.451052631578962, 1.8229934210526348, 0.2559375000000088, -2.3124177631578853, 5.027664473684224, 7.34393092105263, 10.98222039473684, 15.021414473684223, 12.599309210526288, 12.448569078947349, 18.08175986842108, 33.226332236842225, 38.29569078947383, 36.049342105263264, 36.07435855263168, 40.71330592105271, 43.996233552631594, 40.39578947368427, 51.98738486842109, 45.90197368421051, 46.376003289473736, 43.07447368421055, 41.291891447368414, 40.81208881578945, 34.5631085526316, 33.1596217105263, 33.854950657894726, 33.82929276315785, 39.450937499999995, 47.561398026315786, 69.43090460526315, 71.38539473684213, 66.01263157894735, 83.60240131578942, 71.33664473684216, 67.43664473684217, 51.26190789473682, 53.1227467105263, 50.206726973684184, 44.37917763157888, 38.22513157894729, 39.88583881578942, 40.78001644736839, 41.22838815789469, 50.44406249999997, 49.0110690789474, 57.615444078947405, 73.3796546052631, 62.7438157894737, 65.66432565789475, 42.162335526315786, 39.332269736842115, 21.87463815789475, 18.691776315789475, 19.133733552631597, 19.06894736842107, 19.938749999999978, 18.954769736842096, 19.38902960526314, 15.566644736842116, 14.194588815789485, 18.45764802631581, 16.056710526315783, 14.863618421052637, 16.34279605263157, 21.877203947368436, 17.37873355263158, 18.858552631578924, 13.568536184210531, 13.13427631578948, -0.45414473684208545, -2.2752138157894617], [0.0, -0.6869901315789497, -0.3001973684210566, -0.17832236842105464, -1.4413322368421064, -2.997483552631579, -4.250230263157899, -7.620394736842101, -10.547319078947359, -22.031151315789497, -23.37241776315789, -10.373486842105265, -12.923240131578963, -9.292648026315804, -6.466430921052634, -8.302894736842118, -6.90902960526317, -8.912911184210527, -11.143223684210534, -12.171463815789474, -12.677565789473688, -15.522384868421058, -17.6628947368421, -18.01889802631578, -20.45639802631578, -24.48917763157898, -26.997878289473704, -23.122253289473715, -24.318552631578974, -23.522516447368453, -24.48340460526318, -23.018980263157893, -21.631529605263147, -14.64424342105262, -8.30161184210526, -6.382401315789473, -4.309243421052635, -3.8711348684210614, -5.318240131578946, -7.046940789473682, -18.206200657894723, -21.267187500000006, -18.637253289473676, -18.660986842105274, -19.76363486842106, -19.787368421052633, -25.013240131578975, -17.39412828947367, -17.15615131578949, -3.3098684210526383, 3.7120559210526216, 3.1039638157894625, 3.066759868421042, -1.7812993421052732, -9.075197368421053, -4.806365131578952, -10.470986842105269, -11.46202302631579, -13.746217105263172, -12.25485197368421, -8.219506578947373, -9.481875000000015, -8.871217105263153, -5.8224177631578975, -8.732664473684222, -5.091809210526323, -0.29250000000000886, 5.894901315789465, 5.316957236842096, 6.901332236842096, 4.8852631578947285, 2.7389802631578863, 3.2162171052631496, 1.221315789473675, 0.06671052631577812, -1.443898026315797, -2.579259868421062, -0.5683223684210597, 0.028865131578938108, -1.3412664473684308, 0.32008223684209725, 2.0814967105263085], [0.0, 0.05131578947368176, 0.18666118421052857, 2.835838815789469, 2.5016447368421013, 2.9801644736842046, 0.15843750000000245, -2.117417763157893, -2.8448190789473644, -6.585740131578943, -3.8640789473684247, -5.10078947368422, -5.177763157894747, -4.307960526315803, 0.4188651315789391, 1.7601315789473633, 2.8281414473684134, 0.7838486842105219, 1.9378124999999948, 0.9044407894736803, 2.551677631578943, 1.841595394736839, -0.364983552631581, -0.9737171052631552, -2.820444078947368, -3.544638157894733, -4.962878289473682, -6.0405098684210525, -6.131595394736847, -5.494638157894743, -8.161776315789476, -6.665921052631575, -4.5735197368421066, 1.0866118421052624, 6.600493421052626, 8.826957236842102, 9.713437499999998, 9.386940789473682, 11.243289473684207, 12.623042763157894, 2.7299999999999933, -0.8095065789473734, 0.23412828947367892, -3.0789473684210495, 2.681891447368416, 4.000707236842098, -7.027055921052632, 0.8467105263157837, -0.8390131578947404, 10.634555921052627, 12.440230263157893, 11.314490131578948, 11.102171052631576, 7.8731249999999955, 3.3675986842105208, 5.572253289473679, 0.7735855263157827, 1.6664802631578919, 1.0718585526315714, 0.46055921052631366, 1.3765460526315736, 4.888470394736837, 4.402894736842098, 2.394523026315783, -5.003289473684221, 1.1475493421052585, 1.8191447368420994, 4.84228618421052, 2.6786842105263116, 3.4888322368421005, 1.583733552631577, 1.9705263157894697, 1.5567927631578895, 1.2796874999999939, -0.45414473684211387, -3.204029605263157, -2.796069078947373, 0.20013157894736278, -1.1712828947368479, -1.7152302631579, -0.2585032894736887, 0.5888486842105243], [0.0, 0.273256578947354, 0.02822368421052346, 2.3092105263157983, 3.1777302631578834, 4.179671052631562, 7.025131578947356, 7.539572368421066, 3.8352138157894835, -11.49986842105261, -18.17797697368419, -20.987516447368407, -25.521907894736824, -29.06398026315788, -25.711134868421034, -19.85728618421051, -14.469128289473675, -11.079720394736828, -4.82881578947368, -3.6139144736842077, 1.1398519736842054, 2.7255098684210495, 2.1103618421052524, 4.28935855263159, 3.7486184210526226, 0.41694078947369206, -3.1456578947368357, -2.752450657894734, -11.325394736842087, -11.242006578947352, -12.517845394736813, -10.631990131578924, -10.70319078947366, -3.591463815789467, 2.9416776315789512, 6.9763815789474215, 6.158536184210551, 6.535065789473688, 3.7255263157894802, 4.747351973684214, -2.5702796052631314, -4.692187499999992, -2.74026315789472, -9.315098684210508, -7.130328947368401, -8.377302631578925, -13.537746710526298, -1.3496052631578763, -1.6870065789473436, 18.383240131578955, 22.00292763157893, 18.56092105263156, 19.764276315789463, 15.052845394736874, 6.851940789473712, 8.313157894736886, -1.1821874999999658, -3.4958881578946936, -0.9313815789473381, -1.7562828947368132, -4.236118421052602, -8.710855263157882, -12.988026315789469, -13.574950657894718, -17.41657894736841, -8.817976973684203, -4.121940789473644, 0.7023848684210954, 2.3868256578947857, 2.109720394736893, 1.0782730263158413, -1.0494078947367882, -0.860180921052585, -1.0077138157894403, -2.939753289473643, -9.444029605263136, -10.873815789473664, -9.775657894736828, -11.072664473684194, -12.03483552631576, -14.589720394736831, -16.495460526315775], [0.0, 1.5144572368421096, 1.5676973684210527, 3.080230263157892, 3.248930921052629, 3.5844078947368385, 5.73453947368421, 3.3432236842105216, -0.5227796052631573, -4.942993421052634, -6.48503289473685, -12.744917763157897, -12.500526315789486, -13.749424342105254, -8.580641447368432, -4.288075657894737, -0.44388157894737246, 0.7440789473684197, 1.0769901315789472, 4.05330592105263, 9.432483552631577, 10.867401315789479, 11.87832236842105, 13.057302631578947, 7.218848684210528, 6.40549342105263, 6.129671052631579, 4.94299342105263, -1.1744901315789487, -6.35546052631579, -1.8948355263157937, -2.5920888157894786, 2.765921052631575, 7.477351973684206, 12.405592105263146, 14.813585526315785, 18.830328947368407, 22.250526315789468, 25.024144736842086, 27.7971217105263, 22.140838815789458, 20.418552631578947, 14.932894736842105, 4.375312499999996, 14.96111842105263, 19.056759868421047, 22.20690789473683, 26.1146052631579, 25.326907894736845, 24.374358552631595, 19.077286184210518, 18.61223684210525, 18.50768092105262, 17.291496710526317, 18.36592105263156, 18.303700657894726, 19.265871710526312, 16.28699013157895, 12.819325657894739, 13.362631578947365, 15.941249999999995, 11.902697368421054, 14.729555921052633, 14.850148026315788, 9.1194572368421, 5.742878289473681, 1.869819078947365, 1.3707730263157853, 0.41565789473683834, 0.3707565789473639, -0.403470394736845, 0.37139802631578833, -1.465707236842111, -1.8377467105263237, -1.1206085526315852, -3.804424342105262, -5.916710526315791, -6.022549342105274, -8.617845394736861, -7.401019736842104, -6.261809210526321, -8.365756578947368], [0.0, 1.368848684210544, 1.0551809210526315, 1.6145230263158084, -3.0930592105262953, -2.6812499999999773, -4.098848684210541, -4.866019736842116, -6.863486842105242, -4.345805921052612, 3.143733552631609, 6.501710526315801, 8.345871710526339, 13.478092105263187, 10.884078947368423, 10.535773026315809, 8.193207236842124, 5.771101973684228, 4.717845394736855, 1.7466611842105415, -5.234851973684204, -2.291249999999991, -0.6658223684210505, -1.6010526315789448, -4.025082236842113, -3.669078947368437, -0.7953947368420913, -3.4003124999999947, -3.82559210526313, -0.7306085526315478, 5.80830592105265, 9.507532894736858, 12.34465460526317, 17.79054276315791, 19.019555921052643, 23.1068585526316, 27.15375000000002, 31.901743421052654, 31.59449013157897, 24.381414473684234, 17.882911184210542, 17.256217105263175, 18.27932565789476, 8.423486842105284, 14.97587171052633, 17.995164473684238, 23.710460526315813, 30.408453947368443, 29.183930921052653, 29.810625000000023, 26.939506578947388, 28.08641447368423, 29.745197368421074, 28.060115131578968, 25.63544407894739, 25.922171052631597, 23.75792763157897, 18.292154605263175, 20.590460526315802, 17.272894736842126, 20.870131578947394, 21.052302631578968, 25.80735197368423, 27.827269736842126, 24.44876644736844, 28.332088815789493, 28.24228618421055, 27.592500000000022, 26.58606907894739, 23.526365131578967, 22.653355263157913, 22.934309210526333, 22.17868421052634, 23.366644736842126, 20.237023026315807, 19.67447368421054, 17.64044407894739, 17.71805921052634, 20.031118421052653, 19.453174342105285, 22.92212171052634, 22.67452302631581], [0.0, -6.299654605263186, -5.37661184210549, -3.287417763158089, -7.677483552631827, -5.760197368421302, -8.34843750000033, -22.365986842105542, -33.76322368421063, -71.13779605263184, -122.0148355263158, -174.23827302631582, -228.4764967105263, -271.54391447368425, -281.33560855263164, -271.0095888157895, -250.82452302631586, -228.08457236842108, -194.14046052631582, -189.24300986842104, -194.9198190789474, -214.1978782894737, -224.89337171052637, -240.7461019736843, -268.03134868421057, -298.3653947368422, -339.2332894736843, -392.46059210526323, -455.0786842105264, -515.3587006578948, -584.1827960526316, -625.4926480263159, -664.2617269736845, -695.1955263157895, -707.9013157894735, -714.4819243421052, -724.2267927631576, -736.5143585526314, -739.7838157894735, -750.6787993421051, -758.8848355263158, -744.5882565789474, -743.4888157894736, -785.0943750000004, -796.4075822368425, -796.1157236842109, -867.2073355263158, -875.6712335526315, -868.7929934210529, -870.8193256578945, -868.7731085526316, -868.2772697368418, -859.8108059210524, -858.0667105263162, -834.7385526315791, -800.3781414473688, -765.4596710526318, -708.9847203947368, -661.5593092105261, -628.9872532894735, -596.9347697368421, -579.441217105263, -572.5424506578948, -570.973470394737, -565.4576644736842, -559.2850164473684, -546.4637664473684, -532.1120230263158, -522.4582401315791, -511.23868421052646, -505.40215460526315, -492.0023190789474, -470.51896381578945, -456.0395723684212, -439.74616776315804, -399.9918256578948, -364.42100328947373, -330.9066611842106, -305.8061842105264, -277.99751644736847, -253.12218750000002, -232.60741776315797], [0.0, 0.37139802631578966, -1.7363980263157894, -0.37588815789473645, -2.1815625, -4.3765953947368414, -2.3990131578947373, -3.5324506578947354, -10.138075657894742, -25.406447368421066, -17.702023026315796, -6.640263157894736, -4.715279605263157, -4.955822368421054, -6.810888157894736, -10.744243421052623, -15.07786184210526, -16.73472039473684, -11.853305921052634, -12.200970394736842, -7.957796052631581, -9.758980263157895, -11.1336019736842, -10.407483552631582, -12.514638157894737, -16.93292763157896, -18.22672697368421, -13.26769736842105, -22.814358552631592, -15.443486842105255, -19.780312499999997, -18.25430921052631, -16.335740131578945, -12.287565789473675, -7.519046052631578, -1.6517269736842102, -1.438766447368421, 0.33355263157894854, -1.613240131578948, -5.208552631578949, -11.155411184210529, -13.778930921052616, -15.321611842105266, -13.972006578947372, -14.793059210526309, -16.28442434210526, -20.321694078947367, -16.630805921052627, -15.759720394736835, 4.032138157894742, 8.3817927631579, 7.3586842105263175, 8.478651315789474, -1.7755263157894732, -0.8755756578947369, -0.8075822368421053, -7.248996710526315, -6.517746710526312, -8.504950657894739, -6.291315789473684, -2.2482730263157897, -1.734473684210526, -0.5465131578947366, -4.1501644736842085, -7.4465625000000015, -2.6998519736842095, 0.38037828947368535, 7.14893092105264, 9.063651315789482, 7.364457236842102, 7.846184210526309, 6.217549342105262, 7.302878289473687, 7.550476973684211, -0.20398026315789364, -0.21616776315789454, 0.8871217105263158, 4.04560855263158, 2.7409046052631587, 3.155279605263159, 3.9814638157894757, 4.70694078947368], [0.0, 0.1975657894736873, 1.0275986842105507, 13.120164473684225, 11.01621710526317, 10.941809210526328, 14.637828947368437, 13.193289473684224, 19.04200657894738, 28.590592105263173, 22.699539473684226, 25.357055921052652, 23.86312500000001, 21.440378289473706, 27.06587171052632, 25.793881578947385, 25.79324013157895, 18.843799342105275, 17.43646381578949, 27.214687500000014, 34.08779605263161, 35.58044407894741, 43.57223684210531, 47.347796052631566, 49.86483552631576, 59.39674342105263, 64.76437500000002, 65.24161184210529, 69.98639802631578, 66.07613486842106, 62.17998355263157, 58.20108552631581, 52.431907894736895, 55.77641447368421, 49.72500000000002, 52.30105263157901, 56.44159539473688, 61.34866776315795, 64.56937500000001, 66.96069078947376, 68.74327302631583, 73.40467105263158, 71.91523026315794, 73.42134868421047, 79.5920723684211, 65.40774671052638, 59.14978618421058, 56.91819078947371, 56.16320723684214, 54.351118421052675, 49.13230263157901, 48.60695723684212, 46.06554276315795, 44.485016447368466, 52.4511513157895, 53.01049342105267, 56.047746710526326, 56.82453947368421, 52.61151315789475, 59.05485197368424, 56.051595394736864, 40.75628289473687, 23.670690789473696, 22.716217105263162, 20.699506578947382, 21.138256578947377, 23.442335526315798, 23.719440789473683, 23.105575657894747, 22.59819078947369, 23.487878289473695, 23.25503289473685, 23.46606907894737, 24.163963815789486, 28.944029605263186, 27.982499999999995, 24.722664473684226, 28.7317105263158, 25.87085526315791, 21.546217105263175, 12.89822368421054, 10.46008223684212], [0.0, -1.0776315789473827, -1.93845394736843, -2.678042763157908, -3.7486184210526226, -6.996266447368406, -6.299013157894731, -7.82245065789472, -8.824391447368399, -10.356167763157924, 1.7614144736841695, 9.491496710526278, 11.897565789473656, 11.642269736842074, 8.413223684210495, 6.77047697368417, 0.7915460526315528, -1.3733388157894915, -3.404161184210544, -8.46261513157895, -11.527450657894718, -11.420970394736834, -14.106069078947368, -15.270937499999992, -15.973963815789464, -15.846957236842126, -12.56018092105268, -10.98286184210529, -9.068141447368454, -3.9865953947368666, 0.7357401315789183, 2.230312499999961, 2.7274342105262797, 3.0391776315789247, 2.95835526315787, 3.3765789473684027, 4.59789473684209, 3.392615131578932, -1.489440789473722, -4.486282894736853, -6.865411184210561, -5.6485855263158165, -1.209769736842123, -2.554243421052675, -3.7216776315789666, -3.9949342105263455, -0.8242598684210876, 4.853832236842079, 5.795476973684185, 7.238092105263133, 8.717911184210497, 9.605032894736809, 11.261891447368383, 11.746825657894698, 8.887253289473653, 8.781414473684176, 7.293256578947338, 3.919243421052599, 4.580575657894705, 3.4118585526315446, 6.83141447368418, 7.894934210526284, 12.13105263157891, 12.483207236842073, 12.648059210526284, 17.063141447368388, 19.430723684210495, 19.64304276315786, 18.206842105263128, 20.46922697368418, 21.86629934210523, 21.17738486842102, 21.918256578947332, 20.784819078947333, 19.148486842105232, 17.763601973684178, 15.39409539473681, 18.803388157894705, 17.101628289473652, 16.41078947368418, 20.181858552631546, 20.820098684210492], [0.0, -0.8774999999999973, -3.1071710526315743, 1.7396052631578907, 4.510657894736843, 15.177286184210546, 15.116348684210559, 15.391529605263178, 16.136891447368452, 21.40830592105263, 13.550575657894724, 8.398470394736846, 2.418898026315794, 0.6555592105263175, 5.392648026315792, 7.490822368421066, 9.71664473684211, 8.336249999999994, 7.232319078947365, 9.207976973684207, 21.464753289473737, 43.339391447368385, 40.06736842105261, 41.54590460526313, 37.597154605263164, 42.94361842105261, 43.270756578947385, 43.55555921052634, 47.612072368421074, 47.11944078947366, 40.01861842105266, 32.75486842105264, 31.611167763157898, 33.44314144736842, 37.168026315789454, 37.49901315789474, 41.991069078947376, 43.69475328947366, 40.203355263157874, 51.62175986842106, 65.41993421052629, 72.45725328947361, 64.25891447368419, 75.91465460526315, 74.16799342105261, 54.23565789473686, 35.64330592105263, 39.812713815789486, 37.01023026315791, 42.546562499999965, 43.799309210526296, 42.19633223684209, 44.59406249999999, 42.54078947368424, 49.78144736842104, 50.729506578947365, 54.48518092105263, 66.97480263157898, 58.41340460526311, 60.940065789473664, 48.181677631578964, 44.585082236842105, 22.361496710526314, 19.43200657894739, 14.349177631578948, 14.929687499999991, 18.90601973684212, 18.33256578947369, 18.080476973684206, 15.660937499999987, 16.104177631578935, 16.26774671052631, 18.033651315789474, 17.531398026315784, 21.049736842105254, 20.427532894736835, 20.82009868421053, 23.269144736842104, 14.18560855263158, 12.869358552631587, 5.5709703947368485, 3.5388651315789548], [0.0, -1.0320888157894734, -2.5600164473684206, 8.634523026315792, 7.515197368421056, 10.481250000000008, 14.449243421052627, 15.261315789473684, 18.1131907894737, 21.38842105263158, 13.060509868421057, 10.445970394736841, 7.711480263157894, 7.531233552631582, 12.394046052631587, 11.9649177631579, 12.263190789473686, 13.436398026315791, 16.915608552631568, 27.915148026315794, 38.782549342105234, 37.502861842105276, 46.036036184210516, 51.75325657894735, 53.437697368421084, 57.131792763157904, 48.309325657894746, 43.6062335526316, 48.29393092105258, 45.2515460526316, 42.08023026315789, 41.687023026315764, 45.36444078947367, 47.61848684210525, 51.77699013157888, 51.593536184210436, 49.365789473684146, 47.973848684210495, 57.05674342105257, 64.82787828947366, 68.09541118421053, 73.26419407894737, 72.11215460526316, 63.81759868421056, 68.62909539473686, 58.93874999999997, 49.859062499999965, 48.132286184210514, 46.993075657894686, 48.741661184210415, 43.96031249999995, 43.26947368421045, 45.6659210526315, 49.628782894736766, 53.0573190789473, 55.48199013157891, 58.58338815789469, 59.45254934210528, 54.88416118421054, 57.43968750000002, 50.148355263157846, 44.73197368421056, 34.532960526315755, 28.232664473684224, 23.951644736842105, 21.630246710526325, 25.409654605263142, 19.06253289473685, 17.38001644736843, 16.158700657894737, 17.269046052631584, 17.812993421052642, 17.03684210526316, 18.118963815789474, 26.204407894736836, 21.60266447368421, 22.716217105263155, 23.64054276315789, 14.377401315789479, 14.734687500000001, 9.733963815789481, 9.241973684210537], [0.0, 0.9846217105263335, -1.2386348684210375, -0.6799342105263904, 4.38300986842107, 1.3496052631579403, -0.27518092105260195, 3.4792105263158533, 3.309226973684261, -1.724210526315801, 21.50195723684213, 38.59011513157898, 42.83713815789476, 39.93458881578951, 44.27269736842108, 37.180855263157916, 30.63745065789476, 21.487203947368457, 15.528799342105302, 4.236759868421096, 14.39472039473688, 21.172894736842174, 11.51911184210531, 10.848799342105274, 13.958536184210551, 20.70784539473687, 24.75409539473685, 39.767171052631625, 39.2578618421053, 46.05014802631581, 51.32284539473687, 46.719819078947395, 43.529259868421086, 38.42911184210528, 36.90375000000003, 34.064703947368464, 33.00054276315792, 36.876809210526346, 39.75434210526318, 44.08603618421056, 46.370871710526345, 49.052121710526336, 50.40108552631582, 57.233141447368446, 54.62245065789477, 46.58960526315793, 39.84286184210528, 41.516398026315805, 33.88317434210528, 36.25652960526317, 31.698404605263196, 33.45917763157898, 37.21421052631581, 41.178996710526334, 45.42537828947371, 48.01682565789476, 63.638634868421086, 65.04725328947372, 60.358273026315814, 63.1639638157895, 52.5031085526316, 46.72944078947371, 39.55164473684213, 38.155213815789494, 35.213536184210554, 38.33930921052634, 43.37338815789477, 48.33947368421055, 51.57236842105266, 54.135592105263186, 55.32868421052634, 56.08174342105266, 58.06125000000003, 60.68412828947371, 66.52899671052634, 70.9485690789474, 70.77345394736845, 64.62004934210529, 69.3000493421053, 66.62970394736844, 60.401250000000026, 58.553240131578974], [0.0, -0.3181578947368404, -0.5631907894736745, 0.49199013157895877, 0.8601809210526365, 2.801842105263166, 3.948108552631588, 3.3919736842105337, -2.5965789473684406, -14.807812500000024, -18.875871710526344, -19.870756578947393, -25.410296052631608, -22.50774671052634, -20.062549342105292, -16.580773026315814, -13.77059210526318, -10.31126644736845, -5.7909868421052835, -3.5542598684210613, -0.3290625000000027, 2.560657894736856, 3.8178947368421134, 2.1873355263157954, -3.547845394736857, -9.9956743421053, -12.699375000000025, -18.093305921052654, -21.4217763157895, -25.284572368421074, -23.100444078947394, -20.668717105263184, -16.425542763157917, -8.757680921052653, -3.817894736842124, 1.2309374999999925, 1.388092105263155, -0.09878289473687119, -2.112927631578975, -3.483700657894765, -7.8102631578947594, -8.382434210526338, -14.226661184210549, -15.775115131578971, -11.200312500000022, -17.838009868421075, -17.873930921052654, -10.631348684210547, -10.019407894736869, 3.175805921052625, 2.981447368421044, 2.6049177631578715, 3.8461184210526334, -4.214309210526347, -1.0102796052631842, -2.287401315789511, -7.024490131578968, -6.087976973684231, -8.01616776315792, -7.2631085526316035, -5.8525657894737115, -8.619128289473705, -8.563322368421074, -11.208009868421076, -15.616677631578971, -10.324736842105288, -8.533815789473707, -6.461940789473708, -4.985328947368448, -6.741611842105282, -7.524819078947388, -7.3355921052631805, -8.463256578947387, -8.088651315789495, -12.903996710526341, -13.243963815789495, -12.166332236842129, -11.132960526315811, -11.321546052631602, -11.63136513157897, -13.014967105263182, -14.485805921052656], [0.0, -3.4086513157894487, -1.4836677631578716, 1.9371710526315695, 5.456792763157907, 11.30550986842104, 16.45569078947363, 16.028486842105238, 10.234292763157875, 11.374144736842126, -3.478569078947338, -26.08894736842103, -28.029325657894717, -23.835542763157882, -20.069605263157882, -13.284374999999976, -8.227203947368377, 3.8955098684210228, 3.885888157894726, 14.467203947368354, 30.330197368421075, 40.17449013157904, 45.45680921052642, 50.13167763157903, 36.68565789473681, 34.39120065789482, 33.316776315789475, 20.585970394736798, 27.30898026315792, 16.544210526315787, 15.405000000000065, 21.900296052631646, 25.072253289473743, 29.439226973684335, 39.023092105263295, 38.50287828947375, 38.03462171052643, 38.56830592105269, 45.428585526315906, 55.476217105263224, 57.97016447368426, 65.18388157894742, 49.36322368421049, 47.7191940789474, 60.006118421052555, 43.86794407894741, 45.291315789473735, 46.82052631578953, 48.28815789473692, 39.944851973684344, 38.111595394737044, 38.99807565789481, 42.275230263158, 49.53577302631593, 43.547220394737046, 44.01675986842118, 50.83085526315795, 41.15911184210531, 36.547746710526376, 31.01590460526321, 27.766332236842153, 20.03432565789477, 13.555707236842117, 18.102286184210534, 13.762894736842128, 10.998256578947455, 8.221430921052693, 1.4522368421053287, -2.8082565789473186, -5.37083881578943, -5.477319078947339, -6.519029605263146, -8.594111842105232, -11.123338815789435, -7.066184210526298, -12.030345394736838, -14.815509868421046, -17.53011513157893, -16.114440789473665, -19.02468749999998, -23.961907894736825, -27.758634868421034], [0.0, -0.498404605263179, 1.4188815789473814, -3.798009868421037, -4.876282894736793, -6.948157894736806, -7.05399671052626, -7.559457236842075, -14.435773026315768, -26.296134868421053, -6.227812500000017, -3.1578453947368423, 2.1244736842105105, 7.322763157894705, 0.15266447368421865, 2.3958059210526415, -5.432417763157897, -6.848092105263152, -3.7800493421052472, -8.358059210526324, -15.22667763157894, -15.620526315789451, -12.566595394736826, -14.029095394736817, -19.61866776315789, -24.289046052631566, -24.539851973684218, -23.16202302631582, -30.269901315789486, -23.98050986842105, -18.168355263157924, -7.899424342105267, -5.780082236842116, 2.211069078947361, 7.194473684210529, 11.254835526315777, 12.28499999999999, 11.123980263157897, 5.2502467105263015, -1.297648026315791, -3.9724835526315907, -1.0372203947368597, -6.776250000000008, -9.442105263157917, -6.450394736842117, -5.697976973684231, 1.6119572368420876, 12.19070723684209, 9.182960526315764, 15.761644736842088, 13.898881578947357, 16.426825657894724, 18.550016447368417, 16.14458881578945, 19.657154605263152, 17.96501644736841, 12.141315789473673, 11.752598684210511, 11.876398026315787, 11.05342105263156, 18.666759868421032, 21.680279605263138, 21.7277467105263, 21.792532894736823, 18.207483552631558, 21.97021381578945, 25.600164473684195, 25.73101973684209, 25.844555921052624, 23.338421052631556, 23.534703947368413, 21.401249999999983, 21.493618421052616, 20.013157894736818, 19.07792763157893, 19.742467105263138, 18.825838815789453, 20.654605263157876, 22.16521381578946, 23.81309210526314, 25.546282894736823, 26.818273026315772], [0.0, -1.887138157894718, -1.4066940789473819, -3.916036184210533, -6.494654605263165, -7.773059210526277, -8.040542763157873, -9.021315789473661, -15.68659539473682, -5.102072368421098, 5.7448026315789065, 7.091842105263158, 12.671151315789434, 14.589720394736808, 11.265740131578898, 9.075197368421026, -1.5260032894736852, -4.107187499999995, -5.385592105263143, -8.284292763157879, -12.324128289473641, -7.016792763157888, -7.36509868421053, -11.594802631578908, -15.150986842105226, -14.972664473684212, -14.879654605263148, -22.117746710526383, -11.246496710526358, -14.306200657894792, -7.474144736842106, -2.1090789473684666, 3.9808223684209985, 8.894309210526302, 13.447944078947373, 17.213881578947344, 20.228684210526293, 22.300559210526288, 15.922648026315791, 10.757072368421046, 15.84118421052629, 14.741101973684184, 8.542796052631537, 1.844161184210492, 8.732023026315748, 12.300394736842097, 24.575131578947342, 25.551414473684183, 26.85868421052628, 19.974029605263144, 20.372368421052606, 22.448733552631545, 23.796414473684184, 28.62009868421049, 30.855542763157864, 32.947302631578914, 29.24230263157892, 28.04600328947365, 26.206332236842073, 26.242253289473652, 32.90304276315786, 32.35909539473681, 34.20646381578944, 35.44702302631576, 35.00057565789471, 32.89598684210523, 36.022401315789445, 34.72603618421049, 32.647746710526285, 33.04159539473681, 33.180148026315756, 33.25391447368418, 30.12044407894734, 28.881809210526285, 32.25774671052629, 32.7914309210526, 30.072335526315758, 28.18840460526313, 32.695213815789444, 31.869671052631546, 36.77802631578944, 35.69141447368418], [0.0, 0.279029605263144, -0.7838486842105254, -3.1418092105263185, -1.3996381578947492, 3.347713815789465, 4.551710526315784, 4.22970394736841, -5.114259868421051, -16.869424342105265, -19.945164473684216, -44.97315789473683, -44.96289473684212, -41.90896381578949, -41.98273026315789, -30.36547697368422, -20.863075657894743, -12.217006578947368, -5.964819078947354, -7.26567434210526, -7.399736842105273, 0.6651809210526345, 2.087911184210512, 4.671019736842101, -3.5273190789473823, -12.966858552631578, -19.860493421052634, -35.89090460526317, -41.891644736842096, -53.68593750000002, -48.474177631578954, -40.85057565789474, -24.070312500000004, -8.183585526315792, -5.104638157894733, 1.2533881578947614, -1.9121546052631366, -6.218190789473674, -9.000148026315784, -14.665411184210527, -14.360082236842098, -7.559457236842107, -19.219687500000003, -29.83820723684211, -23.120328947368428, -26.332055921052635, -23.954851973684214, -18.194654605263157, -16.15870065789474, 6.614605263157927, 7.041167763157926, 10.126529605263165, 6.229095394736877, -12.027138157894726, -7.551118421052614, -14.77124999999999, -23.15175986842106, -20.23189144736843, -15.86235197368422, -22.66682565789474, -20.35633223684211, -24.215279605263163, -15.45952302631579, -17.060575657894734, -26.47381578947369, -30.619490131578953, -28.121052631578955, -23.081842105263163, -23.211414473684215, -27.706036184210536, -32.43029605263158, -31.978075657894735, -36.16095394736842, -36.194309210526306, -44.63319078947369, -42.396463815789474, -45.920575657894744, -41.54077302631579, -33.43736842105264, -35.66190789473684, -36.54069078947369, -35.60610197368421], [0.0, -3.560032894736846, -6.980871710526348, -7.197039473684281, -8.41707236842112, -11.290115131579004, -14.515312500000103, -14.726990131579033, -14.419736842105326, -20.024062499999996, -12.197121710526293, -1.705608552631535, -1.668404605263138, 6.7640625000000085, 7.00332236842107, 0.9608881578947575, -2.7133223684210215, -17.1106085526316, -17.99131578947375, -21.009967105263232, -19.913092105263257, -19.0041611842106, -23.654013157894806, -26.05687500000006, -30.517500000000044, -34.159638157894705, -29.756101973684213, -33.45597039473681, -34.79338815789471, -29.466809210526296, -29.674638157894794, -16.329325657894753, -3.4400822368421196, 6.506842105263175, 13.21317434210528, 14.095164473684228, 13.471036184210554, 10.33243421052633, 7.9674177631578935, 6.741611842105289, 2.0616118421052683, -1.8415953947368102, -1.0051480263157693, -16.47878289473685, -6.791003289473661, -0.6837828947368436, -5.513881578947345, 7.345213815789478, 11.505641447368443, 17.9669407894737, 23.616809210526334, 22.124802631578962, 22.339046052631595, 22.066430921052653, 22.398700657894754, 21.41215460526318, 19.368503289473708, 15.572417763157906, 11.58518092105265, 15.063750000000011, 12.129769736842114, 11.791085526315804, 15.485822368421074, 17.241463815789487, 17.294062500000017, 19.09652960526317, 19.124753289473706, 18.85406250000002, 16.118930921052637, 11.053421052631602, 11.914884868421076, 9.945641447368441, 9.710871710526344, 5.898750000000025, 5.323371710526342, 3.4683059210526537, 4.769802631578962, 4.419572368421068, 5.462565789473704, 7.147648026315789, 5.82819078947368, 8.59218750000003], [0.0, -6.189325657894692, -13.090657894736772, -18.283815789473607, -13.635888157894705, -14.023963815789408, -15.553815789473617, -16.48391447368408, -10.614671052631579, -9.815427631578899, 1.5433223684210375, -6.011003289473656, -9.096365131578928, 5.865394736842074, 12.57814144736843, 10.370921052631576, -4.4901315789473415, -25.31728618421053, -35.85819078947364, -36.504769736842036, -28.736842105263094, -28.01842105263148, -26.072269736842003, -25.55526315789468, -25.455838815789406, -18.000937499999964, -15.825148026315745, -25.430822368421033, -25.32305921052634, -24.585394736842154, -29.107598684210558, -24.723947368421022, -17.321003289473673, -16.304950657894743, -16.435164473684218, -15.291463815789491, -13.699391447368448, -12.070756578947424, -0.6792927631579033, -6.711463815789507, -10.207351973684261, -9.539605263157895, -3.558749999999982, -8.900723684210554, -4.769161184210546, 2.0494243421052687, -0.733815789473681, -3.1514309210526648, -3.063552631578979, -5.758273026315834, -9.185526315789524, -11.64740131578953, -13.51722039473691, -14.308766447368455, -8.752549342105269, -6.771118421052648, -0.779999999999994, 7.995641447368424, 6.209851973684227, 5.991118421052633, 4.771085526315794, 5.211118421052607, 1.2649342105262846, 5.127730263157886, 10.061101973684202, 5.143124999999976, -2.0628947368421393, -3.982746710526378, -7.14957236842109, -13.711578947368466, -16.01309210526322, -12.965575657894753, -12.778914473684246, -14.313256578947417, -12.90143092105263, -6.13993421052632, -6.774325657894735, -7.7448355263158035, -5.039210526315799, -2.0135032894737037, -3.6286677631578925, -4.53310855263161], [0.0, -2.1013815789473327, -2.644687499999989, -0.22322368421050243, -3.9615789473683876, -5.324013157894711, -9.243256578947381, -9.556282894736839, -8.553700657894701, -6.635773026315789, -0.14240131578947057, 0.8948190789473287, 3.9320723684210463, 10.272779605263118, 17.888684210526282, 16.211299342105285, 11.272796052631548, -4.239325657894746, -4.620345394736837, -9.43312499999999, -14.494786184210511, -12.902072368421038, -8.113026315789462, -9.00912828947365, -16.43388157894737, -18.376184210526297, -13.624983552631583, -16.25748355263157, -17.114457236842107, -11.733996710526256, -11.308717105263135, -10.510756578947394, -4.849342105263219, -2.702417763157925, 0.7113651315788729, 3.078947368421005, 7.590888157894696, 11.775049342105262, 16.00796052631578, 14.272845394736805, 9.98284539473682, 10.756430921052598, 10.040575657894728, -4.755690789473718, -3.408009868421047, 6.902615131578905, 7.38177631578948, 18.241480263157893, 19.32103618421051, 15.174720394736802, 13.521710526315744, 13.358141447368403, 13.038059210526285, 13.591628289473675, 21.698881578947365, 24.22041118421053, 26.69575657894737, 28.10309210526315, 27.12167763157892, 26.507171052631573, 19.24149671052631, 23.270427631578954, 25.746414473684187, 27.218536184210528, 30.01075657894736, 28.667565789473677, 27.691924342105278, 25.07161184210525, 25.750904605263155, 23.8297697368421, 23.570625000000014, 25.976694078947364, 25.35128289473684, 24.904835526315793, 23.863766447368416, 29.420624999999973, 29.254490131578947, 27.013914473684196, 27.19544407894736, 28.736200657894702, 30.344950657894735, 33.33473684210526], [0.0, -1.5016282894736577, -5.553651315789416, -5.841019736842071, -5.112335526315782, -5.200855263157841, -11.08036184210524, -11.530657894736763, -11.390180921052583, -8.403601973684204, -0.0012828947368745958, -0.7139309210526434, -1.775526315789513, 4.0032730263157745, 7.5010855263157765, 8.969358552631554, 5.664621710526298, -12.816759868421059, -8.414506578947389, -11.453042763157868, -13.169555921052591, -20.290263157894692, -21.764309210526285, -20.70335526315788, -16.51406249999998, -17.564753289473686, -17.31394736842106, -21.421776315789472, -32.230164473684205, -29.488618421052657, -30.195493421052667, -18.626990131579042, -8.080312500000034, 4.448437499999969, 11.417763157894722, 14.039358552631558, 13.499901315789437, 13.469111842105232, 12.043815789473655, 7.443355263157848, -0.5920559210526477, -1.3374177631579443, 1.9057401315789164, -9.122664473684239, -11.190049342105233, -2.066743421052685, -4.525411184210569, 12.127203947368393, 19.66228618421049, 27.15310855263155, 31.599621710526293, 29.418059210526287, 30.36868421052629, 27.06843749999997, 20.472434210526288, 18.251101973684175, 16.621184210526295, 8.609506578947347, 5.833322368421044, 9.46583881578945, 12.41008223684208, 19.395444078947346, 21.66296052631576, 21.900937499999962, 19.46279605263155, 24.736776315789438, 29.629095394736808, 27.94273026315787, 25.89843749999997, 21.6090789473684, 23.19281249999998, 21.201759868421036, 18.565411184210497, 17.829029605263134, 18.184391447368416, 14.319029605263133, 11.98608552631574, 13.209967105263129, 14.534555921052608, 15.744325657894684, 19.85087171052627, 21.78740131578945], [0.0, -2.2040131578947424, -3.653042763157842, -2.4657236842104666, -1.769753289473627, -4.236118421052566, -8.417072368420968, -9.629407894736744, -8.404884868421043, -3.458684210526286, 7.680049342105221, 14.602549342105192, 14.192664473684143, 17.294703947368333, 23.04912828947364, 24.726513157894672, 17.082384868420995, 1.1218914473684052, 0.667105263157886, -3.8826809210525965, -0.5407401315789357, -4.760180921052587, -5.817286184210495, -5.965460526315795, -6.919934210526279, -5.38623355263163, -5.367631578947382, -6.2695065789473645, -8.972565789473734, -3.7749177631579514, -3.2142927631579497, -2.3053618421052917, 5.356085526315752, 11.950805921052577, 17.705230263157823, 19.390312499999922, 22.369194078947295, 23.346759868420975, 26.669457236842042, 23.0241118421052, 17.941924342105185, 18.630838815789406, 17.380657894736785, 7.630016447368384, -1.331003289473749, 10.294588815789403, 12.462039473684158, 17.51985197368414, 22.96766447368413, 23.036299342105195, 19.20044407894729, 16.578207236842015, 19.836759868420984, 19.284473684210464, 21.809851973684133, 23.435279605263073, 28.242927631578887, 22.389720394736756, 28.881167763157826, 24.873404605263104, 31.759342105263105, 35.78249999999994, 35.44702302631573, 36.2199671052631, 33.08585526315783, 30.189078947368376, 26.43340460526308, 26.090230263157824, 23.55074013157888, 24.680328947368373, 24.0812171052631, 25.951677631578892, 26.274967105263112, 25.65789473684204, 25.176167763157835, 32.8106743421052, 32.082631578947314, 31.427072368420994, 36.04485197368415, 37.447697368421, 42.5818421052631, 40.46699013157889], [0.0, -3.6427796052631383, -7.737138157894696, -5.998815789473637, -1.910230263157871, -1.7530756578947173, -3.2912664473683986, -4.853190789473642, -6.128388157894689, -12.71669407894734, -13.881562499999996, -6.6781085526315795, -14.125312499999984, -12.845625000000021, -5.597911184210515, -4.345805921052625, -5.476677631578946, -20.589177631578927, -13.36968749999995, -15.190115131578905, -7.342648026315755, -7.352269736842066, -8.690970394736803, -10.434424342105222, -14.882220394736803, -20.541069078947395, -25.450065789473705, -28.231381578947392, -31.536118421052613, -31.445032894736812, -43.886546052631495, -35.34888157894735, -32.1916776315789, -23.33649671052629, -10.533207236842093, -5.891052631578939, -2.4156907894736808, -2.5285855263157977, -1.8845723684210522, -0.5368914473684256, -9.81927631578946, -17.829029605263138, -17.644292763157893, -29.296184210526327, -27.573898026315796, -21.10939144736846, -39.96473684210524, -30.308388157894676, -24.954226973684207, -9.470970394736819, 1.1097039473684038, -0.1032730263158097, 2.6171052631578835, -2.2469901315789595, -6.068092105263121, 0.014753289473675935, -1.9961842105263106, -1.754358552631567, -2.0648190789473606, -8.744851973684204, -6.606266447368421, -5.307335526315763, -4.845493421052618, -6.332368421052623, -5.97636513157895, -5.290657894736837, 0.040411184210526585, 4.239967105263162, 4.74606907894737, 4.850625000000003, 4.5978947368421075, 4.1129605263157885, 4.699884868421066, 3.3592598684210557, 3.3727302631578997, 2.6697039473684203, 2.9089638157894857, 4.88718750000001, 5.7787993421052715, 5.424078947368428, 9.912927631578953, 8.918684210526319], [0.0, -1.4554440789474086, 0.10455592105253686, 3.0295559210525624, 3.3637499999999037, 3.7537499999999184, 3.9801809210525363, 2.4766282894736165, -4.406743421052653, -20.50835526315788, -41.794786184210494, -37.80690789473687, -28.57904605263164, -30.574588815789525, -13.158651315789555, -13.578157894736876, -11.913601973684194, -15.271578947368369, -11.972615131578891, -9.760904605263093, -4.248947368421042, -1.6837993421052104, -3.1661842105263105, -7.642203947368387, -20.821381578947282, -32.36550986842097, -43.15786184210529, -44.024457236841954, -32.23208881578954, -30.22371710526309, -28.834983552631655, -23.52700657894742, -19.691151315789483, -17.17603618421049, -12.51656250000002, -8.143174342105212, -4.766595394736925, -0.8916118421052701, -0.4349013157895314, -4.828174342105271, -19.898980263157895, -29.39945723684221, -27.86383223684217, -13.805871710526361, -8.14253289473686, -12.376085526315833, -38.34957236842102, -33.56565789473689, -31.14483552631583, -19.795065789473725, -16.719325657894714, -19.529506578947434, -14.485805921052645, -16.59167763157896, -15.708404605263269, -12.85781249999998, -9.44402960526321, -13.093865131579022, -17.12921052631586, -32.722154605263285, -25.16141447368426, -13.928388157894801, -19.495509868421095, -30.11210526315803, -38.327121710526356, -32.53036184210535, -23.761776315789547, -19.30179276315782, -18.81172697368426, -14.253601973684297, -14.606398026315901, -12.666019736842145, -8.464539473684226, -5.134144736842117, -4.56646381578949, -4.0411184210526585, -5.0475493421053415, -9.723700657894696, -3.0314802631578743, -10.578108552631662, -7.491463815789544, -10.080986842105332], [0.0, -3.0821546052631543, -5.116184210526319, -1.7742434210526328, 6.916085526315789, 8.908421052631578, 9.695476973684213, 8.806430921052634, 8.708289473684212, 8.873141447368422, 4.0500986842105275, -2.7075493421052617, -8.400394736842102, -10.257384868421045, -4.094358552631574, 3.1379605263157915, 4.605592105263164, -5.066151315789472, 2.6305756578947372, 5.981496710526316, 18.43840460526317, 23.82399671052632, 23.47440789473685, 25.16590460526318, 25.414786184210524, 28.96712171052633, 27.687434210526323, 22.972154605263142, 26.931167763157884, 19.75914473684209, 17.567960526315794, 18.446101973684232, 22.765608552631562, 27.765690789473695, 30.105049342105268, 29.634226973684243, 30.551496710526354, 31.42322368421055, 39.878782894736815, 51.69488486842102, 51.30937499999999, 47.32855263157891, 42.538865131578966, 31.378322368421056, 42.808914473684226, 45.46065789473687, 30.13070723684211, 44.60560855263155, 47.13226973684211, 42.7543914473684, 37.46501644736841, 32.43735197368422, 33.05763157894737, 31.927401315789464, 41.93205592105259, 37.44705592105264, 44.16236842105264, 51.94889802631579, 38.3271217105263, 42.58248355263158, 39.04361842105265, 35.61700657894738, 29.29682565789475, 23.691858552631583, 23.09082236842106, 24.617467105263152, 19.325526315789475, 15.881595394736848, 12.973914473684221, 12.146447368421063, 10.9777302631579, 13.202911184210535, 12.003404605263166, 10.243914473684214, 14.661562500000002, 18.30498355263158, 16.591036184210527, 16.857236842105277, 12.043815789473685, 11.35810855263158, 11.102812499999999, 7.9892269736842145], [0.0, -4.490773026315791, -6.309917763157895, -1.9461513157894768, 0.09750000000000159, 1.5099671052631594, -0.8300328947368409, -0.7350986842105254, -6.041151315789477, -20.446134868421026, -23.547532894736836, -14.547384868421046, -18.642384868421054, -21.29412828947367, -13.7866282894737, -10.331792763157898, -13.06435855263158, -24.0523519736842, -13.809720394736836, -11.068815789473684, -11.009161184210527, -9.382450657894735, -8.67621710526316, -10.4902302631579, -16.429391447368396, -21.97919407894733, -25.950394736842092, -29.441151315789444, -35.58878289473681, -34.13205592105264, -40.94422697368425, -39.092368421052655, -38.37523026315791, -27.600838815789473, -13.646151315789469, -7.969342105263152, -3.8794736842105277, -2.5362828947368468, -5.304769736842108, -5.061661184210527, -14.388947368421046, -16.519194078947375, -14.269638157894738, -21.372384868421054, -27.104358552631567, -23.759851973684196, -40.76141447368419, -26.326924342105254, -20.841266447368422, 0.048108552631579204, 9.706381578947378, 8.613355263157894, 11.830855263157911, 5.445246710526314, 5.157236842105263, 10.0636677631579, 6.792286184210523, 8.23490131578948, 8.968717105263167, 4.468963815789472, 4.946200657894741, 5.94108552631579, 0.48814144736842197, -0.7427960526315784, -4.781990131578947, 0.15202302631578998, 7.984095394736846, 17.428125000000023, 18.33192434210528, 19.406348684210535, 17.251726973684214, 15.388322368421052, 17.48842105263157, 17.606447368421065, 17.89574013157894, 16.256842105263164, 17.004769736842103, 18.897039473684217, 18.611595394736845, 16.145230263157895, 16.74626644736842, 16.139457236842112], [0.0, -2.5568092105263136, -7.6928782894737004, -1.170000000000001, 4.662039473684206, 9.155378289473667, 8.367680921052626, 7.569078947368416, 6.658865131578941, 0.5926973684210509, -6.184835526315793, -17.00605263157896, -26.75797697368423, -32.72664473684209, -22.138273026315787, -7.681332236842101, -6.711463815789475, -16.077878289473688, -4.27332236842107, -9.494703947368432, 0.762039473684209, 10.505624999999993, 17.294062499999992, 15.335082236842082, 10.594144736842086, 7.256694078947358, 5.434983552631572, -2.558092105263158, -10.794276315789482, -6.589588815789473, -18.258799342105267, -17.45699013157895, -17.2299177631579, -5.9712335526315785, 4.340674342105261, 9.526776315789466, 10.066874999999994, 14.898256578947374, 18.91692434210526, 27.21661184210527, 24.574490131578962, 28.669490131578943, 22.296710526315774, 4.577368421052632, 9.971940789473683, 16.43901315789472, -6.445904605263157, 6.807039473684209, 15.909819078947352, 30.428980263157904, 31.97550986842106, 25.722680921052667, 27.001726973684224, 21.578930921052635, 24.303799342105282, 28.736842105263168, 37.43871710526314, 43.95582236842104, 40.16615131578948, 37.051282894736865, 31.605394736842104, 25.609786184210517, 20.357615131578967, 16.544210526315798, 11.871907894736848, 13.130427631578947, 16.524967105263155, 17.943207236842124, 16.16254934210528, 14.67246710526316, 13.725049342105251, 13.850131578947373, 15.687236842105266, 16.17922697368424, 16.913684210526338, 18.957335526315784, 19.889358552631577, 19.41019736842105, 18.966315789473676, 16.385773026315796, 16.14330592105263, 12.643569078947369], [0.0, -3.451628289473688, -5.478601973684217, 0.9583223684210553, 2.846101973684216, 2.894851973684223, 2.3836184210526383, 2.1379440789473767, -1.3444736842105343, -12.227269736842109, -21.099128289473693, -11.119490131578946, -4.74478618421053, -8.331759868421052, -1.9852796052631607, -0.9204769736842127, -6.772401315789477, -18.02531249999999, -11.93220394736842, -7.567154605263155, -5.34261513157895, -6.285542763157903, -4.950690789473684, -3.7755592105263185, -7.973832236842108, -11.00851973684211, -12.841134868421053, -16.049013157894738, -21.581496710526327, -28.436003289473682, -25.945263157894757, -28.32054276315789, -29.97675986842105, -25.493042763157906, -16.666726973684206, -11.947598684210536, -8.732664473684213, -10.773750000000005, -12.93735197368421, -15.183700657894745, -16.32868421052632, -6.341990131578951, -9.131003289473686, -22.323009868421046, -15.832845394736847, -15.732138157894736, -35.878075657894726, -31.937664473684233, -26.54629934210528, -16.288914473684216, -2.6658552631578973, -0.33547697368421714, 3.682549342105256, -7.491463815789476, 2.036595394736839, 6.084769736842109, 5.655641447368424, 17.23248355263157, 17.83672697368421, 19.574407894736815, 16.177302631578954, 7.974473684210523, 5.234851973684215, 0.5279111842105211, -4.9474835526315815, -7.747401315789476, -4.6415131578947415, 7.776907894736841, 18.299210526315804, 20.604572368421046, 16.909835526315778, 20.938125000000024, 24.96962171052635, 26.57131578947369, 26.021595394736856, 31.486726973684192, 32.87995065789473, 34.78055921052636, 31.722779605263163, 30.65412828947366, 29.29874999999999, 26.413519736842115], [0.0, -3.028914473684239, -5.203421052631626, -5.153388157894781, 0.02052631578943931, 0.5779440789473469, -3.902565789473691, -2.874325657894765, -3.7223190789474074, -4.865378289473739, 1.1764144736841118, 17.851480263157818, 18.8624013157894, 16.755246710526226, 20.738634868420977, 25.32434210526307, 16.587828947368347, -3.227763157894806, -0.7274013157895212, -1.720361842105298, -3.4407236842105604, -0.9705098684211038, 0.20077302631574412, -1.4868750000000546, -0.8685197368421669, 0.04939144736833612, 1.2809703947367694, -0.017319078947402033, 3.9609374999999147, 5.653717105263095, 5.2932236842104174, 8.158569078947309, 5.975082236842013, 11.615328947368358, 16.449276315789398, 20.009950657894656, 22.167779605263068, 24.952944078947272, 24.020279605263077, 22.64116776315781, 19.894490131578856, 22.90800986842097, 26.486003289473608, 20.389687499999923, 19.46151315789466, 20.002894736842045, 4.5946874999999, 14.062450657894665, 17.834802631578864, 30.01075657894728, 34.40146381578939, 33.2744407894736, 36.95699013157887, 36.849868421052555, 36.967253289473604, 43.8865460526315, 46.88659539473676, 54.20871710526308, 54.7943585526315, 52.80074013157886, 46.86863486842097, 45.52031249999992, 39.914703947368345, 39.41758223684203, 34.981973684210445, 36.923634868420976, 44.84935855263149, 51.823815789473606, 53.207417763157814, 51.807138157894656, 54.186266447368354, 56.743717105263066, 59.208799342105195, 61.83552631578938, 64.35833881578941, 65.98440789473678, 67.73042763157889, 69.00370065789465, 68.30259868421044, 66.92797697368414, 63.95166118421045, 63.434013157894626], [0.0, -3.0738157894736915, -6.388174342105273, 0.37845394736842763, -2.2700822368421143, -4.354144736842088, -5.409967105263142, -5.9321052631578866, -2.4862500000000054, -3.329753289473736, 8.680707236842043, 22.558421052631523, 24.41797697368415, 22.49235197368416, 26.685493421052577, 25.519342105263092, 16.227976973684157, 1.6331249999999642, 0.1879440789473108, -4.749276315789487, -0.8255427631579266, -1.5465296052631672, 0.8928947368420737, -0.030148026315799825, -2.1584703947368666, 1.6953453947368047, 3.3932565789473372, 3.9269407894736403, 3.3348848684209713, 7.594095394736772, 3.0135197368420705, 2.2085032894735974, 1.2149013157894117, 8.191924342105182, 16.52175986842097, 23.64310855263153, 25.20888157894732, 27.250608552631526, 28.06396381578942, 26.797746710526262, 22.18894736842099, 29.003684210526252, 30.36611842105258, 18.87458881578941, 22.120312499999955, 22.551365131578883, 1.2758388157894203, 9.70958881578942, 12.60572368421047, 29.788815789473638, 32.26416118421048, 32.19039473684206, 34.25200657894732, 31.40462171052627, 32.91907894736837, 39.2912171052631, 43.57608552631574, 48.5473026315789, 51.657680921052574, 49.43378289473679, 52.2978453947368, 45.209210526315736, 40.90638157894732, 36.16993421052626, 28.029967105263097, 30.774720394736786, 35.68756578947363, 40.861480263157844, 42.504868421052585, 42.83008223684206, 42.900641447368365, 42.73001644736837, 46.35355263157889, 49.25866776315785, 49.32409539473679, 53.62820723684206, 54.528799342105216, 57.5237171052631, 55.99963815789467, 57.31524671052625, 56.54422697368416, 54.047072368421006], [0.0, -3.139884868421058, -4.034703947368422, 2.574128289473685, 0.8178453947368389, -0.5946217105263187, -0.17447368421051834, 0.30661184210526393, -4.338108552631576, -14.771250000000009, -9.39592105263159, -1.1879605263158002, 0.7479276315789374, 0.08531249999999169, 6.55174342105262, 5.493996710526305, 0.17639802631577517, -7.696726973684221, -6.6017763157894755, -6.977023026315791, -5.24703947368422, -5.089884868421054, -5.518371710526308, -4.099490131578943, -5.671036184210518, -7.9449671052631565, -8.574226973684219, -9.523569078947375, -16.117006578947368, -12.143240131578963, -12.836003289473691, -12.152220394736855, -10.790427631578943, -6.975098684210536, -0.33291118421053234, 4.80187499999999, 5.153388157894727, 5.1437664473684075, 3.416348684210515, 3.052648026315784, 1.6921381578947283, 4.423421052631566, 3.1520723684210408, -8.127138157894745, -3.9962171052631703, -6.13608552631581, -17.319720394736837, -5.932746710526327, -3.1405263157894776, 14.52108552631578, 16.06504934210526, 15.648749999999996, 17.99067434210525, 13.383799342105254, 15.65259868421052, 20.007384868421056, 15.903404605263148, 17.005411184210516, 19.04393092105262, 15.260032894736835, 15.533930921052626, 9.989901315789464, 9.75513157894736, 9.62684210526315, 3.7075657894736747, 8.075180921052622, 12.782121710526305, 19.829703947368422, 21.582138157894732, 20.25113486842104, 21.653338815789468, 21.95417763157893, 23.92791118421053, 25.69060855263156, 25.40388157894736, 26.269194078947372, 24.558453947368406, 23.659144736842087, 23.668766447368405, 23.406414473684194, 23.86120065789473, 24.482121710526307], [0.0, -1.6401809210526266, 4.356069078947384, 4.789046052631593, 8.842993421052661, 14.48452302631582, 14.755855263157919, 17.27866776315792, 15.894424342105278, 21.326842105263157, 14.053470394736848, 8.278519736842124, 2.4868914473684347, -2.31434210526315, 7.617187500000006, 11.61661184210529, 18.13243421052633, 14.273486842105303, 16.435164473684267, 15.444128289473728, 27.044703947368482, 35.43226973684211, 40.016694078947374, 38.752401315789456, 38.44322368421054, 42.56131578947369, 44.932105263157894, 44.324654605263134, 49.206710526315824, 44.690279605263214, 35.94414473684208, 32.25197368421053, 30.578437500000014, 34.24944078947372, 32.925493421052686, 36.59072368421059, 41.48304276315797, 42.24636513157901, 41.93975328947371, 50.61404605263161, 57.42429276315794, 65.37118421052624, 59.39417763157888, 65.70345394736844, 67.87090460526315, 53.401134868421074, 32.04799342105265, 41.8974177631579, 40.586940789473694, 49.40042763157903, 48.79297697368431, 41.28932565789475, 42.690888157894804, 41.24634868421058, 45.78394736842108, 52.20547697368421, 54.11955592105266, 69.46425986842102, 55.068898026315814, 63.8695559210526, 48.528700657894746, 41.99748355263157, 20.15299342105264, 21.82396381578948, 15.441562500000018, 16.435164473684225, 20.45447368421053, 16.00796052631582, 18.626348684210544, 15.365871710526338, 15.94894736842108, 15.161250000000006, 18.099720394736867, 19.639835526315807, 24.713684210526335, 20.467944078947376, 22.98690789473683, 24.083782894736856, 15.875180921052625, 15.312631578947375, 7.011019736842113, 5.840378289473693], [0.0, -2.3015131578947363, -1.758848684210526, 1.5381907894736822, 1.1231743421052633, 3.3926151315789483, 1.939736842105264, 0.8139967105263163, -3.6690789473684218, -7.252845394736839, -3.9378453947368426, -7.874407894736843, -12.670509868421062, -13.139407894736834, -7.741628289473677, -3.1604111842105285, 0.5882072368421057, -6.610756578947368, -3.268174342105265, -3.9243750000000013, 0.052598684210525826, 1.7088157894736846, 0.8961019736842121, -0.49583881578947353, -4.987894736842105, -7.947532894736845, -10.23557565789474, -17.165131578947367, -20.802138157894735, -25.059424342105252, -27.57133223684209, -26.770805921052627, -20.907976973684182, -11.839194078947365, -2.015427631578947, 6.22268092105263, 7.144440789473681, 6.796134868421054, 4.906430921052631, 0.8088651315789476, -2.610049342105263, -4.7370888157894715, -11.413914473684207, -22.799605263157915, -19.603914473684206, -20.91118421052631, -27.88115131578948, -19.0432894736842, -17.574375000000014, 7.7211019736842115, 10.53577302631578, 7.712121710526304, 7.096973684210526, -5.962894736842103, 0.08916118421052677, -0.2944243421052633, -6.363799342105262, -1.2905921052631575, -3.415707236842104, -4.15529605263158, -5.445888157894735, -6.66784539473684, -8.000773026315786, -10.227878289473686, -13.841792763157889, -14.14391447368421, -11.749391447368417, -2.4272368421052617, -1.8614802631578948, -2.2790624999999998, -4.875000000000001, -2.725509868421052, -1.8486513157894726, -2.4997203947368427, -9.581299342105261, -8.443371710526312, -8.689046052631573, -7.8609375, -8.374736842105262, -6.487598684210527, -5.400345394736844, -4.469605263157897], [0.0, 1.2027138157894832, 2.1738651315789745, -1.2367105263157967, -0.9339473684210162, -0.27838815789469606, -2.39324013157891, -3.651118421052608, -7.2682401315789456, -5.359934210526269, 3.3079440789474255, 7.5645888157895325, 10.21697368421057, 13.526842105263214, 8.14638157894741, 10.017483552631635, 7.9051973684211045, 2.1129276315789873, 2.787730263157929, 4.291282894736884, 4.31886513157899, 2.311776315789512, 1.3900164473684526, 0.8024506578947772, 2.035312500000046, 1.2020723684210957, 2.2931743421053135, 0.5651151315790024, -0.0513157894736338, 2.4368585526316267, 4.810213815789529, 12.327976973684263, 15.476200657894786, 18.31717105263163, 19.63213815789479, 21.452565789473738, 24.557812500000054, 27.578388157894786, 29.423190789473733, 26.189013157894795, 16.68597039473689, 16.234391447368473, 17.569243421052683, 14.156743421052685, 16.660953947368473, 17.254292763157945, 20.902203947368474, 24.65531250000005, 23.090822368421104, 23.110065789473737, 20.660378289473737, 19.355032894736894, 17.172828947368473, 12.852039473684263, 12.146447368421107, 12.925805921052682, 11.413914473684262, 9.632615131578996, 5.622286184210575, 11.735279605263216, 13.51465460526321, 15.852730263157946, 15.145213815789523, 14.85592105263163, 10.718585526315836, 8.508799342105315, 8.082236842105313, 3.116792763157937, 2.68958881578952, 1.7216447368421584, 1.2155427631579379, -0.9140624999999254, -1.0179769736841635, -1.1417763157894107, -1.061595394736802, -2.010296052631528, -1.2456907894736347, -0.24246710526312043, -1.4092598684209854, 1.0423519736842657, 0.8486348684211045, 0.8710855263158415], [0.0, 0.7274013157894803, 0.6735197368421062, -2.1417927631578877, -3.4971710526315753, -2.726792763157899, -3.4003125000000054, -5.0546052631578995, -11.025197368421022, -16.637220394736808, -10.313190789473655, -17.931019736842085, -14.11504934210527, -5.1707072368420945, -8.426694078947367, -3.493322368421037, -2.57412828947367, -2.90768092105262, -1.4541611842105162, -4.656907894736847, -4.365690789473671, -6.093108552631577, -5.320164473684212, -6.37470394736842, -9.517154605263151, -12.272812499999976, -14.157384868421044, -18.914999999999967, -26.40325657894738, -24.94717105263157, -20.755953947368415, -12.31707236842104, -5.134144736842089, 3.9525986842105336, 7.809621710526325, 11.041233552631592, 11.877039473684222, 13.013684210526328, 11.066891447368432, 6.357384868421062, 1.1174013157894755, 1.2784046052631695, -0.7043092105263113, -8.509440789473661, -1.021184210526302, -1.27263157894736, 1.8820065789473777, 10.807746710526327, 11.286907894736853, 15.47684210526317, 14.188174342105274, 14.98870065789475, 15.13495065789475, 11.880246710526327, 10.8892105263158, 8.265690789473698, 4.5901973684210695, 0.7581907894736979, 1.157171052631588, -3.3156414473684066, 2.7851644736842207, 2.221332236842107, 6.494013157894745, 8.124572368421063, 4.540164473684223, 7.851315789473698, 7.896858552631594, 5.000723684210538, 0.1449671052631789, -1.9455098684210377, -3.5799177631578765, -4.757615131578934, -7.940476973684184, -9.957187499999993, -10.146414473684192, -10.229802631578924, -13.435756578947348, -11.684605263157884, -9.023881578947332, -9.145756578947353, -5.595986842105251, -3.7691447368420974], [0.0, -1.640180921052636, 1.669046052631554, -1.7242105263157974, -2.7421875000000036, -4.909638157894701, -7.688388157894668, -6.995624999999951, -5.461924342105295, 0.9640953947368054, 7.264391447368393, 0.5939802631578637, 4.033421052631542, 13.183667763157843, 10.469062499999943, 13.202911184210464, 12.20481907894732, 10.051480263157842, 7.672351973684144, 5.626776315789414, 3.3650328947367676, 2.107154605263119, 4.052023026315744, 3.298322368421008, -1.1424177631579333, -1.4317105263158147, -6.0469243421052745, -5.593421052631623, -10.215049342105313, -14.08297697368425, -7.745476973684244, 0.2803124999999653, 10.197730263157823, 20.82009868421047, 25.52511513157889, 30.879917763157845, 34.57337171052626, 38.667730263157836, 38.166759868420996, 31.66312499999995, 23.639259868421007, 21.730312499999954, 12.607006578947328, 9.547302631578887, 16.26197368421049, 21.91504934210522, 27.060740131578896, 28.200592105263105, 27.752220394736785, 31.67531249999995, 28.517467105263098, 30.74393092105258, 28.03958881578941, 26.82853618421046, 26.71564144736836, 27.588651315789424, 21.064490131578893, 20.41470394736838, 17.328059210526266, 20.89386513157889, 27.226874999999946, 29.99600328947363, 32.874177631578895, 28.716957236842052, 19.168371710526266, 20.731578947368362, 19.081134868421, 16.981036184210467, 13.313240131578876, 12.385707236842045, 11.971332236842045, 10.412615131578896, 9.13228618421045, 7.651184210526253, 6.132236842105183, 3.671003289473628, 5.472187499999954, 5.543388157894682, 9.093157894736763, 12.639078947368372, 14.680805921052595, 15.133667763157838], [0.0, -0.626052631578947, 0.5362500000000026, -2.9974835526315733, -3.3291118421052683, -3.028273026315796, -2.72294407894738, -3.364391447368426, -4.039835526315779, -4.506167763157883, -3.32398026315788, -4.440740131578925, -1.7902796052631427, 2.0256907894737033, 0.07376644736843296, -1.4451809210526179, -3.2829276315789446, -2.6729111842105198, -3.1988980263157885, -4.165559210526313, -6.198947368421033, -6.193815789473657, -5.178404605263145, -5.944934210526304, -6.248980263157879, -7.630657894736814, -6.866052631578913, -9.633256578947378, -8.91162828947368, -10.2561019736842, -8.75896381578946, -4.538240131578929, -3.4208388157894554, 0.3297039473684418, 1.2033552631579258, 3.9891611842105448, 3.130263157894756, 1.6767434210526497, -0.787697368421032, -4.068059210526306, -1.6818749999999891, -1.2816118421052458, -1.0635197368420908, -3.8217434210526076, -2.139868421052622, -5.256019736842081, -5.60560855263156, -0.4663322368420886, -1.3611513157894546, 3.8243092105263345, 2.71588815789476, 3.7652960526316006, 4.3631250000000215, 1.5279276315789705, 0.8659539473684443, -0.5740953947368208, -0.97756578947366, -2.4766282894736733, -2.631217105263133, -2.6639309210526054, -1.5490953947368329, -3.175164473684191, -1.840312499999973, -1.7242105263157708, -5.387516447368412, -1.7030427631578888, -0.7851315789473574, -1.6132401315789338, -3.9416940789473447, -5.730049342105259, -5.824342105263156, -6.47476973684209, -6.591513157894742, -6.142499999999984, -6.719802631578933, -5.58059210526314, -6.848092105263131, -6.453601973684194, -5.09116776315788, -5.278470394736823, -3.4336677631578763, -4.135411184210517], [0.0, 1.5991282894736885, 3.9615789473684266, -1.166792763157913, -3.162976973684227, -2.587598684210544, -4.31437500000002, -7.176513157894751, -14.447960526315772, -17.615427631578942, -10.186825657894731, -26.679078947368406, -25.68483552631575, -16.360115131578947, -13.973930921052638, -4.787763157894737, 0.6138651315789518, 4.458700657894742, 6.842319078947369, 6.980871710526317, 5.091167763157898, -0.4387500000000015, 2.207861842105268, 1.0089967105263207, -0.08723684210525828, 0.6715953947368449, -0.7787171052631541, -6.669128289473679, -13.161217105263166, -18.377467105263154, -12.178519736842098, -0.6029605263157878, 9.581940789473691, 14.12980263157895, 16.6263157894737, 15.624375000000002, 16.600657894736855, 24.305082236842114, 30.45527960526317, 26.61814144736843, 8.813486842105265, 10.427368421052632, 6.035378289473687, 1.8268421052631645, 5.396496710526319, 18.526924342105268, 27.590575657894735, 30.232697368421064, 30.219226973684226, 24.07865131578949, 17.280592105263175, 15.380625000000013, 8.996299342105264, 7.485049342105267, 1.7947697368421034, 3.1283388157894767, -2.52152960526315, -2.8172368421052596, -7.753815789473684, -0.491990131578941, -0.020526315789470395, 3.2630427631578973, 5.030871710526319, 8.00077302631579, 4.555559210526319, -1.0064309210526252, -7.336233552631578, -14.95598684210525, -19.204292763157877, -24.36537828947367, -25.56809210526314, -28.871546052631533, -30.68748355263156, -31.53226973684207, -30.108898026315774, -34.073684210526295, -34.03391447368416, -30.818980263157872, -30.30967105263156, -25.870213815789466, -29.226266447368413, -30.64322368421053], [0.0, 0.06671052631575236, 1.3322861842105311, -5.727483552631604, -4.371463815789475, -6.601776315789472, -9.631973684210543, -11.250986842105249, -17.45827302631583, -21.591118421052705, 7.173947368421004, 20.065115131578914, 28.022911184210493, 27.899753289473644, 19.351184210526277, 19.303075657894706, 8.601167763157875, 1.1776973684210361, -0.7107236842105777, -10.653799342105302, -11.855230263157914, -8.138684210526336, -12.604440789473706, -18.093305921052647, -17.95475328947368, -18.720641447368422, -11.129753289473683, -7.625526315789507, -5.744161184210576, 4.5260526315789065, 9.124588815789444, 11.67049342105257, 10.798124999999963, 5.548519736842067, 9.419013157894664, 10.045707236842052, 12.147730263157857, 12.550559210526274, 9.41580592105257, 9.181677631578921, 15.979736842105211, 16.381282894736795, 18.212615131578918, 17.860460526315748, 17.906644736842065, 15.524309210526283, 21.75148026315785, 19.380690789473643, 19.6507401315789, 12.231759868421015, 14.821282894736814, 17.580789473684142, 21.905427631578902, 29.50786184210522, 32.04606907894733, 34.38157894736838, 41.65174342105259, 39.2905756578947, 34.60736842105259, 29.734292763157853, 32.89149671052627, 32.632351973684166, 37.15583881578944, 39.99039473684206, 41.35090460526312, 39.77871710526312, 44.68835526315786, 42.2733059210526, 42.97504934210522, 45.044358552631536, 46.164967105263116, 46.662730263157854, 46.443355263157855, 44.18546052631575, 50.89371710526312, 47.6512006578947, 47.08287828947364, 46.84233552631575, 47.39398026315786, 47.12842105263154, 49.73526315789469, 49.49087171052628], [0.0, -0.17383223684210947, -1.595279605263194, -4.346447368421089, -5.120674342105282, -6.828207236842154, -8.115592105263218, -7.5735690789473935, -2.20080592105262, 7.554967105263195, 14.12467105263164, 22.160082236842147, 28.791365131579003, 31.792697368421095, 29.478355263157944, 27.131940789473738, 24.199243421052685, 18.487154605263235, 13.048322368421104, 7.236809210526339, 5.8429440789474185, 2.411200657894746, -0.6254111842105274, 2.719095394736854, 7.501726973684249, 12.92259868421058, 12.322845394736888, 12.302960526315811, 19.35246710526321, 25.575789473684264, 26.595690789473743, 30.66375000000005, 31.741381578947426, 29.543782894736903, 29.01587171052637, 25.035049342105328, 26.325641447368493, 25.460328947368485, 28.8612828947369, 31.450164473684254, 32.55409539473689, 36.46820723684215, 33.056348684210576, 36.41945723684215, 39.00192434210532, 38.58498355263163, 40.162302631578996, 36.21932565789478, 35.24432565789479, 24.78360197368429, 24.055559210526397, 23.03565789473691, 21.17802631578956, 26.446233552631643, 27.233289473684263, 28.346200657894784, 32.88315789473688, 30.829884868421097, 32.89470394736847, 30.81320723684215, 37.19881578947373, 36.37070723684216, 36.58559210526321, 34.07560855263163, 29.845904605263208, 24.884309210526364, 24.93690789473689, 20.293470394736918, 19.433289473684287, 18.804671052631655, 19.01506578947375, 19.404424342105337, 17.385789473684277, 17.49611842105271, 22.532121710526376, 21.711710526315855, 20.28000000000007, 20.193404605263204, 22.62192434210534, 23.09082236842112, 25.404523026315857, 25.726529605263195], [0.0, 1.760773026315782, 0.2026973684210578, 2.608766447368412, 7.014868421052652, 9.83531250000003, 9.639671052631618, 11.023273026315826, 6.118766447368431, -0.12444078947368098, -9.701891447368416, -11.94759868421052, -7.860937499999997, -7.689029605263153, -5.943651315789464, -1.2238815789473705, 2.4002960526315746, 3.363750000000005, 7.940476973684232, 16.177302631578996, 29.4033059210526, 36.42330592105258, 26.34039473684208, 22.113256578947386, 27.897187499999987, 31.696480263157873, 36.04356907894734, 37.323898026315796, 30.82282894736842, 28.60791118421058, 25.50715460526316, 21.927236842105287, 21.884259868421047, 19.69371710526316, 21.50773026315789, 26.28330592105263, 32.12560855263156, 32.003092105263136, 36.89412828947364, 45.31376644736841, 43.374671052631584, 37.89286184210528, 45.243848684210555, 50.46266447368423, 41.91217105263163, 30.459769736842134, 34.56567434210523, 29.154424342105266, 29.014588815789473, 21.075394736842043, 18.498700657894716, 18.75271381578945, 17.984901315789457, 26.539884868420998, 23.60526315789472, 24.594374999999978, 34.36105263157895, 26.921546052631548, 26.346167763157908, 12.57044407894738, 10.991842105263155, 2.071233552631579, -0.30597039473683374, -0.3271381578947352, -2.002598684210522, -4.549144736842097, -1.8717434210526243, -6.5286513157894674, -10.000805921052626, -10.821217105263154, -10.157319078947364, -12.096414473684204, -11.968766447368417, -12.41585526315789, -13.04319078947368, -14.294013157894732, -14.437697368421048, -14.049621710526312, -17.106118421052628, -24.079934210526307, -23.675180921052632, -24.3294572368421], [0.0, 5.3785361842105175, 7.091842105263069, 7.425394736842122, 15.579473684210505, 25.22491776315791, 27.980575657894725, 30.054375000000014, 22.96381578947367, 20.168388157894768, 5.089884868421123, 3.2739473684211475, 4.8422861842106215, 1.1533223684211436, 6.596003289473771, 13.398552631579044, 27.666907894736916, 54.76934210526326, 53.428717105263274, 55.01052631578958, 60.488486842105395, 76.28990131578956, 73.22699013157903, 63.376924342105355, 72.56822368421061, 63.793223684210616, 55.0175822368422, 60.18444078947378, 54.060542763158, 50.14963815789483, 56.44608552631587, 67.01072368421062, 79.82620065789483, 83.75763157894745, 81.15143092105272, 94.68532894736852, 95.24531250000011, 90.91105263157904, 90.10796052631589, 92.62692434210535, 93.11891447368431, 94.14651315789483, 96.4518750000001, 73.53296052631588, 61.47952302631588, 57.68472039473693, 64.84134868421062, 66.68550986842115, 61.63603618421062, 53.59164473684221, 54.282483552631675, 55.816184210526416, 54.970115131579036, 59.9047697368422, 67.07486842105271, 61.23513157894746, 51.34401315789482, 52.06564144736852, 43.2932072368422, 42.3643914473685, 53.32287828947378, 46.98986842105269, 33.59644736842117, 24.113930921052763, 13.581365131579034, 13.330559210526367, 8.268898026315796, 1.3874506578947319, 8.786546052631607, 7.58575657894734, 3.1565624999999073, 2.5016447368420955, -0.7825657894737077, -2.948733552631637, -0.4175822368420512, -0.29570723684206257, -5.956480263157857, 2.4791940789474154, -1.624144736842041, 8.67429276315795, 3.346430921052715, -4.504884868420987], [0.0, 3.604292763157889, 1.7036842105263101, -0.34574013157894967, -0.4368256578947385, -3.5882565789473606, -2.5670723684210515, -3.02378289473684, -2.3996546052631604, -3.614555921052647, 4.400328947368407, 4.512582236842087, 1.0263157894736636, 7.722384868421031, 6.7614967105263, 7.1912664473684025, 5.004572368421035, 4.95133223684209, 3.821101973684195, 3.9160361842105136, 4.951332236842091, -0.8544078947368483, -3.338733552631586, -3.005180921052631, -2.486891447368418, -2.9339802631579097, 0.32713815789471923, 4.832664473684191, 4.760822368421031, 10.519736842105242, 7.585756578947347, 4.549786184210506, 4.449720394736819, 7.123273026315768, 11.51654605263156, 12.401101973684193, 19.12475328947366, 15.015641447368404, 8.10404605263156, 7.340723684210506, 6.347121710526298, 5.5619901315789315, 11.39082236842103, 25.893305921052594, 20.72516447368419, 19.584671052631563, 11.589671052631559, 10.072006578947349, 16.79437499999998, 10.434424342105244, 6.213059210526294, 5.097582236842076, 3.7928782894736486, 4.044967105263129, 10.924490131578928, 7.803848684210511, 7.436299342105245, 2.7030592105262894, 6.476694078947346, 6.962269736842088, 6.776249999999976, -0.1590789473684513, -0.5009703947368678, 2.470855263157871, 3.0917763157894553, 1.2309374999999783, -1.298930921052646, -3.440082236842118, -7.010378289473698, -10.166940789473687, -9.970657894736826, -8.998223684210549, -8.299046052631597, -10.372203947368428, -11.968766447368433, -9.465197368421085, -8.419638157894765, -9.119457236842125, -8.377944078947392, -11.766710526315789, -11.932845394736843, -11.353618421052643], [0.0, 1.0750657894736406, 2.1122861842104896, 1.10777960526314, 14.322236842105234, 15.360740131578936, 23.343552631578902, 28.05626644736835, 27.060098684210438, 38.744703947368414, 20.247286184210523, 5.501694078947409, -3.758240131578937, -1.9192105263157728, -3.5901809210526068, 3.1251315789473963, 7.979605263157914, 17.056085526315783, 18.95156249999998, 25.01708881578943, 41.26174342105255, 65.14282894736829, 54.97460526315789, 70.85427631578943, 74.80879934210523, 81.29254934210527, 81.72745065789474, 74.54580592105268, 96.33256578947376, 79.349605263158, 71.76000000000013, 70.1781907894736, 68.06077302631576, 63.5584539473683, 51.84819078947357, 45.81024671052621, 41.07764802631572, 46.680690789473665, 58.93618421052624, 91.40175986842104, 100.68286184210513, 73.51307565789472, 93.1355921052633, 124.06682565789473, 114.79342105263152, 101.75921052631585, 87.70381578947368, 77.35470394736836, 66.62585526315789, 54.292746710526224, 64.3570559210525, 65.68292763157885, 66.97865131578939, 65.24546052631567, 65.22365131578937, 63.34356907894726, 75.98328947368412, 98.01508223684203, 88.10087171052638, 79.45031249999988, 60.45577302631575, 42.752467105263214, 24.337796052631667, 21.35378289473691, 24.183848684210616, 24.8964967105263, 26.772088815789452, 31.24490131578947, 27.907450657894735, 23.96383223684213, 20.754029605263185, 22.165213815789514, 18.891266447368466, 18.023388157894757, 21.236398026315825, 20.374934210526398, 13.222796052631608, 13.676299342105295, 12.988026315789483, 6.890427631579001, -10.801332236842065, -12.783404605263119], [0.0, -2.985296052631554, -3.1488651315789866, -1.868536184210484, -4.714638157894399, -8.010394736842045, -7.574851973684133, -22.77266447368413, -37.51440789473688, -62.09146381578944, -108.37317434210522, -159.64342105263154, -211.58462171052628, -259.9965789473684, -281.80194078947363, -272.72995065789473, -261.04983552631575, -235.00707236842103, -202.87569078947365, -190.58748355263154, -196.8223519736842, -214.50641447368423, -227.97424342105262, -243.82376644736843, -262.11335526315787, -290.1696217105263, -327.168947368421, -378.93182565789476, -439.02261513157896, -490.206907894737, -570.4468421052629, -601.5166282894737, -634.6185197368421, -664.9955427631578, -675.2651151315788, -689.5565625000002, -700.9313486842107, -713.4023684210526, -726.7540953947369, -737.480378289474, -749.2118092105263, -741.9570394736841, -722.9131085526312, -758.4755921052631, -785.3663486842105, -776.5336184210528, -827.127138157895, -856.0493585526316, -836.9656578947369, -836.6513486842106, -822.3810690789473, -824.4439638157897, -814.9877467105268, -810.9562500000002, -812.7433223684211, -777.9755921052631, -753.3780098684208, -710.9860361842104, -661.9287828947367, -623.5432894736841, -597.6852631578947, -567.9009374999998, -563.3492269736844, -559.1990625000001, -545.267467105263, -539.7195888157894, -524.7899013157896, -508.3342105263157, -491.1613815789474, -480.4164967105262, -476.49276315789473, -467.73508223684206, -451.66361842105255, -435.61011513157905, -419.12876644736843, -395.93210526315784, -363.06562500000007, -329.47302631578947, -301.42253289473683, -276.21942434210524, -252.32871710526314, -229.59774671052637], [0.0, -4.659473684210411, -7.007812499999943, -11.754523026315837, -13.12786184210512, -19.614177631578684, -19.80019736842084, -39.03207236842087, -45.13929276315773, -68.67335526315762, -108.04667763157852, -141.7579440789471, -188.4719901315786, -237.39453947368378, -253.45060855263117, -244.14833881578906, -235.47725328947328, -219.680328947368, -195.8601809210522, -191.1275822368417, -196.56833881578905, -214.3723519736838, -228.68560855263118, -241.30095394736804, -263.9979276315786, -290.45763157894686, -317.2239473684206, -358.748684210526, -365.5230098684207, -402.5069407894732, -333.4070230263153, -260.1973519736838, -248.63590460526274, -233.17766447368376, -247.72761513157855, -257.3005756578943, -277.4631907894733, -296.00294407894694, -295.17547697368377, -296.2165460526312, -298.435953947368, -280.62873355263116, -281.4003947368417, -308.61059210526275, -234.1674177631575, -235.32907894736798, -107.24422697368371, -83.39393092105217, -146.1236348684207, -205.2971546052628, -204.450444078947, -200.27077302631545, -189.3129276315786, -177.68797697368382, -110.15254934210486, -73.10062499999941, -39.958963815788934, -7.509424342104694, 52.12080592105315, 90.69103618421099, 111.71126644736887, -25.892023026315428, -126.73781249999962, -233.8723519736838, -244.50498355263116, -100.62513157894693, -53.64424342105224, -20.070888157894046, -16.63529605263102, 0.8473519736848516, -20.046513157894367, -8.96743421052571, 15.260674342105858, 28.11335526315844, 50.7102631578951, 97.82970394736884, 142.56360197368468, 153.9159375000006, 126.00848684210564, 133.94639802631627, 120.62738486842159, -2.8204440789469345], [0.0, 2.86021381578945, 7.41769736842101, 13.957253289473634, 17.169621710526265, 13.268338815789434, 16.698799342105225, 19.08177631578944, 29.08065789473688, 43.55363486842108, 43.671661184210514, 33.57592105263162, 30.232055921052684, 32.52843750000006, 25.179375000000043, 22.803453947368546, 18.864325657894746, 22.183815789473663, 23.557796052631595, 34.35271381578945, 37.39381578947364, 38.502878289473706, 48.11753289473685, 61.7418749999999, 69.17945723684207, 84.79100328947368, 96.25944078947373, 92.6134539473685, 99.60074013157896, 89.21185855263161, 81.98787828947377, 72.46174342105272, 65.09087171052622, 50.667927631578856, 36.16544407894735, 29.713125000000026, 32.36807565789474, 61.10171052631572, 83.08667763157897, 97.60712171052643, 76.04615131578953, 83.9718750000001, 108.56304276315794, 120.18029605263166, 114.94672697368418, 112.44893092105264, 101.82271381578954, 95.39605263157901, 105.05047697368437, 96.02787828947362, 78.78449013157888, 66.8080263157893, 65.42249999999984, 65.2300657894736, 67.7368421052631, 61.74187499999996, 72.35654605263156, 78.92175986842102, 67.12810855263155, 78.60424342105262, 94.75203947368425, 77.06412828947373, 58.044572368421136, 47.7814144736843, 48.6185032894737, 49.765411184210514, 50.45304276315786, 46.73521381578957, 35.063437499999985, 36.49065789473679, 31.584226973684217, 27.91194078947374, 24.061332236842155, 23.892631578947466, 25.23518092105268, 29.30644736842107, 21.58662828947373, 27.49884868421058, 25.457121710526373, 13.483865131578987, 21.351217105263252, 12.862944078947486], [0.0, 1.495855263157889, 2.5754111842105054, 2.1231907894736644, 7.234243421052614, 13.319654605263135, 11.806480263157862, 13.229851973684195, 11.238799342105235, 0.24310855263153996, 3.047516447368398, -0.687631578947407, -7.420263157894787, -11.666644736842159, -14.398569078947425, -8.065559210526363, -1.7742434210526739, 2.0917598684210397, 6.530575657894719, 9.145115131578915, 16.895723684210527, 28.31861842105256, 25.081233552631556, 23.303782894736823, 23.817582236842068, 25.421200657894733, 26.41480263157887, 32.015921052631484, 26.229424342105258, 31.719572368421016, 18.499983552631537, 9.127796052631542, 8.499177631578942, 7.802565789473679, 7.5440624999999635, 12.513355263157859, 18.56669407894739, 21.060641447368393, 19.21199013157894, 23.50263157894737, 30.840789473684172, 30.615, 32.27570723684208, 44.81600328947363, 32.24427631578946, 25.85738486842102, 9.175904605263131, 7.644769736842061, 6.182911184210493, 20.009950657894716, 22.732894736842102, 18.639819078947365, 19.956069078947348, 15.124687499999961, 15.280559210526288, 18.685361842105255, 15.555098684210474, 31.034506578947347, 25.00041118421049, 21.190213815789452, 7.889802631578892, 4.773651315789412, -1.5420394736842766, -3.3791447368421714, -6.344555921052692, -7.193832236842141, -5.493355263157959, -2.3451315789474343, -1.3290789473684583, -2.1174177631579667, -1.9807894736842826, -4.256003289473746, -1.7043256578947776, -1.198223684210582, -2.0770065789474152, -4.760180921052683, -6.449753289473751, -3.5504111842105637, -7.737779605263217, -12.690394736842158, -15.998980263157955, -17.560263157894795], [0.0, -5.669753289473679, -5.436907894736841, -2.4984375000000085, -0.8184868421052762, 2.375279605263156, 4.305394736842111, 6.667203947368414, 9.92190789473685, 16.48648026315792, 17.70266447368424, 6.960986842105282, 6.345838815789492, 10.193881578947378, 16.822598684210554, 18.633404605263184, 8.540230263157914, -9.980921052631519, -6.716595394736821, 7.200246710526329, 9.143190789473692, 14.582023026315802, 25.803503289473703, 29.851036184210535, 26.856759868421072, 27.003009868421078, 25.902286184210556, 24.737417763157925, 19.40185855263161, 23.610394736842135, 25.47828947368424, 28.494375000000026, 31.285312500000032, 30.071694078947395, 28.396875000000033, 23.25503289473687, 26.366052631578977, 37.28861842105266, 49.20927631578951, 55.77641447368427, 55.93164473684216, 43.77429276315793, 45.48182565789477, 51.42996710526319, 45.11299342105265, 47.509440789473715, 53.57047697368424, 45.28810855263162, 49.88728618421054, 38.06027960526319, 34.4470065789474, 33.32319078947373, 30.734309210526348, 33.77220394736846, 43.544013157894774, 40.12830592105267, 48.640312500000036, 50.08228618421059, 47.06940789473688, 39.99360197368425, 38.9044243421053, 33.47328947368424, 33.21222039473687, 32.70483552631582, 34.29562500000004, 30.42962171052634, 28.17236842105266, 25.802220394736867, 16.079161184210562, 12.70578947368425, 10.599276315789508, 13.166348684210558, 11.698075657894769, 11.359391447368452, 9.547944078947406, 19.892565789473714, 15.995773026315813, 12.961085526315815, 19.38582236842108, 17.598750000000027, 15.668634868421083, 12.126562500000038], [0.0, 1.3855263157894715, 0.7152138157894719, 2.0353124999999963, -1.2995723684210603, -1.3669243421052766, -1.2905921052631655, -0.6311842105263352, -3.694095394736861, -6.182911184210516, -3.3983881578947273, -1.4798190789473367, 2.4702138157894886, 4.3759539473684494, 2.354111842105292, 0.21937500000002075, 1.6793092105263305, 3.3964638157894917, 3.3502796052631716, 5.901957236842128, 1.688930921052636, -0.10391447368421147, 2.571562500000006, 1.0404276315789414, -0.6465789473684183, -1.3213815789473689, -3.241874999999988, -0.2309210526315688, -2.47855263157893, 0.8653125000000212, 4.917976973684231, 6.713388157894761, 8.054654605263181, 10.47226973684213, 13.898240131578973, 14.385740131578972, 14.980361842105287, 15.508273026315813, 13.203552631578972, 10.077779605263183, 9.22978618421055, 8.592187500000026, 10.171430921052655, 15.38511513157897, 10.664703947368446, 9.500476973684236, 11.724375000000025, 13.097713815789499, 12.618552631578972, 12.305526315789498, 11.581973684210551, 13.340180921052657, 13.626907894736867, 13.764177631578972, 11.25868421052634, 10.930904605263184, 7.717894736842132, 4.07832236842108, 7.270164473684235, 6.585098684210546, 9.872516447368445, 8.560115131578966, 12.31899671052634, 10.687154605263183, 7.885312500000022, 8.333042763157923, 8.796809210526344, 7.287483552631603, 6.812812500000027, 8.163059210526345, 7.821167763157916, 6.7582894736842345, 5.933388157894759, 5.238700657894761, 4.249588815789501, 2.6587993421052953, 1.2828947368421417, 2.6594407894737095, 3.1071710526316014, 1.4317105263158147, 4.313092105263182, 7.353552631578969], [0.0, -0.7062335526315842, 1.1988651315789305, -1.3720559210526453, -2.3586019736842196, -0.9608881578947468, -3.4214802631579104, -4.3932730263158035, -4.833947368421072, -6.230378289473716, 3.9102631578947076, 9.488930921052594, 12.352993421052593, 12.854605263157861, 9.625559210526287, 7.815394736842077, 6.253470394736809, 4.906430921052602, 5.7499342105262805, 6.131595394736818, 0.7075164473684126, -2.0949671052631693, -2.8563651315789507, -3.224555921052648, -5.973799342105284, -7.680690789473694, -7.086710526315812, -2.86085526315793, -2.3143421052631723, 4.53374999999996, 3.019292763157857, 4.279736842105219, 4.719769736842064, 5.737746710526277, 9.585148026315755, 11.988651315789436, 12.545427631578923, 14.59036184210522, 10.5492434210526, 8.531891447368396, 4.306036184210502, 3.0135197368420634, 7.5953782894736594, 10.742319078947347, 7.569078947368395, 5.919917763157855, 6.229095394736808, 4.8948848684210216, 6.0854111842105, 9.887269736842082, 11.877680921052603, 13.064999999999959, 14.968174342105225, 15.950230263157856, 12.494753289473646, 13.392138157894696, 11.153486842105227, 9.509457236842069, 12.522335526315754, 11.334374999999962, 10.836611842105222, 13.59162828947365, 16.50059210526312, 15.381266447368382, 12.447286184210487, 15.730855263157856, 18.6083881578947, 20.856019736842068, 20.52759868421049, 20.474358552631543, 20.336447368421016, 18.654572368421015, 19.995197368421014, 18.63981907894733, 18.714868421052596, 18.02402960526312, 17.709720394736806, 19.63085526315786, 20.306940789473646, 19.67447368421049, 21.267828947368386, 20.389046052631542], [0.0, -1.5003453947368453, 2.0564802631579084, 7.952664473684218, 10.721792763157865, 8.084161184210538, 15.59230263157892, 19.50833881578945, 23.346118421052633, 36.616381578947426, 21.380082236842114, 2.54205592105264, -0.6440131578947277, 3.4105756578947464, 0.5227796052631657, 5.0013651315789485, 9.571677631578961, 12.474226973684214, 12.78725328947365, 34.494473684210604, 39.74407894736854, 43.13797697368432, 52.2118914473685, 62.94009868421062, 53.819358552631634, 51.50565789473686, 46.08478618421058, 40.03016447368426, 40.44133223684211, 38.52532894736844, 38.29120065789475, 45.5325, 52.47167763157896, 48.163717105263146, 47.29583881578942, 44.81151315789467, 49.24583881578941, 57.612236842105155, 63.13381578947358, 66.99981907894735, 64.74449013157897, 55.33060855263158, 66.47126644736846, 83.70824013157898, 68.28143092105262, 66.29679276315784, 61.47246710526314, 47.13932565789472, 46.45746710526316, 38.538799342105214, 42.304095394736756, 39.25080592105256, 38.31942434210522, 39.06606907894732, 43.90835526315785, 43.575444078947285, 46.34521381578946, 52.34082236842105, 37.24564144736841, 43.78455592105266, 34.66702302631577, 28.695148026315763, 21.166480263157876, 20.689884868421082, 26.045970394736877, 13.81741776315788, 9.563338815789479, 6.14570723684213, 2.1494901315789647, -1.9910526315789348, -5.247680921052622, -1.252105263157885, -3.1950493421052553, -3.1257730263157804, 1.5811677631579055, -1.454802631578941, -0.2527302631578916, 4.482434210526318, -2.314342105263152, -3.715263157894735, -10.43185855263157, -13.298486842105259], [0.0, 0.9275328947368333, 2.049424342105265, 1.6036184210526265, 9.494703947368366, 10.51781249999994, 9.444029605263095, 13.4601315789473, 16.126628289473622, 25.827236842105215, 25.72075657894733, 13.041266447368399, 7.661447368421035, 3.9301480263157593, 2.0725164473683897, 11.492171052631564, 19.0522697368421, 23.969605263157845, 24.630937499999938, 29.407796052631525, 36.85179276315782, 38.86978618421043, 37.31555921052623, 46.61462171052629, 59.272944078947454, 60.144671052631644, 60.60138157894742, 60.27488486842102, 64.35256578947362, 62.57062499999987, 57.01761513157886, 61.84322368421051, 64.33717105263156, 63.48468749999997, 52.206118421052665, 41.60876644736837, 39.110328947368366, 48.6749506578947, 62.07286184210519, 70.88249999999996, 65.71499999999996, 57.58722039473681, 61.392286184210526, 78.77871710526317, 70.23784539473682, 70.93317434210519, 76.08014802631578, 63.725871710526356, 61.27425986842102, 55.71226973684207, 54.592944078947276, 46.905197368420986, 43.40161184210518, 39.64080592105258, 35.38416118421047, 34.563749999999935, 35.464983552631544, 48.62812499999995, 29.016513157894735, 40.46378289473682, 31.16472039473682, 33.05763157894731, 25.46225328947365, 23.410263157894732, 21.558404605263135, 13.912351973684173, 14.00343749999997, 5.726842105263133, 5.329786184210489, 0.20847039473683004, 0.2206578947368314, 0.07697368421050932, -2.9384703947368536, 0.8986677631578655, 5.020608552631559, -3.1386019736842243, -1.4060526315789676, 0.5272697368420829, -4.0359868421052845, -4.923750000000024, -11.58774671052634, -13.26320723684213], [0.0, 1.2476151315789537, 3.2643256578947444, -2.6235197368420984, -0.2944243421052608, 2.3335855263157903, 4.792894736842101, 2.7736184210526282, -0.47274671052631145, -10.970032894736839, -0.7075164473684206, -8.43631578947368, -15.13174342105263, -12.819325657894733, -18.357582236842102, -10.597993421052628, -8.095707236842102, -0.07376644736842053, 9.034786184210537, 11.075230263157904, 16.145230263157913, 16.09583881578947, 19.399292763157902, 18.598766447368412, 9.165641447368428, 2.7280756578947383, 2.891644736842112, 0.4599177631579092, -14.879013157894732, -8.99052631578947, -10.199654605263152, -3.9564473684210517, 3.5516940789473743, 12.683338815789481, 21.900296052631568, 29.94340460526311, 31.394358552631573, 34.502812499999976, 33.670213815789424, 33.83763157894738, 20.43907894736843, 13.798174342105261, 9.106628289473692, -0.31751644736841733, 1.663273026315796, 9.103421052631594, 17.297269736842097, 18.912434210526314, 13.58200657894738, 22.74700657894732, 20.96185855263156, 16.59745065789472, 18.750148026315756, 16.698799342105254, 9.27661184210527, 10.975164473684211, -3.722319078947365, -2.682532894736841, -5.653075657894735, -3.282927631578943, -1.2700657894736835, -0.3624177631578869, 4.136052631578945, 0.9044407894736874, -5.103996710526314, -4.693470394736837, -7.111085526315785, -8.409374999999995, -12.258059210526312, -12.635871710526308, -13.134276315789474, -17.025937500000005, -16.006677631578945, -17.49291118421052, -24.39809210526316, -25.9260197368421, -25.382072368421056, -25.169111842105245, -22.904802631578942, -18.30498355263157, -19.539769736842103, -21.666809210526317], [0.0, 1.0564638157894883, -0.4688980263157845, -6.894917763157846, -5.875657894736801, -7.5729276315788745, -8.561398026315704, -9.306118421052556, -11.463947368420985, -16.26325657894733, 3.3881250000000307, 14.004078947368448, 21.54750000000002, 21.203684210526337, 12.897582236842139, 11.16695723684212, 3.9506743421052697, 4.522203947368446, 1.2610855263157994, -9.735888157894696, -12.708996710526261, -10.008503289473612, -15.951513157894663, -17.876496710526208, -15.526874999999936, -11.877039473684189, -8.379868421052574, -1.390657894736819, -5.542746710526298, 7.112368421052643, 10.054687500000014, 11.451118421052664, 11.882812500000025, 6.668486842105313, 4.254078947368452, -0.30981907894732075, -0.971151315789406, 1.0500493421053179, 2.7774671052631845, 2.474062500000045, 4.632532894736869, -0.8916118421052452, 5.4510197368421345, 12.340164473684233, 6.275279605263183, 6.622944078947388, 9.086743421052656, 8.98282894736845, 8.057220394736845, 4.2861513157895175, 7.606282894736879, 7.50557565789477, 5.976365131578984, 7.8647861842105655, 7.983453947368446, 6.90133223684213, 8.05593750000003, 6.115559210526332, 5.042417763157921, 3.767220394736885, 6.20664473684214, 11.433799342105289, 16.451200657894766, 15.519177631578962, 14.270279605263184, 13.60766447368424, 15.238223684210556, 14.576250000000009, 14.062450657894749, 14.828338815789492, 14.784720394736862, 15.004736842105281, 13.793684210526344, 12.141315789473706, 13.542878289473707, 13.086809210526336, 11.546694078947384, 12.233042763157924, 14.512746710526336, 16.142664473684235, 18.628273026315814, 18.491644736842137], [0.0, -0.16613486842106084, -1.7177960526315843, -4.829457236842124, -3.593388157894772, -7.225904605263203, -6.728141447368451, -6.913519736842137, -8.807713815789523, -8.58962171052632, 10.484457236842104, 17.800805921052625, 22.097861842105257, 25.190279605263154, 17.424276315789466, 9.92960526315789, -0.47659539473685797, -5.397779605263157, -7.08991776315791, -17.324210526315852, -10.456875000000036, -8.190000000000026, -13.131069078947412, -14.145197368421101, -13.334407894736877, -12.01046052631581, -7.155345394736852, -5.067434210526322, -4.823684210526338, 7.347138157894737, 7.549194078947362, 9.716644736842106, 8.372171052631575, 8.835296052631579, 6.36572368421052, 6.5145394736842, 8.632598684210535, 8.359342105263144, 3.265608552631562, 1.4028453947368256, 3.5978782894736803, 3.1495065789473635, 6.898125, 5.354161184210524, 6.102730263157893, 3.082796052631572, 6.0180592105263155, 7.1803618421052615, 8.176529605263152, 11.315773026315787, 14.142631578947363, 12.475509868421053, 13.624983552631575, 13.656414473684201, 11.042516447368413, 9.812220394736835, 9.249029605263155, 9.453651315789466, 8.274029605263165, 6.987286184210523, 6.043075657894727, 7.267598684210519, 10.960411184210514, 13.468470394736839, 15.918157894736837, 19.33899671052631, 22.632828947368417, 20.48975328947368, 19.494868421052626, 16.598733552631572, 16.214506578947365, 14.976513157894733, 15.583322368421046, 15.348552631578944, 13.462055921052627, 11.597368421052622, 11.546694078947361, 14.687861842105255, 13.690411184210518, 13.229210526315782, 14.168930921052624, 17.795674342105258], [0.0, -0.035279605263157876, 0.9493421052631605, 1.3669243421052633, 4.397763157894741, 4.771085526315791, 5.848717105263158, 6.748026315789471, 8.39398026315789, 16.518552631578952, 12.138108552631586, 14.007927631578944, 11.74490131578947, 11.895641447368408, 10.367713815789472, 14.197154605263155, 16.58847039473685, 16.188848684210523, 14.553799342105261, 19.694358552631588, 25.273026315789465, 24.205657894736834, 23.50840460526315, 26.273684210526312, 31.36036184210527, 37.574062500000004, 37.304013157894744, 38.8826151315789, 46.489539473684225, 43.19891447368419, 42.702434210526356, 41.90383223684212, 42.9609375, 36.089753289473705, 31.55407894736843, 26.05366776315792, 27.798404605263222, 30.618848684210512, 39.96345394736847, 46.22911184210528, 44.81921052631578, 45.51069078947366, 44.77302631578951, 46.37343749999998, 46.51070723684211, 48.730115131578955, 59.2363815789474, 43.91733552631578, 43.563256578947424, 29.380855263157947, 26.929884868421055, 23.507763157894722, 20.99200657894736, 27.214046052631574, 26.25957236842106, 24.854802631578934, 33.4995888157895, 31.551513157894753, 23.750871710526305, 29.85167763157896, 22.047187499999993, 20.008026315789476, 18.62634868421053, 19.828421052631583, 24.31021381578947, 11.432516447368418, 5.087960526315784, 2.5151151315789386, 3.654967105263151, 3.950674342105258, 4.638947368421047, 4.69347039473683, 3.8923026315789544, 2.91537828947368, 7.159194078947372, 3.1636184210526315, 1.9012500000000019, 3.427253289473687, -0.7819243421052633, -1.0891776315789503, -5.036003289473684, -7.333667763157895], [0.0, 0.5170065789473881, 1.075065789473701, -4.062286184210507, -4.925674342105253, -7.234243421052621, -6.877598684210508, -7.34457236842103, -8.979621710526292, -8.834654605263093, 7.808338815789508, 17.7411513157895, 20.52567434210529, 21.065773026315817, 11.165032894736868, 11.689736842105283, 6.496578947368437, 3.11807565789476, 2.1725822368421213, -1.6870065789473578, -5.920559210526296, -7.583832236842095, -5.880789473684207, -5.443963815789456, -7.154703947368407, -10.400427631578932, -6.3785526315789305, -1.8082401315789234, -5.281036184210496, 7.037319078947391, 8.118157894736871, 12.330542763157922, 14.618585526315805, 15.88865131578949, 18.91884868421054, 18.25879934210528, 18.94258223684212, 19.149769736842124, 15.535213815789499, 13.826398026315815, 9.426069078947386, 7.329819078947388, 12.367746710526342, 16.278651315789503, 12.72054276315793, 18.301134868421073, 20.95480263157898, 18.503832236842133, 18.755921052631603, 17.43453947368422, 20.115148026315808, 19.60840460526317, 19.43585526315791, 21.255000000000017, 16.141381578947396, 15.45375000000002, 10.477401315789507, 7.3926809210526585, 9.43312500000004, 10.76348684210528, 16.17217105263161, 24.164605263157924, 24.784243421052658, 23.52315789473687, 24.153059210526344, 22.29606907894739, 23.550098684210553, 22.406398026315813, 20.71105263157897, 21.088865131578967, 19.533355263157915, 18.60453947368422, 16.83542763157897, 15.726365131578964, 15.35625000000003, 15.691085526315817, 15.870690789473707, 18.4178782894737, 19.16837171052634, 18.340904605263184, 21.804078947368453, 22.304407894736872], [0.0, 1.221957236842103, 0.727401315789475, -2.6767598684210556, -1.095592105263158, 1.7966940789473576, 3.2957565789473637, 1.2142598684210508, -6.461299342105263, -12.433815789473686, -8.084802631578947, -17.90151315789474, -15.526233552631586, -11.386332236842104, -16.760378289473685, -8.039259868421054, -5.9019572368421045, -3.556825657894736, 3.009029605263157, 3.468305921052634, 11.437006578947372, 15.252976973684234, 14.104144736842105, 12.437023026315789, 3.432384868421046, -2.12575657894737, -3.0289144736842104, -7.050148026315789, -15.920723684210525, -14.22152960526316, -13.514654605263164, -6.67233552631579, 1.501628289473686, 7.319555921052629, 13.730822368421062, 19.299868421052633, 22.41152960526315, 22.361496710526325, 20.749539473684216, 20.35953947368421, 15.626299342105263, 13.706447368421053, 0.5785855263157842, -1.676101973684215, 2.363733552631576, 7.127121710526314, 11.585822368421066, 10.608256578947383, 10.576825657894744, 12.107960526315804, 11.046365131578952, 11.8308552631579, 12.594177631578951, 10.731414473684222, 9.8930427631579, 8.547286184210527, 0.6908388157894692, 2.022483552631579, -6.655016447368421, -3.4003125000000027, -4.291282894736841, -1.0853289473684233, 1.1655098684210508, 1.2707072368421013, 1.1430592105263155, -1.6151644736842128, -2.4894572368421066, -6.667203947368422, -8.496611842105267, -11.429309210526313, -13.48065789473684, -15.498651315789473, -16.47814144736842, -20.89129934210527, -23.206282894736844, -25.297401315789454, -25.512927631578947, -22.088881578947362, -23.07606907894737, -19.34797697368422, -20.52310855263158, -18.93167763157895], [0.0, -0.38615131578944073, -0.1051973684210239, -2.887796052631572, -3.372730263157905, -6.769835526315738, -7.023848684210478, -6.645394736842043, -0.8967434210526193, 10.367713815789429, 20.78674342105261, 22.079259868421, 30.333404605263112, 32.40848684210522, 25.55398026315786, 26.961315789473645, 18.43455592105258, 12.858453947368368, 8.631957236842052, 0.12764802631579641, 4.4837171052631675, 6.127105263157894, 4.269473684210524, 2.585674342105257, 2.92435855263156, 6.81666118421051, 8.266973684210505, 9.998240131578896, 7.460032894736813, 8.151513157894684, 10.454309210526272, 10.258667763157867, 15.43707236842101, 22.848355263157856, 23.153042763157835, 28.84524671052629, 32.33536184210523, 38.72866776315786, 38.026924342105225, 34.38478618421048, 31.038996710526284, 32.462368421052595, 27.88628289473681, 27.53541118421049, 30.62975328947364, 34.288569078947326, 24.456463815789427, 24.314703947368375, 20.210082236842073, 30.951118421052584, 32.33536184210522, 32.685592105263105, 32.8684046052631, 29.602154605263124, 30.992171052631537, 33.2641776315789, 32.282121710526276, 32.84531249999996, 33.43993421052628, 33.010805921052594, 40.12958881578943, 43.32720394736839, 43.02251644736838, 35.5644078947368, 22.777154605263107, 28.666282894736803, 29.080657894736802, 32.870970394736794, 32.98963815789469, 30.22243421052628, 29.53287828947365, 27.01327302631576, 26.97029605263154, 27.946578947368387, 25.84391447368417, 26.727828947368387, 28.06973684210523, 29.650904605263122, 32.26672697368417, 34.414934210526276, 36.21740131578944, 35.83381578947365], [0.0, 0.19050986842105355, -0.2771052631578933, 0.1982072368421064, 1.7646217105263264, 1.5074013157894808, 3.4920394736842226, 3.638930921052646, 0.9018750000000055, -1.9057401315789444, -2.683815789473681, 6.089901315789479, 4.7800657894736895, 0.7953947368421086, 0.7806414473684247, 2.752450657894742, -1.3624342105263132, -1.107779605263156, 1.310476973684213, 0.9865460526315835, 5.0026480263158, 5.65500000000001, 6.107220394736854, 7.17651315789474, 6.196381578947372, 4.975707236842113, 6.928273026315787, 5.850641447368429, 9.900740131578953, 9.648009868421056, 10.96490131578947, 9.71215460526316, 7.9058388157894735, 8.75383223684211, 8.825674342105271, 10.060460526315792, 9.545378289473682, 6.604342105263155, 5.830756578947374, 6.9988322368421025, 10.8866447368421, 11.151562500000002, 14.447319078947368, 14.272845394736843, 12.092565789473687, 6.678108552631578, 7.558815789473688, 6.318898026315787, 6.220756578947369, 8.371529605263149, 9.937302631578937, 10.819934210526313, 12.179802631578948, 14.599983552631585, 13.320937499999994, 11.835345394736827, 12.79238486842105, 12.900789473684211, 13.049605263157895, 9.961036184210535, 9.955263157894741, 7.773700657894737, 5.8455098684210505, 1.7588486842105298, 1.5157401315789507, 3.934638157894738, 7.26439144736842, 9.040559210526313, 9.58129934210526, 11.184917763157898, 13.986759868421043, 14.236282894736831, 13.89759868421053, 14.725065789473685, 13.297203947368427, 12.872565789473688, 10.987993421052629, 10.275986842105253, 9.31702302631579, 6.681315789473687, 6.345838815789482, 5.921842105263163], [0.0, 0.3341940789473643, 3.0981907894736826, -0.31879934210526706, -0.9185526315789474, -2.0481414473684136, -0.8287499999999994, -4.155937499999988, -11.898207236842078, -15.586529605263122, -4.606874999999992, -3.7948026315789267, 0.21488486842106802, 2.849309210526334, -1.0423519736841946, 2.7947861842105457, 0.3527960526315894, 1.4086184210526405, 4.623552631578962, 4.348371710526322, 1.3059868421052627, -0.4451644736842013, -0.0673519736842021, 0.6568421052631628, -1.8467269736842002, -3.2681743421052527, 1.5285690789473865, -1.5856578947368192, -3.092417763157874, 1.0352960526315904, 5.224588815789491, 6.672976973684227, 11.168881578947385, 12.954671052631596, 12.411365131578965, 12.805213815789491, 13.923898026315804, 15.998980263157915, 17.115740131578963, 9.914851973684227, 4.768519736842123, 5.222664473684229, 8.451710526315807, 7.828223684210544, 7.231036184210542, 9.320871710526333, 12.416496710526332, 10.957845394736859, 13.721200657894752, 18.062516447368452, 17.899588815789492, 16.78026315789476, 14.499917763157912, 8.832730263157913, 8.52611842105265, 6.52159539473686, 4.230345394736858, 1.1571710526315968, 4.158503289473699, 4.755049342105282, 5.821134868421071, 8.04567434210528, 7.102105263157911, 3.873700657894756, 2.6106907894736997, 6.304786184210543, 5.038569078947388, 6.183552631578966, 5.780082236842124, 3.5593914473684496, 2.134095394736871, 1.7543585526315937, 1.0596710526316002, 0.9871875000000188, -3.103963815789456, -2.3553947368420918, -0.9204769736841865, -0.23476973684208247, -1.0930263157894604, 0.6048848684210775, -0.8281085526315692, -1.8711019736841887], [0.0, -1.437483552631571, -1.1052138157894777, 5.057812500000031, 5.374046052631604, 9.386940789473757, 10.583881578947429, 11.794292763157946, 8.13483552631583, 10.024539473684241, 2.6498190789473792, -4.645361842105255, -2.403503289473683, -1.6542927631578888, -0.639523026315798, 9.127796052631597, 12.302960526315827, 17.34088815789481, 18.74052631578956, 27.251891447368465, 27.77723684210533, 27.099868421052726, 40.35409539473693, 40.57282894736851, 44.32850328947376, 41.73513157894742, 39.47723684210528, 36.205855263157986, 36.091036184210544, 32.42773026315788, 32.81837171052634, 37.325180921052635, 45.43628289473687, 44.53184210526317, 44.859621710526405, 40.212976973684285, 34.21929276315795, 43.257286184210585, 59.5109210526317, 63.947812500000026, 48.67944078947373, 51.954029605263216, 60.06256578947371, 54.610904605263215, 62.12289473684214, 62.532779605263215, 61.167138157894726, 58.86626644736843, 55.315855263157985, 46.69416118421058, 42.97184210526323, 40.48495065789476, 36.52850328947373, 37.52659539473691, 31.89853618421059, 34.05893092105262, 37.05384868421055, 35.452796052631605, 36.73889802631583, 37.22319078947368, 29.758026315789493, 31.951134868421057, 28.936973684210535, 27.21276315789474, 20.37172697368422, 9.860970394736844, 8.202187500000024, -0.8479934210526423, -0.35279605263158587, -4.654342105263155, -4.937861842105257, -6.407417763157889, -7.5350822368420936, -10.323453947368414, -6.509407894736834, -7.095690789473677, -9.4363322368421, -8.328552631578944, -11.689095394736835, -10.720509868421047, -16.37679276315789, -15.787944078947366], [0.0, 0.7735855263157667, 0.6260526315789328, 2.8916447368420783, 7.855164473684209, 11.71282894736839, 11.251628289473668, 9.461990131578926, -0.9961677631579136, 4.1642763157895, 2.533717105263168, -5.8897697368420765, -9.594128289473655, -14.277335526315776, -8.408092105263137, 2.3528289473684225, 9.727549342105274, 11.818667763157887, 15.965625000000028, 26.55976973684204, 37.704917763157866, 44.23613486842099, 40.24312499999991, 35.34567434210524, 32.64389802631577, 35.115394736842106, 37.133388157894714, 28.106299342105284, 32.96269736842103, 22.251809210526343, 18.007993421052635, 16.129835526315798, 22.336480263157885, 30.82924342105257, 37.534292763157936, 42.33360197368417, 44.31824013157893, 45.207286184210574, 46.555608552631554, 47.67365131578947, 45.034095394736866, 39.71970394736836, 30.39947368421051, 40.01541118421055, 41.02569078947367, 37.88388157894744, 40.160378289473755, 29.93378289473686, 30.75804276315787, 30.167269736842076, 25.843914473684155, 27.976085526315753, 27.17876644736838, 21.619983552631535, 28.618174342105274, 23.7444572368421, 21.584062500000027, 23.003585526315863, 20.671282894736894, 17.04838815789473, 19.546184210526345, 13.8905427631579, 11.485115131578969, 1.9564144736842266, -3.9025657894736625, -6.4824671052631615, -7.6191118421052515, -7.430526315789461, -4.045608552631574, -7.19190789473684, -8.374095394736834, -10.70383223684209, -10.551167763157892, -10.17207236842103, -17.483289473684195, -16.42361842105261, -16.393470394736823, -17.979769736842087, -15.000246710526298, -16.585263157894722, -20.786101973684193, -23.29480263157893], [0.0, 2.267516447368415, 3.19761513157896, -1.5375493421052546, 0.18409539473683978, 2.050065789473681, 1.491365131578931, 1.577960526315799, -4.913486842105268, -14.48131578947368, -3.944259868421099, 16.112516447368378, 17.62504934210522, 15.038733552631534, 11.373503289473648, 5.8467927631578505, 3.9577302631578632, 2.95129934210523, 6.171365131578934, 1.9564144736842017, 1.5606414473684111, 7.5344407894736865, 4.837796052631578, -0.18345394736842735, -3.6113486842105544, -6.068733552631599, -2.8845888157895097, 0.25914473684205674, 2.2623848684210053, 12.192631578947324, 11.435082236842062, 9.717927631578887, 4.721052631578914, 5.141200657894711, 14.773174342105214, 17.87649671052627, 18.897039473684163, 12.847549342105216, -0.0667105263158092, 0.9050822368420768, 20.69950657894732, 17.33383223684206, 18.026595394736802, 18.944506578947326, 11.438930921052584, 7.8590131578946885, 9.234917763157844, 5.981496710526269, 8.299046052631535, 3.397105263157883, 5.953914473684176, 10.016842105263107, 17.351151315789426, 24.6078453947368, 24.356398026315745, 19.20429276315785, 18.228009868421005, 21.097845394736797, 19.669983552631535, 20.45447368421048, 17.431973684210483, 11.986726973684164, 9.245180921052585, 6.001381578947324, 8.925740131578896, 14.222812499999957, 17.47944078947364, 21.036266447368376, 23.097236842105218, 27.086398026315745, 27.44368421052627, 29.53095394736838, 30.84912828947364, 33.47393092105259, 33.03646381578943, 30.20832236842101, 31.372549342105224, 33.432878289473635, 29.260904605263114, 27.92990131578943, 27.026101973684167, 26.019029605263114], [0.0, -1.093667763157896, 1.9583388157894674, 0.3656250000000085, -1.0436348684210728, -0.73125000000001, -4.197631578947373, -8.134835526315761, -4.541447368421046, 0.03463815789470459, 21.055509868420987, 48.3163815789473, 52.40817434210519, 44.9372368421052, 34.74976973684204, 35.67217105263151, 38.459259868420986, 30.602812499999935, 22.94585526315782, 19.11256578947361, 18.040065789473598, 14.906595394736762, 9.986052631578872, 5.288733552631548, 5.112976973684177, 8.25286184210519, 11.997631578947292, 19.447401315789396, 30.786907894736782, 34.26162828947361, 37.57534539473678, 39.5048190789473, 35.29884868421046, 37.684391447368355, 40.27968749999994, 43.58891447368415, 42.617121710526256, 37.14814144736836, 41.78901315789467, 40.42080592105257, 40.000657894736776, 41.77746710526309, 42.911546052631515, 38.37587171052625, 39.22001644736836, 44.75699013157888, 45.64026315789467, 42.8166118421052, 42.4753618421052, 40.266217105263095, 44.703749999999935, 48.71023026315782, 50.83213815789465, 50.26445723684203, 55.26518092105253, 52.970082236842025, 55.19590460526308, 55.36203947368415, 53.67439144736835, 57.25687499999993, 54.8399013157894, 59.904128289473626, 66.25766447368412, 62.7406085526315, 62.197944078947295, 59.868848684210434, 60.38713815789466, 63.987582236842, 64.99722039473676, 65.79453947368413, 65.23391447368411, 64.59054276315781, 64.09791118421045, 62.816299342105154, 61.74957236842097, 64.3217763157894, 65.47189144736835, 64.20631578947359, 69.78947368421045, 68.96200657894731, 74.65741776315784, 75.61253289473677], [0.0, 0.08851973684210468, 0.7857730263157914, 0.4047532894736856, 0.8980263157894746, 1.7158717105263193, 3.2572697368421206, 2.9192269736842205, 1.2469736842105246, -8.147664473684202, -15.516611842105256, -2.1482072368421044, 5.602401315789474, 3.440723684210531, -5.427927631578947, -9.134210526315789, -7.7018585526315775, -7.444638157894728, -8.587697368421034, -4.516430921052629, -7.5992269736841935, -4.775575657894739, -5.694128289473669, -4.496546052631579, -4.982763157894734, -10.11690789473683, -13.064999999999992, -12.384424342105252, -12.537088815789463, -12.42804276315789, -9.72370065789473, -12.849473684210519, -19.25111842105263, -20.49745065789474, -14.694276315789462, -13.712220394736837, -9.814786184210528, -9.791052631578946, -14.188815789473677, -12.876414473684209, -18.67830592105263, -16.02527960526315, -14.160592105263149, -21.009325657894717, -16.055427631578926, -15.414621710526303, -16.25363486842105, -25.57578947368421, -26.269835526315788, -18.77067434210526, -1.0981578947368402, -0.7998848684210502, -0.3335526315789432, -4.105263157894737, -18.913075657894733, -8.740361842105257, -18.23314144736843, -14.46592105263158, -12.113733552631585, -7.9642105263157905, -5.190592105263159, 0.45799342105263396, -1.0744243421052608, -3.74861842105263, -7.437582236842103, -9.589638157894733, -7.386266447368415, -3.3483552631578934, 5.359934210526316, 7.134819078947359, 4.8673026315789505, -0.38615131578947204, 1.8903453947368456, 0.8922532894736868, 1.5471710526315785, -2.656874999999999, 0.17126644736842445, 1.4169572368421062, 3.255345394736847, 7.256694078947374, 9.936661184210532, 7.400378289473688], [0.0, 3.593388157894651, 2.5657894736841627, 2.887796052631529, 1.1193256578946347, 5.800608552631523, 10.353601973684157, 15.202302631578839, 19.68409539473671, 12.061134868421, 11.680115131578894, -6.404210526315829, -23.620657894736873, -25.722039473684248, -27.868963815789527, -17.89317434210531, -5.478601973684242, 0.47723684210519934, 11.20608552631574, 9.631332236842034, 7.182286184210476, 9.172697368420991, 12.34208881578936, 18.34796052631564, 27.65921052631564, 35.83060855263147, 41.47791118421032, 41.61004934210511, 26.136414473684177, 27.112055921052566, 23.763059210526272, 18.57246710526308, 18.521151315789417, 19.941315789473684, 20.03496710526317, 18.9669572368421, 14.256809210526363, 9.860970394736889, 5.213684210526289, 6.41832236842108, 8.837220394736796, 23.95292763157895, 32.63812499999998, 25.17103618421047, 40.13536184210525, 30.74842105263162, 20.27679276315785, 33.597730263157835, 38.77870065789478, 39.89738486842115, 42.134753289473785, 36.67411184210544, 34.28600328947386, 34.1038322368422, 21.35570723684217, 17.055444078947367, 12.964292763157879, 7.734572368421006, 2.9031907894736477, 11.597368421052558, 8.065559210526281, -6.490164473684246, -2.47662828947373, -6.039868421052667, -8.989243421052677, 0.2091118421051945, 0.052598684210508395, -1.252746710526381, -6.503634868421159, -9.204769736842202, -8.01296052631588, -13.294638157894795, -15.354967105263256, -15.292746710526416, -12.152220394736936, -25.25250000000006, -28.31797697368428, -24.025411184210576, -26.927319078947434, -35.42136513157901, -37.962138157894785, -40.34126644736848], [0.0, -0.5452302631578885, -0.8216940789473615, -1.9641118421052504, 0.21873355263157812, 2.7575822368421097, 0.49391447368421026, 2.4824013157894793, 1.8672532894736893, 6.536348684210527, 6.175855263157892, 14.506332236842102, 27.834325657894738, 21.843848684210535, 18.590427631578947, 16.09583881578947, 13.351085526315792, 13.487713815789473, 9.875082236842106, 5.461282894736842, 3.5664473684210556, 14.567911184210528, 10.331151315789473, 4.855756578947376, 11.034177631578947, 21.19662828947368, 27.497565789473665, 27.580312499999987, 39.52342105263157, 33.82865131578947, 38.34444078947371, 36.925559210526316, 34.22250000000001, 30.834375000000012, 27.625855263157902, 24.09917763157896, 26.842648026315825, 30.643223684210525, 27.66947368421054, 28.817023026315788, 31.12944078947369, 35.1609375, 34.79723684210526, 48.0251644736842, 41.05712171052629, 32.177565789473704, 27.77210526315792, 31.287236842105273, 29.779835526315818, 36.04549342105267, 37.14044407894741, 36.06217105263162, 38.20139802631581, 36.2719243421053, 34.47587171052635, 33.665723684210555, 36.287960526315814, 41.00837171052629, 32.97616776315789, 42.385559210526324, 27.80802631578947, 24.363453947368434, 18.660986842105267, 13.431266447368422, 9.589638157894736, 15.44669407894736, 24.314703947368443, 26.759259868421072, 29.190345394736866, 30.352006578947385, 34.278947368421086, 34.035197368421095, 34.593256578947376, 36.69271381578949, 40.15460526315791, 32.0069407894737, 28.209572368421057, 30.10248355263156, 29.722105263157882, 24.616184210526328, 18.789276315789472, 17.150378289473686], ...]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>950962270</th>\n",
       "      <td>1.198207</td>\n",
       "      <td>-0.066247</td>\n",
       "      <td>901.39</td>\n",
       "      <td>0.315913</td>\n",
       "      <td>149</td>\n",
       "      <td>0.320897</td>\n",
       "      <td>NaN</td>\n",
       "      <td>83.914876</td>\n",
       "      <td>NaN</td>\n",
       "      <td>noise</td>\n",
       "      <td>0.034338</td>\n",
       "      <td>110.0</td>\n",
       "      <td>0.382293</td>\n",
       "      <td>109.690620</td>\n",
       "      <td>850180684</td>\n",
       "      <td>1.985781</td>\n",
       "      <td>148</td>\n",
       "      <td>0.039330</td>\n",
       "      <td>0.82</td>\n",
       "      <td>0.343384</td>\n",
       "      <td>0.759075</td>\n",
       "      <td>NaN</td>\n",
       "      <td>87.22</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>0.370854</td>\n",
       "      <td>NaN</td>\n",
       "      <td>[19.395708318799855, 102.00173658791952, 190.18593118173294, 1015.8633472297348, 1015.8677805627963, 1015.8824805618951, 1015.8995805608467, 1015.9132805600069, 1015.9139472266327, 1015.9183805596942, 1015.9335472254311, 1015.9638805569049, 1015.9647805568496, 1015.9743472229299, 1015.9867805555009, 1015.9901472219613, 1015.9926472218079, 1016.0013805546059, 1016.0223805533185, 1016.0471472184668, 1016.0590472177372, 1016.0783138832228, 1016.1003138818741, 1016.1784138770861, 1024.7077466875235, 1024.7284466862543, 1024.7412133521384, 1024.7501133515927, 1024.7610800175871, 1024.7744800167657, 1024.7846800161403, 1024.796146682104, 1024.8014800151104, 1024.8042800149387, 1024.8122133477857, 1024.8167800141723, 1024.8273800135225, 1024.8406466793758, 1024.8435133458668, 1024.8614800114321, 1024.870680010868, 1024.8725800107516, 1024.8816133435312, 1024.8935800094641, 1024.8943133427524, 1024.9034133421947, 1024.9052466754156, 1024.919780007858, 1024.9318133404536, 1024.9330466737113, 1024.937046673466, 1024.9446800063315, 1024.956713338927, 1024.9746133378296, 1025.0084133357575, 1025.031446667679, 1025.0406133337835, 1048.6209785548413, 1048.6358452205966, 1048.646345219953, 1048.6490785531187, 1048.6648118854876, 1048.6786118846414, 1048.698778550072, 1048.737678547687, 1048.7436118806565, 1048.7715785456087, 1052.4409449873226, 1052.4667116524097, 1052.6131116434344, 1061.1850777845914, 1061.20364445012, 1061.2667111129201, 1061.3139777766892, 1061.3479111079423, 1061.3991111048033, 1061.5206110973547, 1061.5279777635699, 1062.872077681169, 1063.6074109694223, 1063.705944296715, 1063.7706776260798, 1063.9225776167673, 1063.926444283197, 1063.9320776161849, 1067.2808774108846, 1070.400643886292, 1071.9444437916486, 1072.1709104444315, 1072.2509104395272, 1072.3172771021252, 1072.422043762369, 1072.4324770950627, 1072.4876770916787, 1072.5233104228275, 1072.5738104197314, 1072.6123770840338, 1072.6303770829304, 1072.6781104133374, 1072.7815104069984, ...]</td>\n",
       "      <td>[0.00019237517752654387, 0.0001818922267256817, 0.00018042713824013861, 0.00015337732797639242, 9.879534120428042e-05, 0.00012012502433757851, 0.0001147456067850323, 0.00012473110015433282, 0.00014322538860651985, 0.00010106488631362562, 0.0001307502923359978, 0.00013707348412279739, 0.00012502868872484995, 0.0001192855440373873, 0.00016878676644776426, 0.00013881762746059976, 0.00010239299624498396, 0.00012300971016120923, 0.0001073520597423015, 0.00010844556466141513, 0.00010779578881829308, 0.00020384120026112682, 0.00015427184215193035, 0.00010031936458259807, 0.000143723226814683, 0.0001828078778880797, 0.00011809553167716513, 0.00013874854370575195, 0.00018991800280406025, 0.00013547593200563047, 0.00010146414223674947, 0.0001682957511346243, 0.00012105732087712881, 0.00017812794695253194, 0.00013024232857861454, 0.0001738038789494365, 0.00018146721787077317, 0.00011746389323379728, 0.00011202219927952437, 0.00010495345467789303, 0.00010966634221685018, 0.00017250760660453613, 0.00015039028318551136, 0.00010752525869933729, 0.00010895300776507794, 0.00017207583702221282, 0.00012595349406758658, 9.698886706809397e-05, 0.00020913439911175667, 0.00016633877698942352, 9.926361871464367e-05, 0.0001746625845825291, 0.00011020966380151776, 0.0001496676002796242, 0.00015751694468532952, 0.00013883107120591886, 0.00012460905736806906, 0.00011658112096529819, 0.0001514509247526282, 0.00013148059077391547, 0.00010464539863630955, 0.0001327186276116359, 0.00019435849519580924, 0.00014757722998867337, 0.00015366555255089248, 0.00011828872529125642, 0.00010207012877069633, 0.000116145901080708, 9.860283920483272e-05, 9.760425645281314e-05, 0.00012018960871176751, 0.00010220053310029151, 9.819793380029442e-05, 0.00010491272712343213, 0.00012058260901929491, 0.00010688553846687588, 0.0001238325373132971, 0.0001037192800028452, 9.853733008746858e-05, 0.0001146625974859002, 0.00012176447742281512, 0.00011046933013090355, 0.00011649735788391409, 0.00011933309448687142, 9.610313406724426e-05, 9.921538442146704e-05, 0.0001381822745026293, 9.770167309519471e-05, 0.00010971942558348296, 0.00011609005125550088, 0.00010548421063471034, 9.740822644158806e-05, 0.00010040079637866672, 0.00011481685086427242, 9.621020223083179e-05, 0.00010827657755984925, 0.00010089600023442342, 0.00010756273799625867, 0.00010888474773104158, 0.00015234601397854394, ...]</td>\n",
       "      <td>[[0.0, -2.690804999999976, -2.049059999999919, -2.0870849999999734, 0.19480500000005918, -4.288634999999928, -2.657459999999979, -2.8953599999999966, -4.858229999999949, -5.894459999999988, -8.771685000000005, -11.080679999999965, -13.957905000000054, -17.185545000000083, -21.080085000000018, -21.970844999999976, -26.757705000000016, -25.95566999999999, -28.73851500000002, -29.565705000000037, -29.84046000000012, -25.22812500000002, -26.494065000000006, -17.893004999999988, -14.883570000000084, -7.672664999999995, -3.071444999999933, 5.866769999999995, 5.481060000000024, 8.69095500000002, 4.803239999999999, 4.308330000000012, 7.064654999999998, 1.455284999999968, 3.6619049999999937, 0.7860450000000583, 2.791034999999976, -0.08521499999987014, 1.5884700000000223, 3.281655000000004, 1.4862899999999932, 2.3596950000000163, 5.328960000000013, 2.159235000000031, -0.6117149999999896, 0.35607000000001676, -0.18563999999999936, -2.5344149999999956, -3.622125000000011, -2.608319999999992, -3.185520000000025, -2.18809499999999, -12.239954999999973, -8.43628499999997, -11.262225000000022, -10.33460999999999, -12.756119999999981, -13.104974999999975, -12.317955000000033, -12.542010000000026, -11.427779999999984, -8.458905000000037, -7.899255000000004, -10.995465000000031, -8.70830999999994, -4.468229999999991, -5.824259999999967, -0.4804799999999858, 0.6649499999999833, 0.12011999999997869, -2.034825000000019, -3.4741200000000774, -6.2869949999999974, -0.3211649999999793, -2.4421799999999934, -0.6308249999999234, -1.9252349999999439, 0.38590500000002237, -0.3535349999999724, -0.0415349999999961, 1.007370000000062, 1.0290150000000757], [0.0, 0.2936699999999992, -0.8219249999999999, -0.21976500000000154, 0.31921500000000336, -0.6511050000000005, -0.8788650000000006, -0.31590000000000185, -0.7170149999999997, -1.261064999999999, -2.4999, -5.358405000000003, -7.14246000000001, -8.642400000000013, -10.669230000000022, -12.975105000000008, -16.413345, -18.77850000000002, -20.69262000000002, -21.32344499999999, -21.335340000000013, -21.678735, -21.188700000000022, -18.512715000000032, -13.959269999999995, -10.335000000000015, -3.761940000000001, 1.2476099999999972, 3.7740299999999953, 5.943990000000004, 8.399625000000002, 9.00003000000001, 7.847384999999992, 8.666774999999994, 6.962475000000001, 6.161804999999997, 5.826209999999997, 5.415150000000002, 5.784089999999999, 5.107440000000006, 4.4571149999999955, 4.894110000000001, 4.0337699999999845, 2.970630000000008, 3.1788899999999956, 2.8565549999999993, 2.143439999999997, 2.040869999999994, 2.136225000000006, 1.206074999999998, -0.7324200000000012, -1.5032550000000005, -1.9784700000000006, -2.8540200000000002, -2.6993850000000013, -3.442725000000003, -3.784365, -4.645680000000002, -5.767515000000003, -5.978699999999997, -6.125535000000004, -7.257315000000003, -6.7684500000000005, -5.4364050000000015, -4.868565, -4.430205000000001, -2.396355, -2.954250000000002, -0.46702500000000025, -0.08930999999999978, -0.4717050000000005, -0.91845, 0.45590999999999626, 0.3408600000000006, -0.09710999999999825, -0.5582850000000015, -0.14742000000000166, 0.8035949999999978, 0.5005650000000039, 0.6175649999999955, 1.7052750000000003, 0.8051549999999987], [0.0, -1.0886849999999946, -1.4412450000000483, -2.4961949999999895, -0.10530000000001394, -0.991575000000001, -1.8809700000000014, -2.5246649999999917, -0.9519900000000128, -2.7157649999999975, -1.758120000000023, -4.668690000000002, -6.365775000000003, -9.871289999999993, -10.600589999999993, -15.868904999999987, -19.771244999999997, -25.613249999999997, -28.184324999999994, -32.039280000000005, -33.58329000000001, -34.468005000000005, -32.265284999999984, -32.190599999999975, -24.893505, -18.39006, -10.497240000000014, -5.522789999999983, 2.5065299999999766, 4.347719999999963, 8.822969999999941, 10.111920000000005, 10.315499999999936, 13.455584999999978, 13.275209999999959, 11.783264999999972, 11.22829500000001, 9.524970000000039, 8.171279999999989, 5.966025000000013, 6.0810749999999985, -0.029055000000024478, 0.6401850000000202, 0.1495649999999742, 3.389879999999984, 2.0215649999999954, 2.306070000000016, 1.4738100000000074, 1.5830100000000193, 0.6245850000000068, -0.43036499999999833, -1.6372199999999921, 1.7807400000000015, -2.32303499999999, -3.4741199999999886, -3.428880000000003, -8.686079999999995, -5.4130049999999805, -9.372480000000007, -7.472594999999993, -10.632179999999986, -9.90385499999999, -8.980725000000001, -6.781124999999999, -8.793720000000004, -8.242454999999985, -5.875934999999988, -8.064030000000006, -6.003659999999982, -5.155604999999991, -0.5307900000000032, -1.6311749999999883, 0.48242999999999014, -0.0719549999999991, 0.3359850000000044, -1.8417749999999984, 0.29698499999997097, -1.1054549999999779, -2.1787349999999854, -2.7050400000000003, -0.6563700000000168, -4.04703000000001], [0.0, 0.21937500000000654, 0.4163250000000076, 0.08209500000000602, -0.16848000000000063, 0.5974800000000018, -0.7281299999999886, -0.6200999999999972, -0.21918000000000237, -0.355680000000004, -1.2700349999999982, -2.153775000000004, -2.5077000000000007, -2.5078950000000058, -3.058185000000006, -3.215745000000009, -5.366594999999999, -6.0202350000000004, -6.292260000000004, -7.013955000000002, -7.074600000000003, -7.057635000000003, -6.6487200000000035, -5.3938950000000006, -4.108260000000001, -2.355600000000009, -0.5438550000000006, 0.8632650000000011, 1.9538999999999875, 1.2168000000000072, 2.0084999999999953, 1.812525, 1.822079999999997, 1.9895850000000062, 1.6190850000000063, 1.7834700000000074, 2.4181949999999963, 2.070705000000001, 2.7966899999999937, 2.0931300000000066, 2.1405150000000015, 1.6227899999999904, 1.5120299999999895, 1.897154999999997, 2.704845000000014, 2.2450349999999952, 1.7306250000000025, 1.5681900000000022, 1.4728350000000026, 1.4002950000000096, 0.9363899999999967, 0.47209500000001103, 1.3946400000000052, 0.7072650000000014, 1.194375000000007, 0.28567500000000123, -0.45766500000000665, -0.022619999999998086, -0.5487300000000079, -0.7776600000000009, -0.02827500000000782, -0.6000150000000009, -0.1786200000000031, -0.24959999999999827, -0.8691149999999981, -0.3593850000000014, -0.40306500000000334, -0.39448500000000397, -0.42509999999999426, 0.037829999999990704, 0.5887050000000027, -0.2675399999999941, 0.02437499999999382, 0.6785999999999941, 0.4748250000000045, 0.11212499999998915, -0.21625499999999764, 0.1860299999999988, 1.2522899999999906, 1.4010750000000014, 0.8942700000000015, 0.4373849999999999], [0.0, 0.2911349999999988, -0.11719500000000149, -0.204749999999998, -0.19285499999999267, 0.12460500000000785, -0.43640999999999774, 0.6011850000000027, 0.7480199999999959, 0.4093049999999989, -0.09087000000000334, 0.29406000000000354, 0.6786000000000012, 0.2925000000000022, 0.8488349999999958, 1.2405899999999983, 1.570725, 3.515460000000002, 3.326505000000002, 4.325879999999998, 4.9567049999999995, 4.0509299999999975, 3.6948600000000025, 2.6315249999999977, 2.389334999999996, 2.4427650000000036, 2.9312400000000003, 3.7570649999999963, 3.8179049999999988, 3.942899999999997, 4.226819999999998, 4.03026, 3.84657, 3.18045, 3.1646549999999993, 2.8604549999999977, 2.2709699999999993, 1.5664349999999958, 1.5527850000000019, 1.0438350000000014, 1.3661699999999994, 0.903044999999997, -0.0077999999999969205, -0.0779999999999994, 0.14975999999999967, 0.5631600000000034, -0.08190000000000275, 0.03685499999999209, 0.4828200000000056, 0.7369050000000108, 0.6025500000000026, 1.1879400000000029, 1.4174550000000048, 0.8238750000000037, 0.7936500000000066, 0.8817899999999996, 0.9227400000000019, 1.2107549999999998, 1.5514199999999976, 1.2598950000000038, 0.59436, 0.8823749999999997, 1.046175000000007, 1.323464999999998, 1.4006849999999984, 0.8464949999999956, 0.7821449999999981, 1.1504999999999974, 0.7302750000000024, 0.7739549999999955, 0.26266500000000637, 0.8888099999999968, 0.9365850000000027, 0.014040000000001385, 0.08540999999999688, -0.023595000000003807, -0.7411949999999958, -0.16847999999999708, 0.09808499999999665, -0.32760000000000655, 0.7019999999999946, 0.5448299999999957], [0.0, -0.19324499999999878, -0.6277049999999993, -0.5887049999999983, -0.47404499999999716, -1.155374999999995, -1.2074399999999983, -0.8895899999999992, -0.9410699999999985, -1.3464749999999968, -1.2226499999999993, -1.685190000000004, -2.5962300000000065, -3.8056199999999984, -4.187040000000003, -5.030219999999999, -5.834984999999996, -6.0719100000000115, -6.844500000000005, -7.057245000000007, -7.1496750000000056, -7.491314999999998, -6.392100000000003, -5.078970000000005, -3.986189999999996, -2.1007350000000002, -0.2119649999999993, 1.2632099999999995, 2.069925000000001, 2.4560250000000003, 3.094260000000001, 3.1067400000000007, 3.035370000000002, 2.791425, 2.819115000000002, 2.5784850000000006, 2.7054299999999993, 2.6849549999999995, 2.799615000000001, 2.5927200000000026, 2.139540000000001, 1.8318300000000007, 1.565655000000001, 1.902225000000001, 1.5613650000000008, 1.096095000000001, 1.4227200000000004, 0.7665449999999996, 1.1641500000000002, 0.6961500000000003, -0.11095499999999836, -0.5126549999999965, -0.2915250000000005, -0.45103499999999785, -0.5378099999999977, -1.1446499999999973, -1.0530000000000022, -1.1040899999999976, -1.4886299999999926, -1.6926, -1.3765050000000003, -1.0736700000000012, -1.4837549999999982, -0.8326499999999974, -1.0153649999999987, -1.2497549999999986, -1.1454299999999988, -1.0849800000000003, -0.4249049999999994, 0.16399499999999967, 0.1458600000000012, -0.18076499999999696, -0.3788849999999959, -0.17179499999999992, 0.388050000000002, 0.26207999999999876, 0.3740100000000002, 0.15912000000000037, 0.15502499999999908, 0.12753000000000214, 0.9662250000000017, 0.534690000000001], [0.0, -0.0444599999999975, -1.5237299999999991, -1.3447200000000024, -1.0931700000000024, -1.653014999999999, -1.1908649999999974, -0.7326149999999987, -2.5931100000000002, -2.374124999999995, -4.036109999999998, -5.401499999999998, -8.25356999999999, -11.103495000000017, -13.78416, -17.162534999999984, -19.650929999999985, -23.212995, -25.882155, -26.452334999999984, -26.794754999999984, -26.28795000000005, -23.824319999999986, -21.23647500000003, -16.6998, -10.612289999999998, -4.874609999999994, 0.7538699999999999, 4.253535000000001, 7.628789999999999, 9.01153500000002, 9.768329999999999, 9.42591000000001, 9.618570000000002, 8.100885000000002, 8.236800000000002, 7.600905000000011, 7.8604499999999975, 6.840600000000008, 5.927804999999999, 5.743334999999999, 5.436600000000002, 4.163444999999999, 4.957095000000001, 4.038255000000004, 3.4988850000000027, 2.94255, 2.5028250000000014, 2.14149, 1.2821250000000013, 0.9527700000000014, 0.42666000000000137, -0.8221199999999969, -2.495024999999999, -3.566549999999995, -5.622240000000004, -6.699030000000003, -7.100924999999996, -7.034820000000008, -7.8885299999999985, -8.110830000000014, -7.390695000000016, -7.370999999999996, -6.867900000000003, -6.086729999999994, -4.917119999999991, -4.046835, -2.719274999999996, -2.4804000000000013, -0.9853350000000001, -0.8386949999999982, -0.736319999999997, -1.1251500000000005, -0.47892000000000134, 0.6596850000000012, -0.3026399999999987, -0.5142149999999965, -0.2919149999999979, -1.088684999999999, -1.0773750000000013, -0.10744500000000001, 0.46683000000000185], [0.0, -0.2757300000000025, -1.0719149999999993, -0.9646649999999979, -0.3833700000000029, -0.20299499999999782, -0.8410349999999962, -1.5067650000000041, -1.655160000000003, -2.079674999999999, -3.8350650000000073, -6.292065000000003, -8.358285000000006, -12.728429999999989, -14.86270500000001, -17.43144000000003, -20.31432000000008, -23.188425000000073, -25.225590000000032, -26.270985000000046, -25.897755000000053, -24.775140000000064, -24.369735000000063, -21.30492000000008, -15.873195000000019, -9.689160000000005, -3.602039999999999, 2.2175400000000005, 5.89914, 8.098350000000003, 10.330905000000008, 10.902645000000003, 12.033254999999999, 10.961144999999993, 10.448880000000004, 8.688420000000004, 8.486985000000002, 8.623875000000002, 8.279310000000002, 7.700939999999998, 6.278025000000005, 5.441085000000003, 3.4887450000000015, 3.4914750000000003, 3.556605000000002, 3.334110000000001, 3.2896500000000004, 2.60559, 1.9277699999999998, 1.0951200000000003, 0.9726599999999992, -0.3315000000000037, -2.120040000000002, -3.2529900000000014, -5.575829999999996, -6.329115000000003, -6.685185000000008, -7.234890000000011, -7.928504999999996, -7.71322500000001, -7.921485000000006, -7.900425000000013, -8.15451000000001, -7.503989999999986, -6.210554999999999, -4.787055000000001, -3.46554, -2.2961250000000017, -1.12203, -0.9122100000000031, 0.4572749999999981, -0.34651499999999835, -0.6622199999999969, -0.6836700000000033, -0.5920200000000047, 0.15638999999999603, 0.15385500000000274, 0.31375500000000134, 0.09243000000000023, 0.4174949999999984, -0.4225649999999992, -0.3806400000000014], [0.0, -0.93639000000001, -1.2538500000000106, -0.07877999999998764, -0.16964999999999364, -0.3531450000000085, -1.66120499999999, -1.1079900000000098, -0.5352750000000093, -1.4560649999999988, -3.0542849999999895, -3.6901799999999962, -6.299280000000007, -8.476455, -10.188360000000051, -12.253410000000065, -15.593565000000028, -17.66348999999998, -19.408155, -20.02435500000005, -20.143500000000017, -19.332105000000013, -16.629990000000042, -14.78724000000003, -11.072490000000004, -7.050225000000021, -1.6840200000000003, 1.261845, 4.021679999999998, 4.887480000000002, 6.220110000000007, 6.5773500000000045, 5.646225000000003, 5.802030000000003, 6.359145000000003, 5.422170000000005, 5.186025000000007, 5.288790000000001, 4.7396700000000065, 3.155684999999994, 3.455984999999999, 2.736240000000003, 1.8353400000000084, 1.646970000000012, 1.6274699999999962, 1.5026700000000002, 1.965210000000008, 1.2772500000000129, 1.0972650000000055, -0.44771999999999146, -0.6085950000000082, -1.4547000000000008, -1.2273300000000162, -2.6843700000000084, -3.4499399999999945, -4.5799649999999925, -5.233409999999996, -5.347095000000001, -6.199049999999996, -6.832410000000019, -6.76298999999999, -6.407895000000023, -5.530199999999994, -4.605120000000014, -4.817084999999993, -4.5421350000000285, -2.800589999999996, -2.8643550000000104, -1.5849599999999988, -1.1711700000000054, -1.0294049999999988, -1.0229700000000097, -1.0949249999999875, -1.1945699999999935, -1.6151850000000003, -0.9562799999999889, -1.4254500000000139, 0.38434499999999083, -0.044850000000007384, -0.7653749999999881, -1.0654799999999955, -0.8535149999999998], [0.0, -0.022814999999998697, -0.5385899999999988, -0.5654999999999982, 0.017940000000002565, -0.8515649999999986, -1.2846599999999986, -0.5844149999999981, -0.5707649999999983, -1.0859549999999982, -1.2901199999999986, -2.4439349999999975, -2.8382249999999996, -3.8438399999999957, -4.576260000000002, -5.5965000000000025, -5.973629999999997, -6.788535000000006, -6.7754699999999906, -6.826560000000008, -6.60933, -6.278220000000003, -5.8831499999999926, -5.117969999999992, -3.996329999999996, -2.6231399999999985, -1.0463699999999994, 0.946530000000005, 2.1516299999999955, 2.8686450000000008, 3.283799999999994, 3.788654999999998, 4.757219999999995, 4.168319999999999, 4.345769999999995, 3.888299999999997, 3.2929650000000024, 3.781049999999999, 3.519359999999995, 3.633044999999995, 2.5392899999999967, 1.502084999999999, 1.153230000000002, 0.6503250000000025, 0.12148500000000212, 0.6665100000000013, 0.43875000000000103, 0.7930650000000021, 0.8392800000000011, -0.06434999999999919, 0.10374000000000155, -0.3184349999999984, -0.6628049999999984, -1.265744999999999, -1.037399999999998, -1.7563649999999982, -1.8105749999999983, -1.8053099999999977, -2.195699999999997, -2.148900000000002, -2.5318799999999992, -2.3575499999999985, -2.0746050000000005, -2.271359999999998, -2.009084999999999, -2.0777250000000014, -1.2095849999999984, -0.8445449999999981, -0.635504999999999, 0.3338400000000011, 0.6458400000000004, -0.24433499999999825, -0.40442999999999846, -0.7055099999999985, -0.7721999999999978, -0.45610499999999843, -0.6787949999999991, -0.3880499999999985, 0.1540500000000014, -0.07877999999999863, 0.08599500000000088, 0.1782300000000015], [0.0, -0.46877999999999975, -1.0882950000000018, -1.054365000000005, -0.5793450000000018, -0.37673999999999364, -0.38863500000000073, -0.1499549999999985, -0.5284500000000056, -0.7872150000000016, -2.0880600000000027, -2.908424999999999, -3.4577400000000007, -4.193474999999999, -5.335395000000001, -6.23337, -7.036380000000005, -7.535969999999997, -8.344050000000001, -8.783384999999999, -9.147839999999995, -8.008650000000003, -7.303334999999999, -6.165509999999998, -4.6332, -2.6518049999999995, 0.23282999999999987, 1.6873349999999938, 2.8302299999999994, 3.198585000000004, 3.374280000000004, 3.5774699999999973, 3.6344100000000106, 3.553095000000005, 3.9115050000000062, 3.0133350000000005, 2.3542350000000063, 2.7970799999999993, 2.5874550000000065, 2.965754999999991, 2.3476050000000086, 1.7044949999999988, 1.5713100000000013, 1.289144999999995, 1.0748399999999991, 1.1323649999999947, 0.7698600000000022, 0.4508399999999959, 0.7499700000000056, 0.556919999999999, 0.019305000000000128, -0.36932999999999705, -0.49490999999999996, -0.8587800000000048, -1.2288899999999994, -0.8878350000000004, -1.4254500000000037, -1.8097949999999972, -1.6518450000000011, -1.840409999999998, -1.974960000000002, -1.9006650000000005, -1.4903849999999998, -1.4020499999999991, -1.5369900000000039, -0.950625, -1.2489749999999997, -1.1776050000000033, -0.6694349999999938, -0.45513000000000225, -0.7012200000000046, -0.7452900000000038, -0.5044649999999997, -0.8720400000000019, -1.0531949999999974, -0.8139300000000058, -0.4391399999999992, -0.012090000000001488, -0.18076500000000006, 0.025544999999998375, -0.4863299999999988, -0.5317650000000063], [0.0, 0.11680499999999672, -0.7801950000000035, -0.03763500000000608, -0.9732450000000057, -0.8568300000000058, -0.7213049999999983, -0.0029249999999994003, 0.35743499999999795, 0.3675749999999969, 0.47229000000000365, 1.6617899999999963, 2.4846899999999996, 3.944849999999998, 5.5142099999999985, 8.552700000000002, 11.53698, 15.831659999999996, 18.041789999999992, 19.536270000000005, 21.051809999999993, 20.761260000000007, 17.850105000000003, 14.956305000000018, 9.978539999999992, 6.81018, 4.437419999999996, 3.618224999999998, 2.423264999999998, 0.31199999999999717, 0.43757999999999875, 0.5249400000000022, -0.17257500000000459, -0.9209849999999982, -1.4652300000000036, -1.5108600000000045, -2.0985900000000086, -1.6976699999999951, -1.6629599999999947, -1.4642549999999988, -2.0549100000000005, -2.4218999999999937, -2.6250900000000073, -2.668184999999996, -2.0874750000000084, -2.443349999999997, -2.29729500000001, -1.6600350000000068, -0.833624999999997, -1.0044450000000058, 0.0033149999999979585, -0.35489999999999977, 0.865799999999997, 1.1495249999999988, 2.053155, 3.5626499999999965, 3.1067399999999985, 4.0177799999999975, 4.534334999999998, 4.281419999999998, 4.308524999999997, 4.752929999999997, 4.043714999999997, 3.0731999999999964, 2.9870099999999997, 2.346044999999998, 1.8803849999999969, 0.9913799999999933, 1.0584599999999993, 0.14098499999999436, 0.022034999999995364, 0.4966649999999926, -0.012675000000000658, -0.9157200000000012, -0.8160749999999988, -1.155179999999996, -0.9689550000000029, -0.7285200000000005, -0.5401499999999944, -0.3960449999999964, -0.7815599999999998, -1.4673750000000076], [0.0, -0.16321499999999967, -0.8718449999999962, -0.3623099999999928, -0.17744999999999678, -0.20435999999999765, -0.3018599999999969, -1.3174199999999967, -0.9239099999999958, -1.985099999999995, -3.0560399999999963, -4.100654999999998, -5.7244199999999985, -7.871954999999993, -9.509174999999997, -11.964419999999997, -13.11609000000001, -14.890980000000013, -16.214640000000024, -16.764735000000005, -16.50675000000002, -15.635880000000018, -14.377155000000009, -12.05295, -8.810099999999993, -4.755269999999999, -0.7632299999999972, 2.5367550000000048, 4.4820750000000125, 5.0179350000000085, 5.725005000000006, 5.9720700000000155, 5.843565000000004, 6.079904999999999, 5.518889999999998, 5.182514999999995, 5.002725000000012, 4.313985000000013, 3.703440000000005, 3.427905000000001, 3.0447300000000093, 2.860650000000004, 2.1539700000000073, 1.5366000000000009, 0.7918950000000002, 0.2189850000000022, 0.5610150000000038, 0.665730000000003, -0.10685999999999884, -0.14839499999999983, -0.8310899999999954, -0.9673949999999931, -1.886624999999996, -2.0857199999999954, -3.623489999999996, -3.3183149999999966, -4.195229999999997, -4.273229999999996, -4.465109999999995, -4.692479999999996, -3.7492649999999967, -3.647279999999996, -4.0491749999999955, -3.147104999999997, -2.8557749999999964, -2.5227149999999963, -2.312114999999996, -1.2214799999999955, -0.42334499999999675, -0.5105099999999951, 0.3597750000000053, -0.34202999999999584, -0.8977799999999976, -0.9787049999999982, -0.6680699999999957, -1.360709999999996, -0.8480549999999936, -1.942589999999997, -0.9935249999999956, -0.625559999999993, -0.48632999999999793, -1.1614199999999975], [0.0, -0.3293550000000004, -0.08580000000000176, -0.2603249999999996, 0.06902999999999992, 0.2774849999999999, -0.4225650000000003, -0.29815499999999906, -0.8478599999999996, -2.2440600000000037, -1.9535099999999999, -3.7547249999999925, -5.055960000000002, -6.728280000000016, -7.363005000000006, -7.65531000000001, -8.67554999999999, -8.620364999999994, -9.062039999999998, -9.440145000000005, -9.142380000000003, -8.117850000000002, -7.8805350000000045, -6.942779999999998, -4.824494999999997, -2.861819999999998, -0.004485000000000627, 2.856944999999998, 4.034939999999997, 4.6745399999999995, 5.6481749999999975, 5.692050000000006, 5.670794999999997, 5.213715, 4.211219999999998, 4.210829999999993, 3.3719399999999995, 3.130724999999998, 2.5722449999999997, 2.735264999999999, 2.484495, 1.6627650000000014, 1.2756900000000004, 0.5350799999999999, 0.6048899999999995, 0.40228500000000006, 0.18680999999999964, 0.6232199999999997, 0.64194, 0.28177499999999883, -1.0471500000000038, -1.327755, -2.200185000000001, -2.1619650000000004, -2.510819999999998, -3.3146100000000063, -3.030299999999995, -3.028544999999995, -3.0577950000000023, -2.367689999999996, -2.4443249999999983, -2.5554749999999977, -2.2559549999999975, -1.907880000000002, -1.6539900000000014, -1.2144599999999988, -1.0151699999999975, -0.4095, -0.6489600000000011, -0.3547049999999998, 0.2993250000000005, 0.5590650000000011, 0.22970999999999947, -0.3958500000000006, -0.7294950000000009, -0.46000499999999933, -0.575055000000001, -0.7798049999999983, -0.13630500000000134, -0.43835999999999964, -0.4600050000000009, -0.674895], [0.0, 0.18642000000000425, 0.178230000000001, -0.2074799999999979, 0.1017900000000016, -0.5083649999999987, -0.18447000000000013, -0.2599349999999989, -0.38999999999999824, -0.22931999999999775, -1.3092299999999986, -2.095079999999999, -2.8514850000000003, -3.48504, -4.195425000000003, -4.883774999999995, -4.880654999999989, -3.8561250000000022, -3.3017399999999997, -2.001869999999999, -2.1676199999999977, -3.3442499999999984, -3.2576699999999983, -4.1509649999999985, -4.339919999999999, -2.969070000000001, -0.6832799999999984, 1.8909149999999988, 3.5573849999999987, 4.541550000000001, 5.452005, 5.978310000000004, 5.703165000000002, 5.191484999999995, 5.126549999999995, 4.665765000000006, 4.338945000000008, 3.6966150000000044, 3.8301899999999978, 3.1742099999999964, 2.5268100000000007, 2.545725000000001, 1.730625000000006, 1.4706900000000003, 0.9738299999999986, 1.048125000000002, 0.9026550000000011, 0.9527700000000041, 0.7735650000000005, 0.20787000000000266, 0.16165500000000121, -0.2104049999999984, -0.8180249999999988, -1.7011799999999981, -1.157714999999998, -2.020004999999998, -1.544009999999999, -1.5223649999999989, -1.547324999999999, -1.5358199999999986, -1.7803499999999985, -1.3209299999999988, -1.3805999999999987, -1.7733299999999992, -1.8056999999999983, -1.2749099999999989, -1.3864499999999986, -1.0463699999999987, -0.969929999999999, -1.1573249999999988, -0.9627149999999988, -1.3289249999999988, -1.4917499999999986, -1.8031649999999984, -1.2918749999999983, -1.1479649999999988, -1.3423799999999988, -0.7503599999999991, -0.8722349999999991, -0.16574999999999895, -0.40403999999999785, -0.41515499999999983], [0.0, 0.4282200000000004, 0.1544399999999993, 0.00019499999999936235, -0.18525000000000105, -0.10646999999999981, 0.07799999999999996, 0.02359499999999956, -0.31902000000000086, -0.6994650000000001, -0.9471150000000007, -2.173470000000003, -3.644355000000003, -4.8480900000000045, -6.7700099999999965, -7.738380000000021, -9.050340000000002, -10.342605000000022, -11.424465000000009, -12.88326, -14.007825000000018, -13.506675000000008, -13.422630000000014, -12.496965000000001, -10.943790000000005, -7.537920000000002, -4.566705, -1.6364399999999997, 0.04738499999999951, 1.547325000000001, 2.999490000000001, 3.8128349999999953, 4.578600000000004, 4.111574999999993, 4.715099999999996, 5.077215000000002, 5.023979999999999, 4.207709999999999, 3.2290049999999977, 2.937869999999999, 2.5531349999999984, 2.2027200000000002, 2.1485100000000004, 2.278769999999996, 1.9287450000000026, 2.0469149999999976, 1.9693050000000016, 1.786785000000001, 1.5742350000000005, 0.6651449999999994, 0.43465499999999935, -0.25388999999999984, -0.5524350000000001, -1.4410499999999993, -2.2015500000000054, -2.612999999999999, -2.6697450000000007, -2.8976999999999986, -3.8762099999999924, -3.4967399999999964, -3.5544600000000033, -3.8270700000000017, -3.0710550000000008, -3.1954650000000004, -2.8830749999999994, -3.050384999999998, -2.539094999999998, -2.737800000000003, -1.7785949999999997, -1.4899949999999997, -1.0453949999999992, -0.2160599999999999, -0.8383050000000009, -0.7581600000000001, -0.49959000000000076, -0.4096949999999997, -0.9991799999999998, -0.7681050000000001, -0.3740100000000005, 0.4894499999999996, 0.3365699999999995, -0.23458500000000024], [0.0, 0.6438900000000087, 0.19929000000000396, 1.3509600000000006, 1.763190000000006, 2.738190000000002, 1.665105000000004, 0.8240699999999963, -1.3975649999999984, -2.786159999999996, -6.014774999999995, -8.435504999999996, -12.494039999999991, -16.33768499999998, -21.336510000000004, -26.76550499999998, -31.823414999999997, -36.546510000000026, -39.472095000000074, -42.240315000000024, -42.33918000000002, -40.30377000000004, -36.78089999999999, -30.612270000000013, -21.51513, -12.178139999999992, -2.520374999999996, 4.991999999999989, 9.889620000000011, 13.336634999999987, 15.593369999999993, 15.247635000000013, 14.779050000000048, 15.467205000000025, 15.26791500000001, 13.869375000000009, 12.058020000000013, 11.224005000000012, 11.22751499999999, 9.869534999999999, 8.903505000000017, 6.764160000000026, 5.9855250000000195, 6.678555000000006, 5.756790000000016, 5.533905000000009, 5.104905000000019, 4.108065000000006, 4.082325000000007, 3.2838000000000074, -0.0674700000000028, -0.35509499999999505, -2.794544999999996, -6.041489999999995, -7.004204999999995, -9.117419999999996, -9.507224999999991, -10.622429999999994, -10.170029999999986, -10.384919999999994, -10.435034999999996, -9.393734999999996, -9.152909999999991, -9.140819999999996, -6.8271449999999945, -6.450404999999994, -4.6078499999999964, -2.975114999999998, -2.577509999999993, -0.7117499999999932, -0.012089999999985501, 1.15869, 0.4141800000000089, -0.3683549999999842, 0.9537449999999952, 0.14976000000000766, 0.6709950000000084, 1.2121200000000005, 1.1345100000000041, 0.9242999999999908, 0.8899800000000093, 0.8954400000000033], [0.0, 0.36055499999999957, 0.25584, 0.9073349999999993, 1.555125, 1.2259649999999997, 1.2661349999999982, 0.5715449999999997, 0.005069999999999408, -0.6647549999999995, -1.3104000000000018, -2.4989249999999976, -3.4415550000000015, -5.186609999999995, -6.353490000000004, -7.343115000000004, -8.596575, -9.405435000000008, -9.235590000000009, -9.563969999999998, -10.089105000000012, -9.043320000000005, -8.880690000000012, -7.260630000000015, -5.790915000000002, -1.921335000000003, 1.5221699999999971, 4.068285000000001, 6.470100000000001, 7.241324999999991, 7.619820000000008, 7.966529999999998, 7.350134999999994, 7.356180000000002, 6.308055000000003, 5.745870000000002, 5.473065000000008, 5.051670000000008, 4.5901049999999985, 3.9224249999999965, 3.263325000000002, 2.953275000000003, 2.615145000000002, 2.3167949999999995, 2.0907900000000006, 2.490540000000003, 2.7056249999999977, 2.394600000000003, 1.0528049999999987, 0.6748949999999998, -0.034710000000000574, -0.6546150000000011, -0.5865600000000002, -1.6200600000000034, -2.354820000000002, -2.9380649999999964, -3.4084049999999926, -3.3871499999999912, -3.5240400000000003, -3.237000000000001, -2.55996, -2.9281199999999963, -1.9772999999999998, -1.5426449999999985, -0.9408750000000003, -0.9633000000000007, -0.9036299999999999, -1.1409449999999994, -0.08814000000000022, 0.7296900000000013, 0.6446700000000007, 1.0188750000000013, 0.33676500000000087, 0.1653599999999998, 0.37381499999999857, 0.8228999999999997, 0.09515999999999968, 0.5212349999999992, 0.4009200000000004, 0.6095699999999997, 0.49217999999999995, 0.8753550000000005], [0.0, 0.22483500000000411, 0.03431999999999924, 0.13084499999999677, 0.9209849999999964, 0.8373300000000006, 0.3447599999999946, -0.03256500000000129, -0.2640300000000009, -1.689675000000002, -3.253185000000004, -4.842045000000003, -7.132320000000005, -9.579375000000013, -11.164530000000003, -13.139685000000014, -15.462330000000016, -17.288309999999996, -18.903885000000006, -20.490794999999977, -20.30808000000002, -19.226220000000016, -17.097210000000015, -14.557530000000032, -10.545794999999998, -5.070975000000003, 0.4549349999999954, 5.443815000000003, 7.770750000000002, 9.108840000000018, 10.03938000000003, 10.347480000000022, 10.285274999999995, 10.06278000000001, 9.788415000000004, 9.209069999999997, 8.215935000000009, 7.761390000000012, 7.306064999999994, 6.489405000000004, 5.238284999999993, 5.387655000000001, 3.636554999999989, 4.181189999999987, 4.013684999999996, 3.391830000000007, 3.276780000000012, 2.493074999999994, 2.2939799999999995, 1.6118700000000015, 0.9956700000000058, 0.7552349999999954, -0.2665650000000026, -1.3882050000000064, -2.8830750000000047, -3.1404750000000057, -3.8865450000000044, -3.770130000000004, -5.184465000000004, -4.962555000000005, -4.4282550000000045, -4.826250000000004, -5.019105000000002, -4.869540000000008, -4.146285000000005, -3.213015000000004, -2.5896000000000052, -1.3289250000000021, -0.825045000000002, -0.4713150000000055, -0.34476000000000484, -0.0015600000000031145, -0.266760000000005, -1.025700000000001, -0.8837400000000049, -0.23985000000000856, -0.9790950000000063, -0.37869000000000375, 0.396044999999992, 1.0867349999999902, 0.314534999999994, 0.39350999999999114], [0.0, 0.18895500000000265, 0.053625000000001144, 0.17491500000000082, 0.6577349999999971, 0.4943249999999999, 0.34866000000000064, 0.5908499999999988, 0.28138500000000066, -0.5241599999999953, -0.8084699999999994, -2.0357999999999983, -2.9337749999999985, -3.7186499999999993, -4.608825000000001, -5.076044999999995, -5.278649999999994, -5.0116950000000005, -5.01891, -5.3053649999999966, -5.389019999999995, -5.3722499999999975, -5.160869999999999, -4.832489999999998, -2.9078399999999984, -1.3076700000000003, 0.1811550000000035, 1.2782250000000004, 2.5424099999999923, 3.5782500000000086, 3.622710000000004, 3.9058500000000107, 3.5139000000000067, 3.6790649999999987, 3.5105850000000034, 3.1892249999999978, 3.2182799999999974, 3.361800000000005, 3.0082649999999918, 2.368274999999996, 2.515500000000009, 1.8776549999999999, 1.295775000000003, 1.1764350000000032, 1.3109850000000014, 1.8788250000000017, 1.8333900000000032, 1.8129150000000003, 1.7310150000000029, 1.1982750000000038, 0.7078500000000032, 0.14293499999999915, -0.3531449999999987, -0.40384499999999734, -0.4005299999999985, -0.7733699999999979, -0.6789900000000002, -0.829724999999998, -1.229474999999999, -1.6448249999999995, -1.4780999999999993, -1.6418999999999981, -1.3105949999999977, -1.2830999999999981, -1.3142999999999996, -0.8950499999999961, -1.462499999999998, -1.1974949999999995, -0.7406099999999991, -0.008580000000001142, 0.09047999999999856, -0.040754999999996766, 0.1608750000000021, -0.0701999999999976, -0.4541549999999952, -0.2973749999999993, -0.24023999999999868, -0.038414999999998756, 0.4713149999999957, 0.45747000000000027, 0.6990749999999997, 0.31804500000000413], [0.0, 0.8552699999999991, 1.5299699999999994, 1.0586549999999995, 0.9775350000000014, 1.4026350000000012, 1.6401449999999989, 1.1015549999999998, 0.49081500000000094, 0.19558499999999984, -1.1169599999999997, -2.826525, -4.572165, -6.331259999999999, -8.330595000000004, -9.916530000000016, -11.312535000000032, -12.524459999999998, -13.909739999999996, -14.52087000000002, -14.189955000000026, -13.69407000000004, -12.845430000000016, -10.098075000000009, -6.961889999999995, -2.459145000000003, 1.7195099999999994, 4.601999999999998, 6.7883400000000105, 7.859475000000003, 8.191365000000005, 8.72859000000001, 9.150375, 9.026744999999996, 8.365110000000008, 8.060520000000006, 7.462455000000003, 7.580234999999999, 7.1586450000000035, 6.207240000000007, 5.827769999999992, 5.161455000000004, 4.893525000000003, 4.009589999999999, 3.6084750000000003, 4.142774999999995, 4.054439999999999, 4.012515000000002, 3.808739999999995, 2.8095599999999994, 2.69529, 1.2019799999999985, 0.7938450000000006, -0.06649500000000014, -0.4061849999999999, -0.8950500000000008, -1.493115000000001, -2.1227699999999974, -2.4766949999999985, -2.966144999999994, -3.1484700000000005, -2.3602799999999986, -2.2863750000000005, -2.7610049999999937, -1.0073699999999999, -0.839670000000001, -0.2965950000000003, -0.19831500000000118, 0.0785849999999996, 0.8396699999999996, 1.0196549999999993, 1.6044600000000007, 1.3102050000000005, 0.9845549999999987, 1.1953499999999995, 1.7298450000000007, 0.9638850000000012, 2.1611850000000006, 2.3136749999999973, 1.6524299999999985, 1.6442399999999977, 1.9275749999999996], [0.0, 0.11875500000000083, 0.4309500000000022, 0.3285750000000019, 0.7515300000000005, 0.8133450000000002, 0.905384999999999, 0.0762450000000004, 0.2505750000000013, -0.08462999999999966, -0.9172800000000005, -1.72926, -2.416829999999999, -3.1763549999999934, -3.416400000000001, -2.989935, -2.4269699999999985, -2.7754350000000017, -2.445690000000001, -2.47299, -2.035994999999998, -1.6183049999999997, -1.8312449999999991, -1.7920499999999984, -1.4449499999999986, 0.11797500000000044, 1.7594850000000002, 2.9191500000000006, 3.6527399999999957, 4.774574999999997, 4.850625, 4.4286449999999995, 4.760925000000001, 4.234035, 4.550519999999998, 4.388279999999998, 4.0025699999999995, 3.558554999999997, 3.6318750000000053, 2.813849999999998, 2.754179999999999, 2.3468250000000026, 1.7119050000000022, 2.059785, 2.122575000000003, 2.1588449999999964, 1.9618950000000015, 2.4501750000000015, 2.4437400000000027, 1.8573750000000007, 1.25073, 0.5341050000000016, 1.1040900000000027, 0.018915000000000598, 0.7369050000000015, 0.3882450000000018, 0.10042499999999993, -0.7926749999999996, -0.9943049999999998, -0.3047849999999993, -0.30653999999999915, -0.8583899999999991, -0.2410199999999992, -0.8334299999999997, -0.4492799999999994, -0.30575999999999937, -0.23867999999999928, -0.2416049999999995, 0.45103500000000113, 0.41028000000000037, 0.5343, 0.1253850000000009, 0.777855, 0.9553049999999998, 0.5181150000000021, 0.9660300000000039, 0.22542000000000112, 0.6212700000000009, 0.45415500000000003, 0.9159150000000007, 1.1157900000000036, 0.7398300000000007], [0.0, -0.06903000000000126, 0.14195999999999742, -0.16263000000000205, -0.055965000000000265, 0.5645249999999999, 0.5976750000000026, 0.40813499999999814, 0.41086499999999604, -0.18525000000000058, -1.2600900000000013, -2.079480000000001, -2.690025000000001, -3.6582000000000017, -4.734794999999994, -4.796024999999999, -5.160090000000002, -4.895475, -5.181929999999999, -5.534295000000003, -5.374590000000004, -6.358559999999992, -5.418270000000001, -5.2234649999999965, -3.6697049999999996, -1.1101350000000005, 1.797899999999996, 4.211805000000003, 4.739865000000003, 5.539170000000005, 6.538545000000003, 6.909435000000002, 6.27939, 6.1633650000000015, 5.774535000000004, 5.3082899999999995, 4.976205, 5.008575000000008, 4.527704999999995, 4.2211649999999965, 3.7127999999999988, 3.547049999999988, 3.4123050000000026, 3.3364499999999992, 3.0147000000000013, 3.1307249999999973, 2.969849999999999, 3.301934999999995, 2.9466449999999993, 2.8185299999999973, 2.3856300000000026, 2.0162999999999967, 1.6190849999999968, 1.081079999999994, 0.3701099999999944, -0.04387500000000033, -0.273780000000003, -0.7723950000000009, -0.3876600000000001, -0.38102999999999754, -0.6875699999999987, -1.2043200000000012, -1.4075100000000011, -1.2257700000000011, -0.782925000000001, -0.556725000000001, -0.047970000000001844, 0.1854449999999952, 0.3063450000000023, 0.4321199999999983, 0.11680500000000094, 0.044459999999999944, 0.3847350000000007, 0.2934750000000006, 0.21001499999999873, 0.17354999999999854, 0.024959999999998095, 0.36074999999999924, 0.9775350000000003, 1.0746449999999952, 0.7575749999999999, 0.8700900000000009], [0.0, -1.0147799999999987, -1.649114999999997, -1.1657100000000002, 0.023790000000000422, -0.9486749999999957, 0.29717999999999956, -0.08658000000000277, -1.1469899999999993, -1.7649449999999969, -3.493230000000002, -3.912479999999993, -5.691660000000002, -6.047729999999998, -7.400055000000005, -8.041995000000016, -6.90923999999999, -6.059430000000001, -7.109114999999996, -6.214260000000005, -6.669585, -6.62571000000001, -7.516470000000002, -6.165315, -4.873050000000001, -1.1372400000000007, 2.5837499999999993, 6.340034999999995, 8.560499999999996, 9.698325, 10.577189999999995, 9.3171, 9.748245000000002, 7.768604999999999, 7.3487699999999965, 7.165080000000003, 6.53289, 6.029399999999996, 4.661865000000001, 4.278495000000001, 3.8711400000000005, 3.8175149999999975, 3.4910849999999987, 3.1511999999999984, 2.2978799999999993, 2.5944749999999996, 1.8349499999999987, 2.039699999999999, 0.5643300000000004, 0.7012199999999993, -0.9098699999999948, -1.217969999999995, -1.153424999999995, -1.6165499999999988, -1.681094999999997, -2.076360000000005, -2.4751350000000065, -2.9218799999999994, -2.982915000000007, -3.9454350000000047, -3.5236499999999977, -3.6422100000000044, -3.1315050000000038, -3.2882849999999944, -2.299634999999999, -1.8300750000000048, -1.4691300000000012, -0.7273499999999999, -0.5976750000000015, -0.1735499999999992, -0.07624500000000145, -0.8386949999999973, 0.33325499999999675, 0.5473649999999997, -0.06122999999999745, -0.4141800000000013, -0.7441200000000014, -1.0531950000000014, -0.33520500000000153, -0.21820500000000154, 0.15639000000000358, 0.6339449999999973], [0.0, 0.7688849999999983, 0.6370650000000033, 0.5029049999999984, 0.8622899999999882, 0.2365349999999955, 0.4155450000000007, 0.9521849999999974, 0.5590649999999977, 0.003119999999992018, -0.9814349999999994, -1.1744850000000078, -2.8399800000000113, -3.500250000000019, -5.314335000000018, -7.366710000000017, -9.254505000000014, -11.351145000000036, -12.686115000000052, -13.265850000000084, -13.884000000000077, -13.592865000000062, -13.143000000000056, -11.11168500000001, -8.648250000000031, -5.323890000000015, -0.784290000000011, 2.173274999999998, 4.490654999999995, 5.696534999999996, 6.621224999999996, 7.4950199999999985, 7.759049999999997, 7.682609999999999, 6.940049999999996, 6.351929999999996, 5.870474999999996, 6.047144999999997, 5.844344999999996, 5.9322899999999965, 5.469359999999996, 4.6959899999999966, 4.3132049999999955, 4.043714999999997, 3.7568699999999944, 3.229004999999995, 3.277559999999996, 3.2972549999999927, 3.4733399999999954, 3.180059999999998, 3.0523349999999976, 2.6576549999999997, 1.9441499999999898, 1.2723749999999905, -0.04816499999999824, -0.03139500000000872, -1.1547900000000135, -1.4823900000000076, -1.3979550000000067, -2.040675000000011, -2.5999350000000145, -2.8906800000000086, -2.6958750000000204, -2.275649999999999, -1.9568250000000056, -1.6662750000000033, -1.2230400000000108, -0.9488700000000074, -0.27358499999999, 0.38960999999999313, 0.7060949999999941, 0.9761699999999962, 0.708825, 0.40345499999999745, 0.23790000000000155, 0.12284999999999613, 0.2661749999999916, 0.15755999999999482, 0.5089499999999987, 0.5949450000000072, 0.46468499999999224, 1.0247250000000028], [0.0, -0.1530749999999994, -0.2872350000000079, -0.5200650000000042, -0.14469000000000598, -0.008190000000005249, 0.3221399999999983, 0.6206849999999977, 0.6707999999999972, 0.6331649999999929, 0.5695949999999961, 0.6128849999999968, 0.6782099999999947, 0.6019649999999945, 0.3125849999999937, 0.29698499999999317, 1.727309999999993, 2.7925949999999933, 3.517019999999997, 4.001204999999996, 5.158139999999995, 4.445024999999995, 3.655664999999995, 2.541239999999999, 1.1846249999999938, 0.2002649999999946, 0.3342299999999958, 0.38902499999999707, 1.1062349999999967, 1.8655649999999961, 2.4359399999999924, 3.1354049999999978, 2.8070249999999954, 2.585894999999997, 1.684019999999998, 2.0488649999999966, 1.2832949999999954, 1.5781350000000005, 1.261259999999996, 1.248389999999994, 0.6928349999999912, 0.575249999999992, 0.45473999999999304, 0.8747699999999963, 0.863654999999997, 0.5565299999999955, 1.3312649999999984, 0.7002449999999962, 0.7222799999999951, 1.3123499999999924, 1.4566499999999971, 1.034864999999996, 0.7499699999999963, 1.449434999999998, 1.9815899999999966, 1.8565949999999964, 2.3618399999999937, 2.3665199999999986, 1.4375399999999945, 1.5052049999999966, 1.102334999999996, 1.266719999999994, 1.176434999999998, 0.860339999999999, 0.28703999999999175, -0.03900000000000592, -0.23497500000000926, -0.19987499999999692, -0.6257550000000052, -0.4369950000000049, -0.32721000000000444, -0.3410549999999999, -0.8509800000000043, -0.6895199999999972, -0.7039500000000025, -0.38727000000000267, -0.03529500000000674, -0.3734250000000001, -0.42939000000001304, 0.030419999999991454, 0.1626299999999956, 0.035879999999997914], [0.0, 0.1743299999999941, -0.07078500000000432, -1.0639200000000013, -0.5282550000000015, -0.48691499999999266, -0.3139499999999966, 0.11817000000000188, -0.49900499999999326, -0.7175999999999938, -0.298350000000001, -0.503099999999999, -1.5457650000000003, -1.5529800000000016, -2.6638950000000037, -4.077450000000002, -4.4323500000000005, -4.290779999999994, -4.496115000000009, -4.246320000000002, -4.086420000000003, -4.0591200000000045, -5.0317799999999915, -5.110949999999991, -4.229354999999999, -2.93065499999999, -0.19831499999999114, 2.354430000000003, 4.451850000000001, 5.788965000000001, 5.4239250000000006, 6.249164999999999, 6.968909999999998, 6.504030000000004, 6.236295000000001, 5.832060000000001, 4.859985000000001, 4.702815000000001, 4.383210000000001, 4.851210000000001, 3.322020000000002, 3.1283850000000015, 3.249285, 3.105960000000001, 2.299440000000002, 2.2389900000000034, 2.016104999999998, 2.0242950000000004, 2.5515749999999997, 2.596424999999999, 2.2660950000000013, 1.949609999999998, 1.7546099999999996, 0.8180250000000036, 0.6667050000000057, -0.0335400000000039, -0.1924650000000021, -0.9184499999999938, -0.4469400000000041, -0.06903000000000148, -0.9030449999999961, -1.0083449999999958, -1.0138050000000014, -1.8068700000000009, -1.3437450000000046, -1.2456600000000009, -0.8490299999999991, -0.6423300000000003, -0.3016649999999954, 0.10413000000000316, 0.6349200000000006, 0.2320500000000001, -0.2884050000000009, 0.1437149999999967, 0.08892000000000078, -0.23887499999999928, -0.034905000000005515, 0.24765000000000104, 0.374595000000002, 1.0143899999999983, 0.6103499999999968, 0.7944300000000029], [0.0, 0.9338550000000101, 1.106234999999982, 0.4455749999999945, 0.43075499999998357, 0.2301000000000002, 0.05791499999999239, 0.41690999999998724, 0.6390149999999846, 0.26578499999998506, 0.1595099999999814, -0.05070000000000441, -1.1056499999999883, -1.6105050000000123, -2.9131049999999874, -4.039620000000015, -4.95319500000001, -4.673175000000015, -4.599270000000024, -5.222490000000002, -5.364449999999998, -6.3024000000000235, -6.604065000000009, -5.643300000000011, -4.437224999999991, -2.54397, -0.1647750000000272, 3.287894999999984, 5.819190000000001, 7.293779999999991, 7.960679999999985, 9.072179999999989, 8.474699999999991, 8.069489999999988, 7.968089999999984, 6.91060499999999, 5.405594999999993, 4.706909999999997, 3.7032449999999937, 3.1997549999999935, 4.414409999999995, 2.6268449999999905, 1.9722299999999855, 1.812914999999986, 0.9578400000000098, 0.8338199999999834, 1.8265649999999987, 1.7657249999999998, 1.35466499999999, 1.4745899999999885, 1.3854749999999836, 0.22697999999999574, 0.644474999999991, 0.8901749999999993, -0.02983500000000383, -0.33384000000000214, -0.5658899999999925, -0.08755500000001071, -0.8566349999999971, -1.4045850000000222, -1.8162300000000133, -2.560544999999996, -1.8879900000000003, -1.3053300000000139, -1.7064450000000217, -2.542800000000021, -1.0120499999999986, -0.14390999999999998, 0.4882800000000014, 1.155569999999983, 0.6711899999999993, 0.5409300000000048, 1.0223849999999945, 0.7287149999999887, 0.79209, 0.13416000000001027, 0.8771099999999894, 1.033499999999993, 0.6442799999999931, 0.053819999999992874, -0.4151549999999826, -0.24823499999998866], [0.0, 0.6686550000000002, 0.6121049999999999, -0.577589999999998, -0.43172999999999995, 0.1487850000000006, 0.806325, 0.3966300000000008, -0.11992499999999906, -1.0643099999999988, -0.6185399999999999, -1.0785450000000025, -1.7729399999999982, -3.1424249999999976, -4.328415, -5.614635000000006, -6.6457949999999935, -7.0746000000000056, -7.433790000000016, -7.9558050000000105, -9.219015000000011, -8.348340000000004, -8.315970000000002, -7.423455000000002, -5.871060000000006, -3.2383649999999946, -1.2485850000000018, 1.1571300000000004, 2.3604750000000028, 3.284384999999996, 4.249050000000001, 4.604145000000003, 3.912869999999998, 5.058495000000004, 5.274944999999999, 4.487925000000005, 4.567094999999999, 4.646069999999997, 3.8734799999999963, 3.450330000000001, 4.536285000000006, 4.221164999999999, 4.297410000000002, 4.353179999999993, 3.9413400000000003, 3.1164900000000006, 3.4665150000000002, 3.3705749999999997, 3.2789249999999974, 2.7251249999999994, 2.1775649999999986, 1.2903149999999992, 1.9866599999999988, 1.384890000000001, 0.8605349999999997, 0.5764199999999998, -0.18739500000000153, -0.2767050000000002, -0.643109999999999, -1.454310000000002, -0.6087900000000002, -1.0988250000000013, -0.8652149999999994, -0.04328999999999872, -0.08423999999999876, -0.16516499999999934, -0.06357000000000035, 0.10666500000000034, 0.11075999999999997, 0.7878000000000004, 0.3929250000000001, 0.8923200000000004, 0.5151899999999998, 0.41106000000000004, 0.8412299999999995, 1.0426650000000013, 0.4235399999999994, 0.8158799999999998, 1.0666500000000003, 1.4942850000000005, 1.6432650000000004, 1.7384250000000003], [0.0, 0.1415700000000013, 0.07351499999999955, -0.07780500000000123, -0.005264999999997855, 0.06454499999999963, -0.01833000000000018, -0.35256000000000043, -0.06142499999999984, -0.15560999999999847, 0.4906200000000007, 0.44420999999999977, 0.6932250000000002, 0.10842000000000529, 0.04679999999999973, 0.3543150000000017, 0.8375250000000003, 1.3203450000000005, 1.2643800000000005, 2.7884999999999995, 2.9858400000000005, 2.4921000000000006, 2.2191000000000005, 1.047150000000001, 0.5450249999999992, 0.15249000000000157, 0.82758, 1.52178, 2.1329100000000007, 2.994225000000001, 3.2479200000000024, 3.0207450000000002, 3.447795, 3.4637850000000006, 3.0353700000000012, 3.09816, 2.3470200000000006, 1.9812000000000005, 1.9365450000000002, 2.23197, 1.032915, 1.8778500000000007, 1.5426450000000003, 1.9314750000000005, 2.2192950000000002, 1.498184999999999, 1.143675, 1.8973500000000003, 1.6364400000000003, 0.9806550000000006, 0.8408400000000005, 0.7353449999999992, 0.9999600000000005, 1.2193350000000005, 0.6349199999999999, 1.0264799999999998, 1.5309450000000007, 1.0746450000000007, 1.5921750000000006, 1.382355, 0.9375600000000006, 0.05479500000000015, 0.3086849999999981, 0.4500599999999997, -0.056354999999997935, 0.23029499999999925, -0.23497499999999727, -0.8111999999999995, 0.14137500000000114, 0.2854800000000006, 0.10101000000000004, 0.5321549999999997, -0.14566500000000104, 0.03354000000000301, 0.6013800000000009, 0.6706050000000001, 0.22229999999999928, 0.6249749999999987, 0.14995500000000228, -0.1349400000000025, 0.038024999999999975, -0.02652000000000032], [0.0, -0.6784049999999988, -0.6940050000000042, -1.0580699999999963, -1.1362649999999892, -1.4420249999999992, -0.3471000000000046, -0.4945199999999952, -0.9069450000000003, -1.6489199999999995, -1.9654049999999987, -2.2066200000000036, -2.9320199999999956, -3.1722599999999996, -2.8682549999999947, -3.7927499999999954, -4.581719999999999, -3.7301549999999932, -4.237154999999992, -4.609214999999991, -4.134585000000001, -3.698564999999997, -4.092659999999994, -4.8042149999999975, -3.971564999999999, -2.8115099999999966, -1.50657, 0.8975849999999959, 2.4727950000000005, 3.612960000000016, 4.296045000000016, 4.8923549999999905, 5.147025000000009, 4.52985000000002, 4.2925350000000035, 3.9567449999999864, 3.377789999999991, 2.6594099999999985, 2.7169350000000216, 2.844855, 2.72531999999999, 1.7191200000000046, 1.845089999999984, 1.7608499999999987, 1.3187849999999992, 0.5130450000000062, 0.7731750000000082, 0.5477550000000049, 0.19714500000001323, 0.620879999999997, 0.29094000000000086, 0.3022500000000097, 0.10725000000000762, -0.3250649999999906, -0.23945999999999934, -0.42471000000000103, -1.251509999999998, -1.5560999999999998, -2.110289999999992, -2.237624999999986, -1.957409999999995, -1.6064099999999932, -1.4188199999999878, -1.0742549999999982, -0.3765449999999948, -0.17082000000000086, 0.07059000000001259, -0.0501150000000008, -0.3513900000000012, -0.32681999999999434, -0.27143999999999213, -0.24238499999999608, 0.02925000000000555, -0.5844150000000008, -0.5056350000000025, -0.8886150000000015, -1.1703900000000003, -1.5617550000000016, -0.7620599999999955, -0.7310550000000005, -0.48925499999999644, -0.49764000000000674], [0.0, 0.015794999999999226, 0.12655499999999853, 0.1515149999999985, -0.6085950000000009, -0.9506250000000012, -0.8131500000000016, -1.0699650000000012, -1.2862200000000006, -1.248000000000002, -1.6809000000000016, -1.7507100000000013, -2.4722100000000014, -3.1979999999999977, -4.340309999999995, -5.2232699999999985, -5.791695000000007, -6.646769999999997, -7.467525000000004, -7.546304999999994, -7.150649999999997, -6.702734999999998, -6.183060000000005, -5.358405000000005, -4.013294999999998, -1.8595200000000016, 0.7113600000000007, 2.8195049999999955, 3.63948, 3.7313249999999956, 3.9737100000000005, 4.501769999999991, 4.2995549999999945, 4.453019999999995, 3.9251549999999966, 3.588974999999997, 2.712254999999996, 2.1083400000000023, 2.6560949999999988, 2.2949549999999967, 2.602664999999994, 2.2836449999999986, 2.166254999999999, 2.2315799999999935, 2.7288299999999968, 2.1771750000000014, 1.847819999999997, 1.9137299999999966, 0.9576449999999999, 1.2226499999999976, 0.5305949999999997, 0.043874999999998665, -0.3987750000000013, -0.30400500000000075, -0.7265700000000006, -0.6565650000000018, -1.3010400000000004, -0.8946600000000015, -1.6411200000000006, -1.4034150000000012, -1.4168700000000016, -1.466205000000001, -1.2708150000000018, -1.1612250000000015, -0.49978500000000126, -0.07117500000000054, -0.10276500000000055, 0.4262699999999986, 0.3613349999999975, 0.34183499999999967, 0.7234499999999995, 0.300689999999999, -0.28821000000000163, -0.19168500000000166, -0.3006900000000019, 0.2954249999999994, 0.19792499999999924, 0.004485000000000738, 0.3486599999999991, 0.46078499999999845, 0.3919499999999978, -0.06084000000000078], [0.0, 0.463514999999997, -0.901095000000004, -0.6817200000000034, -0.5479500000000019, -0.731055000000002, -0.5335200000000033, -1.3782600000000018, -1.4219400000000026, -1.807455000000004, -2.4291150000000026, -3.7326900000000025, -4.43937, -5.714085000000004, -6.7686450000000065, -8.620755, -9.616620000000003, -11.148150000000006, -11.891880000000006, -12.76060500000001, -12.445680000000012, -12.227474999999998, -11.749334999999997, -10.421579999999997, -8.788259999999992, -4.928040000000005, -2.076945000000003, 1.7789849999999947, 3.2732699999999935, 4.588349999999998, 5.226779999999996, 5.811975000000002, 5.74294499999999, 5.188365000000001, 5.278650000000001, 5.017350000000009, 4.428840000000003, 3.3738899999999945, 4.242029999999998, 4.041960000000001, 3.4403849999999934, 2.8861949999999905, 2.718495000000002, 3.049799999999984, 2.9207099999999957, 2.1865349999999943, 2.457194999999992, 2.4322349999999857, 1.9872449999999948, 1.5886649999999976, 0.45902999999999805, 0.31726499999999636, -0.8388899999999999, -1.5057900000000024, -1.4149200000000028, -2.016105000000003, -2.616900000000003, -2.9934450000000026, -3.309540000000003, -3.871725000000003, -3.581175000000002, -2.736045000000002, -2.6147550000000024, -1.411995000000003, -1.5931500000000023, -0.8687250000000017, -0.611130000000002, -0.14995500000000073, -0.5280600000000026, -0.13065000000000593, -0.6015750000000004, -0.43153500000000466, -0.7762950000000037, 0.1532699999999978, 0.10217999999999483, -0.2195700000000027, -0.44284500000000593, -0.20280000000000475, 0.0655199999999958, -0.898950000000005, -0.8626800000000012, -0.47619000000000256], [0.0, 0.22717500000000024, -0.22854000000000074, -0.3480749999999997, -1.6604250000000003, -1.5020850000000003, -1.9531200000000017, -2.275065000000004, -2.348384999999997, -2.0732399999999984, -2.7822600000000026, -3.215550000000003, -3.3292350000000024, -4.231110000000006, -5.466239999999997, -6.622590000000007, -7.301579999999998, -8.101860000000014, -8.053890000000008, -7.926945000000002, -8.329425000000004, -8.269950000000001, -8.422244999999993, -7.4507549999999965, -7.031504999999992, -5.082674999999996, -1.9615049999999983, 0.5729100000000004, 1.321905000000001, 2.3370749999999987, 2.902770000000001, 2.9308499999999986, 3.1810349999999987, 2.762955, 2.4183900000000005, 2.3501400000000023, 2.3470200000000006, 2.275649999999999, 2.3027550000000003, 2.4558300000000006, 2.451929999999998, 1.7101499999999987, 1.7109299999999998, 1.8511350000000006, 1.6711500000000015, 1.7462250000000006, 1.6307849999999993, 1.21524, 1.0635299999999996, 0.6522750000000005, 0.5781750000000001, -0.026714999999999656, -1.4913599999999994, -1.6253249999999988, -1.7323800000000025, -2.142270000000001, -2.727854999999999, -2.8001999999999994, -2.641859999999995, -3.074174999999994, -3.334500000000002, -3.213599999999997, -2.9259750000000047, -2.5234950000000005, -2.1206249999999995, -1.688505, -1.581645000000002, -1.8207149999999979, -1.6951350000000005, -1.2887549999999994, -1.4389049999999968, -2.0492550000000014, -1.54908, -1.3616850000000003, -1.6224000000000003, -1.2949950000000012, -1.3626599999999995, -1.4303249999999983, -0.39000000000000123, -0.46839, -0.6606599999999991, -0.808469999999998], [0.0, -0.24063000000000045, 0.04055999999999993, 0.452399999999999, -0.35606999999999833, -0.5157750000000001, -0.7021949999999997, -0.984165, -1.7440800000000007, -2.5234950000000005, -3.2602050000000005, -5.11914, -6.559409999999999, -8.20326, -11.174475000000008, -13.155090000000012, -16.144049999999982, -18.71356500000004, -20.521020000000046, -22.04611500000004, -22.200360000000043, -21.753420000000034, -19.46977500000002, -16.569734999999994, -13.246544999999994, -8.183759999999996, -2.494830000000001, 0.6598799999999994, 3.7198200000000066, 5.462340000000011, 7.012199999999996, 7.505745000000004, 6.7943850000000054, 6.5980200000000035, 6.909435000000005, 6.1003799999999915, 5.553405000000002, 5.2622700000000036, 5.3755650000000035, 4.369754999999992, 4.075305000000006, 3.085874999999996, 3.7714949999999945, 3.5796149999999898, 3.355755000000003, 3.08938500000001, 2.0584200000000012, 1.62474, 1.6362449999999988, 1.3415999999999975, 0.8892000000000022, 0.5890950000000001, -1.32093, -2.0239049999999987, -2.6982150000000003, -3.503175, -4.366439999999997, -5.038995000000002, -5.359185, -5.646029999999996, -5.737875000000001, -5.943600000000003, -4.747664999999997, -3.3816899999999985, -2.5077000000000003, -2.329274999999999, -1.5295799999999988, -0.5218199999999997, 0.1725749999999997, 0.7019999999999973, 0.5536050000000021, 0.4927650000000008, 0.6594900000000004, 0.4711200000000002, -0.11368499999999926, -0.36679500000000065, -0.37517999999999896, -0.4071599999999994, -0.57057, -0.9125999999999997, -0.7989150000000003, -1.2160200000000003], [0.0, -0.19851000000000196, -0.5799300000000005, -0.7275449999999974, -1.1674649999999998, -0.849809999999998, -1.3437449999999997, -2.1676199999999994, -2.051009999999999, -2.4176099999999985, -3.8017199999999987, -4.841069999999997, -6.061184999999995, -7.461089999999999, -8.834280000000007, -10.661039999999996, -11.750115000000006, -13.018590000000001, -13.89297000000002, -14.67628500000002, -14.714310000000005, -13.005330000000006, -11.007945000000005, -9.428054999999997, -7.5704850000000015, -4.9867349999999995, -1.2550199999999987, 2.3725649999999994, 4.02460500000001, 4.684484999999993, 5.5292249999999985, 5.335590000000005, 5.425095000000004, 4.833659999999998, 4.813964999999998, 4.133220000000003, 3.4895250000000035, 3.6853049999999983, 4.0265549999999966, 3.589754999999999, 3.6642450000000033, 3.1201950000000047, 3.0262050000000005, 2.995590000000002, 3.1375500000000023, 2.741700000000001, 2.422874999999998, 2.6159250000000003, 1.5208049999999993, 0.6017699999999988, 0.22385999999999884, -0.5719349999999985, -1.5872999999999993, -2.3345399999999987, -3.5279399999999983, -2.9552249999999978, -3.068714999999999, -3.9079949999999997, -3.7527749999999997, -3.9048749999999988, -3.710849999999998, -3.5209199999999985, -2.5621049999999994, -2.1459749999999986, -2.1210149999999985, -1.3827449999999988, -0.38122499999999837, 0.46917000000000186, -0.09203999999999812, 0.13513500000000134, 0.5259149999999995, -0.31862999999999975, -0.2749499999999987, 0.8367450000000018, -0.14605500000000005, 0.1690649999999998, -0.5793449999999993, -0.7318349999999991, -0.40657500000000013, -0.7924799999999996, -0.6356999999999997, -0.67041], [0.0, 0.5190900000000034, 0.9482850000000032, 2.138955000000002, 2.3702250000000022, 2.189655000000003, 3.485235000000003, 3.9717600000000015, 4.968405000000002, 8.708115, 12.000690000000004, 15.974985000000007, 23.02696500000001, 28.222155000000043, 36.868259999999985, 44.74079999999998, 54.328754999999994, 62.14611000000016, 68.95882500000009, 73.811985, 75.38056500000002, 72.19153500000004, 65.61301499999998, 54.313740000000024, 40.57345499999999, 24.44754000000004, 10.25817, -4.321785000000003, -14.750774999999978, -24.429015, -28.68898500000001, -28.57529999999999, -29.636879999999984, -28.232880000000065, -24.97384500000001, -22.70775000000004, -20.630220000000023, -18.108285000000016, -15.23690999999999, -14.02147499999999, -11.416080000000013, -9.590294999999996, -8.360234999999996, -8.065980000000007, -7.615530000000016, -6.785609999999981, -6.411795000000003, -5.9820150000000005, -3.6544949999999954, -1.7902949999999986, 1.4045850000000037, 4.8508200000000015, 8.225099999999998, 11.626094999999992, 13.660724999999976, 16.999514999999985, 19.368180000000017, 20.817614999999968, 22.475699999999996, 21.743084999999994, 22.45366499999998, 22.058595000000004, 20.228910000000006, 18.654089999999997, 16.612245000000033, 12.954629999999995, 11.541855, 7.7730900000000025, 4.974840000000004, 2.5283700000000024, 1.6929900000000024, 1.6512600000000015, 2.1375900000000025, 0.3096600000000014, 1.0278450000000021, 0.022425000000000583, 0.8658000000000055, 1.5812550000000023, 1.0721100000000023, 0.6216600000000005, 3.5337900000000015, 3.344250000000002], [0.0, -0.028275000000002937, 0.17608499999999982, -0.22288500000000067, -0.41769000000000245, -0.49588500000000235, -0.7897500000000024, -0.9543300000000023, -1.2164100000000024, -1.552785000000002, -1.8503550000000022, -2.3946000000000045, -2.682810000000005, -3.2161350000000013, -3.61257, -3.968834999999997, -3.674385, -3.8227800000000034, -4.0854450000000035, -4.741815000000002, -4.712174999999997, -4.33875, -3.7948950000000012, -3.724890000000002, -2.7711450000000033, -1.588860000000002, 0.01910999999999774, 1.0413, 1.7994599999999996, 2.4655799999999974, 3.114149999999997, 3.365504999999988, 3.167969999999997, 2.853434999999994, 2.9495699999999934, 2.1684, 2.146364999999994, 2.076749999999995, 2.288519999999995, 2.4326249999999945, 2.38758, 2.1097049999999973, 1.7222399999999978, 1.8384600000000024, 2.5291500000000013, 1.8954000000000006, 1.6021199999999978, 1.1986649999999994, 0.5871449999999983, 0.4639049999999998, 0.045824999999996896, -0.43075500000000233, -0.641940000000002, -0.7236450000000012, -0.321360000000003, -0.38376000000000177, -0.37693500000000224, -0.30810000000000204, -0.7062900000000019, -0.5097300000000022, -0.5077800000000061, -0.34437000000000284, -0.4251000000000025, -0.0050700000000027945, 0.2248349999999948, 0.5159699999999992, 1.2423449999999951, 0.7899449999999977, 1.0229700000000024, 0.978509999999998, 0.9309299999999976, 0.8359649999999947, 0.9808499999999987, 0.632579999999999, 0.6076199999999985, 0.955889999999999, 0.74919, 0.4681949999999986, 0.2579849999999986, 0.40306499999999956, 0.019499999999996964, -0.48340500000000197], [0.0, 0.051479999999999804, -0.7396349999999998, -0.7049249999999998, -1.1797500000000007, -1.535820000000001, -0.7766850000000002, -0.8289449999999998, -0.6514949999999999, -1.0705500000000003, -1.4999400000000005, -1.6711499999999986, -2.0989800000000014, -3.0667650000000006, -3.174599999999998, -3.7106550000000045, -3.7036349999999962, -3.174014999999997, -3.7044149999999982, -4.007834999999998, -3.84345, -3.9132599999999966, -4.4015400000000025, -3.703830000000003, -3.330015000000004, -2.072849999999998, 0.004680000000000184, 1.80687, 2.5223249999999995, 3.2877000000000045, 4.8982049999999955, 4.797389999999996, 4.127174999999998, 3.871919999999992, 3.5807850000000014, 2.7908400000000015, 2.7358500000000023, 1.8636149999999998, 2.191214999999997, 2.093715000000001, 2.075774999999998, 1.3517400000000008, 1.2160199999999999, 0.8299200000000003, -0.15717000000000036, -0.2146950000000003, -0.27397499999999964, -0.46351500000000057, -0.5079749999999996, -0.4481100000000001, -0.8057399999999988, -0.39292500000000086, -1.6666650000000032, -1.680704999999998, -1.105455, -1.5570749999999993, -1.351935, -1.7392049999999983, -2.1976499999999994, -2.3926499999999975, -2.36028, -1.2355200000000002, -1.3152750000000006, -1.257555000000001, -0.8792550000000005, 0.3923399999999999, 0.30186000000000035, -0.026910000000000045, 0.56628, 1.3827449999999994, 0.7778550000000001, 0.68016, 1.2175800000000003, -0.11309999999999978, -0.6926399999999999, -0.5916300000000003, -0.5440499999999995, -1.0818600000000007, -0.771225, -0.6963449999999995, -0.5354700000000002, -0.8761349999999991], [0.0, -0.11641500000000393, -0.9344400000000079, -0.49373999999999807, -0.8351850000000076, -1.3203450000000014, -1.0682100000000099, -1.1737050000000036, -1.4443650000000048, -1.930890000000001, -2.6128050000000047, -2.5279800000000026, -2.900820000000007, -3.1551000000000005, -3.8844000000000043, -4.369170000000016, -3.756480000000009, -3.8134200000000127, -3.326700000000009, -2.8557750000000017, -2.427555000000002, -2.220465000000003, -1.9344000000000041, -1.294215000000004, -1.0726950000000044, -0.15931500000000431, 0.7179899999999952, 1.892864999999996, 2.4848849999999962, 2.200964999999996, 2.7344849999999967, 2.2649249999999967, 2.5137449999999966, 2.293199999999996, 1.8045299999999964, 2.2376249999999964, 2.1292049999999967, 1.3339949999999963, 1.7635799999999962, 1.7505149999999963, 1.4482649999999961, 1.3768949999999962, 1.4377349999999962, 1.319174999999996, 1.004249999999997, 0.9291749999999965, 0.3492449999999958, 0.36367499999999353, -0.24316500000000607, -0.6532500000000043, -0.30888000000000515, -0.921960000000003, -0.729300000000003, -0.7965749999999994, -0.759720000000009, -0.37323000000000217, -0.5994300000000039, -0.38278500000000193, -0.9558900000000037, -1.169610000000004, -1.1183250000000005, -0.8845200000000051, -0.1031550000000041, -0.37654500000000146, 0.5444399999999971, 0.7583549999999954, 0.6376499999999945, 1.1795549999999952, 1.2622349999999964, 1.161224999999996, 0.7597199999999962, 0.6433049999999947, 0.6446699999999956, 0.06668999999999103, -0.08560500000000637, 0.5138249999999958, 0.26851499999999406, -0.026910000000004874, -0.32799000000000467, -1.079714999999998, -0.4839900000000026, -0.9673950000000056], [0.0, -0.5087550000000005, -1.5754050000000002, -0.9523799999999996, -1.8185699999999982, -1.4749799999999993, -1.5196350000000003, -1.9531200000000004, -2.6732549999999984, -2.1929699999999994, -2.582970000000001, -3.536714999999997, -5.169449999999996, -6.3788399999999985, -7.704255000000003, -8.312460000000009, -8.991060000000015, -9.83346000000001, -10.691460000000005, -11.335155000000004, -12.04827000000002, -11.421345000000022, -10.042304999999995, -10.024170000000025, -8.155485000000008, -5.356064999999995, -2.395185, -0.31531499999999996, 1.4418300000000002, 2.822039999999999, 3.38403, 3.911309999999996, 3.571425000000001, 3.5642100000000028, 4.033965000000003, 3.4376550000000057, 2.5476749999999995, 2.673449999999997, 2.5394850000000027, 2.904914999999999, 1.8513299999999997, 1.2218699999999987, 1.5438149999999988, 1.60563, 0.47833500000000007, 0.6473999999999998, 0.4317300000000005, 0.21040500000000026, -0.713309999999999, -0.32954999999999973, -1.501695, -1.585739999999999, -1.9008600000000009, -2.4375000000000013, -3.041219999999992, -2.9446949999999967, -3.398070000000001, -3.610425000000003, -3.471779999999997, -4.403684999999998, -4.425524999999998, -3.9869700000000003, -3.4694399999999996, -3.548220000000003, -2.6715000000000013, -1.6719299999999988, -0.766544999999998, -1.2612600000000005, -0.8191950000000003, 0.04641000000000017, -0.1511250000000004, -0.21449999999999897, -0.07780499999999968, -0.20006999999999991, -0.7721999999999998, -1.3632449999999998, -2.1290099999999974, -0.7310550000000002, -0.7905300000000004, -1.548885, -1.5196349999999992, -0.962325000000001], [0.0, -0.5153849999999958, -0.7222800000000014, -0.8408399999999983, -1.3581750000000004, -1.1912549999999957, -1.2922650000000002, -1.9049549999999988, -2.568539999999999, -2.3440949999999994, -3.444674999999999, -4.315349999999999, -5.259930000000001, -6.504419999999991, -8.140470000000008, -8.957520000000006, -10.074480000000001, -11.100375000000003, -11.258129999999996, -11.366355000000011, -11.353874999999992, -11.621025000000015, -10.691070000000003, -9.264645000000007, -7.262969999999999, -4.37658, -1.5847649999999982, 1.0381799999999979, 2.721225000000005, 3.2186700000000004, 4.794660000000005, 4.672589999999989, 4.926675000000012, 4.387694999999993, 3.8200500000000064, 3.5057099999999988, 3.3957300000000084, 2.5383150000000008, 2.708940000000008, 3.3188999999999957, 2.575559999999986, 2.272334999999998, 1.9570200000000018, 1.4593800000000021, 1.2306449999999955, 0.8429849999999948, 0.38258999999999954, 0.2129399999999988, 0.16048500000000265, -0.273000000000005, -1.1536200000000008, -2.070899999999999, -2.2906649999999993, -2.369639999999998, -2.781869999999999, -3.383249999999999, -3.492644999999999, -3.985409999999998, -3.7418549999999984, -3.811859999999999, -3.151394999999999, -3.818489999999999, -3.119024999999999, -2.1083399999999997, -2.435939999999999, -1.3669499999999994, -0.5027099999999991, -0.694785, -0.008189999999996367, 0.10081500000000077, 0.5436600000000023, 0.7899449999999923, 0.38512499999999905, 0.508560000000001, 0.30907499999999954, 0.3123899999999966, -0.9822149999999994, 0.10549499999999767, -0.3849299999999998, -0.6733350000000002, -1.1965199999999983, -1.021800000000002], [0.0, 0.7062899999999939, -1.4539200000000072, 0.7782449999999823, 0.3389099999999825, -0.16496999999999495, -0.25759500000001445, -0.18681000000000658, 0.5686200000000046, 0.2850899999999683, 0.7605000000000022, 0.7684949999999802, -0.6339450000000202, 0.7289099999999955, 1.3591500000000085, 2.8902900000000145, 5.246670000000011, 6.955065000000001, 11.134889999999995, 11.140154999999998, 11.143469999999999, 9.111179999999997, 6.8784299999999945, 5.709795, 3.8416950000000156, 1.9583850000000051, 4.2794699999999875, 5.048745000000002, 5.61054, 5.099249999999987, 6.866534999999994, 6.42875999999999, 4.93330500000001, 3.93470999999999, 4.7285549999999965, 3.48835500000002, 2.8288650000000146, 1.2852450000000122, 1.149329999999999, 1.1750700000000052, 0.767519999999994, 1.1499150000000071, 1.0734749999999877, -0.17959500000001505, 1.733939999999988, 0.05927999999998512, -0.7289100000000168, -0.9203999999999795, -0.15736500000002884, -1.5867150000000088, -0.33364499999996156, -0.8677499999999831, 0.3843450000000086, 0.320190000000002, -0.2047499999999829, 1.245075000000007, 2.4991200000000084, 3.605744999999997, 1.2667199999999994, 2.3594999999999935, 2.3827049999999943, 2.126864999999995, 2.2982699999999916, 1.9712549999999993, 0.06434999999999391, 1.9628699999999935, 2.2284600000000125, 3.1336499999999976, 2.4101999999999837, 1.9589699999999972, 1.521584999999991, 1.9439550000000043, 1.2723749999999843, 1.3211249999999986, 0.6064499999999899, 0.5781749999999928, 0.7293000000000145, 0.5608200000000085, 1.3285350000000076, -0.16419000000001027, -0.15151499999999274, 0.449279999999991], [0.0, 0.3482700000000001, 0.8778900000000006, 0.2579850000000001, 0.1634099999999998, 0.1854450000000001, -0.3547050000000015, 0.012869999999999993, -0.8523449999999985, -0.9738299999999992, -1.3573949999999995, -2.3105550000000012, -4.134000000000001, -4.877730000000004, -6.046560000000001, -7.487025000000002, -8.387340000000002, -9.323144999999995, -10.052445, -10.125375000000021, -11.273535000000013, -10.357229999999994, -9.13594500000001, -7.652580000000004, -5.21819999999999, -2.5638599999999983, -0.5740800000000009, 0.7856549999999994, 1.9784700000000006, 2.5812150000000003, 3.164654999999994, 3.379349999999999, 2.9355299999999978, 3.2231549999999967, 2.8957499999999996, 2.6338649999999975, 3.0002699999999978, 2.7013350000000003, 2.385435000000002, 2.5032150000000013, 2.634254999999998, 2.6972399999999963, 2.359500000000001, 1.859325000000001, 2.295734999999998, 2.4084450000000026, 1.817205, 1.1526450000000006, 0.9777300000000003, 0.63219, 0.10919999999999988, -0.21976500000000065, 0.031394999999999645, -0.29113500000000053, -0.4629299999999992, -1.161615000000002, -1.5888600000000013, -1.8877949999999988, -2.4755250000000006, -2.5390949999999997, -2.123354999999997, -1.482779999999999, -1.2669149999999996, -1.238445, -0.32584500000000016, 0.4896449999999993, 0.15131999999999893, 0.5430749999999994, 0.4921799999999997, 0.12421500000000009, 0.9952799999999996, 1.2764699999999998, 0.4524000000000004, 0.8427900000000002, 0.4155449999999993, 0.4360199999999992, 0.48262499999999986, 0.6536400000000009, -0.07527000000000042, -0.07917000000000049, -0.06844499999999978, -0.02086499999999991], [0.0, -0.5380049999999956, 0.05070000000000219, -0.580319999999996, -0.6386249999999967, -0.17627999999999489, -0.8308949999999964, -0.6199049999999975, -1.272569999999996, -2.589989999999996, -3.4493549999999953, -4.690529999999995, -7.217144999999997, -9.828974999999993, -12.408239999999996, -13.179270000000011, -15.974400000000024, -18.13090500000001, -19.91788500000001, -20.708024999999996, -21.462675000000075, -20.57523000000004, -18.348914999999995, -15.969329999999996, -12.17755500000002, -6.974759999999998, -2.998514999999997, 1.4172600000000029, 3.5472450000000006, 5.091840000000008, 6.2680799999999905, 6.9267900000000004, 6.597630000000008, 6.508125000000007, 6.850155000000015, 5.69497500000001, 5.068440000000011, 4.681365000000007, 3.9214500000000005, 3.377790000000004, 3.531255000000009, 3.449549999999999, 3.9947700000000173, 3.58000500000001, 3.6810150000000106, 2.255564999999996, 1.491359999999998, 1.0208250000000025, 1.641315000000009, 0.923910000000006, -1.326779999999997, -1.1019449999999984, -2.488979999999996, -3.5156549999999958, -3.983069999999995, -4.946174999999997, -5.209814999999994, -5.712329999999993, -5.873984999999999, -5.442254999999995, -5.348459999999993, -5.659289999999993, -5.474819999999999, -4.926479999999996, -3.707534999999996, -2.8417349999999937, -2.236454999999995, -1.2142649999999993, -1.338869999999996, -0.5695949999999979, 0.3578249999999987, 0.39487500000000075, 0.09204000000000079, 0.10393500000000211, 0.6403800000000013, 0.08579999999999943, 0.14488499999999638, 0.13533000000000817, -0.812954999999997, -0.5196749999999959, -0.7164299999999959, -0.32720999999999734], [0.0, 0.11310000000000375, 0.24180000000000534, 0.7753200000000025, 0.37810500000000635, 0.5662799999999999, 0.16906500000000602, -0.1476149999999965, -0.574079999999995, -1.0005449999999958, -2.299634999999995, -3.9267149999999944, -4.878314999999996, -6.224984999999992, -7.058609999999988, -8.035559999999997, -8.871915000000007, -9.429225, -9.38691, -10.068044999999993, -9.83502, -10.271235000000004, -9.574499999999993, -8.568494999999999, -7.626449999999997, -4.2363749999999945, -1.2226499999999965, 0.864239999999997, 2.5309050000000037, 3.5304750000000094, 4.304235000000007, 4.857450000000007, 4.829174999999999, 4.4670600000000125, 4.5659250000000124, 4.508400000000011, 4.029285000000003, 3.930030000000009, 3.861975000000006, 3.457155000000006, 3.341714999999994, 3.0665699999999965, 3.396315000000008, 3.6299249999999987, 3.111030000000008, 2.5827749999999985, 1.7401800000000098, 1.3121549999999984, 0.9395100000000078, 0.35782500000000494, -0.3886349999999945, -0.971684999999991, -1.3234649999999946, -1.2082199999999943, -1.8797999999999944, -1.7245799999999936, -2.203499999999997, -3.4056749999999947, -3.3596549999999934, -3.3928049999999934, -3.0053399999999937, -3.1057649999999963, -2.6896349999999947, -2.646149999999994, -1.904564999999994, -1.3144949999999938, -0.8609249999999924, -0.7901399999999921, -0.1253849999999992, 0.5062199999999999, 0.45805500000001187, 0.17784000000000066, 0.42003000000000057, 0.5389800000000018, 0.799110000000006, 0.9131850000000026, 0.6119100000000017, 0.8297249999999976, 0.5668650000000004, 0.9038250000000105, 0.4834050000000065, 0.4549349999999994], [0.0, -0.8119799999999997, -1.0030799999999984, -1.3092299999999972, -0.85293, -0.9746099999999993, -1.1142299999999974, -0.5479499999999966, -1.7672849999999989, -2.558594999999998, -2.9064749999999986, -4.96392, -6.1442549999999985, -8.290814999999995, -8.719230000000001, -11.099010000000003, -12.119055000000005, -12.656475000000004, -13.12291500000002, -14.114490000000002, -12.852840000000016, -13.111800000000013, -12.151425000000016, -11.462294999999987, -8.325135, -5.745089999999998, -1.7682599999999988, 0.30147000000000723, 2.0549099999999965, 3.747704999999993, 4.154865000000003, 4.6883849999999985, 3.884984999999993, 4.303845000000003, 4.154474999999996, 3.884399999999998, 3.333134999999999, 3.1010850000000034, 3.0792450000000025, 2.7237599999999866, 2.5217400000000025, 2.2452300000000007, 2.272920000000004, 2.1648899999999993, 2.3224500000000003, 2.2040850000000014, 1.6863600000000027, 1.2078300000000004, 0.22444499999999934, -0.6672900000000002, -0.4738499999999992, -1.0629450000000007, -2.002065, -2.838809999999999, -2.8060499999999995, -3.3343049999999987, -3.474704999999999, -3.9050700000000003, -4.76931, -4.191135000000001, -4.215899999999997, -4.076084999999999, -3.4639799999999985, -2.881904999999998, -2.1890699999999996, -2.1756149999999983, -1.467764999999996, -0.4898399999999987, -0.4412849999999988, -0.6218549999999965, -0.014625000000001442, -0.32389499999999716, 0.42666000000000137, 0.45981000000000316, -0.12869999999999937, -0.19285499999999667, -0.26383500000000026, -0.16321499999999922, -0.3821999999999992, -0.4625399999999984, -0.7113599999999989, -1.100384999999998], [0.0, 0.0003900000000007786, 0.40345500000000034, 0.19461000000000184, -0.5188949999999994, 0.6828900000000006, -0.8392799999999987, -1.7821049999999998, -2.4800099999999956, -2.3618400000000026, -4.772624999999999, -8.946795000000007, -11.369669999999994, -13.119794999999991, -17.278560000000013, -20.132385000000024, -23.30172000000005, -25.433265000000034, -27.064050000000037, -29.06865, -29.328390000000013, -28.24009500000006, -25.403625000000034, -22.19334000000002, -16.18090499999999, -8.367449999999998, -3.2873100000000024, 1.9716450000000016, 4.215120000000001, 6.508515000000008, 7.653164999999998, 8.774414999999994, 8.414250000000001, 9.58249499999999, 8.315579999999999, 7.957559999999998, 7.4624550000000065, 6.278805000000002, 7.742280000000002, 5.975189999999994, 5.61405, 5.221124999999999, 5.043284999999992, 4.987710000000004, 3.9586950000000005, 2.8744950000000022, 2.3035349999999992, 1.5007200000000014, 1.2538500000000004, 0.5212350000000013, -0.39097499999999963, -3.751215000000003, -4.232084999999995, -5.066295000000003, -5.5146000000000015, -7.310744999999999, -7.048470000000007, -8.066175000000007, -8.105955000000009, -8.983844999999995, -9.961380000000013, -9.160709999999995, -8.3967, -6.602700000000002, -6.474389999999996, -4.974450000000008, -2.7067950000000005, -2.255175000000004, -0.8773049999999993, -1.735695, -0.9467249999999992, -0.6162000000000001, -0.1774499999999981, 0.050700000000000744, 0.7098000000000007, -0.14039999999999875, 0.19344000000000078, 0.5021250000000007, -0.8901750000000002, -1.576184999999999, -1.6036800000000035, 0.020670000000001187], [0.0, 0.3701100000000004, 0.5101200000000068, 0.5307900000000019, 0.8301150000000002, 0.43660500000000013, 0.32233500000000115, 0.6914699999999976, -0.018134999999999568, 0.02944499999999639, -1.1891099999999966, -1.8776549999999972, -4.479734999999998, -5.693219999999997, -7.664669999999993, -9.985560000000007, -11.952330000000007, -14.375595, -15.921749999999992, -16.59099000000002, -17.832555000000013, -17.205434999999998, -16.740750000000027, -13.878150000000023, -10.904790000000002, -7.130174999999994, -3.3099299999999996, -0.10178999999999849, 2.1194550000000065, 3.3594600000000057, 4.409340000000008, 4.680585000000005, 4.987320000000001, 4.889625000000001, 5.055375000000006, 5.0949600000000075, 5.365815000000006, 4.7279700000000044, 4.973280000000007, 4.1946449999999995, 4.080764999999998, 3.957330000000015, 4.103580000000015, 4.105139999999998, 3.1818150000000047, 3.1445700000000105, 3.0230849999999965, 2.401620000000001, 2.473575000000001, 1.7637749999999963, 1.1048699999999956, 0.5048549999999983, 0.4215900000000059, -0.5089500000000013, -2.3378549999999985, -1.3072799999999987, -2.533439999999999, -3.391634999999998, -3.5004449999999987, -3.8569049999999994, -4.4311799999999995, -3.6722399999999977, -3.067934999999998, -2.368664999999999, -2.1149699999999982, -1.236885, 0.08170499999999992, 0.012090000000000156, 0.17920500000000317, 0.46195500000000456, 0.274754999999999, 0.3691350000000062, 0.8098350000000014, 0.8112000000000026, 1.1083799999999964, 0.9800699999999991, 0.9098700000000028, 1.1949600000000058, 1.0689900000000008, 0.9716850000000004, 0.7720050000000023, 0.7018050000000011], [0.0, 0.06493499999998864, -0.12148500000000517, -1.0701600000000084, -0.3309150000000063, -0.8117849999999986, 0.18271499999999374, -0.5575050000000035, 0.3313049999999942, -0.6903000000000059, -0.9611550000000113, -2.106585000000016, -3.4710000000000067, -5.216445000000006, -6.084195000000008, -9.364680000000005, -10.919025000000008, -13.924755000000008, -15.464280000000002, -17.185155000000023, -19.724055000000007, -19.92432, -18.057585000000007, -15.604290000000002, -12.288315000000006, -7.568340000000005, -3.5575800000000064, -1.3531049999999984, 0.2932799999999949, 3.1726499999999866, 5.28021, 6.517095000000001, 6.701175000000001, 6.959160000000017, 5.784090000000013, 5.634719999999994, 5.015790000000004, 4.611749999999995, 5.298930000000002, 4.304040000000025, 3.8931749999999976, 3.5714250000000014, 3.0927000000000024, 3.687059999999999, 2.6159250000000043, 2.9825250000000043, 2.4531000000000045, 1.415699999999994, 1.9665749999999882, 1.3400400000000081, 0.2860649999999998, 0.43621499999999536, -0.46351500000000456, -0.6224400000000099, -1.8408000000000042, -2.125500000000013, -2.8329600000000066, -4.970940000000006, -4.290585000000007, -4.330950000000007, -5.213520000000008, -5.317845000000007, -3.5624550000000115, -3.1317000000000066, -2.6962650000000057, -2.4827400000000113, -1.0543650000000087, -0.9073350000000033, -0.8402550000000053, -0.9114300000000082, 0.3123899999999997, 1.6795349999999996, -0.0015599999999986736, 0.7983299999999991, 0.95803499999999, 0.485744999999989, 0.8404499999999953, 1.5130049999999873, 0.6819149999999947, 0.23789999999998468, 0.2029949999999907, 0.10198499999999466], [0.0, -0.18837000000000348, 0.04601999999999862, -0.320189999999994, -0.5528250000000066, -0.34904999999999564, -0.034125000000010175, -0.3088800000000065, -0.551070000000009, -0.06727500000000575, -0.13084500000001587, -0.6542250000000047, -1.6830450000000114, -1.8365100000000245, -2.880540000000006, -3.8011350000000084, -4.202250000000022, -4.621890000000017, -5.48262000000003, -5.824455000000005, -6.908655000000015, -6.974175000000012, -7.971599999999994, -7.7459850000000285, -6.458790000000005, -5.4211950000000195, -3.4805550000000016, -2.40591000000001, -0.39097500000000895, 1.1485500000000046, 1.8725849999999937, 2.667014999999995, 2.3286900000000035, 3.0002699999999995, 3.266445, 3.017039999999989, 3.1182449999999946, 2.6999699999999907, 2.810340000000001, 2.205254999999995, 2.083574999999991, 1.8686849999999966, 1.6777799999999994, 1.448654999999997, 1.7540249999999942, 1.7431049999999981, 0.7696649999999963, 1.008539999999991, 1.1820899999999916, 0.5807099999999918, 0.37849500000000713, -0.11875500000000816, 0.18992999999999238, 0.09184499999999396, -0.34320000000001283, -0.6444750000000097, -0.9022650000000096, -0.9699300000000042, -0.7078500000000103, -1.214070000000011, -1.9849050000000004, -2.107560000000004, -2.1504600000000034, -1.9433700000000096, -1.951365, -1.3219049999999948, -0.7963800000000072, -1.0077600000000144, -0.6156150000000133, 0.4022850000000018, 0.4951049999999926, 0.5356650000000034, -0.05888999999999278, 0.015404999999987012, 0.0442649999999869, 0.378885000000003, 0.7688849999999885, 0.7113599999999982, 0.28197000000000383, 0.496274999999998, -0.3404700000000149, -0.01599000000001105], [0.0, 0.0070200000000002, 0.2846999999999998, 0.1179749999999998, 0.7000500000000002, 0.35899499999999984, 0.693615, 0.23829000000000095, -0.18700500000000003, -0.6503250000000006, -1.4784899999999999, -2.2464, -2.985839999999998, -3.8902500000000013, -4.7250450000000015, -7.1145749999999985, -8.851245000000002, -9.864659999999988, -11.792235000000025, -13.896285000000013, -14.498835000000026, -13.76778000000002, -13.932944999999986, -12.719850000000012, -10.442640000000024, -8.1588, -4.52829, -2.1147750000000016, -0.8934899999999988, 0.42295500000000125, 1.9425900000000047, 3.017624999999999, 3.1084949999999965, 3.392805000000003, 3.2884799999999963, 4.0973399999999955, 3.125655000000003, 3.3434699999999973, 3.571229999999996, 2.8226250000000013, 2.551769999999997, 3.013724999999994, 2.798444999999996, 2.841150000000002, 2.7943499999999943, 2.266094999999998, 2.483715, 2.4653849999999955, 1.3755299999999988, 1.9923150000000014, 1.080104999999998, 0.05908499999999982, 0.24141, -0.13883999999999974, -1.0292099999999995, -1.5406949999999988, -2.0570550000000005, -2.722199999999998, -3.6934950000000013, -3.5072699999999997, -3.7845600000000013, -4.163054999999997, -2.9226599999999987, -3.1769399999999983, -2.394209999999996, -1.9096350000000004, -2.245035000000002, -1.5172950000000003, -0.7355400000000012, -0.8427899999999998, -0.04329000000000009, 0.0912599999999998, 0.27397500000000025, 0.5692049999999995, 0.20260500000000004, 0.5194799999999978, 0.039000000000000125, 0.7760999999999998, 0.07975500000000027, 0.10393500000000011, -0.28625999999999985, 0.14624999999999966], [0.0, 0.5678400000000021, 0.06318000000000268, -0.6134699999999995, -0.28450499999999934, -0.07624500000000545, -0.012089999999995271, 0.0664949999999962, -0.2850899999999914, -0.5861699999999992, -1.462889999999998, -2.063099999999997, -3.237000000000001, -4.390619999999999, -6.2372700000000005, -7.4371050000000025, -9.092655, -10.356255000000003, -10.592205000000003, -12.08142, -13.743015000000007, -13.390064999999996, -13.706745, -12.827295000000003, -10.421775000000002, -7.537335000000002, -4.491630000000008, -3.0566249999999977, -0.5851949999999988, 1.0118549999999988, 3.0696900000000173, 2.838420000000008, 3.188835000000017, 3.6043800000000115, 3.9934050000000205, 3.2559150000000177, 2.4975600000000036, 2.614950000000018, 2.247959999999999, 2.1455850000000165, 2.8721550000000207, 2.3953799999999923, 2.711670000000007, 3.1391099999999916, 1.8760950000000172, 2.449980000000007, 2.055885000000007, 1.4289600000000124, 1.6146000000000047, 1.314885000000018, 0.3482699999999852, -0.10334999999999539, -0.24433500000000308, -0.7008299999999901, -1.714440000000013, -2.8101449999999986, -2.9669250000000096, -2.6794950000000073, -3.3738900000000083, -3.6654150000000003, -3.771494999999998, -3.150420000000003, -3.8555399999999977, -4.009200000000006, -3.235830000000001, -2.307045000000006, -2.0746049999999903, -1.5857400000000057, -1.5453749999999946, -1.3343849999999868, -0.4231499999999997, -0.5331300000000123, -0.03490499999998953, -0.32116500000000237, 0.23243999999999332, 0.3305249999999873, 0.029249999999999332, 0.405405, 0.025544999999986828, 0.0779999999999923, -0.1322099999999864, -0.33325499999998875], [0.0, -0.18544500000000014, -0.29347500000000004, 0.3299400000000005, 0.3564600000000001, -0.08950500000000033, -0.02749500000000002, -0.1719900000000006, 0.3279900000000003, 0.11271000000000009, 0.9771450000000012, 0.5489249999999986, 0.5329349999999996, -0.774735, -0.9619350000000002, -0.5424900000000002, -1.0609950000000001, -0.7084349999999999, -1.8185700000000011, -2.3772450000000003, -3.5846849999999986, -3.9538199999999986, -5.0815049999999955, -4.861934999999998, -5.562375, -4.982640000000005, -4.886699999999995, -4.127760000000002, -3.4335600000000013, -2.0028450000000024, -0.45259500000000064, -0.07858499999999961, 0.5768099999999996, 1.5013050000000003, 2.20545, 2.1834149999999957, 2.0441850000000006, 1.7978999999999985, 2.1635250000000013, 2.253420000000001, 1.7702100000000018, 1.1157900000000018, 0.9980100000000015, 0.8490299999999998, 0.8663849999999996, 0.96798, 1.2832949999999999, 1.3378949999999992, 0.8650200000000005, 1.19847, 0.5516550000000007, 0.48613499999999965, 0.0988650000000002, 0.174915, 0.9178649999999992, 0.12674999999999964, -0.2302949999999997, -0.6376500000000003, -1.3458900000000007, -1.2926549999999999, -1.042275, -0.5225999999999997, -1.0631399999999995, -1.455285, -0.7123350000000004, -0.6686549999999999, -1.017509999999999, -1.042275, -0.733005, -0.5089500000000007, 0.3176550000000002, 0.29737500000000083, 0.38687999999999945, -0.11368499999999994, 0.13454999999999984, 0.5822700000000008, 0.7632300000000004, 0.2404350000000005, -0.08248500000000035, -0.22912500000000036, 0.14664000000000055, 0.48087], [0.0, 0.7146750000000175, 0.07644000000001583, 0.6737250000000241, 0.16906500000003888, -0.8059349999999874, -0.11524499999998028, 0.08853000000000577, 0.09087000000002377, 1.2210900000000144, 0.3958500000000136, 1.8019950000000495, 1.5208050000000135, 2.2896900000000002, 3.0382950000000033, 3.8064000000000444, 4.860960000000009, 5.5411200000000225, 6.3029850000000085, 5.997225000000025, 5.151510000000021, 5.422365000000042, 3.9243750000000066, 1.5334800000000097, 1.069964999999998, -0.35918999999997325, 1.506375000000018, 1.6888950000000005, 2.7340950000000372, 3.251625000000022, 4.853160000000019, 5.124990000000022, 4.987125000000011, 3.8184900000000184, 3.758625000000025, 2.7032850000000224, 1.4827800000000124, 0.31336500000004364, -1.3250249999999895, -0.6267299999999771, -1.190474999999953, -2.3362950000000033, -1.621814999999959, -1.6573049999999725, -2.0145449999999734, -1.4989650000000019, -0.34534500000000534, -0.5456099999999999, -1.0781550000000024, -0.08852999999994537, -0.11465999999995802, 0.3570450000000207, -0.0005849999999831823, -0.10471499999997746, 1.599779999999992, 0.5951399999999882, 1.0945350000000253, 1.561950000000028, 0.6745050000000372, 0.7844850000000303, 1.4878500000000194, 0.80125500000001, 1.2222600000000075, 0.1230450000000296, 0.8074950000000332, 0.5290350000000288, 0.5890950000000021, 0.576030000000042, 0.3063450000000252, 0.5577000000000432, 0.4096949999999957, 0.47404500000002514, 0.5194799999999979, -0.42743999999998294, 0.10725000000001117, 0.2841150000000532, 0.7312500000000206, 0.21664500000003173, 1.2682800000000167, 1.3583700000000238, -0.29659499999999994, -0.47540999999997524], [0.0, 0.5032950000000023, 0.5586749999999991, 0.4198350000000035, 0.1739400000000022, 1.463474999999998, 0.3059550000000013, 0.6054750000000082, -0.04757999999999685, 0.1924650000000061, -0.4697549999999935, -1.1165699999999958, -1.6881149999999983, -3.8483249999999933, -5.486714999999993, -7.489949999999996, -8.25064499999999, -9.32294999999999, -12.124125000000006, -12.065039999999996, -13.352429999999995, -14.857440000000024, -14.304029999999988, -14.360970000000005, -12.800189999999988, -9.960795000000005, -6.409259999999993, -2.697044999999994, 0.4420649999999977, 2.3160150000000064, 4.474080000000008, 6.081660000000015, 5.896020000000025, 6.056310000000021, 6.7083900000000245, 5.892900000000022, 5.219565000000024, 5.635110000000003, 4.710420000000013, 4.550520000000015, 2.953080000000009, 2.922270000000003, 2.8228200000000037, 2.7766050000000124, 2.6048100000000085, 2.907840000000016, 2.2440599999999957, 2.5470900000000043, 1.6426800000000004, 1.8097950000000118, 1.1218350000000115, 0.7874100000000084, -0.2433599999999947, -0.43913999999999875, -1.030574999999991, -2.057639999999994, -2.345069999999996, -2.741699999999993, -2.7931799999999942, -2.5416299999999934, -3.863144999999993, -3.233099999999994, -3.5677199999999933, -4.414604999999994, -3.6441599999999936, -2.144609999999994, -2.531099999999994, -1.5360149999999928, -1.0190699999999948, -0.5914349999999913, -0.05147999999999664, 0.36250500000000496, 1.114229999999992, 0.7076550000000035, 1.0450050000000077, 0.15580499999999864, 0.6877650000000042, 0.6825000000000054, 1.0188750000000049, 1.2015900000000137, 1.052025000000012, 1.1633700000000031], [0.0, 0.41164499999999915, 0.44440499999999794, 0.44518500000000216, -0.018330000000000624, 0.5791500000000023, -0.25116000000000094, -0.25837499999999947, -0.6522749999999995, -0.057720000000001104, 0.105104999999998, 0.2644199999999983, 0.1751100000000012, 0.1162199999999991, -0.3057600000000018, -0.6103500000000002, -0.11387999999999887, 0.0386100000000007, 0.21508500000000108, -0.5358600000000009, -1.0106849999999994, -2.3325900000000006, -4.0388399999999995, -5.658119999999999, -6.495254999999995, -6.2466300000000015, -5.4422549999999905, -4.192890000000003, -3.3579, -2.737215, -1.2949950000000001, -0.07117500000000154, 0.4290000000000014, 1.2072450000000037, 2.016690000000004, 1.2021749999999993, 1.9850999999999968, 1.062165, 1.3143000000000014, 1.4847299999999992, 1.6976700000000033, 1.4352000000000011, 1.215045000000001, 1.2234300000000002, 1.1251500000000008, 0.9459449999999994, 0.541709999999999, 0.800084999999999, 1.260284999999998, 1.0311600000000005, 0.6183449999999999, 0.6626099999999975, 0.4633200000000022, 0.3804449999999995, 0.23009999999999997, -0.2735849999999994, -0.47580000000000067, -0.7903349999999999, -1.2579450000000003, -1.1038949999999998, -0.7647900000000004, -0.9139650000000004, -1.4724449999999998, -1.576575, -1.9747649999999999, -1.6534050000000002, -0.8525400000000003, -1.41921, -0.8556599999999996, -0.5319600000000005, -0.5885100000000009, -0.2796300000000014, -0.5171400000000003, 0.07741499999999868, -0.7041449999999999, -0.6592950000000004, -0.33481499999999964, -0.08560500000000082, -0.4773600000000007, -0.19519499999999845, 0.20806500000000083, 0.3260400000000012], [0.0, 0.5226000000000011, 0.062204999999997845, 0.08833500000000205, -0.2934749999999995, -0.3459300000000003, -0.28313999999999884, 0.43796999999999975, 0.5721300000000008, 0.6318000000000012, 0.9701250000000006, 0.24160500000000185, -0.7033649999999985, -1.1602500000000022, -2.439644999999992, -3.281459999999998, -4.0279200000000035, -4.80558000000001, -5.975774999999999, -7.204860000000002, -9.971324999999997, -10.250174999999993, -11.107004999999997, -13.033215000000014, -13.06714500000001, -12.269985000000032, -10.508744999999992, -7.44704999999999, -3.9413399999999963, -2.8173600000000003, -0.3211649999999986, 2.3017800000000017, 2.900625000000001, 3.1689450000000003, 3.3263100000000003, 4.050540000000003, 4.57353, 3.3350850000000016, 2.8840500000000002, 2.8220400000000003, 2.694705, 2.1555300000000006, 2.0391150000000002, 2.1541650000000008, 1.326195, 1.7454449999999992, 1.5364050000000005, 1.1762399999999993, 1.7171700000000003, 2.504385, 1.8645900000000009, 1.3685100000000006, 0.46507500000000024, 0.6610500000000015, 0.30556499999999986, -0.4574699999999994, -1.7171699999999959, -1.6984499999999971, -1.8688799999999999, -2.8130699999999975, -2.9928599999999963, -2.8432949999999955, -4.148235000000003, -4.349085000000008, -3.8280449999999964, -3.4518899999999992, -3.7016849999999955, -3.2687849999999945, -2.3117249999999983, -1.986075, -1.352715000000003, -1.314300000000002, -0.8634599999999995, -0.16808999999999985, -1.139385000000003, -0.24706499999999898, 0.6840599999999988, 0.38766000000000034, 0.12031500000000106, -0.4477199999999999, 0.6308250000000006, 0.5746650000000006], [0.0, 0.49257000000000073, 0.7166249999999995, 0.47638500000000084, 0.2338050000000006, 0.568815000000001, 1.6319549999999996, 0.9613500000000003, 0.9898200000000009, 0.745485000000001, 1.529580000000002, 1.9716450000000005, 1.6413150000000005, 2.1176999999999975, 3.140084999999998, 3.8405249999999955, 4.961580000000003, 6.083220000000005, 6.507150000000004, 6.543614999999996, 5.975775000000005, 5.0813099999999976, 3.0977700000000032, 0.27436499999999975, -2.212470000000001, -3.3514650000000032, -3.2908199999999943, -3.1562699999999975, -2.4568049999999997, -3.2134049999999976, -1.1054550000000007, -0.2659799999999999, 0.6397950000000011, 1.5110550000000003, 1.2961649999999985, 1.5026700000000006, 1.595099999999999, 1.37241, 1.168635000000001, 0.945554999999998, 1.312934999999999, 1.0551450000000004, 1.1113049999999989, 0.7193549999999992, 0.7694699999999989, 1.463085, 1.278029999999999, 0.37088999999999983, 0.9820200000000004, 1.0179, 0.9707100000000003, 1.0284299999999997, 1.3575900000000005, 1.9158749999999998, 2.019614999999998, 2.16801, 1.642875, 1.3790399999999998, 1.456259999999999, 1.5894449999999996, 1.0810799999999996, 0.7055100000000009, 0.4921800000000003, 0.1626299999999984, -0.23926500000000053, -0.49568999999999996, -0.02788500000000077, -0.08287500000000003, -0.8104200000000003, -0.1006199999999996, -0.11661000000000002, 0.4596149999999999, 0.0407549999999996, -0.25974000000000014, 0.5194799999999996, 0.33267, 0.6477900000000002, 0.6943949999999975, 0.7261799999999993, 0.8505899999999994, 0.4171049999999996, 0.009554999999999536], [0.0, 0.8123699999999952, 0.6220500000000015, -0.20240999999999598, 0.15366000000000213, 0.6542250000000047, 0.5803199999999995, 0.8115899999999971, 1.1577149999999992, 0.7778550000000006, 0.19382999999999928, 0.9237149999999978, -0.07858499999999946, 0.05557500000000859, -0.5912399999999964, 0.14937000000000422, 0.8067150000000018, 1.5652649999999984, 1.8686849999999997, 1.5330899999999992, 1.1469900000000033, 0.045630000000001836, -1.0498799999999981, -3.418350000000003, -4.449120000000006, -4.750200000000005, -3.937830000000007, -2.9872050000000065, -1.3554450000000022, -0.4806749999999953, 0.30556499999999787, 0.7437300000000038, 1.7978999999999998, 2.1237449999999995, 2.1841950000000008, 2.29749, 2.0590049999999978, 1.99212, 1.8835049999999962, 1.8119400000000006, 0.9714900000000046, 1.0052250000000056, 1.4979899999999984, 1.4673749999999997, 1.0894649999999997, 1.1483549999999991, 0.5183100000000005, 0.5185050000000015, 0.8743799999999999, 1.3907399999999979, 1.0861499999999986, 0.9730500000000002, 0.5586750000000018, 0.1735500000000041, 0.6368700000000005, 0.6027450000000019, -0.5647199999999986, -0.7220849999999954, -0.8825699999999985, -0.8527350000000009, -0.4933500000000004, -1.0358399999999888, -1.4845350000000002, -1.4558699999999982, -1.8312450000000027, -0.660075, -0.8307000000000038, -0.3153149999999987, -0.14507999999999655, -0.43290000000000006, 0.009944999999999204, -0.37361999999999895, -1.1146199999999977, 0.015210000000004609, 0.1610700000000027, 0.33384000000000125, 0.19734000000000362, 0.1928550000000011, 0.06630000000000447, 0.6267300000000025, 0.19012500000000143, 0.15951000000000093], [0.0, -0.3862949999999984, -0.033734999999998516, -0.28255499999999856, -0.2533049999999999, -0.38414999999999844, 0.38883000000000423, -0.1382549999999989, -0.22561499999999834, -0.6376499999999992, -1.082834999999999, -0.9592049999999989, -1.483754999999999, -2.0724599999999986, -3.140084999999996, -3.1350149999999974, -3.257670000000001, -2.725709999999998, -2.8811249999999973, -3.5714249999999943, -3.8385750000000005, -3.927884999999998, -4.855889999999994, -4.970744999999998, -4.834634999999999, -3.9042899999999925, -2.373734999999999, -1.2084149999999987, -0.782534999999999, -0.27183000000000157, 0.49276500000000256, 1.451580000000001, 1.205294999999998, 1.5013049999999992, 1.4667900000000034, 1.2675000000000016, 1.1621999999999988, 0.9040200000000003, 0.8615100000000024, 0.9186450000000008, 0.7281300000000004, 0.37225500000000156, 0.6546150000000008, 0.6212700000000011, 0.751725000000002, 0.506220000000001, 0.16789500000000346, -0.5366399999999986, 0.2780700000000025, -0.32408999999999955, -0.7885799999999982, -1.488629999999999, -1.7760599999999984, -1.201394999999999, -1.2066599999999994, -1.5793049999999988, -2.1091199999999994, -1.845284999999999, -2.1953099999999988, -2.0299499999999995, -1.9367399999999992, -2.083964999999999, -1.8903299999999983, -1.9919249999999988, -1.3790399999999992, -0.9944999999999993, -0.4467449999999986, -0.1565849999999993, -0.9297599999999987, -0.5247449999999988, -0.5771999999999987, -0.17725499999999883, 0.2613000000000023, 0.14059500000000158, -0.2923049999999987, 0.02028000000000163, -0.11387999999999954, -0.09203999999999901, -0.23828999999999967, -0.32954999999999846, -0.47189999999999965, -0.4525949999999991], [0.0, -0.26169000000000153, -0.24999000000000038, -0.9088949999999998, -0.2209350000000021, 0.530790000000001, -0.18934500000000076, -0.2825550000000012, -0.1942200000000014, -0.7577700000000056, -0.3786900000000033, -0.895830000000001, -0.9843600000000001, -0.7154550000000035, -1.2025650000000017, -0.7907250000000059, -0.04036499999999821, 0.44927999999999146, 0.5713499999999994, 0.4982249999999966, 0.9149399999999965, 0.8763299999999945, -0.4366050000000081, -1.857179999999999, -2.522324999999997, -2.843489999999999, -2.171519999999999, -2.2590749999999984, -1.6420949999999963, -0.9274199999999992, -0.7291050000000006, 0.10081499999999322, 0.2488199999999936, 0.4036499999999932, 0.749579999999995, 0.7616700000000018, 0.04309499999999922, 0.5218199999999968, -0.027884999999996385, 0.35704499999999095, 0.4256849999999992, 0.11017499999999725, -0.060645000000001836, -0.372255, 0.08618999999999577, -0.1105650000000038, 0.07214999999999794, -0.05596500000000448, 0.07078499999999588, 0.007604999999999862, -0.5600399999999999, -0.48886500000000366, -0.8913449999999981, -0.3898050000000022, -0.37849500000000047, -0.5370300000000041, -0.726570000000001, -0.6614400000000047, -1.0079550000000035, -0.5409300000000021, -0.5612100000000018, -1.3314600000000008, -1.1896949999999986, -0.6936150000000012, -1.2093899999999977, -0.8521499999999955, -1.0048349999999995, -0.4401150000000058, -0.4506450000000024, -0.37869000000000286, 0.1879799999999956, 0.0813149999999978, 0.02086499999999969, 0.2858699999999943, 0.17413499999999393, 0.07994999999999663, -0.27729000000000203, -0.0547950000000017, -0.04231500000000343, 0.17549999999999555, 0.15443999999999436, -0.24375000000000568], [0.0, -0.7712250000000008, -0.6924449999999985, -0.5506799999999995, -0.5407349999999985, -0.8340149999999998, -0.43816500000000047, -0.31316999999999884, -0.7817549999999992, -1.2162150000000005, -2.0336550000000027, -2.7728999999999964, -3.363164999999999, -4.333289999999993, -5.288009999999998, -6.153615000000012, -6.352515000000008, -7.065045000000004, -7.051785000000004, -7.454460000000004, -7.2813000000000105, -7.768410000000004, -7.457579999999996, -7.046325000000004, -5.786040000000004, -3.773250000000001, -1.4591849999999988, 0.7222799999999998, 1.915484999999998, 2.7793349999999983, 3.5380799999999994, 3.58332, 3.5041500000000023, 2.8838550000000014, 2.174249999999999, 2.715374999999999, 1.839240000000001, 1.5163199999999988, 1.8626400000000012, 1.8384600000000004, 1.1454299999999997, 1.0656749999999997, 0.8778900000000004, 0.7413899999999997, 0.4204200000000002, 1.006395, -0.04153500000000032, -0.1107599999999993, 0.07878000000000024, 0.10588499999999978, -0.914355000000001, -1.2651600000000012, -2.084744999999997, -2.088059999999996, -2.4226799999999944, -2.8785899999999938, -3.260009999999997, -3.427709999999994, -3.6002849999999977, -3.321044999999992, -2.8606499999999984, -3.079244999999991, -3.350879999999995, -3.2469449999999966, -3.2313449999999952, -2.079479999999999, -1.402830000000002, -0.896415000000001, -1.1483550000000027, -0.34437000000000084, -0.5887050000000013, -0.2858700000000002, -0.42490500000000087, -0.5682300000000015, -0.3049800000000009, -0.8291400000000005, -0.4506450000000012, -0.2690999999999998, -0.7376849999999994, -0.7587449999999988, -0.32408999999999843, -0.9976200000000018], [0.0, 0.3032249999999985, -0.0015600000000075553, -0.8806200000000048, -0.789360000000003, -0.241410000000001, -0.4342650000000079, -0.939705000000008, -0.30615000000001036, -1.0467600000000061, -0.9950850000000031, -1.9482450000000018, -2.796885000000002, -3.7672050000000024, -5.276310000000002, -6.006585000000003, -5.898360000000002, -6.272370000000001, -6.697860000000002, -7.179900000000005, -7.294560000000002, -7.526025000000006, -8.060325000000002, -7.549035000000002, -6.236100000000002, -4.324905000000003, -2.422095000000007, -0.9884550000000036, -0.07371000000000105, 0.04485000000000472, 0.32701500000000294, 1.0992149999999965, 1.4227200000000062, 1.3226849999999972, 0.9047999999999989, 2.067390000000003, 1.3008450000000016, 0.7099949999999948, 0.7780499999999995, 1.3796250000000017, 1.4603549999999972, 1.1064300000000005, 0.3821999999999939, 0.07527000000000239, -0.12616500000000386, 0.3621150000000011, 0.29776499999999384, 0.6637799999999983, -0.10627500000000278, 0.8884200000000044, 0.8915400000000009, -0.3051750000000082, -0.3940950000000045, -0.9416550000000026, -2.095665000000008, -2.552939999999999, -3.0513599999999994, -3.561284999999999, -3.609060000000002, -2.954250000000003, -3.2933550000000045, -3.2282250000000006, -2.9251950000000018, -2.5948650000000058, -2.0164950000000066, -1.8632250000000017, -1.7253600000000073, -1.2232350000000074, -0.3387150000000059, -0.5151899999999943, -1.1202750000000048, -0.28138500000001, -0.6228300000000093, -0.4759950000000046, -0.8644350000000065, -0.1119299999999992, 0.16945499999999747, -0.044850000000002055, -0.2544750000000029, -0.4594199999999997, -0.33637500000000564, -0.6078150000000084], [0.0, 0.3289649999999886, 0.13981499999999247, -0.019110000000013727, -0.17901000000000167, -0.43212000000000295, -0.42900000000000915, -1.0149750000000113, -0.6680700000000028, -1.3178100000000077, -2.7635400000000114, -4.125225000000015, -4.904835000000013, -7.0541250000000115, -8.90409000000001, -10.27611000000001, -12.111450000000012, -13.390455000000006, -14.916330000000016, -15.709200000000019, -15.291510000000017, -14.63358000000001, -12.718875000000018, -9.52984500000001, -6.65515500000001, -3.3696000000000135, -0.4970550000000049, 1.5389399999999984, 2.5886250000000075, 3.334500000000009, 3.0139200000000077, 3.4903050000000118, 3.3224099999999996, 2.787915000000009, 2.8776150000000147, 2.504580000000008, 2.1843899999999934, 2.2467899999999954, 2.041260000000003, 1.8330000000000055, 1.6169400000000067, 1.3907400000000028, 1.4570400000000188, 1.7497350000000047, 1.7442750000000107, 1.373775000000018, 1.0440300000000047, 0.8347949999999891, 0.6220499999999909, 0.6766499999999933, -1.0463700000000005, -1.7980950000000169, -2.16157500000001, -2.8444650000000093, -3.810690000000014, -3.5958000000000117, -4.387890000000015, -4.42474500000001, -4.362150000000014, -4.76131500000001, -4.616820000000012, -4.319250000000008, -3.624660000000015, -3.5244300000000144, -2.5724400000000136, -2.080065000000009, -1.6688100000000103, -0.8472750000000122, -0.3970200000000004, -0.29016000000000197, -0.44713500000000916, 0.09379499999998409, -0.16516499999999734, 0.04367999999999661, -0.13162500000000854, -0.2765100000000045, -0.3344250000000111, 0.6626099999999866, 0.41398499999998695, -0.4471350000000056, -0.6610500000000012, -0.23770500000001338], [0.0, 0.05148000000000197, -0.05479500000000059, 0.056549999999998546, -0.23692500000000227, 0.14137499999999958, 0.2860649999999971, -0.3958500000000005, -0.7343700000000026, -1.290315000000001, -2.3850450000000007, -3.1884450000000006, -4.981665000000002, -5.7408, -7.086300000000005, -8.266634999999996, -10.767509999999994, -11.482185000000005, -12.10326000000001, -12.85947000000001, -12.714390000000023, -12.677145000000019, -12.624495000000012, -10.797539999999993, -8.057399999999994, -4.675514999999999, -1.9398600000000012, 0.9406799999999986, 2.799614999999989, 3.370965000000004, 3.7348350000000052, 3.5690850000000007, 3.2124300000000017, 3.082559999999995, 2.888925000000001, 2.1475349999999955, 2.007914999999998, 2.4821549999999974, 2.1202349999999917, 2.3025599999999975, 1.9847099999999953, 1.3521299999999927, 1.3507649999999929, 1.8072599999999919, 1.455284999999995, 1.700399999999994, 1.0477349999999914, 1.0325249999999957, 0.3196049999999957, -0.061035000000001505, -0.7741500000000003, -1.793415000000001, -1.703325000000001, -2.345460000000002, -3.0457050000000017, -3.4612500000000015, -4.04898, -4.150185000000002, -4.222335000000001, -4.751174999999998, -4.202640000000002, -4.552859999999999, -3.8403300000000042, -3.427710000000002, -2.9476199999999997, -2.158260000000001, -1.1674650000000004, -0.3170700000000024, -0.09282000000000146, -0.021645000000000802, -0.18232500000000118, -0.15288000000000346, 0.14859, -0.34553999999999996, 0.4254899999999995, 0.6043049999999948, 0.12382499999999941, 0.1569749999999992, -0.2123550000000003, -0.1772549999999995, 0.06551999999999825, -0.22776000000000263], [0.0, -0.6076199999999967, -0.8316749999999988, -0.3254549999999967, -0.48593999999999893, 1.0666499999999952, -0.9593999999999996, -0.5670599999999992, -1.585349999999997, -2.3027549999999977, -3.261374999999998, -4.849844999999995, -7.830809999999997, -9.095384999999997, -10.357620000000004, -11.7624, -13.613730000000004, -16.764735000000005, -17.994014999999997, -18.401565000000016, -18.8604, -17.93902500000002, -15.786224999999998, -13.680615000000007, -9.311055000000003, -4.733234999999999, -0.9067499999999957, 2.990910000000005, 3.369990000000004, 4.325879999999996, 5.222880000000002, 4.870905000000005, 5.491785000000004, 5.416905000000012, 5.267145, 4.184700000000002, 4.239300000000008, 4.637295000000003, 3.0059250000000075, 3.4413600000000004, 3.174990000000003, 3.2732699999999957, 2.5466999999999924, 2.606954999999994, 2.201160000000005, 1.5030599999999992, 0.4908150000000018, 0.21801000000000093, 0.07312500000000188, -0.587534999999997, -1.1083799999999961, -1.6147949999999973, -2.895554999999998, -3.3144149999999986, -4.943055000000001, -5.950229999999996, -5.488274999999996, -6.307665000000003, -5.797154999999997, -6.5656499999999935, -6.738614999999995, -6.352709999999994, -5.634719999999993, -4.512105000000002, -3.9920399999999967, -2.654729999999998, -2.596034999999998, -0.6479849999999976, 0.08736000000000432, -0.19519500000000045, -0.30498000000000003, -0.07741499999999713, 0.04173000000000382, -0.0875549999999996, 0.7893599999999976, 0.0789750000000029, -0.0822899999999942, -0.49744499999999614, -0.9453599999999991, -0.5976749999999982, -1.1894999999999976, -1.254434999999997], [0.0, 0.0990599999999997, 0.1439099999999982, 0.1922699999999984, -0.12772499999999853, -0.0009750000000008363, -0.18057000000000256, -0.22210500000000089, -0.27300000000000035, -0.5803200000000002, -1.3150799999999996, -1.3702650000000007, -1.8341700000000003, -2.0826000000000007, -2.237820000000001, -2.3620349999999997, -2.929095000000001, -3.149054999999999, -3.560114999999999, -3.5606999999999998, -3.3811049999999994, -2.8758600000000007, -3.063645000000002, -2.1855599999999997, -1.322295, -0.5401499999999997, 0.056744999999998935, 0.30088499999999874, 0.6729449999999977, 1.3092299999999941, 1.2255749999999983, 1.3571999999999949, 0.7082399999999986, 0.7887749999999993, 0.8242649999999956, 0.8018399999999959, 0.5151899999999996, 0.7796099999999968, 0.8946599999999951, 0.9681749999999942, 0.8849099999999956, 0.5471699999999977, 0.6770399999999994, 0.8373299999999948, 0.43816499999999836, 0.4640999999999993, 0.2581799999999994, 0.21605999999999992, 0.08560499999999882, -0.2622749999999989, -0.12577500000000086, -0.42607499999999954, -0.7088250000000013, -0.8944649999999997, -0.8866650000000007, -1.0647000000000009, -1.2567750000000006, -1.3226850000000006, -1.0594349999999995, -1.1179349999999995, -1.0652850000000003, -1.0210200000000005, -1.1456250000000003, -0.6928350000000008, -0.8334299999999996, -0.38493000000000044, -0.18174, -0.11485500000000193, -0.03822000000000014, 0.13591499999999912, 0.2809949999999981, -0.06551999999999758, 0.21020999999999979, 0.5943599999999964, 0.23984999999999945, 0.2016299999999993, 0.04992000000000041, 0.27455999999999725, 0.18895499999999976, 0.019695000000000018, 0.04289999999999927, 0.24803999999999715], [0.0, -0.2271750000000079, -0.6630000000000082, -1.5592200000000038, -1.4196000000000022, -1.2419550000000075, -1.8271500000000027, -2.0673900000000036, -2.0868900000000012, -3.261375000000001, -5.081505000000003, -7.287734999999998, -9.71802000000001, -12.449775000000002, -15.157740000000015, -18.00649500000001, -21.48198000000004, -24.83325000000009, -27.72627000000008, -28.01370000000005, -28.563600000000072, -27.326715000000068, -24.359595000000056, -19.52554500000002, -14.082120000000003, -8.17089, -2.0319000000000003, 1.556879999999996, 4.3026749999999945, 5.5838249999999965, 6.313515, 6.72574500000002, 6.756360000000012, 6.384105000000019, 5.082869999999995, 5.644664999999997, 5.017350000000008, 4.745130000000011, 3.665415000000009, 3.502785000000001, 2.4854699999999985, 2.017274999999996, 2.7602250000000073, 1.6561350000000008, 1.7429099999999904, 1.2548249999999959, 0.9313199999999977, 1.3283399999999954, 0.7762949999999949, -0.4139849999999998, -1.9449300000000016, -3.667560000000002, -4.235595000000003, -6.70449, -7.498920000000004, -8.085870000000007, -8.85924, -9.432735, -9.822345000000002, -9.503130000000002, -8.467875000000005, -8.721375000000002, -8.520914999999999, -6.721455000000004, -5.978310000000001, -4.412655000000003, -3.7233300000000025, -3.0070950000000023, -2.0983950000000027, -1.448460000000006, -0.8277750000000061, -0.5300100000000039, -0.17257500000000636, -0.695370000000008, -0.07605000000000484, -1.2218700000000018, -0.43563000000000374, -0.4522050000000055, -0.4958850000000061, -1.4630850000000066, -1.008345000000002, -0.5499000000000036], [0.0, -0.17920499999999961, -0.09086999999999978, -0.4295849999999997, -0.410865, -0.4978349999999998, -0.5651099999999996, -0.27397500000000014, -0.11934000000000033, -0.9619349999999999, -0.581685, -0.7565999999999997, -1.461329999999998, -2.06076, -1.7963399999999996, -1.2316199999999995, -0.7653750000000002, 0.18856499999999854, 0.3666000000000025, 1.1643450000000002, 1.0198500000000028, 0.8936850000000003, 0.24180000000000113, -1.2686699999999997, -1.0843949999999993, -0.841035, 0.26286000000000076, -0.03275999999999901, 0.20026500000000025, 0.19032000000000038, -0.5766149999999997, -0.2560349999999999, -0.20045999999999975, -0.5598450000000003, -0.37479000000000007, -0.2768999999999994, 0.06474000000000102, -0.04933499999999991, -0.17238000000000075, 0.4744349999999993, 0.017940000000000178, 0.3476850000000009, -0.0932099999999999, 0.9457500000000005, 0.23517000000000032, 0.5204549999999986, 0.39467999999999925, 0.22366500000000067, 0.26831999999999967, 0.19539000000000062, -0.8059349999999998, -0.882375, -0.6803549999999997, -1.0728900000000001, -1.0099049999999998, -0.6173700000000003, -0.947114999999999, -0.8338199999999999, -1.017315, -1.245855, -0.9467249999999998, -1.0204350000000004, -0.82797, -1.2234299999999998, -0.9716849999999997, -0.4130099999999998, -0.3022500000000003, -0.19187999999999983, 0.060254999999999614, -0.4003349999999996, 0.09945000000000026, -0.136305000000001, -0.08677499999999949, -0.20026500000000014, -0.12304500000000007, 0.034710000000000685, -0.1300650000000002, 0.1441050000000006, 0.03744000000000014, -0.07215000000000016, 0.13708500000000012, -0.4233450000000001], [0.0, 0.06922500000000026, 0.6312150000000002, 0.43660500000000035, -0.050504999999999634, 0.13825500000000013, 0.07059000000000054, -0.055574999999999375, -0.800279999999999, -1.5131999999999999, -2.099564999999998, -2.7826499999999976, -4.639634999999995, -6.0223799999999965, -6.718140000000004, -7.918365000000002, -8.663654999999995, -8.493030000000013, -8.387145000000006, -9.082710000000004, -8.87289, -9.204584999999996, -7.6597950000000035, -6.906315000000013, -4.850624999999996, -1.9698899999999995, 0.7554300000000008, 3.0067050000000015, 4.3239299999999945, 4.969185000000004, 5.478525000000004, 4.771259999999999, 4.572945000000002, 4.329975000000003, 4.273815, 3.502979999999998, 3.2157449999999983, 2.9756999999999993, 3.0420000000000007, 2.316794999999998, 2.160015000000003, 2.3635950000000006, 2.121990000000003, 1.6569150000000015, 1.7567549999999998, 1.8548400000000036, 1.0155600000000014, 1.7514900000000029, 1.21719, -0.17374499999999965, -0.9455549999999979, -1.552199999999999, -1.5502500000000003, -1.6198649999999977, -2.2514699999999994, -3.032054999999996, -3.284774999999994, -3.632654999999998, -3.513900000000001, -3.80952, -3.0320549999999997, -2.6913899999999993, -2.188095000000002, -2.4259950000000017, -1.9498050000000018, -1.4714700000000003, -0.8150999999999988, -0.24920999999999877, 0.11465999999999982, 0.7191600000000002, 0.8129550000000004, 0.4947150000000004, 0.7179900000000001, 0.5766150000000003, 0.7597200000000008, -0.24043499999999923, 0.5699850000000001, 0.7080450000000005, 0.6435000000000004, 0.6048900000000008, 0.027690000000000492, -0.5621849999999999], [0.0, 0.03978000000000037, -0.28977000000000164, -0.4342650000000021, -0.13513500000000045, -0.3650400000000005, -0.3334499999999996, -0.511094999999997, -0.3381299999999987, -1.3462799999999961, -2.3661300000000023, -2.9049150000000084, -3.847545000000014, -4.560855000000014, -4.540185000000026, -4.624230000000015, -3.708705000000014, -3.543930000000017, -2.531685000000015, -2.8743000000000065, -2.5357800000000066, -2.9567850000000013, -3.6420150000000127, -3.8346750000000145, -2.6950949999999927, -0.8515649999999995, 1.1380199999999974, 2.5463099999999983, 3.5454899999999974, 4.003739999999997, 4.024604999999997, 3.0956249999999974, 3.2637149999999973, 3.221789999999998, 2.606954999999997, 2.2924199999999995, 1.6621799999999978, 1.7337449999999999, 1.615574999999997, 1.2284999999999986, 1.3334099999999989, 1.102335000000001, 1.1251500000000032, 0.7296899999999966, 0.37381500000000223, 0.7181850000000045, 0.6093749999999987, 0.18232499999999696, -0.4229550000000013, -0.5894849999999976, -0.8230949999999981, -1.5130049999999993, -2.0307300000000095, -1.9864650000000164, -2.4014250000000117, -1.9909500000000109, -2.144220000000002, -2.3132850000000187, -2.3561850000000066, -2.145195000000012, -2.127060000000004, -2.0944950000000007, -2.0369700000000077, -2.030925000000001, -1.9523400000000088, -1.0524149999999932, -0.6477899999999992, -0.6072299999999964, -0.3270149999999976, -0.18876000000000248, -0.3849299999999998, -0.3194100000000035, -0.6772350000000009, -0.10412999999999784, -0.7326149999999969, -0.31141499999999356, -0.3402749999999961, -0.09788999999999692, -0.6399899999999978, -0.5354700000000059, -0.5266949999999979, -0.9227399999999988], [0.0, -0.6440850000000076, -2.156504999999992, -2.826330000000034, -1.099605000000011, -2.873909999999995, -0.6415499999999952, -2.706599999999998, -0.42178499999999275, -1.766699999999993, -1.7928299999999986, -2.6759850000000185, -3.754920000000009, -4.43819999999997, -7.713224999999969, -8.58506999999998, -9.414404999999977, -10.397399999999951, -10.084424999999989, -11.142300000000013, -11.444549999999992, -12.434955000000024, -12.531675000000014, -12.45484499999997, -10.947690000000001, -7.492680000000039, -5.814119999999992, -0.723840000000024, 3.6679499999999727, 5.589284999999993, 10.30379999999999, 7.114769999999977, 9.900344999999987, 9.291164999999983, 6.877844999999978, 6.998939999999987, 4.58444999999999, 2.4880049999999905, 0.7606949999999735, -0.17550000000000665, 0.32974499999997775, -1.6485300000000187, -0.4122300000000294, -1.1803350000000528, -0.7482150000000125, -2.2370400000000004, -2.865914999999987, -1.2801749999999927, -1.2091950000000296, -1.7397900000000242, -2.850900000000017, -4.78588500000005, -3.3793500000000094, -5.059860000000015, -3.6082800000000432, -5.75210999999997, -5.141369999999998, -6.002490000000016, -6.057674999999975, -5.638425000000016, -5.95334999999999, -5.807489999999973, -6.258525000000031, -5.358989999999977, -4.024020000000032, -4.628519999999984, -2.2300199999999677, -3.491279999999996, -0.21664500000002818, -0.8191950000000467, 0.17276999999996434, 1.1019449999999864, 1.550249999999977, 1.3809899999999864, -1.2162150000000302, -1.7146349999999764, -0.9744150000000324, -2.236260000000044, -0.07468500000003431, -1.901250000000033, 0.04133999999997329, -1.1895000000000202], [0.0, 0.17237999999999687, 0.29659500000000083, -0.7688850000000036, 0.1719900000000063, -0.5577000000000059, -0.5725200000000035, -0.6538349999999991, -0.7675200000000055, -0.4795050000000156, -1.2920700000000123, -1.7477850000000092, -2.5987650000000078, -3.264300000000005, -3.863730000000002, -4.646460000000003, -5.879250000000002, -7.435740000000003, -8.406450000000003, -8.512530000000002, -9.000615000000003, -8.570445000000003, -7.811505, -5.4752100000000015, -5.3650350000000016, -2.770365000000001, -0.8034000000000079, 0.06142499999999185, 1.1859899999999994, 1.271790000000001, 0.6682649999999999, 1.7624100000000134, 2.0001149999999974, 1.4679600000000015, 2.2302149999999976, 1.5564899999999966, 1.9063200000000196, 1.824615000000013, 1.0970699999999987, 1.3915199999999945, 0.31804500000000946, 1.1075999999999961, 1.39658999999999, 1.2727650000000121, 0.7835099999999926, 1.0442249999999929, 0.18914999999999704, 0.703364999999998, 0.2230799999999995, 0.3283799999999921, -0.43504500000000323, -0.7944300000000037, -1.1109150000000065, -1.9414200000000097, -1.656330000000005, -2.7976650000000065, -2.7545700000000064, -3.112200000000001, -3.087825000000006, -2.5609350000000077, -2.8838550000000085, -2.4796200000000095, -2.5236900000000086, -2.0289750000000044, -2.0689500000000125, -1.1155950000000043, -1.029989999999998, -0.2607149999999958, -0.9960600000000008, -0.19968000000000963, -0.2683199999999992, 0.05264999999999542, 0.10315500000000899, -0.06688499999999742, -0.23322000000000198, 0.45142499999999863, 0.11563500000000104, -0.39038999999999824, 0.12148499999999274, -0.6392099999999967, -0.7193550000000029, -0.1760849999999996], [0.0, 0.37868999999999664, -0.7928700000000015, -0.16964999999999808, -0.7497749999999992, -0.45824999999999916, -0.7566000000000002, -0.726570000000005, -0.8416199999999985, -0.6803550000000049, -1.186964999999999, -1.9928999999999983, -1.6916250000000033, -1.8068700000000057, -1.7483700000000018, -1.922700000000002, -2.505749999999997, -2.117504999999998, -2.2407450000000044, -2.0874750000000035, -2.273504999999998, -1.6924049999999986, -2.662725000000004, -2.6131950000000024, -2.2315800000000023, -1.9753499999999993, -1.1358749999999977, -0.09320999999999824, 0.7706399999999998, 1.1904749999999957, 1.5040349999999973, 2.0320949999999973, 2.5348049999999964, 1.9774949999999971, 1.6902599999999963, 1.7076149999999972, 1.5319199999999968, 1.3536899999999992, 1.063919999999999, 1.1777999999999944, 1.555709999999997, 0.39623999999999526, 1.0502699999999967, 0.34280999999999606, 0.05109000000000252, -0.6659249999999997, -0.7452899999999998, -0.9422399999999982, -0.8318700000000034, -0.5922149999999955, -1.4720550000000014, -1.0637249999999954, -1.4531399999999963, -1.615769999999999, -2.0404799999999965, -1.998555, -1.549275000000001, -2.4062999999999932, -2.079675000000003, -1.6682249999999983, -1.5627300000000077, -1.4521650000000021, -1.9441499999999912, -1.1183250000000005, -1.430129999999998, -1.0676249999999978, -1.0652850000000025, -1.0272600000000014, -0.7201350000000031, -0.2080650000000026, -0.3350100000000036, -0.09457499999999852, -0.35021999999999975, 0.007409999999997918, -0.16029000000000027, -0.6240000000000019, -0.6236100000000047, -0.5715450000000035, -0.773175000000005, -0.6208800000000037, -0.5777850000000058, -0.33910500000000443], [0.0, 0.8755500000000094, 2.3076299999999925, 2.8700099999999953, 3.6190049999999996, 3.7516049999999996, 4.6692749999999865, 5.522009999999982, 6.14756999999999, 8.132085, 11.789114999999995, 15.786224999999995, 21.088664999999992, 27.531075000000012, 34.74822000000007, 43.276155000000045, 51.68572499999994, 60.21015, 67.50880499999997, 72.45615000000004, 74.31118500000002, 73.98631499999993, 68.80243500000009, 58.63201499999992, 45.854640000000025, 31.08066000000003, 15.698474999999995, 1.365779999999985, -11.078535000000034, -20.077005, -25.61812500000009, -27.54706500000001, -27.384629999999937, -26.811525000000024, -24.88823999999994, -22.086675000000014, -20.050289999999997, -17.540639999999986, -15.723629999999986, -13.318305000000006, -11.654760000000007, -9.589905000000048, -8.61978000000001, -7.095465000000065, -6.741540000000036, -5.578950000000024, -4.906005000000032, -4.216875000000055, -2.978820000000006, -1.2208950000000005, 2.3164049999999925, 5.071754999999991, 8.115314999999988, 11.498954999999995, 14.168309999999995, 17.245604999999998, 19.66809, 21.339434999999987, 22.538294999999998, 23.54079000000001, 23.588759999999997, 23.095604999999992, 22.10870999999999, 20.067449999999994, 18.21222, 15.699059999999996, 12.498719999999993, 9.895274999999994, 7.012199999999992, 3.9370499999999975, 3.4399950000000032, 2.7808949999999832, 2.340389999999994, 2.2378199999999904, 2.0465249999999955, 1.8528899999999737, 2.4357449999999936, 2.5999349999999897, 2.370225000000005, 3.1180499999999736, 3.384615000000002, 4.2648449999999904], [0.0, 0.9131850000000128, 1.7659199999999977, 2.284815000000009, 1.7511000000000116, 1.6315650000000073, 2.464800000000002, 3.641040000000001, 4.718805000000006, 7.123350000000012, 10.477350000000012, 15.24139500000001, 21.063120000000012, 27.21985500000001, 34.88160000000013, 43.95534000000007, 53.275365000000015, 62.275785000000035, 69.87396000000001, 75.30588000000004, 77.77243500000004, 76.1319, 70.11342000000008, 59.20297499999997, 44.92741500000006, 29.220165000000044, 13.30173000000001, -1.3480349999999746, -13.685100000000004, -22.537709999999947, -28.305224999999922, -30.005429999999926, -30.352724999999957, -26.510444999999912, -25.48825499999986, -22.795694999999917, -17.604209999999917, -13.813994999999947, -11.39696999999997, -8.975459999999932, -6.50344499999998, -4.896644999999996, -3.8563199999999824, -9.437415000000014, -9.027135000000014, -8.245575000000011, -7.2003750000000135, -4.152330000000003, -2.490344999999996, -0.47774999999999146, 2.0599799999999977, 5.5717350000000065, 8.91325500000001, 12.268620000000013, 15.445560000000004, 18.47703000000001, 21.182655000000025, 23.294504999999987, 24.221925000000006, 24.81414000000002, 25.30846500000003, 24.881415000000004, 23.539425000000023, 19.214714999999998, 16.772535000000005, 14.081730000000016, 10.82250000000001, 7.419945000000009, 4.554030000000001, 2.640884999999992, 1.0904400000000063, 0.5508750000000102, 0.07975500000000757, -0.20123999999998787, -0.024960000000000093, 0.16731000000000407, -0.04640999999999451, 0.043875000000030084, 0.1464450000000017, 0.6356999999999982, 1.5258750000000152, 2.317379999999998], [0.0, -0.41145000000002163, -0.17316000000000287, -0.14976000000000766, -0.13260000000000893, 0.0544050000000027, -0.6298500000000189, -1.009515000000004, -0.5331299999999963, -0.7513350000000294, -0.8817900000000058, -1.9404450000000182, -2.488395000000036, -2.34507000000003, -2.7298050000000345, -3.5554350000000365, -3.4555950000000273, -4.182165000000023, -3.992040000000028, -4.012710000000034, -3.952650000000016, -3.396900000000045, -3.6295350000000273, -2.221050000000046, -2.626455000000025, -1.3226850000000283, -0.8449350000000369, 0.21410999999997848, -0.7961850000000243, -1.496820000000005, -1.2290850000000244, -1.4242800000000102, -1.2684749999999898, -1.7380350000000107, -1.2242100000000011, -0.883545000000014, -0.2716349999999963, -0.252135000000024, 0.19636499999998414, 0.7755149999999826, 1.2366899999999887, 1.1083799999999897, 1.4389049999999877, 1.6163550000000004, 1.4849249999999916, 0.8862750000000084, 0.6202950000000023, 0.6046950000000155, 0.19948499999998504, -0.11153999999999797, -0.08599500000003069, -0.7464600000000239, -0.5565300000000182, -1.3207350000000204, -0.9342450000000202, -1.4258400000000062, -1.7752800000000324, -1.7031300000000336, -1.1434800000000411, -1.492530000000027, -1.1729250000000384, -1.3663650000000356, -1.0122450000000107, -1.2413700000000158, -0.931125000000014, -0.8238750000000401, -0.9730500000000291, -0.415350000000025, -0.9227400000000152, -1.2622350000000093, -1.515150000000018, -1.1881350000000221, -0.6713850000000026, -0.8412299999999906, -0.7741500000000059, -0.628680000000033, -0.29016000000001796, -0.15093000000002377, -0.46176000000000883, -0.4533750000000154, -0.33657000000002313, -0.5818799999999982], [0.0, 0.16438499999999998, -0.5309850000000005, -0.7335900000000003, -0.10179000000000041, -0.3155099999999996, -0.4869149999999999, -0.846299999999999, -0.9085049999999992, -1.1635650000000015, -2.029949999999998, -2.1395399999999998, -2.9509349999999976, -4.417920000000003, -5.245304999999998, -5.769659999999998, -6.000149999999997, -5.838105, -5.760690000000004, -5.728320000000005, -5.669820000000003, -5.317455000000001, -5.374784999999994, -5.391164999999992, -4.511129999999998, -3.185324999999998, -1.2497549999999995, 1.0576800000000006, 1.5884700000000007, 2.8111199999999954, 2.633280000000001, 2.778555, 2.909984999999995, 2.331419999999999, 2.3189399999999982, 2.0256599999999985, 1.5984150000000013, 1.5650700000000024, 0.8652149999999996, 1.7971199999999974, 1.2749099999999987, 1.2140699999999993, 1.1549849999999997, 1.6463849999999987, 1.2511199999999996, 0.5926049999999994, 1.0350599999999985, 0.589095000000001, 0.43738499999999847, -0.13689, -0.47814, -1.0974599999999994, -1.5196350000000018, -1.882724999999999, -2.409809999999997, -2.721615000000004, -2.7079649999999975, -2.8259399999999966, -2.6326949999999982, -2.8813199999999997, -3.1248749999999994, -2.7742649999999984, -2.0662200000000013, -2.223974999999999, -1.7704049999999996, -1.8618599999999992, -1.5722850000000006, -1.069379999999999, -0.37167000000000017, -1.003859999999998, -0.7712250000000005, -0.47677500000000006, -0.55497, -0.6083999999999999, -0.5383950000000006, -0.26734500000000005, 0.06317999999999982, -0.3492449999999999, 0.1493699999999997, -0.4445999999999999, -0.6396000000000004, -1.206270000000001], [0.0, -0.06552000000000124, 0.22522499999999945, 0.5982599999999998, 0.7649849999999995, 0.07800000000000018, 0.18017999999999934, 0.03295500000000029, -0.08112000000000041, 0.06318000000000024, 0.925665, 0.39799500000000027, 0.07273499999999988, 0.32428500000000005, 0.3576299999999994, 0.5202599999999991, 0.5286450000000003, 0.3482699999999991, -1.549275000000001, -1.278029999999999, -1.369289999999999, -1.7462249999999986, -2.6096849999999945, -2.11965, -2.1329099999999985, -2.3932349999999976, -1.482585000000002, -1.160054999999999, -1.1306100000000001, -2.521935000000002, -2.0406750000000047, -3.9175500000000074, -3.2568899999999985, -2.4062999999999968, -0.6384300000000016, -0.5883150000000001, 0.1815449999999995, -0.6206850000000019, 0.038414999999999866, -1.3831350000000024, 0.4243199999999994, 1.2066599999999998, 0.042119999999998825, 0.521234999999999, 0.3827849999999997, 0.5939699999999992, 0.6043049999999992, 0.45688500000000026, 0.2642249999999997, 0.1899299999999995, 0.7661549999999998, 0.4939349999999999, -0.10998000000000097, 0.8517599999999999, 0.42217500000000024, -0.5565300000000017, 0.004679999999999462, -0.83694, -0.22581000000000118, -0.12090000000000067, 0.33286500000000063, -0.03783000000000003, 0.33169499999999963, 0.2870400000000004, -0.5945549999999995, 0.3201899999999994, 0.26090999999999964, -0.05538000000000076, 0.5676450000000007, -0.2049450000000006, -1.0089300000000025, -0.20318999999999998, 1.1508900000000004, 1.18326, 0.9143549999999995, 0.24959999999999982, -0.04270500000000055, 0.2546700000000003, 0.6959549999999999, 0.6879599999999996, 0.557895, 1.4080949999999999], [0.0, -0.48106500000000013, -0.9090900000000004, -0.3198000000000003, -0.3636750000000004, 0.13318499999999878, -0.2570100000000001, -0.24492000000000053, -0.3055650000000002, -0.7655700000000006, -1.9743749999999989, -2.247374999999999, -3.1439849999999985, -3.6535199999999954, -3.80094, -4.5027449999999964, -4.982639999999998, -5.368934999999997, -6.510269999999998, -5.796375000000005, -5.226780000000002, -5.108024999999998, -5.102955000000006, -4.022264999999997, -2.5818000000000003, -1.520805000000002, -0.04816500000000168, 1.211534999999995, 1.5582449999999999, 1.8681000000000005, 1.775474999999998, 1.886624999999999, 2.1030749999999996, 1.6875299999999993, 1.0237499999999982, 1.345694999999998, 1.0551450000000007, 1.0325249999999995, 0.6879599999999995, 0.6316049999999989, 0.9326850000000007, 0.6425250000000005, 0.59202, 0.8685299999999994, 0.6688499999999973, 0.6197100000000011, 0.9818249999999977, 0.06922499999999954, 0.32974499999999873, -0.2973750000000012, -1.3876200000000005, -1.3377000000000008, -1.8827249999999998, -1.895790000000001, -2.0960550000000007, -2.0841600000000007, -1.7811300000000012, -2.352285000000002, -2.4205350000000014, -2.3015850000000038, -2.2206599999999996, -2.1375899999999985, -2.33727, -2.07831, -1.6229849999999995, -1.3737750000000006, -1.2010050000000003, -0.7564050000000008, -0.47814000000000023, -0.16828499999999963, -0.017745000000001898, -0.049919999999999964, -0.24862500000000076, -0.49783500000000036, -0.042899999999999716, -0.43543500000000024, -0.5809050000000002, -0.13123500000000038, -0.061620000000000896, -0.2517449999999997, -0.3051750000000002, -0.5409300000000004], [0.0, 0.016379999999998618, -0.33111000000000124, 0.07487999999999917, 0.07370999999999961, 0.07975499999999924, 0.07663499999999923, 0.05342999999999887, -0.29152500000000037, -0.3669900000000005, -1.088295, -1.123005, -1.3741650000000027, -1.4535299999999949, -1.728089999999999, -1.527434999999997, -0.8113949999999998, 0.04679999999999962, 0.7148699999999991, 1.076789999999999, 1.6030949999999988, 1.3234649999999992, 0.9083099999999986, 0.4761899999999991, -0.4237349999999992, -0.626144999999999, 0.021839999999999304, 0.6382349999999993, 0.6271199999999986, 0.5173349999999984, 0.36679499999999904, 0.1983149999999989, 0.553604999999999, 0.5892899999999991, 0.2926949999999988, -0.08931000000000111, 0.007994999999999197, -0.25701000000000096, -0.15795000000000015, 0.2774849999999992, 0.24413999999999947, 0.012674999999998993, 0.13182000000000027, 0.17627999999999955, 0.12070499999999851, 0.026129999999999765, -0.10042499999999921, -0.1006200000000006, -0.6009899999999991, -0.9367799999999996, -0.5196750000000002, -0.7478249999999999, -0.778635000000001, -0.6230249999999989, -1.0399350000000016, -0.7634249999999995, -0.4982250000000016, -0.7922849999999998, -0.2745600000000007, -1.1019449999999988, -0.7556249999999997, -0.5844149999999996, -0.3420299999999993, -0.5547750000000017, -0.5064150000000017, -0.6386249999999992, -0.5253300000000002, -0.0721500000000006, -0.323309999999997, -0.04933500000000002, -0.02301000000000153, 0.226395, 0.44206499999999943, 0.1899299999999986, 0.09749999999999881, -0.47424000000000255, -0.25155000000000094, -0.05596500000000115, 0.41573999999999856, 0.1836899999999989, -0.29874000000000167, -0.11719500000000016], [0.0, 0.30907499999999555, -0.05811000000000277, -0.2679300000000009, -0.09594000000000191, 0.7047299999999983, -0.0971100000000007, -1.0892700000000002, -0.7413900000000024, -1.154205000000001, -1.106430000000001, -2.571465000000001, -3.0538950000000016, -3.7709100000000007, -4.84614, -5.827575000000003, -6.777810000000001, -7.95873000000001, -9.010755000000003, -8.503754999999998, -9.848475000000004, -9.042540000000002, -7.799610000000007, -6.754214999999993, -4.953195000000003, -3.408015000000001, -1.41414, -0.2146950000000012, 1.0223850000000003, 0.4960800000000001, 1.0841999999999996, 0.7105799999999989, 0.019889999999997077, 0.7269600000000005, 1.5013049999999923, 0.9016800000000007, 1.245855000000001, 1.6132350000000013, 1.6534049999999985, 1.460745000000001, 1.077179999999998, 0.8702850000000004, 0.9159149999999969, 1.2674999999999987, 1.0100999999999996, 0.2977650000000023, 0.8654099999999998, 0.5136299999999996, 0.9502349999999997, 0.7603049999999989, 0.02769000000000066, -0.39994499999999844, -0.8944650000000014, -1.3199550000000007, -1.0631400000000015, -1.2444900000000014, -2.3686650000000014, -2.732145000000001, -3.0891900000000017, -2.7713400000000012, -2.8321800000000006, -2.912130000000001, -2.8885350000000005, -2.5566450000000005, -1.9605300000000012, -1.164345, -0.9020700000000013, -0.2804100000000018, -1.4168700000000007, -0.12538500000000052, -0.1343550000000009, -0.5265000000000017, -1.0295999999999998, -0.2191800000000037, 0.1756949999999975, -0.6201000000000001, 0.9063600000000016, -0.3535350000000008, -0.7523100000000014, -0.21801000000000004, -0.5760299999999985, 0.28255500000000255], [0.0, -0.03588000000000502, -0.5235750000000006, -0.5202599999999986, -0.42198000000000047, -0.26403, -0.41476499999999694, -1.4018549999999945, -1.2119249999999968, -2.57751, -3.578249999999999, -5.517134999999999, -6.136454999999996, -8.331959999999993, -9.943829999999993, -12.766845000000012, -15.27825, -17.12919000000002, -18.06168000000002, -18.599100000000014, -19.190535000000025, -17.95228500000003, -15.08013, -12.660375000000005, -8.976434999999993, -4.712954999999999, -0.8293350000000026, 3.0347849999999963, 4.387695000000022, 6.265935000000015, 5.263245000000005, 5.344365000000014, 5.923320000000006, 5.051085000000008, 4.4132400000000125, 4.371900000000011, 3.9631800000000124, 3.7311300000000043, 2.1826350000000025, 3.5191650000000014, 2.327129999999998, 1.7559750000000087, 1.8739500000000082, 1.3856700000000015, 1.185990000000007, 2.0322899999999975, 1.6810950000000005, 0.7844849999999997, 1.0309650000000006, -0.1864200000000018, -1.2591149999999987, -2.0196149999999964, -3.9177449999999983, -4.720559999999996, -4.965674999999998, -5.881980000000002, -6.444359999999996, -6.49038, -6.319169999999996, -5.886854999999997, -6.0079499999999975, -5.96154, -5.540729999999997, -4.171829999999998, -3.530084999999998, -3.783974999999998, -2.925779999999998, -1.957799999999998, -1.229864999999998, -1.5701399999999985, -1.1516700000000002, -0.3956549999999939, 0.2304899999999983, -0.6329700000000003, -1.1075999999999997, -0.32194499999999726, -0.6669000000000049, -0.012090000000005485, -0.5943600000000013, -1.069380000000001, -0.5383950000000022, -0.5146050000000022], [0.0, -0.6224400000000143, -1.1670750000000085, -1.2456600000000027, -0.8232899999999992, -0.8991450000000007, -1.015170000000012, -1.4476800000000036, -2.1026850000000117, -3.8691900000000095, -5.233020000000009, -7.055490000000006, -9.759165000000005, -11.931075000000009, -14.881035000000008, -18.87697499999999, -21.654945000000005, -23.208315000000006, -26.164515000000023, -27.63676500000006, -27.45717000000004, -26.650455000000022, -23.668905000000013, -19.22368500000001, -13.859430000000001, -8.424390000000006, -2.308800000000007, 1.9872449999999908, 5.521424999999997, 5.756789999999995, 7.141095000000028, 6.97008000000001, 6.50169000000003, 5.900699999999993, 5.105099999999995, 4.410509999999984, 4.010564999999993, 4.378529999999998, 2.966730000000018, 3.2307599999999876, 3.169530000000016, 2.167620000000003, 2.7896699999999974, 1.8936450000000047, 2.0923499999999926, 1.9164599999999865, 0.40852499999999736, 1.042469999999998, -0.6177600000000014, -0.3482700000000065, -1.789905000000009, -3.575910000000011, -4.963920000000009, -5.923515000000004, -6.977880000000006, -8.417175000000006, -9.286290000000006, -9.874020000000005, -10.718955000000006, -9.458670000000005, -9.708855000000007, -8.377785000000006, -8.074560000000007, -7.330830000000007, -5.7037500000000065, -4.890405000000005, -3.7399050000000056, -2.17444500000001, -0.5385900000000072, -0.9779250000000062, -0.6965400000000086, -0.643500000000004, -0.43231500000000445, -1.0477350000000065, -0.37713000000000196, -0.5161650000000098, -0.8537100000000057, -0.514410000000014, -0.24394500000000807, -0.16477500000002365, -0.6329700000000003, -1.8378750000000155], [0.0, -0.33130500000000307, -0.09983999999999815, -0.08482500000000104, 0.14897999999999945, -0.13143000000000282, 0.17023500000000014, 0.03743999999999903, -0.2630549999999985, -1.0582650000000005, -0.9451649999999996, -1.4763450000000002, -2.03268, -1.90125, -2.5075050000000014, -2.5051650000000003, -2.488395, -1.9927050000000004, -1.3805999999999996, -0.9654449999999994, -1.0231649999999997, -0.33891000000000115, -0.8076900000000015, -0.7353450000000009, -0.32604000000000055, 0.2620800000000001, 1.2528749999999964, 1.4077049999999929, 1.951755, 1.5338699999999963, 1.8597149999999902, 0.9826050000000008, 0.8973899999999988, 0.8728199999999999, 0.6458399999999953, 0.5832449999999993, 0.45415500000000053, 0.06220500000000073, 0.24452999999999814, 0.3527549999999964, 0.011114999999999098, -0.328770000000002, 0.4069649999999976, 0.28352999999999984, 0.24550500000000097, 0.23185500000000347, 0.23575499999999816, -0.19909499999999936, -0.2613000000000003, -0.5666699999999999, -0.4447950000000014, -0.8127599999999999, -1.2483899999999999, -1.3472549999999999, -1.201005, -1.449435, -1.0978500000000007, -0.7421700000000004, -1.0822500000000008, -0.8915400000000007, -1.0748400000000005, -1.1719500000000003, -0.573105000000001, -0.9517950000000004, -0.7790249999999999, -0.3605550000000015, -0.06942000000000292, 0.2160599999999986, 0.22736999999999896, 0.26851500000000006, -0.1298700000000017, 0.49003499999999844, 0.43133999999999917, 0.220545, 0.15424499999999952, 0.16614000000000062, 0.40521000000000074, 0.12089999999999734, 0.5157750000000001, 0.13045499999999843, -0.1187549999999995, -0.08541000000000021], [0.0, 0.29815500000000217, -0.11719499999999883, 0.6224400000000001, 0.4344600000000032, 0.6624150000000011, 0.3572399999999929, 0.05479499999999682, 0.2283450000000018, 0.1376699999999973, 0.3075150000000013, 0.775710000000009, 1.0596300000000118, 1.5578550000000098, 2.336685000000009, 3.2853600000000087, 4.55442000000002, 5.13220500000002, 5.318625000000013, 5.761080000000032, 5.832645000000028, 5.873790000000021, 6.02862000000002, 5.302245000000028, 4.1065050000000145, 2.707380000000012, 1.9414200000000097, 0.6965400000000059, -0.5013449999999962, -1.9168499999999948, -2.1565049999999912, -2.930849999999996, -2.3672999999999957, -2.4872249999999934, -1.9628699999999943, -2.0755799999999924, -1.4139449999999933, -1.1524499999999978, -0.8330399999999969, -0.733004999999995, -0.9911849999999971, -0.6910799999999955, -0.30380999999999725, -0.14469000000000065, -0.25564499999999457, -0.31726499999999813, -0.43563000000000285, -0.5692050000000002, 0.4941299999999975, 0.25954500000000724, 0.1290900000000006, 0.7470450000000044, 1.1516700000000126, 0.6037200000000036, 0.9783150000000127, 1.408875000000008, 1.8659550000000094, 1.786395000000014, 1.8994950000000062, 2.1258900000000134, 1.7464200000000156, 1.6569150000000104, 2.3388300000000086, 1.8099900000000018, 1.6750500000000086, 1.9734000000000211, 1.629420000000013, 1.5465450000000116, 0.9402900000000081, 0.8609250000000044, 0.8279700000000068, 1.1684400000000004, 0.5582849999999997, 0.68133, 0.7640100000000043, 0.6889349999999981, 0.9984000000000082, 0.7663499999999992, 0.6275100000000009, 0.500370000000002, 0.8464950000000098, 0.8180250000000013], [0.0, -0.33345, -0.0914550000000025, 0.12421499999999686, 0.29542500000000516, 0.19480500000001122, 0.07078499999999543, -0.09691499999999298, -0.5861699999999983, -1.6637399999999989, -1.8554249999999977, -3.2687849999999976, -3.873674999999996, -5.6407649999999965, -6.693959999999997, -8.096399999999996, -9.114104999999997, -9.749024999999996, -10.258754999999994, -10.108604999999997, -10.020269999999993, -9.413820000000001, -8.521499999999994, -6.004049999999997, -3.7163099999999956, -0.882375000000005, 0.8737950000000065, 2.743455000000017, 3.46456500000001, 4.044300000000033, 3.551925000000012, 3.7510200000000298, 3.0741750000000136, 3.2609850000000202, 2.9932500000000166, 1.8796050000000157, 2.173860000000018, 1.7035200000000135, 1.1489400000000032, 1.3029900000000048, 0.9205950000000085, 0.8868600000000004, 1.2538500000000088, 1.0024950000000112, 0.6232200000000097, 0.7228650000000068, 1.1360700000000117, 0.3545100000000021, -0.10315499999999744, -0.17998500000000384, -0.3496349999999966, -0.8250450000000011, -1.5949050000000011, -2.4296999999999986, -2.6071499999999976, -3.3473699999999953, -3.3873449999999963, -3.3200699999999963, -3.0698849999999966, -3.2746349999999955, -2.9690699999999977, -3.092309999999996, -2.1594299999999973, -2.105610000000001, -1.7343299999999955, -1.5048149999999976, -0.3291599999999981, -0.05342999999999609, -0.4227599999999958, -0.5440499999999977, 0.4726800000000084, 0.21040499999999884, 0.3911699999999998, 0.11270999999999987, 0.19753500000000024, -0.3094649999999959, -0.2770949999999983, -0.015404999999999447, 0.3738149999999987, -0.20591999999999722, 0.048165000000004454, -0.05811000000000455], [0.0, 0.07761000000000307, -0.20299499999999782, -0.116999999999996, 0.4769699999999979, 0.44772000000000567, 0.2692950000000027, 0.31980000000000075, -0.35353499999999727, -0.888224999999998, -1.6237649999999941, -2.4965849999999943, -4.075304999999994, -4.605509999999993, -5.437769999999995, -6.264569999999997, -7.112819999999997, -8.293349999999993, -8.519159999999989, -8.043749999999992, -7.847969999999995, -7.968089999999997, -6.259109999999994, -4.396664999999995, -2.859089999999995, -1.0110749999999977, 0.6895199999999986, 1.9004700000000017, 1.6771950000000042, 1.7210700000000068, 2.065830000000011, 1.620060000000008, 1.2598949999999998, 0.7944299999999962, 1.169415000000003, 1.479660000000003, 1.1633699999999911, 1.4045850000000049, 1.396395000000004, 1.2634050000000019, 0.7179899999999941, 0.975389999999996, 0.9106499999999964, 0.9038249999999999, 1.1237849999999976, 1.194375000000003, 0.9685650000000021, 0.014235000000000664, 0.2219100000000016, 0.1729650000000027, -0.441479999999995, -0.8117849999999951, -1.1270999999999942, -1.4478749999999956, -2.192384999999995, -2.465189999999995, -2.5870649999999937, -2.8729349999999942, -2.994029999999994, -2.5318799999999952, -2.810924999999995, -2.6477099999999942, -2.2692149999999938, -1.9065149999999944, -1.9718399999999956, -1.2647699999999948, -0.43075499999999645, -0.318044999999993, -0.045044999999998225, 0.18798000000000448, 0.01637999999999673, 0.21001500000000162, 0.011504999999997878, -0.24355499999999886, -0.29932499999999695, 0.028860000000002106, 0.2741700000000016, -0.14039999999999697, -0.03256500000000351, 0.22522500000000267, 0.08969999999999967, 0.4399200000000012], [0.0, 0.43290000000000717, 0.03139499999999895, -0.06005999999999467, -0.13922999999999863, 0.08443500000001336, -0.1891499999999917, -0.1669199999999984, -0.6895199999999972, -1.587105000000002, -3.0741750000000017, -4.526340000000001, -5.828939999999998, -7.433009999999999, -9.630465000000001, -11.071904999999997, -12.773475000000005, -14.591849999999997, -16.53171, -17.033055000000015, -16.639545000000005, -15.945540000000008, -14.219789999999985, -11.603670000000001, -8.600864999999999, -5.144489999999999, -0.7603049999999989, 1.7245799999999978, 3.4910850000000124, 3.6055500000000205, 4.5394050000000234, 4.09948500000001, 4.361370000000006, 4.345380000000015, 3.798405000000029, 3.2563050000000153, 2.9540550000000234, 3.2586450000000244, 2.699190000000023, 2.3717850000000205, 2.2924199999999946, 2.347605000000014, 2.0127900000000185, 1.9591650000000236, 1.7448600000000223, 1.6401450000000164, 0.738270000000008, 1.0177050000000056, 0.8578050000000141, -0.09496499999999308, -0.826800000000004, -1.8177900000000085, -2.235870000000004, -3.5530949999999986, -3.8976599999999966, -4.784324999999999, -5.251934999999999, -5.37186, -5.373029999999998, -5.52201, -5.3001000000000005, -4.829369999999999, -5.6417399999999995, -4.60824, -3.4630049999999963, -2.8237950000000027, -2.3111400000000044, -1.3392600000000003, -0.2542799999999943, -0.719355000000002, -0.2899649999999987, 0.21216000000000346, 0.0009750000000057213, -0.5534100000000013, -0.28391999999997974, 0.43095000000000283, -0.4500599999999917, 0.33345000000000535, -0.01774499999999879, -0.26344499999998927, -0.46546500000000357, -0.3118049999999988], [0.0, -0.36133499999999197, -0.21332999999999513, -0.22327499999999612, -0.14956499999999107, 0.22717500000000213, -0.06122999999999745, -0.8578049999999919, -1.0629449999999911, -1.4956499999999955, -2.4144899999999945, -2.751254999999994, -4.800119999999995, -5.430164999999992, -6.447284999999994, -7.948784999999991, -9.072569999999999, -10.396425000000008, -10.713105000000006, -11.083214999999992, -10.844924999999998, -10.48612499999999, -9.378719999999998, -8.260394999999997, -6.177209999999993, -2.848559999999994, -0.21293999999999347, 2.2089600000000065, 3.2752199999999894, 3.4401900000000065, 3.3226049999999985, 3.8982450000000037, 3.897855000000007, 3.284580000000018, 2.972580000000007, 2.581604999999996, 2.822040000000004, 2.0905950000000013, 1.9638450000000098, 2.0802600000000018, 1.3848900000000084, 1.2407850000000007, 1.1079900000000027, 1.4246700000000034, 1.4291550000000042, 1.5730650000000121, 0.9650549999999987, 0.5198700000000032, 0.26325000000000687, -0.1963649999999939, -0.7640099999999861, -0.7402199999999937, -1.9067099999999937, -2.364374999999993, -2.867279999999996, -3.815564999999995, -3.8670449999999943, -4.109624999999995, -3.9893099999999944, -3.8898599999999943, -4.004519999999995, -3.6422099999999946, -3.9614249999999953, -3.0476549999999945, -2.646149999999995, -2.3593049999999964, -1.0533899999999936, -0.7690799999999958, -0.38531999999999655, -0.30166499999999097, -0.33013499999999274, -0.254864999999993, -0.7780499999999955, -0.6331649999999978, -0.1680899999999954, -0.9937199999999957, -0.6263399999999923, -0.2921099999999939, -0.09086999999998957, -0.14702999999999777, -0.6902999999999935, -0.5372249999999963], [0.0, -0.19129499999999888, -0.22190999999999939, 0.05811000000000455, 0.09944999999999915, -0.01871999999999785, -0.0035099999999967935, -0.2299049999999987, -0.40013999999999905, -0.2788500000000025, -0.6462299999999974, -1.2651599999999954, -1.4143349999999923, -2.066414999999991, -2.4570000000000047, -1.791269999999992, -1.0360349999999956, -1.007369999999995, -0.5241599999999984, -0.05362500000000159, -0.5126549999999983, -0.6990749999999948, -1.423889999999996, -2.200184999999998, -1.523729999999992, -1.0900499999999935, 0.05304000000000153, 0.08658000000000321, 0.12148499999999918, 0.12811500000000087, 0.10569000000000406, 0.3868800000000001, 0.2847000000000013, 0.14059499999999914, 0.3287700000000018, 0.46663500000000124, 0.6551999999999996, 0.634139999999999, 0.6312150000000023, 0.38258999999999843, -0.056354999999999045, 0.2796300000000016, 0.1638000000000006, 0.060645000000001836, 0.14390999999999887, 0.190124999999999, -0.47014500000000137, -0.1842750000000004, 0.012480000000003155, -0.8899799999999973, -0.5097300000000007, -0.8223149999999975, -0.7406099999999953, -0.6922499999999965, -0.6774299999999984, -0.9085049999999986, -1.3203449999999974, -0.9200099999999929, -1.200029999999995, -1.0789349999999964, -1.136654999999998, -0.9309299999999991, -1.3098149999999982, -0.6746999999999979, -0.8946599999999942, -0.8640449999999995, -0.35002500000000003, -0.2554499999999984, -0.5276699999999996, -1.138214999999998, -0.4956900000000011, -0.2710499999999949, -0.6762599999999988, -0.24706500000000142, -0.42470999999999925, -0.0120900000000006, -0.01540499999999767, -0.3166799999999994, -0.015404999999999447, -0.08287500000000048, -0.11875500000000239, -0.19578000000000007], [0.0, 0.2548650000000008, 0.11758499999999761, -0.15287999999999657, 0.30790499999999854, 0.33384000000000014, -0.38551499999999894, -0.7887749999999945, -0.5836349999999961, -1.2052949999999911, -1.650869999999998, -1.9437599999999975, -3.063255000000001, -3.8264850000000004, -4.5665100000000045, -5.369910000000008, -6.271395000000011, -6.009119999999999, -6.602115000000026, -6.783660000000021, -6.174870000000016, -5.673525000000009, -5.627115000000009, -4.7841299999999976, -3.3594600000000026, -1.367729999999992, 0.9198149999999994, 1.6479449999999995, 2.3581349999999994, 2.2007699999999994, 1.9330349999999992, 2.2296299999999993, 2.24484, 2.0141549999999993, 1.6081649999999994, 1.3458899999999994, 1.3534949999999997, 1.3090349999999997, 0.80769, 0.7729800000000007, 1.1898899999999992, 1.1003849999999988, 0.5658899999999991, 0.7176000000000011, 0.6721649999999983, 0.5961150000000015, 0.7121399999999998, 0.049725000000002684, 0.0011700000000014477, -0.007604999999999196, -0.3178499999999964, -0.9278099999999951, -1.3141049999999947, -1.3566149999999957, -1.4607449999999926, -1.9897799999999974, -2.0603699999999936, -2.2220249999999946, -2.3674949999999995, -2.780894999999998, -2.186144999999988, -2.3981099999999924, -2.149679999999997, -1.9515599999999935, -1.1641499999999918, -0.5571150000000014, -0.5538000000000016, -0.2139149999999974, -0.11621999999999888, -0.09866999999999848, -0.29093999999999776, -0.1571699999999967, -0.009359999999999591, 0.25428000000000117, 0.12850500000000187, 0.15483000000000047, 0.12343500000000307, -0.04913999999999885, 0.20904000000000256, 0.11387999999999998, -0.12499499999999797, -0.07760999999999729], [0.0, 0.08755500000000538, -0.6015750000000004, -0.674505000000007, -0.5879250000000003, -0.47170499999999116, -0.9270299999999922, -1.4063399999999984, -1.696110000000001, -3.343860000000001, -6.046170000000004, -7.2906600000000035, -9.684675000000006, -12.324974999999998, -14.835405000000009, -18.804240000000014, -20.919795000000008, -23.31537000000003, -24.798345000000015, -26.348985000000035, -25.864020000000018, -24.78099000000002, -22.714575000000018, -18.876975000000023, -13.560105000000004, -8.622315000000004, -2.0174700000000074, 1.0524149999999945, 4.411484999999997, 4.850039999999996, 5.759910000000001, 6.504809999999994, 7.030530000000033, 6.241170000000023, 6.326579999999984, 6.229860000000022, 4.9346699999999935, 5.704920000000003, 4.951245000000002, 3.886544999999984, 4.291755000000011, 2.965950000000003, 3.3327449999999796, 3.348345, 2.2405499999999954, 2.32147500000001, 2.1091199999999954, 1.1140350000000119, 1.0465649999999957, -0.5727150000000041, -1.4962350000000049, -2.9831099999999964, -3.921644999999997, -5.046210000000004, -5.876910000000002, -8.101860000000004, -8.224710000000004, -8.053305000000005, -9.351810000000004, -8.716500000000003, -8.629335000000005, -8.214180000000004, -7.926555000000003, -6.6430650000000036, -6.5233350000000065, -5.202990000000003, -3.3998250000000096, -2.5084800000000147, -2.1884850000000027, -1.7830800000000027, -0.8656050000000128, -0.8856899999999959, -0.795599999999987, -0.17160000000000508, -1.5219750000000039, 0.06298499999999407, -1.914900000000002, -0.8892000000000051, -0.8956350000000137, -0.8149049999999933, -1.4449500000000128, -1.1904749999999975], [0.0, 0.28762499999999847, -0.3537300000000041, -0.38161500000000625, -0.3435900000000025, -0.7433400000000057, -1.2875850000000018, -0.8240700000000043, -2.7682200000000003, -3.8666550000000037, -6.0699600000000045, -7.548255000000004, -9.982244999999995, -12.66719999999999, -15.274935000000017, -17.632875000000027, -19.39782, -20.119515000000003, -22.176570000000066, -22.14498000000004, -21.600540000000034, -21.176610000000036, -19.307730000000003, -17.247750000000014, -12.916800000000013, -6.740175000000002, -1.0615800000000055, 3.2116499999999943, 5.318625000000018, 7.50360000000001, 8.200140000000019, 8.997885000000029, 9.051900000000021, 7.825350000000015, 7.447830000000008, 6.295380000000004, 6.3269699999999895, 4.9949250000000065, 5.054985000000012, 3.9413400000000083, 3.7582350000000053, 3.5076600000000004, 3.214185000000003, 1.698255000000004, 2.6044200000000037, 2.492099999999988, 1.820520000000002, 2.0010900000000023, 1.0916099999999984, -1.0752300000000057, -1.6305900000000029, -2.6726700000000037, -4.541745000000002, -6.305130000000002, -6.557070000000003, -7.788885000000004, -8.657609999999998, -8.258054999999995, -8.212425, -9.382424999999996, -8.360235, -8.899605000000006, -7.672665000000002, -6.876285000000006, -5.968950000000002, -4.759755000000003, -3.4899150000000034, -2.2249500000000006, -1.8866250000000035, -0.9443850000000031, -0.4865250000000074, -0.8170500000000032, -1.0962900000000042, -1.055340000000001, -0.7158450000000025, -1.4469000000000003, -1.0611900000000034, -0.3689399999999976, -1.1848200000000042, -0.9607650000000034, -0.8147100000000074, -1.4755650000000022], [0.0, 0.5584800000000003, 0.11271000000000608, -0.018330000000003288, 0.03315000000000534, 1.0132200000000027, 0.10998000000000463, -0.07448999999999462, -0.37303499999999357, -0.10880999999999297, 0.31492500000000456, 0.6932250000000022, 1.3716299999999997, 2.4989250000000025, 4.921800000000004, 6.201195000000002, 8.504925000000004, 10.992344999999997, 13.87132500000001, 14.97268500000001, 15.17002500000001, 13.163280000000015, 10.625744999999998, 7.060365000000001, 4.480710000000003, 3.480750000000001, 2.3056800000000033, 2.3458500000000004, 1.9098300000000061, 1.6510650000000018, 1.714830000000001, 2.1633300000000046, 0.5573100000000024, 0.8956350000000084, 0.22210500000000888, 0.31395000000000683, -0.1595099999999965, -0.48730499999999566, -1.0801049999999908, 0.0029250000000056176, -0.1770599999999991, -0.9761699999999953, -0.5846100000000032, -0.34866000000000064, 0.471510000000011, -1.0348649999999946, -0.2378999999999971, 0.39058500000000285, 0.08716500000001126, -0.3194099999999995, -0.5376149999999988, 0.5631600000000039, 0.7831200000000038, 0.7246200000000029, 0.6318000000000064, 2.127645000000002, 1.9806149999999998, 2.9983200000000014, 1.482975000000002, 2.8384200000000024, 2.0299500000000004, 2.4981450000000045, 1.8815550000000054, 1.5707249999999986, 2.368470000000003, 0.3295499999999989, 0.7550400000000042, 1.0569000000000028, 0.8890050000000054, 2.1584550000000053, 0.7893600000000012, 1.2060750000000047, 0.3433950000000001, 0.14761499999999916, -0.4976399999999961, -0.7004399999999817, -0.5920199999999909, 0.7257900000000004, -0.10432499999999578, 0.4715100000000034, -0.3724500000000015, 0.3962400000000006], [0.0, -0.3447600000000013, -0.032955000000000956, 0.17744999999999722, -0.3404700000000036, 0.4344599999999996, -0.19090500000000055, 0.31180499999999745, -0.32994000000000234, -0.2291250000000029, -0.8897850000000018, -0.44713500000000117, -0.8556600000000021, -1.418430000000003, -2.092545000000002, -2.3000250000000024, -1.770990000000002, -1.5015000000000018, -0.4438200000000019, 0.10900499999999846, 0.5957249999999963, 0.7805849999999972, -0.4475250000000013, -1.1565450000000017, -1.8901350000000023, -1.8667350000000025, -1.409070000000003, 0.10159499999999655, -0.321750000000002, -0.44869500000000295, -0.6936150000000028, -0.8960250000000032, -1.3486200000000015, -0.7525050000000004, -0.3400800000000035, -0.08229000000000353, -0.09418500000000107, -0.7121400000000022, -0.19519500000000156, 0.01891499999999935, -0.21645000000000203, -0.1086149999999999, 0.7345649999999972, 0.9061649999999997, 0.7148699999999963, 0.34651499999999924, 0.5364449999999987, 0.5512649999999986, 0.30361500000000285, 0.37654499999999835, 0.36289499999999775, -0.42529500000000087, -0.8714550000000032, -0.2564250000000028, -1.233765000000002, -0.5994300000000026, -0.40131000000000405, -0.7874100000000019, -0.7963800000000014, -0.9629100000000022, -1.1161800000000024, -0.5399550000000009, -0.8174400000000008, -0.35821500000000084, -0.691080000000003, -0.8203650000000018, -0.2195700000000016, -0.02476500000000237, -0.3049800000000009, -0.12363000000000213, -0.49374000000000184, -0.28196999999999983, -0.37128000000000205, -0.22639500000000035, -0.273780000000001, -0.4970550000000027, -0.18739500000000087, 0.18095999999999401, 0.459225, 0.7240350000000002, -0.4416750000000025, -0.028470000000001328], [0.0, -0.07215000000000016, -0.19792500000000102, -0.22093499999999988, -0.3153149999999991, 0.009164999999997647, -0.24297000000000102, -0.3149249999999997, -0.5561399999999992, -0.33247500000000274, -0.17354999999999832, -0.028859999999999886, 0.16789499999999746, 0.9328800000000017, 1.3710449999999992, 2.155529999999999, 3.1632899999999973, 4.013490000000001, 5.194994999999999, 6.014189999999998, 6.482189999999994, 6.155369999999995, 5.351579999999994, 4.177875, 2.936114999999999, 1.596269999999999, -0.3094649999999981, -0.8689199999999975, -1.9197750000000027, -2.4969749999999937, -3.204629999999992, -3.073199999999998, -3.404115000000007, -2.2081799999999996, -2.4521249999999926, -2.129399999999997, -2.6102700000000034, -2.3171849999999976, -1.3168350000000024, -1.2054899999999997, -0.879255000000001, -1.4798549999999993, -0.7618650000000029, -0.555360000000003, -0.6142500000000011, -0.31784999999999997, -1.0145850000000003, -0.605474999999998, -0.5768099999999992, -0.2597400000000034, 0.3683549999999982, -0.0021449999999991753, -0.47657999999999845, 0.04524000000000017, 0.6555899999999995, 0.5428799999999985, 1.0159499999999997, 0.7326149999999987, 0.582464999999998, 1.2364949999999983, 0.715844999999999, 1.457234999999998, 0.965444999999999, 1.0769849999999987, 0.5380049999999996, 0.3092699999999975, 0.46136999999999784, 0.7094099999999997, 0.005459999999999354, -0.5916299999999999, -0.6261450000000073, -0.2377050000000014, -0.22269000000000005, 0.027299999999999214, -0.3467100000000012, -0.4818449999999985, -0.4631250000000007, -0.5278649999999967, -0.5419049999999985, -0.16068000000000415, -0.1844699999999997, -0.06649500000000241], [0.0, -0.8182200000000018, -1.1249550000000008, -0.740805000000001, -1.0576800000000008, -1.2862200000000001, -0.9619350000000008, -0.07195499999999777, -1.2179700000000004, -1.784250000000001, -2.8869749999999996, -3.607110000000001, -4.9504649999999994, -6.401459999999997, -7.556445000000003, -8.796060000000004, -9.819810000000018, -10.937355000000016, -11.355824999999996, -11.88486000000002, -12.096435000000012, -11.786775000000011, -11.16453000000001, -10.650705000000006, -9.271470000000015, -6.619860000000003, -3.6416249999999994, -1.3572000000000009, 0.8162699999999998, 1.9724249999999932, 2.9265599999999976, 3.3822749999999964, 3.2966699999999953, 3.9391950000000007, 2.9499599999999955, 2.725710000000003, 2.645954999999999, 2.482154999999996, 2.146949999999998, 2.159624999999992, 1.9026149999999986, 1.3899599999999963, 0.6401850000000024, 0.5321549999999995, 0.7092150000000008, 0.7567949999999977, 0.7616699999999956, 0.6353099999999983, 0.8800349999999986, -0.3474900000000001, -0.989820000000001, -1.7807400000000009, -3.0006599999999994, -2.659215000000002, -3.5150700000000006, -4.0716, -4.2394950000000025, -4.962359999999999, -4.949294999999997, -4.869149999999997, -5.558084999999998, -5.061615000000005, -5.297955, -4.59108, -4.196790000000004, -3.734250000000002, -2.932409999999999, -1.9574100000000005, -1.9488300000000007, -1.8320250000000002, -0.9898200000000008, -1.5284100000000007, -0.7396350000000015, -0.3634799999999996, -0.42295500000000175, -0.8051550000000005, -0.6347250000000013, -0.28002000000000016, -1.115400000000001, -1.2296700000000005, -1.5742350000000007, -1.4607450000000008], [0.0, -0.3268199999999961, -0.1881749999999931, -0.5140199999999977, -0.09613499999999764, 0.2143050000000084, -0.2669549999999994, -0.17959499999999728, -0.41749499999999706, -0.3724499999999944, -0.2786550000000023, -0.5007600000000014, -0.147419999999995, 0.044655000000005884, 0.33891000000000115, 0.25135499999999933, 1.7193150000000017, 3.137940000000004, 4.215315000000002, 4.563780000000002, 5.694975000000002, 5.299320000000002, 3.962400000000003, 2.8604550000000026, 2.121015000000007, 1.018485000000012, 0.9453600000000044, 1.6717350000000022, 1.2281100000000063, 1.4396850000000092, 0.8613150000000132, 0.5341050000000029, 1.2363000000000075, 0.4389449999999995, 0.3662100000000068, 0.07371000000000638, -0.4056000000000006, -0.04270500000000421, -0.041534999999990774, 0.5715450000000022, -0.48574499999999254, -0.6791849999999924, -1.1842350000000055, -1.5506399999999996, -0.8273850000000014, -1.0204350000000026, -0.7692749999999924, -0.7218900000000028, -0.48379500000000064, -0.290549999999997, -0.31707000000000196, -0.38278500000000193, -0.4295850000000021, -0.1920749999999991, -0.5245499999999996, -0.4611749999999972, 0.15229500000000584, 0.6214650000000059, 0.40755000000000496, 0.5204550000000001, 0.23146500000000092, 0.23029499999999992, 0.5179200000000073, 0.6144450000000043, 0.29464500000000005, 0.2964000000000011, -0.16380000000000372, 0.3722549999999982, 0.32058000000000586, 0.47248499999999893, 0.14215500000000603, 0.10120500000000465, 0.05674500000000471, 0.3679650000000043, -0.07507499999999467, -0.18017999999999113, 0.08774999999999977, 0.04621500000000278, -0.10296000000000127, 0.2735850000000086, 0.05421000000000564, -0.37010999999999594], ...]</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>950962162</th>\n",
       "      <td>0.461359</td>\n",
       "      <td>-0.127494</td>\n",
       "      <td>46.94</td>\n",
       "      <td>0.384590</td>\n",
       "      <td>141</td>\n",
       "      <td>0.474896</td>\n",
       "      <td>NaN</td>\n",
       "      <td>670.549443</td>\n",
       "      <td>NaN</td>\n",
       "      <td>noise</td>\n",
       "      <td>0.183138</td>\n",
       "      <td>110.0</td>\n",
       "      <td>0.212119</td>\n",
       "      <td>326.924325</td>\n",
       "      <td>850180684</td>\n",
       "      <td>1.104733</td>\n",
       "      <td>140</td>\n",
       "      <td>-0.178666</td>\n",
       "      <td>0.55</td>\n",
       "      <td>0.343384</td>\n",
       "      <td>0.110305</td>\n",
       "      <td>NaN</td>\n",
       "      <td>58.64</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>1.098827</td>\n",
       "      <td>NaN</td>\n",
       "      <td>[190.13126451841765, 190.15079785055343, 190.16876451611864, 190.20936451362968, 190.24836451123872, 242.3307946516265, 242.3729613157081, 242.3869946481811, 242.40256131389344, 242.41269464660553, 242.4524946441656, 242.4565613105829, 242.46299464352188, 242.47292797624624, 242.48629464209347, 242.49469464157846, 242.5172613068617, 282.6091921823344, 282.6486921799128, 298.91462451605315, 298.9168245159183, 298.93549118144057, 298.9372245146676, 298.9386245145818, 298.9523245137419, 298.95389118031255, 298.956357846828, 298.9665245128714, 299.01175784343167, 299.01595784317414, 299.0174578430822, 354.9264210822153, 411.5661842765462, 486.3722130238497, 486.4504130190556, 486.48591301687924, 486.5740463448095, 505.20254520277786, 505.231311867681, 505.25857853267604, 527.7996104841175, 527.8323104821127, 527.875010479495, 527.9226104765768, 548.3926092216509, 548.4130092204002, 548.4291425527446, 548.4484758848926, 548.4555092177948, 548.462675884022, 548.4696758835929, 548.4718425501268, 548.4880425491336, 548.4960758819744, 548.497975881858, 548.5157092141042, 548.5178425473067, 548.5208425471228, 548.5309425465036, 548.5420425458232, 548.5500425453326, 548.5524758785168, 548.5646092111064, 548.5655425443824, 548.5733758772355, 701.729166487925, 701.7362331541585, 701.7712664853441, 701.7847998178478, 701.7880331509829, 701.8077331497751, 701.8195998157144, 701.8360331480402, 784.4675947489278, 784.4873280810514, 989.0758822052902, 994.1317152286725, 994.1656152265944, 994.2463818883095, 994.2836818860228, 1015.860847229888, 1015.8986472275707, 1015.9662472234264, 1016.0755472167257, 1025.0059800025733, 1041.5041123244787, 1041.7561789756921, 1049.0827785265303, 1073.000810393554, 1074.6139436279932, 1074.719843621501, 1074.7656102853618, 1074.7660769519998, 1075.151510261704, 1075.4007102464266, 1075.454210243147, 1075.5179102392417, 1075.5316102384018, 1075.5441102376356, 1075.5459769041877, ...]</td>\n",
       "      <td>[0.000181523346910837, 0.0002248771219875198, 0.000190190860067677, 0.00018195941977656332, 0.00019915466009344442, 0.0002614923509955872, 0.00033319665356618003, 0.00019354492731484934, 0.00039895481159604387, 0.00027337915526919184, 0.00023741539274028736, 0.00022467922460472155, 0.0001807788838292443, 0.0002135547933020408, 0.0002446802811938245, 0.0002109886999026721, 0.000229786316109426, 0.00018053554527300178, 0.0002120665872113948, 0.00031303229371755503, 0.00020635734653613066, 0.0003216856658753765, 0.00027620680352798084, 0.00022096835375392694, 0.00021378469561111183, 0.0002800927745713899, 0.00021790916387198786, 0.0003091703455197159, 0.00022462705764734537, 0.00022146046971218837, 0.00026528759289903104, 0.00026679867278332244, 0.00018771382585280983, 0.00022939631256552938, 0.00018809200182222938, 0.00019454535320316267, 0.00023047176388417198, 0.00020855477811601537, 0.00021739674799639208, 0.00022870004838199996, 0.00023557750716795157, 0.00022045950759964355, 0.00020983833039854655, 0.00023564537783496374, 0.0002074089741782035, 0.00020677347186044616, 0.00026087777674354965, 0.00022203016965639778, 0.00018867591936891899, 0.000203924175463398, 0.00019873432157873876, 0.0002492971718268085, 0.00025988226879747355, 0.0002304042149516987, 0.00019459310780114845, 0.0002894626342266135, 0.0004069962140195235, 0.00019906685720571377, 0.00029556262915969827, 0.00022392422088680732, 0.00038406417110188054, 0.00021055550732710342, 0.0002591433824478882, 0.00018375973901131132, 0.00023803388908956086, 0.00022343190575954564, 0.00027067315330748566, 0.000285338518341661, 0.00021819653409798048, 0.00019406144913598896, 0.00022675582188421686, 0.0002723005785293144, 0.0002320786287368968, 0.0002067882563285425, 0.00019631896847118334, 0.0002677697289044433, 0.00020359009244649788, 0.00019792129839897913, 0.00019137580837438642, 0.0001926268654684903, 0.0001041144075330245, 0.00010286179538864934, 0.00010230320294637757, 9.6456114341894e-05, 0.0001092843445176576, 0.000103690430353891, 0.00010519512150948169, 0.00010839537666602905, 0.0001359890696192917, 0.00014073730454760197, 0.0001546531353510241, 0.00012190023755810399, 0.00011596940604935663, 0.00014106456985641622, 0.00011638881766217645, 0.00020719240087145767, 0.00011631685637031275, 0.00013131060512384227, 0.00013188954344552534, 0.00012192740880594735, ...]</td>\n",
       "      <td>[[0.0, 7.396739999999996, 13.384019999999994, 15.41708999999999, 18.80053499999999, 13.046474999999987, 8.210475, 3.6630749999999885, 0.7495799999999875, -5.393895000000036, -15.84589500000003, -38.133030000000005, -53.56766999999999, -38.09130000000005, -20.55631500000001, -6.814859999999982, -4.240665000000046, 1.3690949999999908, -6.503835000000038, -17.93180999999998, -23.54742000000014, -24.618165000000072, -20.493915000000005, -19.07938499999997, -33.487545000000125, -16.291274999999995, -25.376129999999993, -24.30772500000001, -21.590400000000013, -21.608925000000024, -24.526710000000033, -14.976584999999996, -13.165620000000043, -10.956660000000031, -14.596140000000059, -6.938685000000067, -8.491860000000049, -3.4296599999999984, -6.003855000000048, -14.87830500000005, -20.302619999999994, -13.357890000000001, -15.459600000000027, -11.826359999999987, -13.922025000000023, -11.081070000000015, -16.030169999999995, -13.650585000000024, -19.244355000000045, -25.704510000000102, -25.33888500000005, -19.08679500000004, -24.693435000000097, -26.691405000000056, -21.535020000000056, -32.64007500000004, -29.89915500000009, -32.27074500000005, -34.30927500000003, -36.09137999999993, -36.50477999999998, -36.46948499999998, -41.11984500000004, -42.976440000000025, -44.38921499999999, -43.36117500000002, -34.285875000000004, -25.55358000000007, -25.573859999999993, -28.226445000000037, -41.76002999999997, -36.42580499999998, -42.11649000000001, -35.651655000000005, -36.94996500000002, -41.95171500000001, -37.80192000000005, -37.708319999999915, -41.921684999999954, -41.974139999999835, -39.83733000000001, -40.62142499999999], [0.0, 3.4643700000000353, 3.7635000000000067, 3.3253350000000053, 1.5167100000000167, 2.6656500000000127, 5.985914999999999, 7.344480000000034, 6.203925000000026, 4.854915000000008, 1.5321149999999983, -1.3100099999999921, -4.809089999999989, -3.2344649999999886, -0.00526500000000496, 3.8769899999999895, 2.7001650000000046, -1.3045499999999954, -0.5787600000000017, 0.698685000000002, 1.456454999999992, -0.8905649999999943, -3.901949999999985, -3.05330999999999, -2.530904999999999, 2.636400000000017, 9.361950000000022, 12.99519000000003, 15.992729999999998, 16.824599999999986, 17.572230000000037, 20.428200000000047, 22.805055000000003, 24.45612000000005, 24.807315000000017, 24.656580000000076, 23.959455000000037, 24.020880000000027, 23.34813000000006, 25.584195000000072, 26.471055, 27.723345000000045, 23.23542000000002, 24.638835000000057, 22.688445000000062, 22.814025000000022, 18.67885500000003, 16.539900000000046, 16.780725000000007, 17.380155000000034, 17.198024999999983, 17.099550000000097, 19.52788500000007, 21.413730000000044, 18.790590000000027, 18.596369999999986, 16.167450000000002, 12.525630000000035, 12.126075000000014, 8.654879999999995, 11.054355000000008, 8.83837500000001, 5.810414999999993, 6.971445000000027, 8.198190000000018, 9.676095000000025, 6.542250000000002, 4.815525000000002, 7.948199999999997, 2.800199999999996, -0.13006499999999122, 0.7959900000000131, 1.443585000000021, -1.2039299999999873, -1.4262299999999888, -0.7688849999999929, -2.660384999999989, -3.8898599999999894, -3.6966149999999924, -3.0770999999999953, -3.6525449999999955, -5.191289999999994], [0.0, -0.014819999999994948, -3.1008900000000104, -0.9666150000000027, -0.15989999999999505, 0.736904999999977, 1.0968750000000078, -2.6779350000000193, 2.9914949999999987, -1.0095150000000075, -4.912440000000027, -6.876675000000017, -13.392015000000026, -12.756120000000024, -15.866565000000026, -16.758105000000022, -11.599185000000025, -11.725545000000029, -13.879515000000024, -19.314750000000018, -21.010860000000022, -12.844845000000024, -12.326925000000026, -15.633345000000023, -14.226225000000024, -10.496850000000016, -5.452980000000025, 0.6795749999999767, 3.6921299999999757, 9.567479999999955, 10.139804999999987, 12.18730499999994, 17.70015, 20.77296000000002, 23.12563499999999, 20.633339999999947, 18.799559999999957, 18.613724999999995, 19.577999999999967, 22.938629999999975, 23.110034999999954, 18.46220999999995, 17.884814999999953, 19.880834999999962, 16.851899999999944, 18.236984999999997, 13.588770000000002, 11.32637999999998, 10.850969999999931, 13.032630000000006, 9.553634999999973, 12.669539999999992, 15.664544999999974, 15.21760499999999, 11.604254999999975, 8.851244999999965, 12.909389999999915, 9.561044999999966, 12.202709999999984, 4.476810000000031, 10.248615, 10.073894999999967, 6.224009999999952, 4.011929999999994, 7.933769999999994, 9.121319999999967, 8.753159999999971, 8.53417500000007, 7.460115000000004, 8.41659000000004, 3.314219999999983, 0.9178649999999724, 3.030884999999996, 0.542489999999967, -0.03490500000002861, 0.28528499999998225, -1.5810600000000203, -2.09430000000002, -3.7418550000000224, -6.098430000000021, -8.51194500000002, -9.476025000000021], [0.0, 0.32058000000000014, 3.8056200000000016, 7.457579999999991, 3.6560550000000007, 3.2828250000000017, 1.5149549999999996, -0.7753200000000009, 1.2710100000000015, 2.871375, 5.860530000000003, 6.554534999999988, 7.410585000000004, 8.598915000000009, 6.805110000000003, 5.817044999999999, 5.499390000000006, 1.6859699999999997, 2.992275000000005, 2.704845000000003, -2.7173249999999967, -0.6581250000000012, 1.8700499999999964, 2.2801349999999996, 4.625985000000004, 10.206495000000007, 11.21367, 12.604995000000029, 12.224355000000005, 12.031889999999999, 13.18940999999999, 14.078025000000014, 15.520440000000027, 14.001390000000004, 13.66287000000003, 15.311205000000006, 16.555890000000005, 19.709429999999994, 22.23858000000003, 23.927280000000025, 26.77954500000005, 25.519845000000025, 20.259330000000038, 24.74452500000001, 26.21970000000003, 21.02431500000001, 19.245525000000015, 18.218459999999993, 19.656390000000002, 19.90228500000004, 18.670275000000032, 20.606429999999996, 22.778535000000026, 28.568865000000034, 25.907895000000046, 21.881925000000006, 25.691055000000038, 28.255890000000026, 22.634625000000007, 17.005560000000013, 16.976699999999987, 17.10033000000002, 15.167880000000006, 14.930760000000017, 16.785210000000014, 16.17622500000001, 20.157150000000012, 16.17719999999999, 16.011645000000016, 17.125680000000017, 20.751705000000012, 19.081530000000022, 16.786575000000028, 15.168269999999993, 16.569150000000015, 14.350050000000005, 14.43019500000001, 17.056455000000003, 15.778815000000007, 14.856855000000003, 15.457455000000003, 15.314325000000009], [0.0, 2.5583999999999882, 2.14675499999999, 0.5364449999999827, -0.7768800000000233, -0.314925000000013, -0.19383000000000905, 0.4547399999999886, 1.1491349999999798, 0.5344949999999784, -0.7353450000000095, 0.7507499999999858, -0.7254000000000342, 0.7384649999999962, 7.905494999999988, 8.010014999999992, 7.395959999999989, 7.820864999999988, 8.103809999999989, 7.595834999999995, 6.072299999999991, 2.790254999999993, -0.30030000000002666, -0.13182000000001182, 0.881010000000007, 1.2971399999999953, 1.0853699999999744, 0.38219999999997256, -2.035800000000041, -2.0915700000000044, 1.9074899999999797, 4.198545000000003, 4.080179999999995, 6.063914999999998, 5.52746999999999, 4.638659999999977, 3.2666399999999918, 2.2339199999999995, 3.0751500000000025, 2.5995450000000027, -0.18641999999999648, -1.1060400000000072, -0.5853899999999896, 3.5031749999999953, 4.669664999999979, 4.119764999999985, -1.2649649999999966, -2.005185000000015, -2.3934299999999986, -1.0976550000000156, -0.46955999999999953, 4.89176999999999, 5.125185000000004, 3.4967400000000044, 3.2915999999999883, 0.6177600000000147, 1.9455149999999861, 3.890055000000002, 6.436364999999984, 4.562024999999997, 4.558124999999986, 2.9119349999999837, 1.6376099999999774, 2.0593949999999968, 6.783659999999989, 7.210709999999988, 7.192769999999984, 9.225839999999987, 4.302089999999996, 1.839824999999987, -0.12811500000000642, -1.5902249999999896, -1.1380200000000187, 0.3650399999999969, 0.8102249999999938, -0.0912600000000019, -2.8124850000000414, -2.7235650000000184, -3.073395000000012, -2.9119350000000566, -2.841930000000051, -2.7495000000000047], [0.0, -2.2545900000000003, -4.502160000000011, -3.613154999999969, -3.630510000000008, -4.484415000000016, -4.475250000000017, -2.251860000000029, 1.2739350000000034, -0.9650550000000031, 0.6388199999999884, 0.772395000000003, 1.6990349999999985, 4.295849999999997, 0.30244499999998986, -5.781945000000022, -5.957835000000006, -6.934980000000014, -7.646535000000014, -8.413470000000036, -5.1123150000000095, -2.144220000000031, -5.1540450000000035, -6.160245000000035, -4.82975999999999, -1.0834199999999967, 2.310359999999992, 2.016884999999986, 2.985645, 3.7285949999999985, 1.8337799999999866, 2.825355000000007, 3.4214699999999976, 4.169295, 4.877145000000003, 5.496855000000005, 5.32233, 6.050655000000005, 6.646379999999989, 8.072609999999989, 7.66739999999999, 6.375329999999994, 2.3138700000000156, 0.9718799999999934, 1.180919999999995, 0.7447050000000015, 1.667055000000012, 1.910999999999996, 1.5863249999999862, 2.1904349999999955, 2.637959999999982, 4.117035000000003, 5.0575199999999905, 4.844385000000001, 5.175494999999992, 1.524509999999987, 0.16672500000000134, 0.8786699999999961, -0.9672000000000054, -1.7707950000000015, -1.2437100000000054, -0.9229350000000078, -1.711514999999988, -1.983345, 0.2236650000000182, -0.17784000000001043, 0.09554999999999403, 0.9607649999999985, -0.24062999999998702, 1.6280549999999927, 5.342219999999997, 5.7833099999999975, 5.521424999999992, 5.520644999999995, 5.275334999999994, 5.5645200000000035, 5.1694499999999906, 6.893834999999993, 6.837674999999993, 7.322249999999992, 7.774649999999988, 7.80857999999999], [0.0, 1.2831000000000037, -0.23614499999999516, -0.31531499999999557, 0.1450799999999992, 1.0104900000000079, 0.4707300000000041, 1.4379300000000028, 1.5982200000000062, -0.6343349999999965, -2.2965150000000003, -3.5577750000000066, -7.374509999999992, -8.977799999999988, -9.193859999999985, -12.202319999999975, -10.948664999999991, -12.020969999999995, -13.460264999999975, -14.638844999999979, -13.674179999999964, -9.675704999999978, -11.684009999999983, -9.56767499999998, -8.412884999999966, -5.219174999999982, 0.6263399999999995, 3.039075000000003, 5.355870000000004, 9.073545000000001, 10.312185000000007, 12.262575000000012, 14.506635000000024, 16.612829999999995, 14.765204999999995, 16.106610000000014, 15.238470000000012, 15.239250000000007, 15.347865000000002, 14.430780000000018, 12.947415000000017, 13.706940000000017, 14.498250000000025, 12.498524999999999, 14.336790000000018, 14.091675000000008, 11.455860000000015, 11.210939999999997, 10.586940000000013, 8.14164, 10.782330000000005, 8.998470000000012, 10.081110000000002, 9.021870000000007, 8.970779999999994, 9.807915000000001, 7.082790000000001, 9.651330000000002, 8.189609999999997, 4.517370000000006, 7.476690000000005, 5.217225000000005, 4.048200000000004, 6.034470000000004, 3.834285000000005, 3.5558250000000036, 3.191175000000004, 4.603560000000004, 6.003075000000008, 4.726410000000005, 3.8089350000000044, 4.855695000000005, 3.237975000000003, 3.606525000000004, 2.045355000000002, 1.8179850000000064, 0.9556950000000062, 0.12012000000000622, -0.6288749999999972, -1.7002049999999969, -3.2102850000000007, -2.6781299999999897], [0.0, 0.22269000000000094, -0.2484300000000006, 0.9556950000000003, 2.6943150000000005, 2.259855000000001, 2.3384400000000007, 4.503134999999998, 8.10108, 2.5075049999999974, -3.1913700000000027, -6.674655000000006, -11.953109999999988, -10.125180000000004, -8.588580000000011, -9.59790000000001, -2.994810000000002, -2.8893149999999976, -5.662020000000001, -9.770280000000003, -9.592634999999998, -4.424159999999997, -9.334844999999984, -10.72656000000001, -5.8160700000000025, -2.1668400000000005, 2.908619999999998, 3.754920000000003, 5.291519999999999, 10.83634499999999, 14.09557500000001, 18.336630000000007, 20.15402999999998, 20.915700000000005, 21.618674999999993, 20.18991, 17.11983000000001, 16.83844499999998, 16.916639999999997, 17.43534000000003, 13.917734999999997, 14.862315000000024, 16.89538499999999, 16.57422000000001, 17.938439999999986, 18.798780000000047, 14.113320000000009, 14.767350000000015, 11.521574999999991, 10.519275000000004, 10.519664999999996, 10.290735000000009, 10.241010000000017, 11.39033999999997, 11.28426, 11.177009999999996, 9.032985, 9.841455000000007, 10.476375000000004, 10.129859999999994, 10.466040000000003, 6.615959999999996, 6.69903, 7.1270550000000155, 4.788420000000004, 4.217849999999999, 6.336330000000005, 8.239335000000015, 5.546970000000002, 1.3700699999999995, 0.8197799999999991, 1.861860000000001, 0.9619349999999997, 0.8734050000000003, -0.7644000000000015, -1.6005600000000015, -4.392765, -7.381140000000001, -6.7391999999999825, -7.207004999999989, -9.76871999999998, -10.5261], [0.0, 2.2038899999999977, 4.532384999999975, 3.960644999999978, 2.355404999999992, 3.7841699999999854, 4.002764999999986, 1.4521650000000008, -1.6715400000000393, 0.15014999999996803, 1.7446649999999746, -0.689520000000055, -2.124330000000011, -4.079205000000027, -1.9839300000000613, -1.1093550000000256, -2.597400000000043, -4.997265000000056, -3.536324999999998, -3.2596200000000124, -8.559719999999995, -10.740599999999972, -6.785024999999997, -2.962440000000047, -3.208530000000014, 1.4468999999999923, 3.057014999999973, 5.781554999999948, 9.842819999999971, 11.168819999999972, 10.734164999999965, 12.541424999999965, 11.485694999999971, 13.217294999999968, 14.220374999999969, 13.615289999999968, 14.539394999999969, 15.073109999999966, 16.709354999999967, 18.368024999999967, 18.235229999999966, 15.941054999999967, 14.515799999999967, 13.284179999999969, 11.24389499999997, 9.483824999999973, 10.385504999999972, 10.144679999999962, 9.410504999999969, 10.17217499999997, 9.35941499999996, 9.956504999999964, 11.775074999999966, 12.737789999999965, 15.056729999999964, 12.284024999999959, 10.699454999999965, 11.107784999999966, 7.8567449999999734, 7.937864999999968, 8.300954999999968, 6.146204999999965, 5.184659999999965, 5.7725849999999586, 6.165704999999962, 5.883539999999966, 3.2379749999999934, 4.123664999999958, 3.6076949999999997, 5.633159999999997, 6.78326999999998, 4.450094999999964, 4.656209999999978, 5.200844999999973, 3.667754999999957, 3.6324599999999876, 3.1344299999999485, 2.506139999999961, 1.7551949999999614, 0.7411949999999763, 1.3753349999999571, -0.13669500000005286], [0.0, 0.2302950000000079, -0.631605000000004, -0.9065550000000018, -0.18759000000000015, 0.3262349999999934, -0.584610000000005, 0.9999600000000024, -1.656915000000002, -2.03697, -1.8608849999999997, -0.9781199999999979, -3.297060000000001, -2.981160000000001, -0.1600950000000001, -2.110290000000002, -0.6212699999999982, -0.3632850000000012, -2.930070000000002, -3.062864999999999, -2.0724599999999986, -3.2999849999999977, -4.176315, -2.0964450000000037, -4.678634999999999, -5.20806, -4.3056, -3.2069700000000005, -3.2243249999999986, -2.01220500000001, 0.09145500000000784, 2.6650650000000082, 3.0375150000000035, 4.053854999999992, 4.2028349999999906, 3.2065800000000158, 1.9564350000000053, 0.8125650000000011, 0.793845000000001, 2.401424999999991, -1.1920350000000024, -0.4810649999999974, 1.9197749999999871, 6.170774999999986, 5.743529999999988, 4.0988999999999995, -0.3535349999999866, -1.6615949999999975, -2.2354800000000026, -1.3519350000000006, 0.26110500000000414, 1.6021199999999975, 4.4116799999999925, 3.31656, 0.5820749999999961, 0.8893949999999959, 1.9833449999999955, 5.029049999999999, 7.021560000000002, 4.650749999999998, 6.074640000000021, 5.283329999999988, 1.6044599999999916, 1.2743249999999948, 2.468115000000001, 6.411990000000006, 6.337305000000009, 6.681285000000007, 5.35255499999998, 1.4745899999999956, -1.529774999999998, -0.4984200000000003, -0.23907000000000433, 1.931669999999996, 0.33793500000000165, 0.8219250000000002, -0.9012900000000004, -2.054715, -1.8431399999999987, -2.1256949999999972, -2.161380000000001, -2.656679999999999], [0.0, -3.689204999999985, -5.409104999999984, -3.366284999999986, -2.4527099999999873, -4.069649999999986, -3.7449749999999855, -2.7537899999999866, -1.7386199999999854, -2.644979999999987, -3.5846849999999852, -4.726799999999987, -5.525129999999985, -4.063799999999985, -8.576684999999987, -12.165074999999984, -10.078379999999989, -11.581829999999986, -14.01894, -14.189759999999989, -11.44376999999999, -8.167574999999985, -6.353489999999988, -7.162934999999984, -6.083609999999985, -4.643534999999986, -1.9609199999999856, -0.9749999999999881, -0.09496499999999486, -0.13220999999998906, 0.7667400000000137, 1.7622150000000083, 1.895595000000009, 4.108260000000034, 5.231655000000026, 4.4740800000000265, 4.366440000000032, 4.470765000000019, 4.401345000000011, 5.296980000000031, 3.7568700000000304, 2.831010000000016, 1.7091750000000268, 0.9276150000000047, 0.32896500000001705, -0.235169999999993, 1.0939500000000093, 2.023710000000003, 0.6971250000000193, 1.2762750000000116, 2.7697800000000194, 3.3520500000000144, 3.3073950000000227, 2.738970000000009, 1.951560000000005, -0.2733899999999858, -0.23224499999998738, -1.0512449999999833, -3.900194999999986, -3.4066499999999866, -1.3246349999999865, -2.0531549999999847, -2.775239999999984, -1.6120649999999888, -2.1629399999999825, -0.9640799999999881, 0.1632150000000081, -0.47969999999999313, 1.2655500000000233, 2.4226800000000193, 0.709605000000022, 0.8457150000000135, 1.2376650000000202, 0.6058650000000201, 0.11505000000001253, -0.5729099999999829, -0.034319999999987694, -0.018329999999986413, 0.07878000000000984, -0.1179749999999844, -0.4533749999999874, -0.5128499999999909], [0.0, -0.39351000000001335, 1.2932399999999902, -2.0494499999999984, -3.2473350000000014, -2.4683100000000255, -3.0706650000000213, -3.016455000000006, -6.987044999999986, -2.4977550000000033, 4.454774999999994, 13.246739999999996, 13.400789999999994, 8.079239999999992, 8.622314999999993, 8.658389999999994, 7.10209499999999, 8.118239999999995, 10.271234999999994, 13.939184999999995, 11.967929999999994, 8.373104999999986, 10.869104999999992, 15.303794999999992, 11.178374999999996, 6.233954999999984, 3.5287200000000123, 4.180799999999987, 2.2235849999999857, 1.0321350000000091, 1.664715000000001, 3.4078199999999796, 1.748370000000003, 1.9295249999999928, 1.7159999999999993, -0.3496350000000099, -1.9266000000000165, -2.9536649999999707, -2.031705000000013, -3.5334000000000234, -5.34475499999999, -8.487959999999942, -5.99098499999999, -2.3688599999999997, -1.2185550000000056, -2.5387049999999984, -4.741229999999996, -4.716854999999997, -6.001514999999975, -4.606874999999983, -0.8515649999999955, 0.7897499999999891, 2.6247000000000007, 1.6198649999999954, -0.4223700000000026, 0.4715100000000003, 2.8477799999999984, 4.576259999999987, 5.217029999999992, 7.414484999999996, 9.656984999999999, 8.662679999999988, 4.773014999999999, 5.754059999999992, 6.698639999999984, 11.255984999999997, 12.140504999999994, 12.506129999999994, 11.770979999999991, 11.25812999999999, 7.780694999999995, 7.770554999999987, 8.085869999999996, 9.980879999999994, 9.825659999999996, 8.888684999999988, 8.669699999999988, 7.507890000000001, 10.49158499999999, 8.870744999999992, 10.378875, 10.534679999999993], [0.0, -0.4576650000000033, 0.2603249999999959, 1.3394549999999985, 3.427320000000007, 3.9436800000000067, 4.767359999999994, 4.054634999999998, 3.433754999999999, 3.2204250000000023, 1.987440000000001, 0.6005999999999962, -0.9322949999999999, -2.210130000000001, -2.247375000000001, -4.913415000000003, -3.880305000000001, -5.751134999999999, -5.703165000000005, -3.9239850000000027, -3.585075000000001, -4.840095000000002, -0.8131500000000037, 1.7376450000000034, 3.7081200000000063, 7.8419250000000185, 11.521379999999981, 12.957164999999984, 14.640600000000017, 16.264560000000003, 17.608110000000014, 20.989995000000015, 20.77627500000003, 20.732205000000057, 20.40928500000003, 18.535335000000043, 17.44567500000005, 16.845465000000047, 16.730219999999978, 20.858175000000053, 18.77694000000002, 20.568210000000036, 22.13620499999999, 24.662625000000038, 23.47059000000001, 19.525740000000006, 15.325244999999995, 14.256839999999988, 13.42809000000001, 14.285895000000012, 15.972059999999999, 14.16850499999999, 16.730805000000018, 16.86828000000002, 17.184765000000002, 20.010899999999996, 19.64800500000002, 16.14522, 12.432225000000013, 11.994450000000024, 13.366080000000007, 12.750660000000014, 7.73077499999999, 7.510814999999982, 7.259850000000006, 11.702534999999976, 10.835955000000009, 8.451494999999994, 11.913524999999982, 8.170889999999998, 3.3415200000000045, 4.221360000000002, 3.136184999999995, 4.4325449999999975, 3.187859999999996, 2.8370549999999994, 2.9224649999999945, 0.4272449999999981, -1.0108800000000016, 0.1583399999999986, -1.3778700000000008, -1.3451100000000014], [0.0, -0.6148350000000002, -0.7684950000000006, -0.42334499999999886, 0.786629999999997, 0.2911350000000035, -0.35509499999999916, 0.362309999999999, -0.14410500000000037, -1.7809350000000013, -1.1750700000000012, -0.8431800000000002, -2.153385, -3.0104100000000003, -2.9212950000000024, -2.532465000000001, -1.6686150000000017, -2.376855000000001, -3.223935, -4.643340000000003, -3.476070000000001, -3.0238650000000007, -2.464995000000002, -0.48925500000000066, 0.5967000000000002, 0.7277400000000005, 1.9022250000000023, 2.8157999999999985, 3.640064999999996, 5.111534999999995, 6.3558300000000045, 8.216909999999991, 8.9388, 8.9778, 8.20735499999998, 7.516469999999993, 6.992310000000012, 5.962710000000012, 6.701174999999994, 6.5406899999999855, 5.388045000000002, 5.286060000000001, 7.142265000000007, 6.173114999999999, 5.834985000000001, 4.333680000000003, 3.093674999999998, 2.692949999999999, 3.0133350000000054, 3.5480249999999995, 4.3297799999999995, 5.158725000000002, 4.047225000000006, 3.883619999999993, 3.146909999999998, 4.5212699999999995, 2.6989949999999974, 2.399475000000006, 2.45602500000001, 1.2390300000000005, 2.4657749999999976, 2.423264999999999, 1.2643799999999965, 1.9078800000000005, 2.286179999999998, 4.150964999999996, 3.4938150000000046, 4.213365, 4.028699999999997, 2.813655000000001, 1.3513499999999987, 0.6140549999999987, 0.18641999999999914, 1.107989999999997, -0.08034000000000185, 0.1170000000000011, -0.61542, -1.383330000000001, -1.903980000000002, -1.8070649999999997, -2.7925950000000013, -2.929095000000001], [0.0, -3.636944999999997, -3.9413399999999896, -4.253729999999995, -2.9918849999999937, -1.962284999999989, -2.4934649999999836, -1.4406599999999976, -3.0341999999999985, 0.5331300000000088, 5.657145000000012, 9.376769999999963, 9.949289999999985, 3.6778949999999853, -0.3355949999999819, -2.2623899999999963, -1.0013250000000067, 0.2016300000000033, 1.6253249999999895, 2.302170000000002, 4.635149999999999, 2.5199850000000232, 5.850195000000012, 7.480394999999996, 3.967860000000009, 1.9008600000000104, 1.7618250000000195, 3.7365900000000156, 4.768725000000018, 4.768920000000017, 6.535815000000026, 7.261605000000058, 8.26644000000005, 7.91583000000003, 8.149439999999997, 7.298265000000027, 5.514600000000028, 4.511325000000019, 4.790175000000032, 5.70765000000001, 4.980690000000015, 4.472715000000017, 5.314529999999996, 8.057595000000008, 7.068945000000015, 3.9399749999999862, 1.9578000000000113, 1.6383899999999976, 1.3252200000000158, 2.842515000000022, 4.692674999999992, 6.400680000000035, 7.075185000000003, 7.473570000000004, 8.121555000000013, 10.063560000000004, 10.206300000000004, 10.922339999999982, 10.431914999999991, 9.306765000000015, 11.175060000000025, 9.118200000000014, 7.382505000000021, 7.642635000000025, 9.91633499999996, 12.00517500000001, 12.562874999999961, 13.540214999999995, 13.874249999999991, 11.132940000000017, 11.04187500000002, 10.66103999999998, 9.138285000000002, 10.141365000000027, 9.383010000000004, 8.838570000000013, 7.566779999999996, 6.068985000000035, 6.022769999999985, 6.391905000000021, 6.151665000000028, 5.793450000000009], [0.0, -3.082560000000004, -5.773949999999997, -6.988020000000003, -5.935020000000004, -5.526105000000003, -6.493890000000004, -4.858815000000005, -3.717480000000003, -6.2885550000000014, -7.676370000000008, -8.855535000000003, -10.211565000000007, -6.043830000000006, -6.973785000000012, -11.901629999999997, -9.283560000000016, -10.188945000000018, -14.336790000000008, -15.665325000000017, -13.55016000000002, -11.582025000000023, -11.930685000000011, -13.351845000000026, -13.505310000000026, -12.12705, -9.18489000000001, -8.199945000000007, -5.119920000000004, -2.650050000000004, -2.3704200000000055, 2.044574999999993, 3.076904999999994, 5.447910000000002, 6.882915000000012, 7.170735000000017, 8.484060000000007, 8.501414999999998, 9.175335000000004, 8.08957499999999, 8.883030000000009, 8.831745000000002, 7.029750000000017, 5.741189999999988, 4.814939999999996, 2.1375899999999906, 3.254354999999987, 4.52556, 5.034704999999992, 6.341009999999998, 7.5059399999999785, 6.838064999999992, 8.41268999999999, 6.71853, 5.560619999999989, 4.502744999999991, 3.8147849999999996, 3.404894999999997, -0.11427000000000209, -1.1109150000000034, 2.6155349999999933, 2.3554049999999913, 1.1393849999999972, 3.879914999999989, 3.904289999999995, 6.645599999999994, 6.674460000000004, 6.155955000000007, 5.8051499999999985, 6.779760000000009, 6.414915000000003, 5.899530000000001, 5.656169999999997, 4.793294999999997, 4.037084999999998, 3.0150899999999874, 2.4039599999999988, 2.102489999999996, 1.1015549999999923, 1.5139799999999988, 0.23984999999999612, -0.6199050000000026], [0.0, -0.14683500000000338, -1.2827100000000016, 1.812914999999994, 5.225414999999997, 1.9236749999999994, 0.3783000000000012, 2.6619449999999887, 5.4865199999999925, 2.6919749999999985, -3.080025000000002, -7.847385000000008, -12.371775000000024, -13.693874999999991, -15.607409999999994, -17.573010000000004, -15.203955000000008, -16.610880000000012, -20.64075000000002, -24.41673000000001, -18.904470000000025, -9.448529999999998, -10.571535000000008, -9.395880000000009, -4.277520000000003, -0.38122500000000237, 10.271820000000009, 16.194750000000003, 19.752525, 23.35436999999995, 25.603109999999987, 26.055704999999982, 27.73504499999995, 28.89685499999997, 29.546009999999974, 28.12640999999998, 28.543320000000058, 27.98211000000002, 27.487395, 28.89470999999997, 28.078049999999994, 28.104375000000005, 25.712894999999996, 23.019359999999985, 21.33553500000003, 19.69831500000003, 20.230274999999978, 21.308040000000037, 18.217875, 16.78871999999999, 16.770975000000007, 14.336204999999982, 17.23448999999998, 16.957394999999973, 15.632564999999985, 14.641184999999982, 12.185159999999989, 13.173809999999985, 6.886425, 7.507109999999995, 7.731944999999993, 5.685810000000001, 5.4055950000000035, 5.936774999999996, 2.8343249999999944, 5.0937899999999985, 4.625984999999998, 3.7865100000000025, 5.5970849999999945, 4.031429999999993, 4.132244999999994, 4.827224999999988, 3.468074999999997, 1.6247399999999992, -0.17433000000000343, -0.4332900000000026, -0.962130000000003, -1.8049200000000032, -3.2299800000000047, -4.788615000000005, -5.583045000000004, -6.715215000000011], [0.0, -0.5050500000000024, -0.7035599999999995, -2.9051100000000005, -2.2237800000000005, 1.1216399999999953, 2.194335000000002, 0.8244599999999997, -1.1072099999999998, -1.96053, -0.6583200000000007, -1.6420949999999994, -1.3437450000000015, -1.0239449999999946, 0.5025150000000043, 0.5083650000000053, -1.1101349999999957, -0.21488999999999914, 0.7599150000000026, 2.160210000000007, 2.4302849999999965, -0.55653, -0.8868600000000004, 1.3316550000000018, 0.8599500000000062, 2.0494499999999953, 2.343509999999996, 5.099445000000001, 7.101705000000003, 7.384065000000023, 9.851204999999991, 12.020969999999997, 11.30161500000002, 10.13727000000003, 9.694815000000013, 9.534330000000034, 8.618805000000012, 6.6475500000000025, 8.500440000000006, 5.6949749999999995, 5.153460000000001, 8.52890999999999, 10.315695000000009, 10.29639, 10.429770000000001, 7.734674999999992, 4.883774999999993, 3.769544999999986, 3.355364999999987, 4.29078, 5.0152049999999875, 10.030800000000013, 8.411130000000018, 5.929170000000001, 6.868485000000003, 6.803355000000003, 7.397520000000005, 8.133450000000002, 8.906235000000004, 7.886579999999995, 7.486440000000005, 8.01508500000002, 5.694585000000011, 4.511324999999992, 10.175099999999986, 9.70749, 8.318505000000002, 10.141559999999991, 6.58963500000001, 3.344054999999982, 4.035330000000002, 3.749069999999992, 3.295889999999994, 5.809439999999997, 3.823949999999995, 2.822039999999997, 2.0463300000000033, 0.7138950000000039, 0.2291250000000007, 0.07176000000000204, -1.3843050000000021, -0.5580900000000026], [0.0, 2.7596399999999637, 3.3081749999999737, 2.135249999999985, 3.76564499999996, 8.132279999999984, 8.937239999999964, 6.721649999999961, 3.736004999999956, 0.4293899999999429, -3.7777350000000514, -7.031310000000042, -7.0225350000000315, -4.01388000000005, -0.10218000000005922, -0.5253300000000181, -3.4860150000000374, -3.959670000000033, -1.7386200000000382, -0.7115550000000468, -0.3289650000000357, 0.22444499999995138, 0.7860449999999766, 1.4658149999999779, 4.3724849999999655, 10.326419999999917, 14.16577499999999, 15.711929999999963, 19.10999999999999, 21.233354999999985, 27.64729499999994, 31.12004999999991, 31.634849999999876, 30.74272499999986, 29.991389999999956, 28.618004999999958, 29.086199999999895, 27.2218049999999, 31.494449999999883, 31.54319999999988, 29.46995999999994, 33.575099999999864, 36.29300999999994, 34.93931999999998, 36.33337499999996, 31.672094999999945, 27.711449999999953, 25.12945499999996, 25.183664999999994, 24.19189499999995, 25.64717999999993, 31.504979999999836, 32.88908999999994, 26.926769999999973, 30.665699999999934, 29.06669999999993, 30.01478999999996, 30.134909999999937, 26.145405000000007, 24.155234999999973, 24.922169999999962, 22.086089999999967, 18.55249499999995, 18.346964999999965, 23.07590999999994, 26.17621499999993, 22.0999349999999, 24.43408499999992, 20.769839999999906, 14.475434999999965, 13.673204999999957, 12.46049999999994, 11.585730000000012, 12.851085000000001, 8.451299999999964, 9.597704999999955, 7.114769999999947, 5.368739999999956, 6.031154999999984, 3.24713999999995, 0.8993399999999756, 1.3049399999999594], [0.0, -1.2047100000000048, -0.9884549999999876, -2.736824999999988, -3.4518899999999917, -1.9002749999999882, 0.15093000000000423, -0.7142849999999905, -2.1563099999999977, -0.8285550000000015, 0.7542600000000057, 1.012245000000004, 1.2045150000000064, 1.7807400000000042, 0.0516750000000048, -2.984474999999998, -5.832645000000003, -4.938570000000011, -3.871139999999997, -1.1311949999999937, -1.421159999999996, -4.5653400000000115, -4.315545000000002, -2.6229449999999908, -1.5052050000000001, 1.3685099999999997, 1.12359, 1.5586350000000015, 2.018445000000005, 1.6155750000000038, 1.9049549999999988, 1.4123850000000049, 1.632345000000004, 1.4488500000000024, 1.655355000000005, 1.6456050000000029, 1.559415, 1.742130000000003, 1.9501949999999995, 0.8765250000000009, 2.244645000000002, 1.4480699999999995, 2.341755000000006, 3.7106550000000045, 3.636750000000004, 1.4478750000000011, 1.715025000000006, 1.720485000000001, 1.2733500000000033, 1.9449300000000047, 3.4440900000000023, 4.456335000000003, 3.189225000000004, 3.295110000000003, 2.461875000000004, 3.055455000000004, 4.616040000000003, 5.417880000000003, 3.8225850000000023, 3.3682350000000034, 3.2512350000000008, 2.400450000000004, 1.7918550000000053, 2.9671200000000013, 4.446975000000003, 4.047030000000003, 5.030805000000003, 5.878860000000003, 3.3245550000000055, 3.7796850000000024, 6.111690000000003, 7.098975000000001, 6.009900000000003, 6.904950000000004, 7.296315000000005, 6.902025, 6.278610000000003, 6.942975000000001, 7.2079800000000045, 8.380125, 8.079629999999996, 8.526375000000002], [0.0, -2.0976149999999976, -2.9868149999999893, -2.3600850000000193, -2.0902049999999974, -2.762174999999985, -0.7579649999999525, 1.0290150000000118, -0.2102100000000071, 1.6144050000000547, 1.9266000000000005, 2.6847599999999794, 3.1974150000000137, 4.810844999999997, -0.9092850000000219, -5.520840000000025, -8.369985000000046, -9.305985000000021, -10.310819999999975, -7.7257049999999765, -5.724614999999986, -8.953620000000008, -8.310315000000024, -4.100070000000002, 2.5168649999999957, 8.268389999999993, 7.936694999999984, 9.715679999999994, 12.992265000000005, 16.52781, 14.975609999999989, 14.730689999999997, 15.897959999999994, 15.006224999999999, 14.804984999999995, 15.639585, 15.300869999999984, 12.92791499999999, 12.609480000000005, 10.120110000000002, 11.496029999999989, 11.701364999999996, 10.483785000000001, 8.364135, 6.775274999999995, 9.93915, 13.013714999999998, 15.719729999999998, 14.691105000000004, 14.870699999999996, 13.501214999999995, 14.561625, 6.837285000000007, 8.501999999999992, 10.07642999999999, 11.415689999999973, 6.3628499999999875, 4.849064999999989, 7.868444999999998, 7.806239999999995, 8.918520000000003, 9.481874999999981, 10.739624999999988, 11.559989999999987, 12.086489999999994, 7.419165000000001, 7.852845000000002, 10.535069999999994, 9.196979999999998, 7.309574999999985, 14.398214999999984, 15.186014999999994, 12.863954999999992, 12.30196499999999, 11.763375, 11.99074499999999, 11.386635000000007, 12.363779999999991, 13.391819999999997, 13.260780000000002, 11.793599999999994, 11.780729999999997], [0.0, -2.586480000000005, -1.9503900000000023, -1.662570000000013, -0.6834750000000014, -4.218824999999985, -5.271825000000012, -0.44947500000002094, 1.5174899999999933, 2.920514999999985, 5.6376449999999805, 8.412884999999983, 9.095579999999984, 3.812054999999984, -1.9457100000000107, -2.5890150000000123, -2.0040150000000043, -2.749695000000001, -5.015789999999997, -7.225140000000017, -1.1538150000000158, 3.3588749999999896, 2.0970299999999904, 2.0311199999999907, 2.9998799999999752, 2.545529999999985, 6.439874999999981, 6.287384999999981, 6.8665349999999865, 5.688734999999983, 6.50792999999998, 7.7331149999999855, 6.7321799999999845, 7.351889999999982, 6.626684999999982, 7.201349999999982, 7.213634999999983, 7.234499999999984, 7.686509999999982, 7.423259999999984, 6.071909999999985, 4.870319999999979, 4.592834999999985, 5.569199999999982, 6.226934999999983, 3.996524999999985, 4.0290899999999805, 4.938569999999979, 4.771649999999978, 6.143669999999988, 8.139884999999982, 9.839504999999985, 9.552269999999984, 8.173814999999983, 7.228064999999981, 7.493654999999984, 8.091914999999984, 9.192299999999983, 8.211059999999982, 7.31347499999998, 8.746139999999983, 7.115549999999983, 6.401069999999985, 7.879949999999983, 10.52863499999998, 12.294749999999986, 11.930099999999982, 12.014144999999985, 12.221429999999993, 12.353639999999984, 13.266434999999987, 13.37504999999998, 13.394159999999989, 14.707289999999992, 14.223689999999978, 13.609634999999983, 14.037074999999984, 13.991444999999985, 15.251144999999987, 15.002324999999981, 14.962544999999983, 15.580304999999985], [0.0, -3.3044700000000056, -3.795674999999994, -1.304939999999998, -1.218360000000001, -4.029479999999996, -5.098664999999986, -0.3533399999999993, 0.6084000000000067, 0.847470000000005, 2.4605100000000037, 3.0648150000000047, 3.9546000000000046, 0.9712950000000025, -5.8090500000000045, -6.9336149999999925, -4.209074999999997, -6.807059999999989, -8.45793, -9.544079999999997, -2.904525000000006, 0.47619000000000367, -1.3234649999999948, -1.8829199999999942, -0.7292999999999958, 1.0461750000000063, 4.8365849999999995, 4.469400000000005, 6.293820000000003, 6.476535000000002, 8.160555000000002, 8.897070000000006, 9.43761, 9.079004999999995, 9.158955000000006, 8.790210000000002, 8.605545000000001, 9.165974999999996, 8.78865, 9.262500000000003, 8.446815000000006, 7.060170000000005, 6.028619999999998, 6.720285000000001, 6.329115, 4.767555000000002, 5.237699999999998, 5.924685000000002, 5.719350000000001, 6.615765000000007, 8.478210000000008, 9.43488000000001, 8.784165000000005, 8.003189999999996, 6.992895000000004, 6.056505, 6.016139999999998, 5.886465, 2.989155000000004, 3.572985000000005, 3.397680000000004, 2.9731650000000034, 2.773290000000004, 4.229745000000006, 4.830345000000003, 7.223775000000001, 8.061885, 8.005725000000005, 10.30789500000001, 10.971285000000002, 11.430120000000008, 11.071905000000008, 9.975615000000003, 9.978539999999999, 8.392020000000006, 8.098740000000003, 9.093435000000003, 9.487140000000004, 9.660300000000017, 9.059310000000004, 8.832135000000005, 9.95553000000001], [0.0, -1.7682600000000033, 1.201784999999978, 4.221554999999988, 6.101549999999986, 1.425645000000003, -4.096170000000015, 1.836119999999994, 7.9033499999999925, 11.584754999999989, 14.111759999999988, 14.86270499999999, 16.27138499999999, 9.199124999999995, 4.95416999999998, 4.539404999999993, 5.51108999999998, 6.370844999999981, 4.21901999999999, -1.8275400000000044, 4.66205999999999, 13.253369999999988, 11.994644999999988, 9.605309999999987, 12.484484999999989, 9.270689999999986, 15.20687999999999, 14.67745499999999, 18.028919999999992, 15.981809999999992, 17.362409999999993, 15.103529999999989, 14.142179999999989, 13.144169999999988, 13.821599999999988, 12.929669999999987, 11.744849999999989, 13.344239999999989, 16.340219999999988, 18.93995999999999, 20.42605499999998, 17.057819999999992, 20.408114999999995, 18.411119999999986, 16.06390499999999, 9.98848499999999, 8.006699999999986, 8.569859999999991, 9.878309999999988, 10.361129999999987, 9.78197999999999, 11.027249999999988, 15.756584999999992, 23.656230000000008, 21.64987499999999, 27.994395, 23.693669999999976, 20.479484999999983, 17.857709999999994, 16.362644999999993, 14.550509999999987, 12.484874999999988, 11.816219999999987, 15.29033999999999, 16.296539999999986, 17.36474999999999, 19.438964999999982, 16.933019999999992, 19.823114999999984, 16.23784499999999, 14.376179999999989, 14.67355499999999, 12.48779999999999, 14.270294999999988, 14.864069999999987, 13.429454999999988, 13.95887999999999, 12.768404999999987, 12.21109499999999, 12.19763999999999, 11.816414999999987, 12.292604999999988], [0.0, 4.958265000000001, 3.6948599999999976, 3.1558799999999985, 3.4973249999999987, 2.856555, 5.407544999999994, 4.966259999999998, 5.018909999999998, 4.008029999999996, 1.572284999999998, -0.3693300000000006, -2.9977349999999916, -1.885259999999998, 1.2910949999999985, 5.42802, 1.9338149999999996, -0.34241999999999795, -2.202914999999999, 1.5843749999999988, 2.0391149999999993, 2.151629999999998, 0.6573449999999987, -0.08969999999999656, 0.9603749999999986, 5.445569999999998, 6.949799999999993, 10.221510000000002, 8.285744999999995, 13.46377500000002, 15.132195000000015, 18.748665000000013, 21.16705500000002, 21.772335000000023, 20.68657500000004, 22.091355000000025, 21.982350000000036, 23.429835000000015, 22.748310000000014, 24.792495000000038, 25.690860000000036, 26.606775000000013, 24.64293, 21.683415000000007, 21.83688000000002, 19.370130000000017, 18.09053999999999, 15.937154999999999, 16.39579500000001, 16.565835000000003, 17.151224999999997, 16.600934999999993, 21.28639499999999, 25.007579999999923, 25.30417500000002, 24.234015000000017, 20.759894999999986, 19.994520000000016, 16.98684000000003, 12.544545000000005, 14.663609999999995, 13.502774999999993, 10.48047, 10.907519999999995, 10.77569999999999, 17.024084999999985, 15.612870000000015, 12.821250000000001, 15.515370000000015, 8.987354999999996, 6.223229999999994, 5.776874999999997, 4.0676999999999985, 3.266054999999998, 3.2011199999999977, 3.490499999999997, 0.33286499999999997, -0.019890000000000185, -0.578565000000002, -0.3979950000000043, -1.567410000000005, -2.1360300000000016], [0.0, -0.1279199999999987, -0.576225, -0.7608899999999927, -2.1783450000000104, -1.802384999999994, -0.6592950000000037, -3.6262200000000018, -5.4906150000000045, -3.4620300000000084, -1.278615000000011, 3.6281699999999812, 2.3758799999999862, 3.080024999999978, 2.6352300000000017, 3.8982449999999904, 6.382349999999972, 4.124249999999982, 5.975189999999984, 7.187504999999982, 3.9405600000000067, 0.8291399999999935, 4.2976049999999955, 5.124404999999994, 1.6807050000000014, -1.6487250000000016, -4.534530000000004, -5.4718950000000035, -5.3166750000000045, -4.389645000000004, -3.3504899999999984, -2.1157499999999985, -1.1267100000000028, -3.4082099999999995, -2.010450000000005, -0.49198500000001655, -1.252095000000006, -1.2737399999999983, 0.9615449999999885, -0.10939500000000191, -0.06571500000000441, 0.37127999999999695, 0.6821099999999936, 0.8418149999999942, 1.6440450000000002, -0.1014000000000097, -2.757495000000001, -3.7777350000000043, -4.147065000000005, -2.4302850000000027, -1.1555700000000035, -0.647790000000013, 3.9559649999999795, 5.936189999999991, 6.790484999999984, 3.9668849999999907, 7.468889999999975, 9.021674999999995, 7.844069999999983, 4.759949999999995, 6.238439999999974, 4.873634999999993, 2.5591799999999854, 3.153345, 3.3081749999999897, 8.945234999999988, 9.661274999999979, 9.417134999999965, 6.917234999999982, 5.281574999999986, 5.66065499999999, 4.951439999999989, 3.9980849999999997, 3.626220000000007, 3.978974999999984, 2.7972749999999973, 4.081740000000007, 4.434494999999993, 3.089774999999994, 4.1057249999999765, 4.396469999999995, 3.914234999999996], [0.0, 3.7964549999999937, 4.577039999999993, 2.7643199999999952, 2.7758249999999944, 4.236179999999992, 7.057439999999999, 6.408674999999996, 3.283604999999995, -0.7435349999999987, -3.555825000000011, -2.975114999999999, -6.2809500000000025, -3.497130000000002, 4.692284999999993, 6.562724999999997, 6.704684999999994, 7.373924999999991, 6.6122549999999976, 8.222760000000001, 6.315269999999994, 3.737759999999992, 0.32116499999999437, -0.7427550000000025, -1.0779600000000054, -0.3981900000000085, 2.430479999999994, 4.5466199999999946, 1.5841799999999915, 6.360509999999997, 8.679254999999992, 11.865945000000004, 14.447159999999988, 14.288819999999992, 12.454259999999998, 11.963250000000002, 11.633310000000005, 9.864854999999995, 8.583120000000001, 11.41101, 7.361444999999993, 9.759360000000006, 13.68334499999999, 16.174859999999992, 16.208595000000003, 19.04564999999998, 10.514399999999997, 7.967309999999994, 8.020739999999995, 8.023275, 7.892429999999997, 9.249240000000004, 14.143739999999994, 10.027679999999998, 7.295729999999993, 11.703704999999992, 9.746489999999989, 12.924404999999993, 19.033950000000004, 13.141829999999992, 14.800109999999995, 13.701674999999996, 7.316009999999993, 8.929049999999993, 10.78817999999999, 16.597035000000012, 12.36066, 10.851944999999994, 11.823629999999985, 6.095699999999994, 2.7097199999999937, 2.504384999999991, 2.0383349999999925, 3.935294999999993, 2.415854999999991, 1.306889999999993, -0.9044100000000039, -2.2497150000000037, -3.6870600000000167, -4.106505000000011, -3.813810000000011, -4.657380000000007], [0.0, -2.7354599999999962, -4.471740000000132, -6.50227499999999, -9.371115000000025, -11.448644999999978, -11.830845000000004, -14.424149999999933, -14.000805000000035, -9.161490000000093, -4.149795000000047, 3.0499949999999814, 4.301504999999899, 7.4788349999999895, 4.903664999999947, -1.3726050000000285, -1.5656550000000422, -5.834205000000061, -3.690180000000076, -3.63558000000004, -11.607960000000041, -16.700970000000147, -11.804910000000014, -10.061414999999947, -5.7487950000000225, -6.320145000000032, -2.9094000000000975, -0.905969999999968, 0.4999799999998942, 0.3956549999997847, 0.737489999999859, 3.6447449999999364, 3.585269999999902, 4.153499999999816, 5.835374999999878, 3.0355649999999628, 1.2197249999999187, 0.44674499999999284, -0.5282550000000086, -4.8753900000001025, -5.254275000000028, -10.776284999999994, -20.746245000000066, -19.01776500000009, -16.07365500000001, -19.124040000000072, -17.77132499999997, -18.36919499999997, -17.719455000000018, -17.547075000000056, -14.591655000000067, -10.989615000000079, -11.241164999999988, -10.380435000000183, -11.34081000000004, -20.78115000000016, -19.289985000000023, -17.86375500000012, -17.1264600000001, -15.93383999999994, -14.163630000000019, -16.12806000000007, -15.873390000000192, -14.99744999999995, -12.581595000000043, -13.322790000000161, -5.180370000000046, -1.3975650000000641, -9.731475000000152, -5.070975000000196, 1.3029899999998804, -0.9904050000001376, -1.8478200000000626, -1.0869300000000166, -1.5434250000000773, -2.060175000000079, -4.797780000000053, -3.083535000000019, -1.3433550000000807, -2.818725000000022, -1.6179149999999751, 0.16282499999994826], [0.0, -4.787249999999997, -6.257354999999965, -2.8990650000000215, -4.820009999999982, -5.244914999999978, -9.524969999999943, -7.995974999999937, -1.4722500000000132, -3.188250000000007, -0.032175000000041365, 0.5403450000000056, 0.23809500000001904, 2.7890849999999894, -5.908695000000005, -14.208089999999995, -12.295724999999972, -13.738724999999999, -14.216864999999963, -18.019169999999967, -16.068194999999967, -6.371235000000013, -6.771570000000015, -8.571030000000011, -5.327399999999972, -3.9779999999999873, -1.1643449999999937, 0.40033500000000544, 3.560700000000006, 3.8005499999999888, 3.8194650000000046, 1.4201849999999823, 0.18446999999998148, 1.1107200000000166, 3.089969999999985, 3.212039999999993, 2.8549949999999953, 5.1074399999999915, 5.7942299999999864, 5.249594999999989, 7.86162, 5.117969999999998, 0.7331999999999912, -1.575599999999998, -1.1941800000000313, -5.38824, 0.7950149999999923, 1.341794999999987, 1.8887699999999867, 1.8197399999999817, 2.8672799999999974, 3.8719199999999923, 0.8817899999999952, 3.7276199999999786, 5.407739999999993, 1.3841100000000015, 2.2508849999999807, 0.1649699999999985, -4.302284999999966, -2.207010000000004, -4.63846499999995, -5.524155000000015, -2.68905000000003, -2.4193650000000098, -0.25194000000000294, -5.224049999999995, -0.6591000000000182, 0.5602349999999952, -0.34690499999999425, 5.102759999999991, 6.595094999999988, 7.966724999999997, 7.327904999999998, 6.900074999999998, 7.76275499999999, 6.308639999999997, 5.728319999999989, 7.441004999999999, 6.836700000000002, 7.33843499999999, 7.111845000000003, 8.013329999999995], [0.0, -2.420145000000002, -3.016845000000001, -3.654690000000003, -3.6156900000000043, -3.5232599999999996, -4.0318200000000015, -3.640650000000002, -5.3320799999999995, -3.826485000000002, -0.7544550000000008, 3.104009999999997, 4.190355000000003, 4.157009999999999, 3.039464999999999, 0.716234999999998, 0.9982050000000013, 0.7326149999999956, 2.3694449999999985, 2.5981800000000037, 1.103505000000001, -1.7117100000000023, -2.380560000000002, -0.26481000000000177, 0.8004749999999978, -1.0730850000000016, -2.0447700000000006, -2.1381750000000004, -1.5206100000000013, -0.7774650000000016, -0.25116000000000227, 2.8321799999999984, 2.7079650000000006, 1.7990699999999982, 0.9274199999999966, 1.0746450000000016, 0.5278650000000007, -1.0565100000000012, -0.7581599999999996, -0.25603500000000223, 0.3535349999999964, 0.5927999999999969, -1.0964850000000004, 0.3131699999999975, -0.46917000000000075, -0.6791850000000007, -4.15935, -3.851640000000004, -3.166800000000003, -0.6678750000000024, 0.653835000000003, 0.548339999999996, 4.614284999999995, 3.88712999999999, 4.850234999999989, 3.99925499999999, 1.9782750000000031, 3.1276050000000017, 4.316910000000004, 2.191604999999997, 4.481099999999991, 4.5955650000000015, 2.668574999999996, 3.2824349999999987, 5.306924999999998, 9.520095000000007, 8.14359, 9.541350000000008, 7.7077650000000055, 6.975929999999998, 8.50648499999998, 7.338240000000001, 6.064109999999994, 6.847815000000002, 6.279780000000007, 7.795514999999998, 5.696534999999995, 6.098430000000007, 4.415579999999996, 5.298344999999992, 5.0526449999999965, 4.314765], [0.0, 4.26601499999998, 6.372599999999961, 6.39443999999993, 4.755854999999949, 9.5197049999999, 9.224669999999938, 5.275724999999971, 2.3633999999999755, 2.79824999999998, 2.124134999999944, 1.218554999999986, -0.6029400000000109, 0.8451299999999637, 8.982479999999901, 13.025219999999914, 12.553124999999936, 10.244714999999955, 13.884584999999964, 12.374504999999951, 6.670754999999991, 6.071324999999947, 6.580274999999949, 5.765564999999961, 6.032714999999952, 8.463584999999911, 7.836074999999907, 10.280789999999948, 9.673364999999938, 12.416819999999928, 16.008134999999974, 15.83204999999995, 18.848114999999922, 14.831309999999936, 13.412879999999928, 13.458899999999959, 13.560689999999957, 12.329849999999945, 12.11983499999994, 14.863485000000003, 15.02942999999994, 15.432689999999978, 20.61286499999997, 19.994714999999943, 18.52363499999995, 21.03347999999992, 15.329924999999944, 14.769494999999973, 14.960009999999928, 15.269279999999958, 15.337919999999945, 16.16218499999991, 21.013394999999946, 18.581354999999988, 18.267209999999956, 24.371294999999932, 18.716684999999963, 20.858369999999887, 26.917214999999928, 23.77790999999997, 21.88465499999994, 22.85068499999992, 17.58197999999991, 20.139794999999943, 21.549449999999958, 26.65591500000002, 21.269234999999973, 19.560839999999985, 20.47265999999994, 13.95107999999995, 11.539124999999922, 11.54770499999987, 9.85081499999992, 11.987429999999952, 10.623989999999905, 9.1772849999999, 7.559564999999912, 6.045584999999944, 4.882604999999964, 6.222644999999945, 5.528834999999953, 5.001749999999957], [0.0, -3.577664999999999, -4.710030000000005, -4.025970000000003, -4.043520000000001, -4.775940000000004, -7.336679999999994, -9.111570000000032, -6.566820000000007, -4.6720050000000075, -3.4850400000000072, -4.644705, -4.5608549999999966, -4.100654999999998, -9.356489999999997, -11.196510000000002, -10.296390000000043, -11.341005000000012, -12.579255000000021, -15.060825000000031, -17.081025000000007, -12.271935000000035, -6.2000250000000054, -7.788690000000013, -7.77582000000001, -5.90303999999999, -5.429970000000004, -1.7483700000000018, -3.282435000000001, -2.023125000000005, -1.9414200000000057, -0.3190200000000054, -0.13552500000000167, 1.546154999999998, 1.910219999999997, -0.19578000000000362, -0.19792500000000057, -0.5828549999999981, 0.042899999999998606, -0.28002000000000216, -3.4370700000000114, -3.5981400000000057, -5.2070849999999975, -3.8721150000000013, -3.933345000000004, -4.515419999999999, -3.7313250000000058, -3.4598850000000003, -4.159740000000001, -3.9772199999999995, -2.9846700000000035, -0.1852499999999977, 0.40033499999999855, -0.9005099999999984, -4.087785000000007, -6.55746000000002, -5.858190000000008, -5.459025000000006, -6.626880000000007, -5.757960000000006, -3.302325000000002, -4.012709999999988, -5.370495, -4.421820000000013, -3.3682350000000016, -2.9756999999999967, -1.8764849999999975, -1.1438700000000015, -0.49354500000000057, -0.29952000000000156, -2.5700999999999996, -1.8989100000000065, -0.9720750000000007, 0.0068249999999978606, -0.8053499999999985, -1.8790200000000064, -1.3729949999999986, -1.5658500000000002, -1.7854200000000051, -1.7723550000000023, -1.7366699999999997, -1.8842849999999998], [0.0, -1.0048350000000004, -1.306500000000002, -0.9876749999999994, -0.8346000000000005, -2.2463999999999973, -2.293004999999996, -1.1813100000000039, -1.939665000000002, -2.5322700000000027, -1.777619999999997, -1.8142799999999983, -2.982524999999996, -3.3561449999999984, -4.844774999999995, -6.860880000000003, -8.340930000000016, -8.665994999999999, -10.260510000000009, -10.408905, -8.812244999999999, -8.06403, -7.736819999999998, -6.494864999999999, -4.719975000000005, -2.602275000000002, 1.0851749999999993, 2.1516299999999977, 3.291794999999999, 4.0482000000000005, 3.814394999999996, 7.553519999999994, 7.835879999999994, 8.774415000000008, 7.553130000000008, 7.572824999999996, 6.755970000000007, 6.970080000000001, 7.049054999999997, 7.157669999999998, 6.243314999999997, 6.136064999999991, 4.654844999999998, 5.249789999999999, 5.311019999999997, 3.7794899999999987, 3.199364999999999, 3.5060999999999964, 2.8850249999999997, 2.6742299999999997, 4.265234999999998, 4.020314999999998, 4.340309999999997, 4.871489999999995, 3.0618899999999996, 2.2542, 2.4452999999999996, 2.54748, -0.9792899999999989, -0.9381450000000036, 0.8808149999999988, 1.0939499999999984, -0.9751950000000007, -1.508520000000003, -2.5264200000000057, -1.8018000000000014, 0.27689999999999926, -0.5081699999999993, 1.2663300000000002, 2.0660250000000007, -0.2254200000000004, 0.2765099999999989, 0.5378099999999996, 0.9673949999999997, -0.3484649999999976, -0.6756750000000011, -0.9911850000000006, -0.7185750000000002, -1.9248450000000044, -1.5551249999999999, -1.2639899999999997, -1.6701750000000004], [0.0, -1.3671450000000052, -2.8399800000000024, -2.3784149999999964, -1.6781700000000122, -3.560505000000002, -4.537650000000001, -3.453450000000001, -2.8704000000000036, -4.952610000000002, -6.055920000000001, -7.18536, -8.916960000000005, -6.790290000000001, -5.991375000000001, -7.864545000000004, -4.240275, -3.5353499999999993, -7.3641749999999995, -7.858305000000003, -7.742865000000002, -5.54112, -6.474780000000001, -7.623525000000001, -7.605585000000003, -8.525789999999997, -7.526609999999999, -7.457579999999999, -6.002880000000001, -3.922425000000003, -1.6972800000000055, 2.3130900000000025, 1.5687749999999978, 3.4394100000000023, 3.5768850000000167, 2.9729700000000054, 2.008109999999993, 1.4307150000000126, 1.655159999999995, 1.892280000000003, -0.03802500000000286, 0.2408249999999983, 1.28505, 1.3219049999999868, 1.4796600000000035, -0.5167499999999992, -2.747355000000006, -2.7617850000000033, -2.7951299999999986, -1.76865, -0.6372599999999968, 0.6949799999999948, 1.6247399999999965, 2.407859999999994, 0.6789900000000033, -0.5093400000000035, -0.045434999999996784, -0.5307900000000076, -2.1744450000000004, -2.7048450000000046, -1.965795000000007, -2.514525000000004, -3.805230000000001, -3.948360000000005, -2.7383850000000023, -0.5009550000000029, 1.7351100000000024, 3.1907850000000124, 2.0328750000000113, 1.0093200000000184, -2.6676, -3.308954999999999, -2.422874999999995, -2.5426050000000013, -3.480360000000001, -4.029480000000006, -5.375370000000001, -6.4468950000000005, -7.048274999999999, -8.249279999999999, -8.590725, -8.23914], [0.0, -0.6095700000000095, -0.738855000000008, 0.02378999999998932, 1.4291549999999944, 0.7770749999999937, 1.065284999999995, 3.668534999999994, 1.5644849999999964, -0.8295300000000037, -2.890095000000003, -5.1951900000000135, -6.774105000000026, -5.467020000000002, -7.805070000000026, -11.326185000000017, -9.04858500000002, -10.438740000000024, -13.307970000000019, -12.852450000000015, -9.046440000000008, -9.397050000000032, -9.744930000000021, -6.051240000000024, -3.7092900000000197, -1.1407500000000086, 5.852534999999996, 7.2883199999999935, 11.440260000000002, 13.210859999999993, 15.753465000000002, 17.32243499999999, 17.23000499999999, 18.394350000000003, 18.51193499999999, 18.37290000000001, 18.309135, 19.11468, 19.515795000000004, 18.59286000000001, 19.575854999999983, 19.436039999999984, 17.206409999999973, 15.820350000000001, 15.665325, 13.520520000000001, 13.326104999999998, 15.209024999999997, 14.559285, 14.698710000000005, 13.74398999999999, 12.602069999999996, 12.604994999999999, 13.345604999999999, 14.007824999999993, 13.05622499999999, 12.581594999999986, 11.325795, 6.896369999999994, 6.805304999999993, 8.711039999999997, 8.11609499999999, 6.963644999999996, 7.293974999999994, 5.856239999999994, 4.766384999999995, 5.4200249999999945, 4.453799999999994, 5.787209999999994, 7.06251, 6.050264999999994, 6.084389999999994, 5.493539999999992, 3.6055499999999934, 3.5599199999999893, 1.6138199999999903, 1.981784999999995, 0.7897499999999913, -0.9498450000000034, -1.3800150000000029, -2.696655000000007, -2.905110000000012], [0.0, -1.463084999999996, -1.2251850000000033, -1.4617199999999961, -3.202680000000015, -2.714984999999995, -2.9971499999999995, 0.06376500000000362, 0.7891649999999917, 1.6122599999999965, 2.2329449999999946, 1.7025449999999864, 1.7241899999999957, -0.009555000000014857, -5.635500000000006, -9.728744999999991, -9.338160000000007, -9.498644999999994, -10.513229999999998, -9.968984999999963, -4.996484999999998, -2.650245, -1.5081300000000066, -0.4307549999999907, 2.118675000000004, 3.2165250000000007, 8.252595000000001, 9.990825000000001, 11.734904999999998, 12.527774999999995, 13.972530000000004, 13.342484999999995, 13.751984999999994, 13.304070000000003, 13.759590000000003, 12.869024999999988, 12.722384999999992, 13.276184999999996, 14.896829999999998, 14.692859999999996, 14.132819999999999, 12.230399999999996, 9.846915000000001, 10.701405000000001, 10.6587, 9.828585, 9.371310000000001, 11.117534999999998, 11.218544999999999, 11.279384999999996, 11.01399, 11.217569999999998, 11.802959999999999, 13.650195, 12.559169999999998, 9.586005000000002, 11.179545000000005, 11.602889999999999, 9.309690000000002, 8.794695, 8.81478, 7.819890000000001, 8.514285000000001, 8.10381, 8.140080000000001, 7.120620000000002, 9.120345, 8.735025, 7.515689999999999, 10.819770000000004, 10.58382, 9.972105000000003, 10.321155000000001, 10.077405, 9.915945, 9.21024, 8.731905, 7.879560000000004, 8.89551, 8.64123, 8.446815, 8.808735000000002], [0.0, 2.9359200000000385, 0.0039000000000442014, -1.2257699999999545, -6.6173249999999655, -14.69051999999995, -25.088309999999993, -33.83093999999993, -39.80749499999982, -53.36720999999997, -59.99408999999996, -63.81823499999989, -71.32963499999994, -61.13581499999994, -38.91224999999976, -25.445939999999837, -13.538654999999807, -9.309689999999733, -13.34365499999987, -19.598669999999885, -28.049774999999855, -40.20178499999983, -56.43943499999993, -81.61139999999983, -113.89910999999984, -147.54323999999986, -177.68867999999983, -215.2634249999998, -243.23656499999979, -264.5956949999999, -285.3355049999998, -298.3162649999998, -308.34530999999976, -313.13880000000006, -314.9987099999998, -315.25688999999977, -308.628255, -302.8749749999997, -301.65661499999976, -300.44586, -290.1876899999996, -278.83030499999995, -277.0306499999998, -280.0264349999999, -277.82605499999977, -287.1530999999998, -301.09969499999977, -306.0528899999999, -307.84728000000007, -303.58828499999976, -299.81172000000004, -293.92486499999967, -287.29954499999997, -281.89199999999994, -276.5374949999996, -273.20416499999976, -273.38473499999986, -267.49007999999975, -276.41737499999965, -288.53662499999973, -286.94951999999984, -290.06795999999997, -298.0857749999997, -296.2677899999999, -285.1040399999996, -277.40095499999984, -264.7741199999998, -254.51438999999993, -241.8532349999997, -231.496395, -220.80259499999988, -204.76618499999995, -191.7265349999999, -180.95005499999985, -168.75416999999985, -157.84430999999987, -149.55310499999985, -140.12953499999986, -133.04420999999985, -123.62512499999984, -117.61288499999982, -113.59081499999986], [0.0, -3.1178549999999987, -4.308720000000004, -2.952690000000004, -2.9833050000000005, -5.548139999999998, -7.8212550000000025, -6.232979999999999, -3.5876100000000006, -3.8960999999999997, -2.2540050000000025, -0.8769150000000018, -0.042900000000001604, -2.3776350000000015, -8.12253, -10.179585000000001, -7.436129999999997, -7.94664000000001, -11.303760000000006, -13.320840000000004, -11.061764999999992, -5.665140000000007, -2.9550300000000016, -4.0877849999999984, -2.9587350000000003, -3.776370000000001, -2.618265, -2.4509550000000018, -2.4532950000000024, -1.6697850000000014, -2.4388650000000025, -1.1456250000000012, -1.2286950000000019, 1.1801400000000004, 1.0582650000000002, 1.0613849999999985, 0.4266599999999978, 0.22483499999999945, -0.10510499999999923, -0.1575600000000008, -2.068170000000002, -2.3595000000000015, -1.6978650000000013, -3.006315, -2.7865500000000027, -1.8895500000000012, -3.33411, -3.209310000000002, -3.0127500000000023, -1.9414200000000013, 0.35684999999999767, 1.7805450000000007, 1.984514999999999, 0.3773249999999966, -1.2072450000000015, -1.2082200000000016, -1.9903650000000015, -2.6845649999999996, -3.393975000000001, -4.351425000000006, -2.583360000000001, -1.5420600000000018, -3.016065, -2.692560000000001, -1.6848000000000007, 0.49646999999999797, 0.6431099999999979, 0.0951599999999988, 2.2155899999999997, 1.9921199999999948, 0.30868499999999965, 1.0834199999999974, 1.570529999999999, 2.1627449999999993, 1.5130049999999995, 0.8932949999999975, 1.1945699999999995, 1.2647699999999966, 1.5871049999999995, 1.8302699999999994, 1.9287450000000044, 1.8805800000000017], [0.0, 2.734679999999999, 4.462574999999991, 5.281184999999996, 5.097884999999996, 7.769189999999996, 5.133569999999995, 0.9359999999999928, 0.29015999999998865, 2.603444999999991, 5.435234999999994, 5.024369999999996, 5.9092799999999945, 6.510464999999995, 12.551759999999987, 11.634089999999997, 8.326889999999995, 8.213789999999994, 10.915514999999996, 11.054744999999993, 5.678594999999994, 6.294404999999994, 9.252554999999996, 8.286524999999996, 8.663654999999995, 13.375439999999994, 11.881349999999998, 10.623794999999998, 13.731509999999993, 16.657485, 17.71652999999999, 17.894954999999992, 16.533269999999984, 14.521845000000008, 16.052204999999994, 16.703699999999998, 14.882009999999998, 14.880644999999989, 15.637245, 17.97315, 21.75809999999999, 19.722690000000004, 22.617464999999985, 24.33463500000001, 22.328670000000002, 13.0689, 10.319789999999996, 10.128884999999999, 11.366159999999995, 12.224354999999996, 12.934349999999997, 14.009385000000005, 15.999164999999987, 22.751625000000004, 23.25862499999999, 24.65755499999997, 24.24883499999999, 21.059219999999986, 15.059265, 16.93886999999999, 16.75010999999999, 13.764074999999991, 10.046789999999996, 11.94258, 13.809899999999988, 15.089490000000001, 18.042375000000003, 14.654835000000002, 15.044249999999998, 11.957204999999995, 7.267259999999995, 6.916454999999996, 5.012864999999993, 6.577544999999995, 6.174869999999996, 5.016959999999994, 4.863884999999994, 3.0702749999999934, 2.1742500000000025, 2.9425499999999944, 1.5311400000000015, 2.312309999999991], [0.0, -2.3795849999999676, -3.2974499999999844, -1.3256099999999824, -2.144024999999986, -4.052099999999979, -4.952999999999979, -2.0675849999999905, 0.17043000000000674, 0.7800000000000074, 1.9578000000000064, 3.6954450000000056, 3.8448150000000068, 1.0518300000000016, -4.077839999999985, -6.7265249999999925, -4.418504999999992, -4.336019999999979, -6.21016499999999, -7.14557999999998, -3.5137049999999883, -0.5883149999999908, -0.2985449999999892, -0.49295999999998585, 0.5190900000000029, 0.7119450000000098, 2.0225400000000064, 2.896335, 2.1723000000000083, 1.3739700000000106, 1.4252550000000062, 2.2497150000000032, 1.9981650000000055, 2.586675000000001, 1.9870500000000089, 1.7134650000000065, 1.617915, 0.783705000000003, 1.7860050000000092, 1.6543800000000042, 0.19012500000001165, -2.75300999999999, -2.9614650000000013, -1.9109999999999934, -1.5582449999999959, -0.21020999999998846, -0.2328299999999981, -0.6017699999999984, -0.22073999999998417, 0.384540000000011, 1.3716300000000095, 2.8924350000000083, 3.886740000000006, 1.8271500000000058, -0.6674849999999912, -0.8687249999999889, -1.201199999999984, 0.7813649999999983, 0.8067150000000103, 1.0258950000000109, 1.9675500000000028, 2.477475000000004, 1.3000650000000062, 2.510430000000003, 3.1983900000000065, 5.096715000000007, 4.160520000000005, 3.2434350000000056, 3.638505000000006, 5.185635000000007, 5.2694850000000075, 5.382975000000007, 6.145425000000007, 6.411210000000007, 6.084390000000007, 5.270070000000008, 5.747820000000007, 5.992350000000007, 6.563895000000007, 6.996405000000007, 7.600320000000004, 7.722195000000009], [0.0, 3.6305099999999975, 4.163250000000003, 1.6145999999999985, 2.5482599999999946, 6.614595000000004, 6.538155000000004, 6.594120000000005, 3.656444999999998, 3.3896850000000036, 2.593695, 0.20494500000000065, -1.301624999999997, 0.9453600000000004, 6.865559999999996, 6.501105000000005, 4.500795, 1.639754999999998, 2.95386, 2.495609999999999, 2.9049149999999986, 1.799459999999995, 0.6360900000000005, 1.1659049999999995, 2.921295000000002, 7.282469999999992, 6.762015000000005, 7.936110000000001, 9.993944999999979, 12.889695, 14.54193, 17.193929999999995, 17.430464999999987, 17.494619999999994, 17.322044999999996, 19.15484999999999, 16.951349999999987, 14.630265000000009, 15.814499999999988, 15.472275, 15.140190000000011, 18.96433500000001, 22.81246499999999, 24.628890000000006, 22.98484500000004, 17.661540000000006, 14.859194999999993, 15.279615, 14.355509999999985, 14.096744999999988, 16.350165, 20.003880000000002, 21.096855, 16.850340000000003, 18.63693000000001, 19.490444999999976, 20.27804999999996, 20.78329499999998, 19.022835, 18.60202500000002, 22.372935000000002, 19.66204500000002, 15.46642499999998, 15.501134999999998, 18.743204999999975, 21.077939999999963, 17.36084999999998, 17.61902999999998, 15.896790000000024, 8.590335000000007, 8.35672499999999, 8.097569999999996, 7.445879999999994, 10.351184999999997, 8.588580000000004, 7.371975, 5.027880000000003, 3.728594999999997, 3.721185, 4.420844999999997, 2.7005550000000005, 2.828280000000001], [0.0, 0.9989850000000002, 1.2860250000000057, 1.7171700000000012, 1.4548950000000027, 3.7036350000000016, 4.491825000000004, 2.4037650000000013, 0.5179200000000077, 1.1193000000000066, 1.6405350000000034, -0.07214999999999971, 0.5450250000000016, 4.067699999999997, 7.169759999999998, 5.3348100000000045, 2.344095000000005, 2.4934650000000036, 2.838809999999999, 4.607265000000007, 3.332355000000003, -0.4990049999999975, 2.9466450000000024, 5.029245000000001, 5.96505, 8.692319999999988, 7.299825000000014, 10.484565000000009, 13.79566500000002, 15.770235000000007, 14.976585, 16.91605500000001, 19.676279999999984, 17.36864999999998, 18.210855000000006, 18.805215000000018, 20.13862499999999, 18.555810000000015, 18.23016000000001, 21.406905, 23.764845000000047, 24.480885000000015, 23.75392500000005, 19.57917000000001, 21.056880000000035, 18.046470000000024, 14.121705000000006, 15.883725000000016, 15.023775, 16.233165000000007, 16.53502499999997, 18.873074999999975, 21.575774999999986, 23.547225, 24.569025000000018, 25.62592500000002, 18.59656500000001, 19.53802500000002, 20.071155000000005, 17.37566999999998, 16.241549999999993, 15.970305000000003, 13.063049999999986, 13.840125000000004, 15.076815, 17.036954999999974, 15.132389999999969, 12.263549999999999, 14.969564999999964, 10.495289999999999, 8.869185000000007, 8.72898, 7.261019999999995, 7.925385000000009, 5.510114999999994, 5.270070000000004, 6.182474999999993, 3.2880900000000017, 2.878200000000001, 3.0053400000000052, 1.2460500000000048, 2.056080000000002], [0.0, 1.9648199999999818, 2.123550000000016, -0.05908499999997474, 5.639595, 3.825899999999983, -0.8792549999999935, -0.7575749999999886, 3.859439999999992, 6.511440000000057, 15.68151000000002, 18.680415000000053, 20.080905000000065, 13.248885000000062, 15.613260000000086, 14.452035000000034, 12.141285000000078, 14.38339499999999, 14.916135000000057, 11.565059999999995, 9.887085000000027, 16.855020000000092, 18.292950000000044, 14.292915000000022, 12.99792000000005, 11.286015000000063, 16.13137500000005, 16.857750000000042, 17.04144000000007, 18.589545000000097, 19.85977500000006, 19.033170000000094, 16.726905000000112, 13.711815000000062, 13.499850000000066, 12.605190000000075, 11.043435000000066, 9.543495000000071, 7.713810000000123, 7.332780000000071, 7.637760000000064, 10.02904500000006, 9.231105000000056, 13.987350000000074, 13.652340000000077, 4.997460000000061, 8.25688500000009, 6.14347500000013, 5.889585000000068, 8.85124500000002, 8.943675000000049, 9.163635000000042, 9.460620000000041, 10.176270000000066, 12.313275000000072, 9.167925000000025, 17.129775000000066, 21.127860000000066, 16.797105000000048, 16.50207000000007, 14.66536500000008, 12.885405000000052, 12.071475000000078, 14.726400000000083, 16.534440000000043, 18.61177500000003, 18.202665000000064, 20.65537500000006, 16.73158500000004, 16.25383500000008, 18.604755000000047, 17.87857500000008, 15.14409000000009, 13.772265000000075, 15.305940000000032, 14.54973000000006, 12.389910000000047, 13.289640000000063, 13.979160000000043, 13.131495000000072, 14.344200000000022, 13.122720000000033], [0.0, -1.4045850000000084, -1.6058250000000083, -0.45708000000000215, -1.0530000000000048, -1.2431250000000023, -0.6953700000000045, -1.8856500000000067, -2.9285100000000073, -4.093440000000006, -6.053775000000009, -8.001045000000007, -8.35185000000001, -8.015475, -9.004320000000005, -9.062430000000006, -6.262815000000008, -7.708545000000003, -10.038990000000005, -10.269480000000005, -10.169835000000006, -8.718449999999997, -7.50243, -7.9719899999999955, -8.411324999999998, -6.632925000000011, -5.753865000000007, -4.631640000000007, -3.051555000000007, -3.195855000000006, -1.316055000000007, 1.3115699999999944, 2.214615000000002, 3.043365000000006, 2.4070800000000014, 2.2900799999999872, 2.7260999999999997, 2.3023649999999973, 2.2965149999999994, 1.8345599999999989, 1.3039649999999945, 2.8415399999999993, 1.2017849999999992, 0.7577699999999901, 0.634724999999988, -1.7316000000000082, -1.4662050000000053, -1.4792700000000099, -1.1713650000000109, -0.18174000000001067, 0.38902499999998774, 0.8156849999999949, 0.9554999999999882, -0.24901500000000798, 0.18622499999999054, -1.1971050000000045, -2.1157500000000082, -1.7727450000000036, -4.612530000000007, -2.7678300000000076, -2.083380000000006, -3.0829500000000065, -3.6332400000000065, -3.9399750000000062, -3.019965000000007, -0.34456500000001267, -0.21430500000001151, 0.5218199999999911, -0.2503800000000087, -1.7589000000000063, -2.0313150000000055, -1.9030050000000054, -1.9773000000000047, -2.0209800000000047, -2.805465000000007, -3.0451200000000065, -3.8026950000000066, -4.084275000000007, -4.288440000000006, -4.707105000000007, -5.5323450000000065, -5.315700000000007], [0.0, -2.0742150000000024, -1.8218849999999964, -1.1887200000000018, 0.3010800000000238, 1.4196000000000382, 3.949140000000007, 7.237230000000022, 1.0346699999999949, -2.7430649999999783, -10.095149999999975, -13.944449999999986, -14.309684999999984, -6.436169999999983, -4.969964999999979, -5.323499999999994, -3.2352449999999955, -5.96777999999998, -10.172174999999982, -7.059974999999991, -1.3765049999999874, -5.851559999999983, -8.475479999999976, -6.856784999999981, -6.860099999999996, -1.4106299999999745, 2.573025000000012, 3.212430000000033, 9.299550000000028, 13.253175000000045, 16.596060000000065, 19.43350500000011, 19.18683000000007, 19.01094000000009, 18.412680000000094, 18.404295000000104, 15.699840000000062, 15.722655000000042, 18.688800000000107, 18.315570000000022, 20.87085000000004, 25.375935000000013, 24.01074, 25.261665000000043, 22.75357500000004, 19.188000000000052, 19.709430000000054, 19.36740000000006, 18.47332500000006, 16.81836000000004, 16.091595000000076, 18.358470000000096, 15.870270000000062, 14.958645000000029, 22.190610000000035, 19.603545000000032, 18.21534000000002, 14.921985000000042, 14.874600000000054, 15.70920000000001, 16.018080000000047, 14.964104999999996, 14.341080000000016, 14.219400000000007, 18.945615000000046, 13.60885500000008, 12.238785000000025, 15.479100000000042, 9.879675000000052, 4.6774650000000335, 5.277480000000011, 5.587530000000065, 4.194645000000023, 3.322800000000022, 1.7395950000000155, 2.1155550000000254, -0.7105799999999984, -3.400800000000004, -3.1913699999999743, -6.285629999999982, -8.432189999999991, -8.040824999999984], [0.0, -1.5564899999999895, -1.2829049999999889, -0.17296500000000137, -0.4126200000000271, -4.290780000000016, -5.746845000000022, -0.9677850000000152, 2.3452649999999995, 1.900469999999995, 2.356574999999996, 3.4091849999999777, 3.9467999999999854, -1.3644150000000312, -6.99621000000003, -7.2926100000000424, -5.8129500000000505, -7.116525000000017, -11.571105000000014, -15.109770000000026, -8.991255000000013, -1.9342050000000022, -3.2192549999999898, -3.6708750000000236, -1.7557800000000245, -1.2659400000000325, 3.865289999999975, 5.547554999999979, 5.68736999999999, 5.711354999999986, 7.209149999999979, 9.248459999999985, 9.601214999999982, 11.656319999999987, 12.638534999999985, 12.357149999999985, 13.205594999999985, 14.080559999999984, 13.488344999999985, 13.081184999999985, 12.520754999999985, 9.231884999999979, 6.624734999999983, 6.701369999999979, 7.99285499999999, 7.839974999999985, 6.828509999999985, 8.472749999999987, 8.290619999999983, 9.253334999999979, 12.286754999999985, 11.547704999999985, 12.526799999999984, 12.858299999999986, 7.8703949999999825, 9.17045999999998, 8.083529999999975, 9.163439999999982, 7.416824999999983, 5.789939999999998, 6.7436849999999895, 6.651254999999985, 6.750509999999981, 8.728199999999987, 7.060949999999988, 8.980334999999982, 9.701249999999982, 8.596964999999987, 11.052014999999987, 13.396304999999984, 13.982279999999983, 14.644889999999984, 14.828579999999985, 13.508819999999986, 13.335464999999985, 12.954824999999985, 13.460459999999985, 12.942149999999984, 12.691379999999985, 12.684944999999985, 12.998699999999985, 13.154894999999986], [0.0, -3.7516049999999925, -4.387499999999996, -3.5207249999999846, -5.14663499999998, -5.570954999999978, -3.4171799999999752, 0.8868599999999915, -0.9221549999999787, 1.2597000000000147, 2.0280000000000076, 2.836860000000004, 2.300805000000002, 0.07058999999999926, -7.803899999999972, -10.370490000000002, -8.597354999999988, -10.275719999999994, -12.316589999999968, -9.11800499999996, -3.1927349999999866, -3.70714499999999, -5.419439999999989, -2.125304999999983, -1.5301649999999984, 0.6000150000000115, 3.279119999999999, 5.710965000000003, 6.973590000000004, 8.747700000000005, 10.280205000000006, 9.934665000000006, 9.698910000000005, 11.39892, 12.068745000000003, 12.497355000000002, 13.075335000000003, 14.423175000000008, 13.29822000000001, 12.216165000000004, 12.582570000000008, 8.705970000000008, 8.908380000000005, 10.012860000000003, 5.532540000000008, 8.604375000000006, 9.598680000000005, 10.608000000000006, 10.596495000000008, 10.542480000000003, 11.611079999999998, 10.98825, 10.754250000000003, 12.646140000000004, 8.817120000000005, 11.518260000000005, 11.536785000000007, 7.894965000000006, 9.505275000000005, 7.906665000000006, 7.9400100000000045, 7.972770000000006, 7.830225000000006, 9.658740000000005, 7.830030000000004, 6.36636, 9.186450000000004, 9.284145000000004, 10.135320000000005, 13.868010000000012, 15.711345000000001, 15.180165000000008, 14.965860000000013, 12.646530000000004, 12.611430000000006, 11.687910000000004, 12.507495, 12.330825000000008, 12.434565000000003, 12.569700000000001, 12.165075000000005, 12.608115000000003], [0.0, 0.4650749999999926, -0.3597750000000013, 0.9496499999999983, 1.0752299999999906, 1.5071549999999903, 0.4605899999999936, 6.024134999999988, 5.410275000000003, -2.017080000000009, -10.316670000000009, -13.966095000000013, -15.300285000000024, -13.276770000000017, -12.415260000000007, -9.118590000000005, -9.616035000000007, -12.166050000000011, -16.139760000000027, -21.192014999999998, -13.78591500000001, -9.309690000000007, -15.504060000000013, -15.951585000000001, -11.13450000000001, -7.29612000000001, -2.341365000000007, -2.6465400000000048, 1.957410000000002, 2.9542499999999956, 6.729840000000004, 9.11761499999998, 10.538385000000005, 13.280474999999981, 13.25960999999997, 12.36923999999998, 12.863370000000028, 13.307580000000033, 11.85658500000002, 6.361290000000005, 9.717435000000012, 10.167884999999984, 8.497319999999984, 11.442015000000005, 7.774845000000007, 6.442215000000002, 7.306844999999973, 7.434179999999986, 5.318624999999996, 5.411249999999998, 5.6181449999999815, 5.705115000000011, 4.976009999999998, 4.43585999999999, 0.3431999999999906, 1.571699999999991, 1.2444899999999963, -0.5307900000000121, -1.5625350000000018, -1.453140000000007, -0.04192500000000887, -1.8624450000000077, -1.6883100000000084, -3.778320000000007, -6.224595000000004, -1.2811500000000056, 1.4090699999999936, -0.5617950000000032, -1.1210549999999992, -5.0600550000000055, -2.951910000000005, -2.464215000000002, -3.0361500000000037, -2.1982350000000066, -3.0115800000000053, -3.937830000000005, -6.539910000000006, -6.726525000000009, -6.817395000000006, -9.121125000000006, -9.520290000000005, -10.012080000000008], [0.0, -2.7851850000000162, -3.495570000000008, -4.814745000000029, -3.4117200000000025, -4.099485000000023, -5.543460000000032, -4.99161000000003, -0.9020700000000224, -1.4353950000000104, -2.0654400000000184, -2.7530100000000193, -2.4187800000000124, -2.278380000000009, -4.41402000000002, -10.571535000000004, -12.992264999999993, -14.316120000000009, -17.966520000000028, -19.538219999999995, -18.976035000000035, -13.226850000000013, -12.880335000000027, -13.937820000000006, -8.690370000000026, -4.558125000000022, 0.13318499999998412, 2.9780399999999876, 4.980494999999982, 7.572629999999984, 7.009469999999984, 8.097374999999985, 10.407344999999982, 11.674064999999986, 11.199824999999983, 11.082239999999988, 11.669774999999982, 10.658309999999982, 11.503049999999988, 11.143859999999982, 10.805924999999988, 10.146434999999988, 8.67476999999999, 4.465889999999987, 7.0474949999999845, 4.746884999999985, 4.78471499999999, 7.216364999999984, 8.542169999999984, 8.299394999999986, 9.535889999999984, 10.21234499999998, 7.952879999999986, 6.659054999999985, 5.290349999999983, 6.364604999999985, 2.0863049999999905, 3.1324799999999833, 1.5650699999999862, 0.735344999999981, 2.1598199999999865, 2.7307799999999784, 2.2280699999999873, 2.820089999999982, 3.664049999999982, 2.0180549999999835, 3.583709999999984, 4.152914999999987, 6.222449999999984, 8.302904999999988, 8.249474999999984, 7.967504999999984, 8.199164999999985, 7.447829999999985, 7.149479999999984, 6.8372849999999845, 5.991764999999984, 5.222099999999983, 4.478954999999985, 4.303064999999985, 4.2428099999999835, 3.29257499999998], [0.0, 3.983459999999978, 2.3398049999999806, 2.800589999999975, 1.474589999999969, -0.7747350000000068, 2.840174999999981, 4.860179999999978, 3.9224249999999987, 2.1935549999999484, 1.1850149999999786, -0.7051200000000293, -0.8759399999999999, -0.47424000000001243, 1.6134299999999637, 0.34475999999996887, -3.3031050000000164, -9.040979999999998, -11.836889999999975, -10.769460000000006, -10.383359999999996, -11.997180000000021, -12.806429999999967, -12.24502499999998, -9.574694999999966, -3.3885150000000266, 3.753164999999985, 1.620449999999975, 4.657184999999965, 7.386794999999983, 7.382114999999979, 8.279504999999975, 10.738064999999974, 10.077989999999975, 9.461984999999974, 10.608584999999973, 10.632179999999973, 12.90256499999997, 13.881464999999968, 13.02443999999997, 7.734479999999969, 11.077364999999972, 11.53093499999997, 8.81984999999997, 8.443694999999964, 8.047259999999987, 7.990709999999977, 10.496459999999974, 11.262029999999966, 10.747424999999968, 9.985754999999966, 10.733189999999968, 6.8115449999999615, 3.3208499999999592, 6.164534999999974, 4.670639999999947, 3.649814999999986, 4.861154999999986, 2.5597649999999614, 1.7142449999999485, 3.3656999999999915, 3.1568549999999735, 3.1543199999999736, 4.116254999999969, 3.9393899999999675, 0.41008499999994896, -0.7626450000000169, 1.3517399999999604, 1.2780299999999336, 4.3369949999999715, 5.12440499999996, 6.035054999999966, 7.089419999999974, 6.086729999999967, 5.868719999999975, 5.596109999999982, 5.742164999999966, 4.573334999999963, 4.319834999999966, 4.394324999999972, 3.633044999999976, 3.4331699999999525], [0.0, -0.09945000000000803, 0.36738000000000426, -0.7027799999999864, -3.408405000000034, -4.546035000000039, -4.129905000000047, -4.089150000000007, -3.555435000000003, -3.9774149999999864, -1.6863600000000005, 0.8037900000000171, 0.40287000000003204, 1.1602500000000155, 2.6851500000000357, -0.428024999999991, -3.372720000000033, -6.573060000000034, -7.245615000000068, -6.307275000000015, -7.604220000000048, -6.919575000000041, -6.820710000000052, -8.870745000000067, -9.190155000000058, -6.1062300000000675, -4.3781400000000446, -4.51269000000001, -1.3298999999999772, -0.035099999999943066, 0.16243500000004119, -0.11894999999998745, 0.2716350000000034, 0.27631500000001097, 1.0828350000000029, 2.7017249999999926, 3.305835000000018, 5.082090000000024, 5.953935000000035, 5.839275000000033, 4.113915000000022, 5.311995000000051, 2.01435000000005, -0.32623499999997563, 0.49003500000003086, -2.165474999999997, -0.2915249999999894, 1.7624100000000311, 2.65746000000002, 2.9310450000000063, 3.3337200000000333, 4.094025000000018, 4.783155000000022, 4.047810000000032, 6.655934999999998, 3.068520000000026, 2.3466300000000295, 3.7843650000000206, 0.11700000000003996, -0.06005999999997513, 2.1167250000000273, 2.1286200000000015, 2.3817300000000223, 3.9360750000000078, 6.100770000000026, 5.470530000000023, 3.6427950000000315, 5.176080000000013, 5.799885000000028, 6.760845000000023, 8.961030000000036, 11.09784000000004, 10.895625000000031, 10.587135000000034, 9.607065000000032, 9.576450000000033, 9.358245000000032, 10.099635000000031, 9.187620000000031, 9.90444000000004, 9.73323000000002, 9.002760000000032], [0.0, 0.9853349999999867, -0.767129999999991, -1.7140500000000038, -2.1857550000000145, -4.228965000000006, -3.64084500000002, -1.6066049999999983, -0.19539000000002638, -1.3417950000000154, 1.1411399999999627, 0.017549999999969756, -2.0490600000000256, 0.2435549999999811, 0.6319949999999785, -4.596735000000013, -6.269444999999994, -9.102600000000045, -11.31468, -11.845470000000024, -11.062155000000018, -10.807289999999984, -12.012, -10.607025000000025, -7.914855000000024, -5.031975000000031, 0.23809499999997463, -0.8100300000000136, -0.11739000000004829, 1.4593800000000012, 1.746809999999984, 6.694739999999981, 8.005529999999982, 9.359999999999966, 9.978149999999975, 9.596534999999975, 9.847499999999968, 10.524929999999973, 11.814464999999977, 10.682684999999974, 9.711194999999972, 9.91964999999997, 6.308444999999969, 5.439719999999976, 6.039734999999971, 3.450329999999976, 4.7180249999999795, 5.286059999999988, 5.829719999999984, 6.225374999999979, 6.94726499999999, 10.700819999999975, 8.990084999999972, 7.974524999999977, 8.706359999999975, 4.234814999999978, 3.9389999999999716, 4.674344999999976, -0.4274400000000167, -1.5941250000000124, -0.00331500000003615, -0.8923200000000371, -0.7098000000000333, -1.0372050000000321, 1.5707249999999764, 0.29015999999997, 3.083534999999964, 6.044219999999982, 4.809674999999977, 7.308404999999983, 10.354889999999974, 9.795434999999973, 10.332074999999973, 9.762284999999975, 8.076899999999974, 8.508239999999969, 8.40898499999997, 8.532419999999973, 8.650589999999973, 8.487764999999982, 8.220419999999969, 6.792044999999974], [0.0, -0.3246750000000018, -0.929175000000015, 0.3293549999999952, -1.286610000000012, -3.0158700000000085, -4.244174999999979, -3.051749999999979, -1.2971400000000006, -1.087905000000016, 2.002454999999993, 0.8558549999999903, -0.009165000000006529, 2.9819399999999954, 2.9476199999999935, -2.1399300000000068, -4.17475499999998, -8.924174999999995, -8.914229999999975, -9.77671499999998, -9.352394999999989, -8.565764999999978, -8.907989999999984, -8.162309999999978, -7.512764999999982, -5.095739999999999, -0.15287999999998636, 0.462735000000011, 3.138914999999998, 5.402084999999993, 5.195189999999998, 5.302244999999994, 4.068479999999995, 6.284069999999995, 6.985094999999997, 7.947224999999997, 8.995349999999997, 10.146824999999998, 10.161254999999992, 9.107084999999994, 12.643019999999995, 13.020930000000007, 8.7828, 7.836464999999994, 7.7159549999999975, 0.430755000000012, 4.644509999999996, 5.665334999999998, 4.538429999999993, 5.211179999999997, 5.974409999999998, 7.847579999999996, 3.782220000000005, 6.153029999999996, 8.944844999999997, 6.240779999999996, 9.482264999999995, 7.286759999999997, -1.1473800000000036, 0.9586200000000034, -0.9266399999999946, -3.3222150000000266, -0.06513000000000613, -0.5717399999999975, 1.7846399999999978, -2.978625000000001, 0.483794999999998, 3.552899999999997, 2.5584, 7.341944999999996, 8.565764999999995, 9.120344999999999, 9.121124999999996, 7.399664999999998, 8.622314999999999, 8.961029999999997, 8.601254999999997, 8.7906, 8.779094999999998, 8.068514999999998, 7.552544999999997, 6.270224999999999], [0.0, -2.9216850000000028, -5.325254999999985, -6.919964999999994, -6.213284999999994, -5.685030000000001, -8.13442499999999, -7.303724999999988, -4.1657850000000005, -4.466865000000008, -4.0842750000000025, -5.685224999999991, -6.704684999999998, -1.4886300000000012, -2.7321449999999947, -8.004944999999989, -7.453094999999992, -7.825349999999986, -10.057320000000006, -12.09039, -11.40145499999999, -8.029514999999979, -7.779524999999994, -11.039925000000004, -13.737165000000031, -13.87581000000002, -12.151620000000001, -11.744460000000018, -12.788880000000008, -10.592594999999994, -13.236210000000005, -10.064729999999992, -8.199555000000004, -6.318194999999994, -6.137624999999989, -5.8962149999999935, -5.191094999999986, -4.6630350000000025, -4.009005000000002, -3.755505000000001, -5.642519999999996, -4.151160000000005, -6.241559999999993, -8.83662, -9.527114999999995, -9.979514999999985, -12.216554999999998, -11.557455000000012, -11.895389999999997, -9.614280000000006, -7.948005000000009, -5.470334999999998, -3.7812449999999957, -5.879639999999987, -6.661784999999997, -8.1315, -10.728705000000001, -9.965669999999996, -11.584559999999982, -15.968939999999986, -12.491309999999999, -11.682449999999996, -14.207115000000005, -13.569660000000006, -12.301770000000008, -10.667085000000004, -6.989384999999996, -5.533904999999992, -3.809714999999999, -3.0000750000000007, -4.744349999999998, -3.4263450000000066, -2.731949999999995, -2.131154999999999, -1.735694999999999, -2.963025000000001, -2.1939449999999967, -2.3992799999999974, -2.260829999999997, -2.00265, -2.144805, -2.7136199999999997], [0.0, 3.9101399999999273, 3.4663199999999392, 1.4525549999999043, 0.2962050000000005, 0.10939500000002056, -0.10569000000002404, -4.237349999999964, -8.204624999999794, -9.36487499999987, -8.957129999999921, -3.922815, -6.082245000000171, 0.07761000000010654, 8.980920000000012, 10.137660000000025, 7.840950000000021, 7.222409999999954, 5.006820000000005, 6.436949999999982, 0.637650000000022, -5.110949999999974, -3.95733000000007, -3.1209749999999303, -8.688030000000012, -11.520405000000082, -8.639475000000019, -2.7914249999999754, 0.8716499999999883, 1.3039650000000051, -2.229825000000048, 1.1440650000000971, 3.199559999999977, 1.9254299999999205, -2.1003450000000754, -0.830895000000055, -0.8461050000000512, -2.2912500000001046, -4.7213400000000405, -5.1692550000000494, -4.043520000000058, -5.794814999999943, -11.782289999999819, -15.553200000000032, -15.801825000000164, -11.267684999999886, -16.34255999999999, -16.32579000000011, -18.49945500000007, -17.17247999999988, -14.243775000000014, -15.854280000000003, -11.904555000000016, -7.947224999999989, -11.582609999999804, -12.586274999999802, -16.92170999999982, -14.313389999999984, -11.29654499999998, -18.116669999999957, -9.01056000000004, -8.153534999999877, -13.548405000000002, -11.556869999999961, -13.46553000000003, -7.221240000000037, -4.115670000000122, -8.44876499999998, -6.623174999999961, -4.2634800000000155, -6.878625000000028, -7.236839999999972, -8.023664999999937, -8.703434999999999, -7.956390000000013, -10.90869000000012, -10.345334999999906, -10.591619999999864, -11.186955000000026, -11.39073000000002, -10.184460000000044, -12.087659999999957], [0.0, 2.54202, 3.3538049999999986, 3.759405, 3.3545850000000037, 4.219604999999994, 4.697549999999997, 2.470065000000001, -0.8523450000000012, -0.7644000000000009, -2.065635000000004, -3.4306350000000005, -6.607965000000003, -4.109430000000005, 1.994654999999997, 4.082130000000005, 4.825860000000004, 1.1313899999999995, 0.8381099999999987, 0.26754000000000044, -3.4538399999999996, -6.288360000000008, -6.181500000000002, -6.1540050000000015, -7.2813000000000025, -3.8376000000000037, 1.2949949999999988, 2.6523899999999987, 4.084469999999998, 8.537685, 11.232974999999989, 14.617980000000001, 17.940585000000016, 16.648905000000003, 14.806544999999996, 16.455075000000004, 16.924050000000005, 15.822495000000021, 16.582994999999972, 18.84148500000001, 20.90595000000002, 22.725885000000044, 21.57070500000003, 21.491145000000017, 20.469539999999995, 19.37617500000002, 12.090585000000019, 12.008490000000007, 11.792625000000012, 13.589159999999989, 14.40699, 13.000649999999998, 16.400475000000004, 15.224429999999984, 16.802954999999994, 19.472895000000012, 16.79846999999999, 15.022020000000008, 11.589044999999993, 5.68034999999999, 9.920819999999994, 9.864075000000005, 5.403644999999988, 7.438860000000005, 7.959314999999992, 12.03286499999999, 8.971365000000004, 9.158954999999997, 11.911184999999993, 10.440299999999995, 10.127910000000004, 9.395685000000006, 8.002215000000009, 6.875310000000009, 6.3852749999999885, 4.99278, 4.903080000000005, 4.079790000000003, 2.000114999999998, 0.7131149999999996, 0.21177000000000035, -1.1421150000000038], [0.0, -2.6239200000000023, -4.754295000000003, -7.029555000000005, -7.543380000000005, -7.566585000000001, -8.90877, -9.103770000000003, -7.652775000000004, -7.817940000000004, -5.8529250000000035, -3.692325000000003, -5.794425000000003, -3.600480000000002, -3.0314700000000037, -6.806280000000003, -6.043635000000004, -6.537180000000005, -8.672819999999996, -9.53238, -9.458279999999998, -7.289685000000004, -7.2475650000000025, -10.07253, -14.320020000000008, -17.021355000000007, -16.008330000000008, -16.301415000000016, -16.86067500000002, -15.607605000000014, -16.86535499999999, -12.962430000000007, -11.796915000000002, -8.921054999999997, -7.633665000000001, -6.196320000000002, -5.800665000000005, -5.376540000000003, -4.5046950000000034, -5.319990000000002, -6.533865000000004, -5.314530000000003, -6.626880000000003, -7.760220000000002, -7.636395000000006, -10.914540000000002, -12.177554999999995, -11.181105000000002, -10.223265000000001, -8.525205, -5.240820000000003, -3.513510000000005, -1.6097250000000005, -2.877225000000004, -4.979130000000002, -6.7783950000000015, -7.776600000000004, -6.2940150000000035, -9.297990000000006, -11.487255, -9.239684999999998, -8.284965000000003, -11.077755000000003, -10.033140000000003, -7.986419999999999, -5.331690000000004, -0.905190000000001, 0.48691500000000687, 0.6760649999999986, 0.7059000000000015, 0.060645000000002725, 1.433250000000001, 1.7676749999999952, 2.014739999999999, 2.0389199999999956, 1.6013399999999995, 1.2674999999999992, 1.96521, 1.0167300000000026, 2.123745000000011, 2.0410649999999952, 0.42529499999999754], [0.0, 3.3138299999999976, 2.312505, 1.1423099999999988, -0.09652500000000497, 1.1518649999999975, 0.8289449999999945, 0.587144999999998, -2.9370900000000004, -5.841615000000002, -6.396585000000001, -7.219874999999999, -10.309260000000007, -6.580274999999995, 4.7459099999999985, 6.018674999999995, 4.012904999999992, 0.5381999999999993, -2.6473200000000014, -2.413710000000002, -4.006860000000004, -7.954829999999994, -10.753275000000016, -11.780534999999993, -16.249740000000017, -18.03594000000001, -13.987740000000004, -13.91870999999999, -12.442754999999988, -8.708699999999993, -7.6670099999999985, -1.859715000000001, 1.1128649999999995, 3.3775950000000012, 1.793219999999997, 4.12893, 5.248034999999997, 5.483009999999993, 6.177599999999995, 6.827340000000003, 8.53008, 10.566075000000012, 11.20138499999999, 9.033570000000003, 9.809084999999984, 5.946524999999993, 0.08872500000000072, 1.4314949999999997, 1.1003849999999966, 3.454034999999993, 5.734559999999991, 6.162975000000004, 9.566114999999995, 6.357195000000014, 6.674069999999998, 9.77983499999999, 7.478249999999984, 6.54966, 1.2281100000000007, -2.04165, 1.9603350000000013, -0.36913500000000027, -3.606135, -1.903589999999999, 1.670760000000002, 5.725589999999998, 6.000345000000007, 6.488820000000005, 8.546069999999991, 7.533045, 4.394909999999994, 5.005844999999995, 5.169840000000002, 4.851600000000007, 5.065710000000005, 4.875389999999996, 3.7773449999999995, 2.0135699999999996, 0.6358950000000008, 0.3630899999999999, -0.6904949999999995, -2.3050950000000014], [0.0, -4.483634999999994, -7.425989999999995, -8.046674999999995, -8.461244999999996, -9.453014999999995, -9.782369999999997, -9.258989999999995, -10.312574999999994, -9.969374999999996, -5.7731699999999915, -0.7515299999999936, -0.34690499999999425, 1.5202200000000072, 1.689285000000007, -3.9752699999999956, -2.1198449999999873, -2.673644999999987, -5.194409999999992, -4.742594999999995, -5.471309999999992, -7.185944999999995, -7.2362549999999946, -7.275839999999993, -11.98781999999999, -15.910245, -17.787119999999994, -20.27239499999999, -18.954780000000007, -19.31708999999999, -21.28776000000001, -20.429564999999997, -18.796440000000008, -15.131415000000004, -13.188434999999991, -12.128804999999998, -11.155364999999996, -10.274744999999996, -9.317099999999995, -11.418029999999993, -12.351104999999995, -9.874994999999995, -10.529024999999995, -12.445484999999996, -11.882129999999995, -14.452229999999982, -16.865354999999994, -15.220724999999991, -15.90536999999999, -13.843244999999992, -11.154974999999997, -6.869264999999992, -6.320339999999993, -7.338239999999994, -7.018829999999997, -7.589204999999993, -7.609289999999992, -6.104474999999999, -10.302629999999994, -11.864969999999996, -9.106499999999995, -10.885874999999995, -13.02970499999999, -11.519039999999993, -7.759244999999996, -8.652734999999995, -4.323929999999995, -0.6007949999999962, -0.3451499999999861, -2.5201799999999883, -2.332199999999986, 0.03295500000000473, 0.8884199999999964, 0.8671650000000177, 0.09594000000000769, 0.37225499999999556, 0.14390999999999465, -0.29873999999997913, 0.22210499999999378, 1.007954999999992, 1.0803000000000136, -0.009360000000006252], [0.0, -3.55914000000001, -5.931510000000014, -7.5856949999999745, -9.288825000000022, -8.459100000000001, -9.671220000000018, -7.7153700000000125, -6.021990000000015, -3.156660000000022, 1.5014999999999938, 4.615649999999992, 3.6706799999999964, 5.479694999999991, 5.233214999999987, -2.0447700000000015, -3.2974499999999907, -4.335240000000018, -5.446544999999997, -4.7217300000000115, -3.9643500000000262, -2.1596250000000072, -0.18778500000001053, -1.98256500000001, -6.351150000000018, -8.362380000000009, -8.029515000000012, -5.897775000000022, -6.692790000000025, -6.622590000000011, -6.552779999999993, -5.821334999999985, -4.409339999999997, -4.167539999999995, -4.834440000000011, -3.2028749999999953, -2.106585000000006, -2.1570899999999913, -1.630200000000018, -1.4225249999999985, -1.762410000000017, -1.4513850000000108, -1.144650000000011, -2.9058900000000047, -2.151630000000015, -4.476224999999994, -6.480630000000016, -5.159310000000005, -5.499390000000016, -4.073355000000014, -1.7897100000000066, 1.2109499999999978, 3.216134999999996, 2.710499999999991, 2.3632049999999936, 2.5892099999999862, 0.906164999999981, 2.275260000000002, 1.5286049999999927, -0.8314800000000062, 1.0336949999999865, 0.056159999999992216, -0.8441550000000184, 0.6657299999999875, 3.6849149999999993, 6.403019999999994, 8.337614999999994, 9.79309499999999, 11.094719999999992, 9.359804999999993, 8.949914999999994, 10.88821499999999, 10.65148499999999, 11.016134999999997, 11.414714999999994, 10.657139999999997, 10.265189999999992, 9.288434999999993, 10.297754999999992, 11.022374999999997, 10.790714999999995, 11.08847999999999], [0.0, -3.6184199999999773, -5.54053499999997, -2.860454999999968, -3.29861999999998, -5.034704999999979, -6.163949999999987, -5.703554999999984, -1.9006649999999912, -0.32291999999999366, 4.107870000000017, 6.868485000000015, 7.056660000000015, 6.637995000000015, 2.546505000000015, -4.085249999999993, -4.05365999999999, -4.752929999999987, -4.960604999999987, -4.921604999999973, -4.904249999999989, -2.752619999999995, -0.4307549999999907, -1.8406049999999965, -4.052099999999989, -3.204435000000002, -1.169609999999981, -2.301194999999991, -1.398344999999992, -2.001284999999994, -3.1628999999999934, -1.3540799999999802, -1.052024999999995, 0.5777850000000129, 1.350570000000018, 2.0258550000000097, 2.9817450000000125, 3.6156900000000154, 4.600245000000015, 4.702425000000014, 5.012865000000012, 5.401500000000015, 4.886700000000014, 5.026515000000016, 5.255445000000014, 1.5112500000000182, -1.3692899999999888, -1.5750149999999739, -1.2881699999999903, 1.6861650000000168, 4.349280000000012, 6.897540000000014, 7.877610000000016, 8.608080000000013, 7.396350000000015, 7.287150000000015, 7.517835000000014, 8.548020000000013, 4.436640000000018, 2.4283350000000095, 3.824730000000013, 1.8698550000000118, -0.20143499999999204, 0.4853550000000135, 3.4489650000000154, 4.825860000000015, 8.205405000000015, 8.467680000000014, 9.398025000000017, 9.791925000000015, 7.522515000000014, 8.930415000000014, 10.002330000000013, 9.379890000000016, 10.174710000000015, 9.805770000000013, 10.070775000000017, 9.571965000000015, 8.817315000000015, 9.620130000000014, 9.917310000000015, 9.738690000000013], [0.0, -2.1810750000000017, -4.493385000000003, -3.984630000000005, -4.416165000000006, -6.0483150000000006, -7.278570000000002, -5.756594999999997, -4.48344, -5.293470000000008, -0.9330750000000024, 1.8277349999999952, 1.5428399999999929, 1.7589000000000006, 1.3258049999999968, -3.430635000000003, -2.9281200000000047, -3.2777550000000026, -5.201234999999999, -6.557654999999997, -4.155645000000004, -2.8122900000000026, -3.9288600000000002, -5.3539200000000005, -6.929909999999996, -9.089145000000006, -8.425755000000002, -9.51288, -8.74224, -8.810295, -9.931739999999994, -7.618845000000004, -7.385039999999991, -5.593379999999996, -4.378140000000002, -4.0337700000000005, -3.158025000000003, -3.040440000000003, -3.323580000000003, -3.9629850000000038, -4.034550000000001, -3.586830000000001, -3.795480000000002, -4.482855000000002, -4.2931200000000045, -8.232705000000003, -8.314019999999992, -6.7801500000000114, -6.484725000000008, -4.971135000000002, -2.230215000000002, -1.2173850000000024, -1.1315850000000027, -1.0793250000000025, -1.765530000000002, -2.2202700000000024, -3.001635000000003, -1.649895000000002, -5.697315000000009, -5.775120000000005, -3.9530400000000037, -4.8048000000000055, -5.07019500000001, -3.421275000000004, -2.5853100000000016, -1.0243350000000033, 1.8267599999999948, 2.7481349999999956, 2.838809999999993, 2.5490399999999913, 2.477864999999992, 2.746769999999994, 3.515264999999997, 3.5240400000000007, 3.761939999999997, 3.352244999999997, 2.8898999999999897, 2.7906449999999956, 3.963570000000003, 3.6970049999999968, 3.2356349999999954, 3.203459999999993], [0.0, 2.690610000000007, 3.899415000000008, 0.9340500000000089, 1.0167300000000075, 5.8599450000000015, 6.599385000000003, 4.84146, 1.3115700000000077, 2.1352500000000076, 1.105845000000003, -0.5257199999999993, -1.8934499999999999, 0.765960000000006, 7.5855, 6.87784499999999, 3.589560000000001, 3.425955000000003, 6.022184999999995, 7.765289999999991, 6.012044999999993, 2.303145000000016, 2.523495000000008, 2.723175000000001, 0.3480749999999966, 4.028895000000002, 4.759949999999991, 3.369015000000011, 4.873635, 7.959900000000001, 10.536435000000012, 14.892735, 13.549379999999992, 12.371969999999994, 12.955215000000015, 13.88283, 12.432225, 11.48589000000001, 12.296114999999997, 13.050374999999994, 11.771369999999976, 15.709005, 18.317714999999975, 20.818979999999943, 19.78001999999998, 14.860754999999989, 12.685724999999993, 12.275249999999993, 11.366550000000013, 12.338430000000008, 13.484639999999995, 14.538029999999997, 16.44376499999997, 13.385384999999985, 13.526369999999986, 14.499809999999966, 16.039724999999976, 17.449575, 15.910439999999989, 14.723864999999984, 17.150054999999927, 14.906189999999986, 10.704720000000004, 11.41335000000001, 13.613144999999989, 19.76714999999993, 15.645434999999994, 15.017144999999966, 12.584909999999995, 5.340074999999999, 4.754879999999998, 6.084194999999987, 5.949449999999988, 8.315189999999971, 4.9358400000000024, 5.241989999999998, 0.6877650000000082, 1.2745200000000003, 1.5473250000000074, 0.7683000000000026, 0.13591500000000023, -0.6355049999999989], [0.0, 0.4223700000000008, -0.9894300000000031, -0.5356650000000016, -1.348620000000004, -1.424085000000002, -1.6830450000000003, -0.30263999999999847, -1.4658150000000023, -1.8710249999999995, -3.775785, -4.840875, -6.543420000000003, -3.2081399999999998, -0.2889899999999983, -3.6646350000000014, -2.6968499999999986, -3.566745, -5.4040349999999995, -5.29347, -4.86057, -4.61565, -6.496424999999999, -8.399819999999998, -9.828780000000002, -8.803274999999994, -7.585500000000004, -8.21457, -7.416240000000004, -7.186725000000004, -7.802924999999999, -4.816305, -4.352984999999999, -1.9693049999999999, -1.039350000000006, -0.8634600000000039, -0.36718500000000276, -0.3316950000000034, 0.07721999999999607, -1.1159850000000051, -2.338049999999998, 0.3603599999999947, -0.8291400000000051, -1.883115000000001, -2.7918149999999984, -5.9808449999999995, -6.718725000000002, -6.199635, -6.240585000000001, -5.700825000000002, -3.4953749999999983, -2.585309999999997, -1.935375000000001, -4.846725, -5.01033, -5.29932, -6.584175000000007, -6.115590000000001, -10.053419999999996, -11.797109999999996, -9.892545000000005, -10.50582, -11.145614999999996, -10.020075000000011, -10.328954999999997, -7.709519999999998, -6.01146, -4.024995, -3.279510000000001, -5.29737, -4.908345, -3.891615, -4.195815, -5.0354849999999995, -5.283525, -5.1456599999999995, -4.8790949999999995, -5.308485, -5.063369999999999, -5.310435, -5.173935, -5.485934999999998], [0.0, -1.2265499999999978, -1.507155000000001, -0.518505000000002, 0.23107499999999437, -1.8712200000000117, -2.131545000000002, 0.06805499999999931, 0.8841299999999972, 2.0989800000000023, 1.095704999999998, -0.26519999999999744, -1.9595549999999848, -2.5348049999999986, -5.28839999999999, -7.473569999999999, -7.868835000000008, -9.032985000000007, -11.469120000000018, -12.74442000000002, -8.719425000000019, -5.252130000000001, -4.304819999999994, -2.291055000000016, 1.405365000000001, 5.644665000000003, 9.898199999999996, 11.80530000000001, 12.258480000000004, 12.835290000000015, 13.941135000000012, 14.565915000000002, 15.054585000000012, 14.85646500000001, 14.646450000000018, 15.208635000000012, 15.109965000000019, 15.256995000000009, 15.405584999999999, 16.35153000000002, 15.766530000000008, 13.221390000000007, 12.030525000000011, 11.216985000000008, 11.410230000000006, 12.462449999999999, 11.40165000000001, 11.516310000000006, 10.656750000000006, 11.20899000000001, 10.884704999999993, 10.039964999999999, 11.355435000000009, 10.013445000000004, 8.338980000000005, 8.436480000000005, 6.906900000000002, 6.103695000000004, 4.757610000000003, 4.478760000000004, 4.773990000000002, 3.657810000000003, 3.163485000000001, 4.061265000000004, 3.344640000000003, 4.333485000000003, 3.2779500000000037, 1.603095000000001, 4.082910000000004, 3.3231900000000056, 3.588000000000002, 4.107675000000006, 3.0587700000000018, 2.6543400000000017, 2.0800650000000016, 1.6333199999999999, 2.244449999999996, 1.5720899999999989, 1.5313350000000034, 1.5022799999999954, 0.2316600000000104, 0.1651650000000009], [0.0, -2.1648899999999847, -3.325335, -2.4037649999999813, -2.172884999999975, -4.350839999999974, -3.8366249999999793, -0.467219999999986, 1.3856699999999984, -0.49315499999999, -3.1855199999999853, -4.391790000000008, -4.426695000000005, -3.2763899999999966, -7.654724999999986, -8.060129999999983, -7.449389999999982, -7.977254999999967, -10.019489999999987, -11.490764999999957, -7.465965000000014, -3.4930349999999963, -5.568809999999982, -6.789314999999983, -2.892044999999995, -1.1343149999999875, 2.7071850000000013, 2.994809999999992, 4.312034999999997, 5.8964099999999995, 7.700550000000002, 9.71958, 10.380434999999995, 11.757134999999998, 11.552384999999992, 11.693369999999996, 11.924249999999986, 12.444509999999998, 12.058800000000002, 12.648480000000003, 12.068550000000004, 11.273145, 8.120970000000003, 8.558940000000002, 7.59252, 6.8209050000000016, 8.00436, 9.564554999999997, 8.743409999999995, 9.053069999999996, 10.634324999999995, 10.565295, 10.219170000000002, 9.134580000000001, 6.240975000000001, 5.853900000000001, 4.71978, 3.928079999999997, 1.895205000000006, 1.831245, 2.8848300000000013, 2.2282650000000013, 2.3310299999999913, 3.1722599999999965, 3.01782, 3.5942400000000014, 4.160129999999997, 1.8669299999999982, 2.521155000000002, 4.484805, 5.226195000000001, 5.177445000000003, 5.00253, 4.388670000000003, 4.078815000000002, 2.755934999999991, 2.9226600000000023, 3.2678099999999977, 2.980379999999998, 2.8331549999999943, 1.8263700000000052, 1.496039999999999], [0.0, -2.026829999999986, -2.3347349999999842, 0.2211300000000147, -1.110524999999992, -3.292380000000005, -1.5956849999999747, 2.4571949999999845, 2.6484899999999776, 2.8263299999999933, 1.088489999999993, -0.20806499999999417, 0.5296199999999995, 0.8412299999999817, -5.242770000000007, -7.092734999999992, -6.997184999999993, -7.237034999999976, -10.222874999999961, -9.297600000000012, -3.6903749999999995, -2.3004149999999868, -3.3046649999999964, -1.4114100000000054, 2.585114999999992, 6.743489999999991, 11.69200499999999, 14.20808999999998, 16.38175499999999, 17.03675999999999, 18.442514999999993, 21.23315999999999, 22.14342000000001, 22.025834999999987, 22.226490000000005, 22.17208499999999, 23.150400000000012, 23.440365, 22.946625000000004, 23.911485000000013, 23.118615000000002, 20.34142499999999, 18.971354999999996, 17.95638, 16.894994999999987, 19.126575, 18.22567499999998, 16.80705, 15.386669999999988, 15.418259999999986, 16.459949999999985, 15.90263999999998, 17.05781999999999, 17.064254999999992, 15.749759999999984, 14.507414999999991, 12.90412499999999, 11.77409999999999, 9.43526999999999, 7.208954999999993, 7.585109999999986, 6.872969999999983, 5.827964999999988, 6.163949999999989, 4.124054999999985, 6.339449999999985, 6.56018999999999, 6.388394999999987, 8.20091999999999, 10.71485999999999, 10.19791499999999, 10.33636499999999, 9.04565999999999, 7.144994999999983, 5.323109999999993, 5.467994999999991, 7.0359899999999875, 7.403174999999992, 6.217379999999984, 4.9574849999999895, 4.464719999999989, 4.899374999999989], [0.0, -0.24608999999999526, -0.16165500000000055, -0.3459299999999992, -1.016339999999997, -0.4483049999999942, 0.2886000000000042, 0.7809750000000042, 0.4720949999999968, -0.16692000000000284, -0.3547049999999956, -1.115009999999998, -1.302014999999991, -1.0280399999999972, -2.1286200000000006, -1.6266900000000009, -2.068559999999997, -1.526459999999993, -1.9517549999999986, -1.3470599999999981, -1.1616149999999985, -0.41242499999999715, -2.1510449999999945, -2.3054850000000098, -0.7587450000000011, 0.6682650000000008, 1.2540449999999974, 0.5738849999999953, 0.6639749999999909, 0.1817399999999969, 1.4117999999999977, 1.4272049999999963, 1.4665950000000025, 2.1410999999999967, 2.6354249999999952, 3.232904999999996, 2.5636649999999994, 2.937479999999997, 3.0716399999999977, 2.0925449999999945, 2.8218449999999975, 1.543229999999995, 1.4562599999999981, 2.447834999999997, 2.079479999999995, 1.1514750000000014, 1.7054699999999934, 2.416634999999994, 1.6561349999999981, 1.9831499999999997, 2.312699999999998, 2.7514499999999975, 1.9889999999999959, 1.7748899999999965, -0.13201500000000088, 0.7874099999999924, 0.46273500000000123, 1.0373999999999994, -0.3494400000000031, -0.1981200000000065, 0.2090399999999928, -0.4586400000000035, -0.03743999999999925, 0.16438500000000023, 0.1183650000000025, 0.6372599999999942, 1.3205400000000012, 0.7068749999999966, 0.37537499999999824, 0.993525, 1.1900849999999932, 1.3357499999999929, 1.3170299999999946, 1.0648949999999942, 0.9787050000000015, 0.5415149999999977, 1.0578749999999952, 0.7055099999999959, 1.008344999999995, 1.2540449999999939, 1.0559250000000007, 1.4385149999999975], [0.0, -0.25525499999999823, 0.6975150000000028, 2.738189999999995, 3.4218599999999935, 0.3018600000000031, 0.09028500000001571, 5.1392249999999935, 5.649929999999994, 1.8212999999999937, -5.568029999999974, -9.807330000000025, -9.143355000000007, -9.08817000000003, -11.494469999999989, -9.873240000000028, -9.005489999999984, -11.673090000000073, -16.58904000000007, -19.655415000000037, -11.56857000000005, -7.673250000000017, -9.078420000000015, -8.742045000000026, -3.217890000000006, 3.399044999999993, 10.99741499999999, 13.301924999999983, 16.597424999999987, 19.99179, 22.746750000000013, 24.179609999999997, 25.272389999999994, 25.40986499999999, 25.97770500000001, 25.287210000000005, 25.321724999999994, 25.73844000000002, 25.844714999999997, 27.31209, 26.116740000000025, 25.097865000000002, 22.676550000000006, 20.824050000000014, 18.536505, 20.695154999999986, 21.946079999999995, 22.428510000000003, 20.259135, 18.968429999999998, 17.24073, 14.968004999999991, 15.828734999999998, 17.225324999999998, 14.214719999999991, 13.998464999999984, 11.873744999999989, 8.64571499999999, 6.166094999999991, 7.048469999999988, 7.313084999999988, 7.534994999999986, 7.605974999999988, 9.08894999999999, 5.363084999999982, 5.107634999999988, 4.91107499999999, 3.2995949999999885, 5.148974999999985, 5.252714999999996, 3.114539999999981, 3.159389999999987, 2.6506349999999985, 1.7177549999999915, 0.6419399999999964, -1.3180050000000012, -1.6356600000000032, -2.5193999999999797, -4.4924099999999765, -5.384144999999984, -6.874919999999989, -8.229194999999976], [0.0, -3.432390000000023, -2.4357449999999936, -2.6972400000000043, -1.121445000000012, -4.687410000000046, -6.491550000000039, 0.23789999999999978, 4.556954999999993, 7.484880000000002, 10.982009999999992, 14.285114999999992, 15.147794999999991, 5.025929999999983, -2.1044400000000287, -2.8308150000000047, -0.8513699999999922, -0.7961850000000084, -3.1125899999999618, -4.726799999999976, 3.976245000000004, 9.651719999999985, 8.601839999999996, 6.871409999999978, 5.8418099999999935, 3.3896849999999876, 9.45437999999999, 9.277514999999983, 7.6012949999999915, 8.215154999999989, 8.232314999999994, 8.431214999999986, 5.990009999999984, 6.0857549999999865, 6.675434999999988, 7.086689999999987, 7.692944999999995, 8.080799999999982, 8.426339999999989, 6.7183350000000015, 7.14323999999999, 4.643729999999987, 5.630039999999999, 7.449, 9.00938999999999, 7.080839999999995, 7.602464999999997, 8.291399999999996, 9.064964999999995, 9.120734999999986, 9.45515999999999, 11.101349999999993, 11.516504999999995, 9.14803499999998, 9.75701999999999, 8.933925000000002, 12.663689999999992, 15.39641999999999, 13.190774999999993, 14.007044999999993, 14.26444499999999, 13.97213999999999, 14.909894999999992, 14.938169999999992, 16.129814999999994, 16.98254999999999, 15.084614999999992, 16.05259499999999, 14.149784999999993, 16.89635999999999, 20.08031999999999, 20.28565499999999, 19.678619999999995, 19.468994999999993, 18.504914999999993, 18.20149499999999, 19.13047499999999, 19.720934999999994, 20.443604999999984, 20.437364999999986, 20.647184999999993, 20.777639999999987], [0.0, -0.9892350000000114, -0.4215900000000019, -0.862289999999998, -0.6187350000000027, 1.1501099999999909, 0.6795749999999963, 1.0962900000000015, 2.8144350000000067, 4.37190000000002, 4.87851000000002, 5.521230000000015, 5.132010000000021, 3.0490200000000325, 0.6329700000000216, -1.5835949999999794, -2.5502099999999768, -2.722394999999997, -0.903044999999997, -1.0588499999999978, -1.0875149999999945, -0.6472049999999925, 1.8653700000000182, 3.6379200000000367, 6.920160000000027, 11.97690000000002, 14.126190000000015, 15.363465000000017, 16.930875000000018, 17.931030000000018, 16.450785000000018, 16.720665000000018, 16.908060000000017, 16.486860000000014, 16.101540000000014, 16.086525000000016, 16.140540000000016, 15.491775000000017, 14.569425000000017, 14.052675000000015, 14.859585000000015, 15.245490000000018, 13.063050000000018, 13.502385000000018, 14.424930000000016, 15.591615000000017, 16.301610000000018, 15.868515000000016, 15.417675000000017, 13.812435000000015, 13.011960000000016, 12.624300000000016, 9.88786500000002, 10.189920000000019, 11.771370000000015, 9.517365000000014, 11.069175000000016, 12.289095000000014, 11.196510000000016, 11.18286000000002, 11.56701000000002, 10.966215000000016, 10.557300000000016, 9.122100000000017, 9.221355000000012, 6.215430000000023, 6.873360000000025, 8.131695000000022, 7.199205000000022, 9.844380000000019, 12.417210000000017, 12.24639000000002, 10.575630000000023, 9.223890000000022, 8.486790000000017, 8.036730000000018, 8.375640000000029, 8.657025000000012, 8.677890000000023, 8.681400000000014, 7.975695000000024, 8.431800000000017], [0.0, 1.6218149999999887, 0.5641349999999958, -0.2985450000000123, 2.051204999999989, 5.955494999999986, 3.1810349999999885, -0.7211100000000163, -0.24258000000001712, -3.264690000000016, -4.139850000000006, -4.3958850000000265, -5.491590000000041, -0.5391750000000144, 3.2574749999999892, 3.1361849999999882, 3.595799999999989, 4.426304999999985, 10.195574999999991, 8.329034999999989, 5.2341899999999875, 6.259499999999986, 4.993364999999986, 2.2805249999999933, 5.333444999999986, 7.6913849999999835, 10.78934999999999, 9.711584999999985, 12.054314999999999, 15.310034999999983, 17.347004999999967, 18.002789999999983, 16.422509999999974, 14.132429999999975, 14.335229999999966, 13.294514999999985, 12.087074999999983, 12.424619999999972, 13.359644999999972, 12.163709999999988, 11.929904999999986, 16.36634999999997, 20.648159999999944, 18.50471999999995, 18.65759999999996, 14.92198499999998, 11.79379499999998, 10.936964999999988, 10.758929999999978, 9.705344999999994, 8.25161999999999, 13.67300999999998, 9.95864999999999, 7.6748099999999875, 12.339599999999981, 10.221314999999986, 13.466504999999986, 16.489199999999986, 14.188199999999986, 13.755104999999979, 12.117494999999987, 9.651914999999995, 9.399194999999992, 6.9702749999999885, 12.275249999999977, 8.461634999999994, 5.549699999999986, 7.125299999999988, 2.293199999999991, 1.3324349999999905, 0.7981349999999869, 0.38921999999998036, 0.8306999999999842, 0.968369999999986, -1.178190000000014, -2.9487900000000185, -4.027725000000023, -3.5472450000000126, -4.557930000000029, -5.739825000000021, -5.971680000000001, -6.032325000000009], [0.0, 4.993169999999793, 7.45465499999986, 9.272249999999815, 11.19358499999985, 12.305084999999849, 8.068319999999943, -0.9205950000000769, 0.8952449999999033, 1.959749999999616, 1.1680499999997238, -0.2006550000001397, 1.302014999999642, 4.952024999999779, 9.25157999999982, 10.711154999999899, 15.209804999999832, 11.883299999999792, 15.797144999999844, 11.22205499999977, 6.19670999999984, 7.8774149999998, 9.485189999999875, 4.338554999999914, 11.529959999999868, 13.556984999999777, 12.208169999999924, 13.819259999999815, 20.49235499999979, 23.411504999999714, 29.167319999999755, 27.24110999999975, 27.36707999999981, 24.858209999999808, 29.86853999999982, 28.91888999999972, 23.32141499999971, 25.61773499999976, 28.15819499999978, 24.273209999999793, 27.44663999999971, 25.184444999999805, 26.702519999999687, 23.60572499999973, 20.643869999999822, 20.235734999999707, 22.04728499999974, 23.329214999999728, 18.548789999999784, 18.127979999999802, 17.60576999999975, 14.703974999999787, 11.791454999999708, 22.91366999999967, 30.4708949999997, 24.775724999999746, 29.070599999999807, 21.007154999999727, 22.0065299999998, 22.3189199999998, 19.677449999999773, 14.754479999999688, 15.086564999999794, 16.68751499999979, 16.93652999999967, 12.392249999999741, 17.990699999999748, 16.924829999999773, 10.845119999999852, 9.590294999999728, 9.098309999999685, 10.737869999999752, 4.894889999999847, 4.717049999999716, 5.293859999999853, 2.429114999999584, 1.4814149999997852, -3.1135650000002926, -3.7120200000002512, -4.471155000000209, -4.701840000000203, -6.249945000000295], [0.0, -1.6374150000000114, -1.442804999999992, -0.7452900000000038, 1.644434999999996, 0.029444999999997723, -1.2967500000000003, 0.11231999999999775, 2.8124849999999975, 1.909049999999997, 2.144219999999999, -1.6198650000000052, -0.35860499999999895, 0.3229199999999981, -3.150030000000002, -4.446975000000008, -2.7095250000000046, -0.2322449999999998, -1.332435000000002, -4.859985000000005, -3.6956400000000107, 0.667875, -1.473810000000003, -2.1847800000000035, 0.4568850000000002, 3.034199999999997, 5.323109999999996, 8.55660000000001, 8.857875000000002, 8.691929999999989, 9.491624999999992, 8.504730000000002, 10.978110000000001, 9.61935, 10.162815000000005, 10.308090000000004, 10.967970000000015, 9.497865000000001, 9.373455000000003, 10.450050000000008, 11.117340000000002, 10.239060000000002, 8.652930000000001, 9.60297, 7.207784999999993, 8.050184999999994, 7.1290049999999905, 7.530315000000002, 7.130759999999997, 7.058609999999994, 7.635614999999997, 7.442174999999987, 8.366475, 8.689785, 6.2710049999999935, 5.851754999999992, 5.183684999999997, 1.9714499999999973, 2.9053049999999976, 4.512494999999996, 3.3935849999999976, 3.4928399999999975, 2.754374999999998, 2.1795149999999963, 2.9257799999999983, 2.672669999999998, 1.0229699999999982, 0.5635499999999953, 2.301974999999997, -0.7959900000000126, -1.0104900000000043, -1.3710450000000058, -0.7688850000000045, -1.0676250000000116, 0.22834499999999291, -1.0069800000000066, -1.6023150000000088, -1.8429450000000012, -1.693575, -1.2394200000000088, -1.5853500000000027, -2.2620000000000013], [0.0, 5.917859999999962, 9.32041499999998, 7.420334999999998, 8.04218999999999, 14.415959999999984, 15.272790000000008, 8.44135499999997, 7.9663350000000115, 8.45403, 4.877925000000012, 2.1947250000000054, 2.6726700000000037, -0.030810000000002447, 9.546029999999991, 16.02470999999997, 14.188979999999987, 13.174199999999974, 17.543759999999985, 19.068075000000007, 9.724065000000007, 9.48362999999998, 12.103650000000005, 16.30005000000004, 15.23125500000004, 15.737085000000036, 14.328600000000026, 17.82651, 17.51489999999999, 20.653034999999967, 21.57772499999995, 22.78126499999997, 25.99778999999998, 21.77291999999997, 18.0821549999999, 18.017414999999943, 18.22196999999997, 18.957704999999926, 17.81500499999995, 23.225474999999996, 24.131834999999995, 23.921820000000025, 33.430605000000014, 37.243244999999966, 34.257015, 39.48086999999999, 31.33708500000001, 29.437785000000012, 29.397030000000022, 29.83285500000003, 27.861014999999924, 29.200079999999993, 34.695179999999944, 36.40806000000005, 30.429944999999996, 40.95409500000003, 35.17020000000002, 28.583100000000073, 42.24401999999992, 33.406034999999996, 36.786360000000094, 37.354395000000096, 30.059249999999977, 30.486494999999998, 29.61250500000004, 34.91552999999994, 35.28446999999993, 28.651740000000025, 34.080539999999964, 22.24754999999999, 12.806625000000025, 13.722345000000033, 12.951900000000034, 16.424459999999982, 18.334874999999975, 15.404025000000011, 13.55815500000001, 12.110670000000013, 8.98072500000001, 9.906195, 9.13418999999999, 8.681010000000008], [0.0, 7.225334999999546, 7.514324999999772, 4.268939999999631, -0.5101200000001711, -8.704800000000205, -17.594265000000263, -27.574170000000407, -33.28513500000017, -45.83455500000032, -55.16062500000031, -57.53202000000026, -64.57971000000032, -61.118070000000394, -40.07542500000031, -21.873930000000314, -8.864115000000297, -2.7998100000003348, -4.088175000000277, -11.534835000000186, -20.9853150000003, -30.28135500000019, -46.067190000000195, -68.00352000000021, -97.16070000000026, -130.45285500000023, -161.05908000000022, -197.68359000000024, -227.87739000000016, -251.3963400000003, -273.2757300000004, -285.4772700000001, -292.8303300000004, -298.7019750000002, -301.4635650000005, -302.3601750000006, -298.06315500000005, -293.5292100000001, -287.5939950000001, -288.4362000000002, -288.0309900000002, -274.08595500000024, -269.2866150000004, -271.58547000000056, -271.04415000000046, -274.4320800000001, -286.8255000000002, -295.27192500000024, -294.30316500000015, -292.4532000000003, -290.0313000000001, -280.4963850000002, -275.0915700000004, -272.82060000000035, -270.4464750000003, -268.50817500000005, -266.4060750000003, -261.51352499999996, -264.23377500000026, -275.5656150000001, -277.0384500000001, -277.20478500000064, -284.31487500000014, -286.75549500000045, -277.2521700000002, -268.28412000000026, -255.83044500000017, -242.7012900000003, -231.3228450000003, -221.67444000000017, -211.04245500000025, -196.5204150000003, -183.0812100000002, -172.12494000000024, -161.35431000000028, -151.38376500000027, -142.07329500000023, -132.82971000000023, -125.93041500000024, -118.05670500000025, -111.27558000000025, -106.29801000000026], [0.0, 0.1792049999999108, -2.6629200000001845, -4.7999250000001155, -12.281879999999944, -19.50409499999988, -30.280185000000046, -39.432314999999875, -42.70850999999999, -52.71766500000002, -58.30460999999991, -57.63146999999997, -64.67720999999997, -58.39840499999992, -39.95374500000001, -28.119585000000043, -17.271929999999898, -10.960169999999849, -12.592319999999901, -20.26849500000003, -28.03651500000025, -33.35046000000004, -47.60203499999993, -69.11755499999995, -96.88594499999996, -123.10895999999998, -144.448005, -158.81852999999995, -154.94738999999993, -169.04120999999998, -160.40368500000002, -154.65020999999996, -137.85134999999994, -111.42163499999997, -104.98370999999996, -91.72858499999997, -77.98088999999999, -77.07862499999993, -84.20314499999998, -90.22103999999997, -70.80001499999997, -79.67621999999994, -113.07679499999998, -145.137135, -150.12231000000003, -138.63778500000004, -79.04578499999997, -85.82476500000001, -78.87067499999996, -64.40147999999998, -61.82923499999995, -55.40378999999994, -43.22564999999989, -47.51798999999987, -75.70718999999997, -118.96696499999995, -155.16735, -152.7784049999999, -138.82361999999998, -70.31973000000002, -68.17667999999995, -65.75204999999991, -29.74198499999993, -8.343854999999948, 4.328220000000144, 29.22738000000001, 35.184630000000055, 11.774685000000119, -25.272779999999912, -41.74189499999987, -41.36554499999998, -41.13212999999996, -35.157719999999955, -31.501859999999922, -9.322949999999977, 8.288280000000142, 21.37668000000005, 1.4437799999999754, -26.213849999999894, -23.839724999999945, -33.011159999999876, -24.525344999999987], [0.0, 2.923050000000046, 6.794190000000093, 10.53487500000005, 7.403175000000111, 8.682570000000098, 8.663655000000077, 8.03848500000003, 8.693100000000008, 10.789155000000022, 10.281179999999992, 5.580119999999994, 7.635615000000058, 5.916105000000023, 4.5405750000000396, 8.320455000000095, 5.212155000000003, 4.221360000000047, 7.386990000000161, 11.072685000000135, 11.246430000000018, 12.066405000000046, 15.667665000000092, 17.79609000000002, 17.811299999999996, 23.057969999999976, 21.55588500000004, 20.174309999999956, 20.429955000000113, 17.948385000000044, 19.05072, 21.27723000000008, 19.96449000000011, 16.344315000000073, 16.882710000000053, 19.35238500000009, 21.516300000000065, 24.55030500000003, 30.91842000000002, 37.80855000000005, 42.66112499999996, 38.564760000000156, 33.3781500000001, 44.30068500000005, 47.73658499999987, 42.206384999999905, 34.09418999999996, 30.358769999999943, 31.88484000000002, 31.950165000000077, 28.989480000000064, 29.5575150000001, 35.11891500000005, 47.70558000000006, 49.49879999999988, 42.97136999999996, 49.508550000000106, 44.75035500000012, 38.15545499999987, 37.47159000000013, 35.48727000000002, 32.87466000000007, 28.71804000000005, 27.311505000000018, 29.474835000000034, 28.959060000000044, 32.22160500000003, 23.961795000000073, 20.353320000000075, 26.876655000000092, 21.88231500000007, 17.43066000000001, 15.792270000000066, 16.52488500000002, 18.462210000000006, 15.622230000000101, 16.227899999999963, 15.561195000000104, 14.127360000000067, 13.362569999999948, 12.669930000000043, 12.49540500000004], [0.0, -0.9307349999999897, -1.9355699999999842, -0.8938800000000136, 3.36063000000002, 3.1786950000000207, 0.6193200000000072, 2.0863050000000047, 4.867200000000004, 1.3852800000000087, -1.3460850000000075, -2.855775000000002, -5.021444999999996, -3.7126049999999964, -5.801445000000005, -4.1168399999999945, -0.07858499999998791, 1.0964850000000261, 0.33481500000000075, -2.394405000000001, 1.435590000000012, 8.126429999999983, 4.612335000000003, 1.621815000000007, 1.1389950000000173, 0.9980100000000061, 2.43827999999999, 1.1824799999999946, 1.717560000000022, 3.9731249999999996, 5.620875000000039, 7.101120000000014, 7.922850000000031, 7.787715000000018, 6.962865000000027, 6.107790000000028, 5.815875000000032, 5.376345000000034, 5.677815000000047, 6.169604999999999, 1.0467600000000132, 3.826290000000011, 8.625435000000012, 11.208015000000023, 12.091170000000028, 10.512450000000014, 6.687720000000015, 4.386135000000014, 3.6603449999999977, 3.295304999999999, 3.140084999999999, 5.743920000000001, 8.286720000000008, 4.327050000000019, 2.749304999999998, 1.7573399999999832, 3.090555, 8.880299999999986, 13.081184999999978, 8.468459999999991, 7.996560000000011, 7.643024999999978, 5.754645000000002, 4.155254999999995, 6.0418799999999795, 8.407424999999956, 6.075809999999992, 7.66896, 1.950974999999973, -2.2744800000000076, -4.320225000000001, -3.837015000000002, -2.082015, 1.2643799999999885, -1.393470000000013, -1.2300600000000088, -5.163405000000002, -5.711354999999992, -4.999214999999996, -6.763379999999994, -5.72793, -6.508320000000001], [0.0, 2.6469300000000002, 4.862715000000003, 6.311565000000002, 4.945590000000004, 5.161455000000002, 5.703945000000001, 6.043245000000001, 6.074445000000003, 7.1186700000000025, 4.6932599999999995, 2.6689649999999983, 2.373149999999998, 3.9739049999999976, 7.505550000000003, 6.329895000000002, 4.482854999999995, 4.127174999999999, 2.8271099999999976, 4.0080300000000015, 4.391594999999999, 2.9175900000000015, 2.3485799999999992, 5.386874999999999, 4.713540000000004, 5.874180000000002, 7.347795000000002, 7.641270000000002, 11.408669999999997, 10.558470000000002, 7.246785000000002, 5.439135000000001, 7.012785000000004, 5.657730000000002, 5.850780000000003, 8.88537, 11.693760000000008, 15.677805000000001, 17.32672500000001, 21.301994999999998, 26.33221500000001, 24.0162, 20.429760000000016, 20.228910000000013, 14.450670000000002, 16.905915, 17.35188, 17.367675000000006, 18.105555000000017, 17.623710000000003, 17.787315, 15.587715000000008, 19.336005000000014, 26.208780000000022, 30.436380000000025, 28.724865000000005, 24.379289999999997, 18.86449500000002, 19.618755, 17.50827000000001, 16.90338, 18.477810000000023, 17.573790000000017, 17.371380000000002, 17.78477999999998, 17.214990000000004, 19.41907499999999, 16.77877499999999, 15.317055000000009, 18.11511, 16.475159999999995, 13.021125000000008, 13.633424999999999, 13.065975000000002, 15.338700000000008, 13.393770000000004, 12.474150000000005, 14.656980000000004, 13.75140000000001, 13.646295000000002, 12.99402000000001, 12.536550000000005], [0.0, -2.8035149999999893, -2.2198800000000043, -1.3462799999999921, -1.7440799999999959, -1.8285149999999986, -1.1079899999999965, -0.04835999999999263, 0.2808000000000064, -0.11426999999999943, 0.15327000000000535, 0.6949800000000161, 0.8880300000000103, -0.4859399999999896, -6.115394999999999, -4.831319999999988, -3.549389999999991, -3.33586500000001, -3.0334199999999862, -3.04043999999998, -1.0202400000000003, 0.5766150000000101, -0.03704999999998915, 1.4264250000000045, 3.616275000000015, 4.356495000000011, 5.873400000000012, 7.524855000000013, 7.966335000000013, 8.057010000000014, 8.15217000000001, 8.62641000000001, 8.718255000000013, 8.866260000000008, 9.621885000000006, 10.114260000000007, 9.377355000000014, 9.836190000000002, 9.498840000000008, 10.266750000000005, 9.380280000000003, 7.997145000000014, 7.514520000000012, 8.163870000000014, 8.42419500000001, 8.586045000000007, 7.875855000000014, 8.090745000000013, 7.838025000000012, 6.962475000000012, 6.991725000000012, 7.496385000000012, 8.624265000000012, 8.714160000000012, 7.702110000000014, 6.532110000000013, 6.689475000000012, 6.290310000000012, 5.890755000000012, 5.895630000000013, 6.061965000000012, 6.074445000000012, 5.842980000000012, 5.211375000000013, 4.238325000000014, 4.221165000000012, 4.331145000000012, 4.01154000000001, 2.7596400000000125, 4.464135000000013, 5.025930000000012, 4.278690000000012, 4.280835000000015, 3.8845950000000107, 3.6453300000000124, 3.8845950000000147, 4.27732500000001, 3.737760000000013, 3.9040950000000105, 3.739905000000014, 4.058340000000013, 4.069260000000011], [0.0, -2.891069999999992, -3.6092550000000045, -1.0134149999999842, -1.3041600000000013, -2.9684850000000047, -4.154865000000024, -2.43672000000001, 0.9457500000000039, 1.190280000000004, 2.8429050000000022, 4.231695000000002, 4.688774999999998, 3.1225350000000014, -2.7561300000000166, -3.89454000000001, -2.1311549999999926, -0.7390499999999882, -1.5026699999999948, -2.8616249999999877, -0.5405399999999929, 3.704024999999991, 3.8754299999999997, 2.6937299999999986, 3.0544799999999963, 2.4794249999999947, 3.1447649999999956, 3.9980849999999957, 3.4963499999999996, 2.2947599999999984, 2.451150000000001, 2.332980000000001, 2.130375000000001, 2.5496250000000042, 2.2095450000000056, 2.445300000000006, 2.4162450000000053, 2.6091000000000095, 3.6065250000000018, 3.9148200000000006, 2.7434550000000018, 1.5264600000000037, 0.2531099999999924, 2.8115099999999944, 2.64069, 2.1516300000000044, 2.8259400000000023, 1.2004199999999967, 0.9192299999999989, 1.7916599999999985, 2.189069999999999, 3.354585000000003, 3.819270000000004, 5.160870000000001, 4.041375, 0.9365849999999938, 4.117035000000001, 3.7040250000000023, 2.988375000000001, 3.818880000000001, 3.1147349999999983, 3.247725000000003, 3.6073050000000038, 1.7161949999999901, 2.3413650000000024, 2.9400150000000007, 3.971759999999996, 3.4060650000000003, 2.9392349999999983, 5.185635, 4.484024999999997, 4.471739999999999, 4.82118, 4.69443, 5.452200000000001, 5.377514999999998, 5.187779999999998, 5.675474999999998, 5.932874999999999, 6.300254999999999, 6.249164999999998, 7.166249999999998], [0.0, 1.6701749999999986, 3.4904999999999955, 8.273460000000005, 7.622160000000012, 8.645715000000012, 10.956270000000014, 9.21414000000002, 6.626880000000005, 6.04773, 1.7540250000000146, -2.322839999999996, -1.6736849999999959, 1.151280000000006, 2.3610600000000073, 5.449080000000031, 4.862909999999999, 4.488120000000013, 3.3984599999999947, 5.4791100000000075, 5.019300000000015, 0.60956999999999, 1.7936100000000046, 8.677500000000016, 9.098699999999981, 12.455235000000034, 13.130520000000015, 12.922260000000026, 15.457455000000007, 16.330860000000026, 17.29806000000003, 17.10520500000001, 18.035939999999997, 14.706899999999973, 15.74683499999999, 19.618560000000016, 21.725145000000047, 22.175594999999987, 22.719645000000035, 27.189240000000048, 29.825835000000033, 26.241540000000004, 25.15929, 31.368870000000037, 25.90594499999999, 22.101494999999986, 19.36486500000004, 20.22657000000003, 21.208784999999992, 21.496995000000023, 20.68014, 20.00934, 25.97692500000002, 27.928485000000002, 30.431309999999968, 30.413954999999973, 31.23197999999998, 26.17153500000005, 22.04007000000003, 24.505844999999987, 20.68949999999997, 19.754084999999986, 18.16990499999998, 18.14747999999997, 16.257344999999997, 19.369154999999992, 15.186014999999955, 10.789349999999999, 15.537404999999968, 11.888954999999978, 6.613424999999999, 4.9491000000000085, 5.202990000000007, 6.837869999999997, 6.777224999999984, 5.259539999999996, 6.947654999999996, 4.549934999999998, 2.3807550000000095, 3.391634999999999, 2.613974999999998, 0.6698250000000066], [0.0, -0.41632500000000006, 0.9188400000000025, 3.4165949999999885, 6.315854999999978, 7.28305499999998, 8.541584999999976, 12.430664999999975, 9.316709999999995, 9.852569999999988, 3.7135799999999985, -2.147535000000003, -2.5426050000000036, -1.7074200000000026, -3.2334900000000033, -0.538590000000007, 0.49061999999999895, 0.018914999999998905, -1.4125800000000028, -0.5405400000000002, 4.741229999999983, 3.139889999999993, 3.9783899999999868, 7.979204999999972, 10.530389999999963, 15.74039999999999, 21.002670000000034, 24.479910000000036, 26.417235000000044, 29.030235000000086, 31.5939000000001, 31.101525000000112, 31.614570000000096, 28.607280000000053, 27.86784000000008, 26.70661500000005, 24.50194500000006, 22.85556000000008, 24.636105000000086, 26.250510000000116, 26.03425500000007, 27.071070000000045, 30.410055000000103, 33.70692000000004, 31.002270000000056, 29.68231500000007, 28.86682500000006, 26.53794000000009, 26.534625000000048, 24.658140000000028, 20.889570000000035, 19.525350000000035, 22.15414500000003, 21.865740000000052, 21.437520000000024, 26.271570000000082, 24.798345000000076, 20.498205000000045, 20.291505000000004, 21.140730000000005, 20.63821499999999, 22.964564999999997, 20.90029500000001, 19.92432, 17.411160000000013, 19.210425000000015, 16.87101000000002, 12.758655000000001, 15.45843, 9.962159999999995, 6.771960000000018, 4.970354999999998, 4.412070000000006, 7.59915, 4.227599999999993, 3.2430449999999906, 3.1139550000000007, 1.3117649999999998, 0.1093949999999988, -0.540540000000006, -2.110290000000004, -2.2040850000000036], [0.0, -0.7581599999999995, -2.316794999999999, 2.4917099999999985, 3.6334350000000017, 2.4776700000000003, 2.9429400000000006, 4.897229999999996, 8.405475000000003, 4.054050000000003, -1.5841800000000024, -5.227949999999991, -7.140510000000006, -9.45730500000001, -14.94129, -13.077480000000008, -9.110009999999997, -10.319009999999988, -12.25945500000003, -13.652925000000002, -9.188009999999995, -1.8211050000000015, -2.1941400000000013, -2.6539500000000005, 1.649505, 4.057560000000001, 12.514124999999986, 16.55121, 19.380270000000028, 19.98087000000001, 23.208900000000007, 23.129925000000014, 23.28631500000002, 24.506430000000048, 23.572185000000008, 22.094670000000004, 22.223760000000023, 21.14365499999999, 21.100365000000025, 23.290800000000054, 21.678930000000015, 21.937305000000016, 20.802210000000034, 20.491965000000057, 19.092450000000024, 18.430034999999997, 17.666219999999992, 17.603235000000037, 14.07685499999999, 14.058915000000015, 13.302510000000005, 11.310779999999998, 12.972375, 14.265614999999991, 13.565954999999995, 11.48316000000001, 11.463075000000003, 10.28507999999999, 7.13778, 7.191600000000001, 6.703320000000001, 4.852575, 5.070585000000006, 4.445999999999998, 0.8513699999999997, 2.1216, 2.4445199999999994, 2.1956999999999973, 3.3766199999999973, 4.2318899999999955, 0.4746299999999989, 0.6093749999999997, -0.7098, -1.5904199999999993, -1.6077749999999993, -1.7011800000000008, -2.5455300000000007, -4.353375000000008, -5.259149999999997, -5.891729999999998, -7.680855000000011, -7.396544999999996], [0.0, -2.539874999999993, -2.8171649999999957, -1.8082349999999927, 0.8735999999999944, -1.9659899999999961, -4.162079999999971, 0.7349549999999887, 5.352554999999962, 5.192459999999965, 6.734129999999962, 9.54349499999996, 9.965084999999956, 3.5429549999999645, -3.940950000000008, -4.239299999999993, -1.7202900000000056, -0.4319250000000068, -2.2883250000000146, -4.922969999999983, 1.6586699999999919, 6.857564999999963, 5.138639999999964, 4.240274999999966, 7.68085499999995, 8.05291499999995, 12.210899999999958, 12.746369999999958, 10.592399999999955, 9.97990499999996, 11.309804999999958, 10.465064999999957, 8.500634999999956, 7.459529999999949, 6.175064999999959, 5.912009999999964, 5.5434599999999605, 5.046794999999957, 5.0606399999999665, 4.311059999999962, 3.292769999999962, 1.7284799999999727, 4.555199999999973, 8.597939999999955, 8.681204999999954, 7.209149999999951, 8.637524999999957, 7.5071099999999555, 6.84742499999995, 6.250334999999964, 5.994104999999962, 5.797544999999959, 5.621849999999966, 3.208919999999976, 1.3488149999999859, 2.7705599999999677, 7.057049999999955, 7.3848449999999515, 6.167459999999955, 8.529884999999954, 7.349159999999953, 7.934159999999958, 8.284574999999952, 6.74329499999996, 7.019999999999953, 6.556679999999957, 5.395844999999953, 5.33110499999996, 3.420104999999973, 6.705659999999958, 9.144524999999954, 8.858654999999954, 8.360039999999957, 9.152324999999957, 9.220184999999958, 8.774414999999955, 8.325719999999956, 9.393344999999957, 10.260314999999956, 10.53058499999996, 10.15033499999996, 10.860914999999958], [0.0, -2.2442549999999986, -2.8598699999999933, -2.558205000000005, -0.991379999999999, -1.4215499999999994, -2.5375349999999943, -0.7415850000000042, 4.681560000000005, 5.257785000000004, 6.964229999999997, 7.924019999999999, 9.282974999999995, 4.680975000000003, -1.630004999999994, -1.5011099999999957, -1.967940000000001, -2.349359999999997, -1.532699999999997, -3.102059999999985, -0.31609499999999846, 7.482539999999998, 6.484335000000001, 4.437225000000004, 5.975190000000003, 6.096090000000004, 7.891455000000002, 6.464055000000004, 4.325100000000001, 2.5195950000000025, 2.940405000000002, 1.7029350000000014, 1.0395450000000017, 0.6247800000000008, 0.7567950000000034, 0.634335000000005, -0.08306999999999798, -1.0446150000000007, -0.36074999999999635, 0.8607300000000015, -1.1397750000000006, -2.7364350000000006, -1.300064999999996, -0.3494399999999964, 2.5147200000000023, 0.5584800000000025, 1.8671250000000033, 1.7124900000000016, 1.8799949999999992, 2.7465750000000018, 2.0400900000000037, 4.307160000000003, 5.268315000000005, 2.9519100000000025, 0.1561950000000012, -0.614835000000002, 0.3537300000000023, 4.45458, 4.523220000000003, 4.599270000000005, 5.688735000000003, 5.887635000000001, 5.887050000000002, 6.060989999999998, 8.109270000000002, 10.518104999999997, 8.705190000000009, 7.818915000000002, 6.007170000000004, 5.8281600000000005, 8.264879999999998, 7.35384, 7.668180000000005, 9.235005000000003, 8.366475, 9.053069999999996, 9.989265000000007, 10.576020000000002, 11.081265000000004, 11.625315000000008, 11.800230000000012, 13.131300000000003], [0.0, 1.1331450000000007, 1.9950450000000006, 3.838965000000004, 4.176705000000005, 5.229315, 6.134310000000022, 5.617170000000009, 3.5269649999999966, 4.936814999999994, 1.5073499999999993, 0.48008999999999924, 0.5417099999999988, -0.6869849999999982, 0.5036850000000008, 0.9937200000000099, 0.8127600000000035, 0.5399550000000053, 1.943370000000002, 3.227054999999989, 4.1457, 1.4133600000000066, 3.3005699999999982, 7.02234, 9.04878, 13.079429999999983, 14.463735000000034, 17.39205000000003, 18.988515000000064, 20.99116500000009, 19.596525000000067, 18.99612000000008, 19.23304500000007, 17.76703500000006, 17.428320000000085, 17.008680000000073, 16.551600000000082, 15.016950000000039, 15.388815000000038, 17.32146000000005, 17.636385000000057, 17.558580000000052, 19.078995000000052, 17.394195000000046, 16.891680000000054, 18.013515000000044, 18.431205000000066, 17.54200500000005, 17.62605000000004, 14.246895000000029, 13.665405000000012, 12.035790000000022, 13.22178000000001, 14.765595000000024, 16.94920500000002, 16.878225000000004, 15.421770000000029, 12.285195000000032, 13.788255000000001, 15.221310000000033, 13.288665000000014, 14.466270000000025, 14.100840000000021, 14.655615000000035, 12.534210000000032, 9.979709999999994, 8.366670000000017, 7.404540000000006, 7.851090000000008, 5.558670000000008, 5.463119999999998, 5.88003000000001, 4.0203149999999965, 4.165785, 3.0244500000000065, 1.7204850000000014, 1.200420000000003, 0.3625049999999983, 0.10413000000000405, -0.10062000000000104, -1.0295999999999979, -1.789124999999999], [0.0, -0.05108999999999497, 0.16848000000002727, 2.057444999999996, 2.5517699999999923, -0.14215499999999892, -1.1261250000000054, 1.4572350000000043, 6.653789999999988, 7.713224999999989, 8.59345499999999, 9.653279999999992, 9.30773999999999, 0.9085049999999875, -5.095350000000018, -3.718844999999998, -3.7401, -2.9448900000000133, -4.635735000000016, -7.413705, -4.4458050000000195, 4.073549999999983, 4.571774999999981, 6.459764999999997, 9.961184999999992, 11.148149999999989, 14.663414999999985, 16.03640999999999, 15.721679999999981, 15.06608999999999, 14.929004999999986, 13.899989999999992, 14.918669999999986, 15.75521999999998, 15.489824999999986, 15.119519999999984, 15.606434999999983, 15.692624999999989, 15.862664999999986, 16.709744999999998, 15.50717999999998, 12.178334999999992, 12.22259999999999, 12.16721999999999, 11.69024999999999, 14.063984999999986, 13.827449999999992, 14.00548499999999, 14.07490499999999, 14.567474999999982, 13.64882999999999, 14.019914999999985, 15.271424999999986, 14.023424999999987, 10.92779999999999, 12.616694999999991, 11.69882999999999, 11.17505999999999, 10.99838999999999, 10.913759999999991, 11.840009999999989, 12.26666999999999, 11.65573499999999, 11.54126999999999, 10.875539999999988, 10.53058499999999, 10.07291999999999, 8.281259999999985, 10.56314999999999, 12.32965499999999, 11.97592499999999, 11.71189499999999, 11.89558499999999, 11.83123499999999, 11.81036999999999, 10.12283999999999, 11.33690999999999, 12.23605499999999, 12.01687499999999, 12.537134999999989, 13.141049999999991, 13.68373499999999], [0.0, -1.0457849999999913, -2.115749999999993, -0.061034999999999506, 1.5951000000000084, 0.5159700000000069, 0.906945000000003, 3.831750000000004, 4.341285000000012, 1.9147050000000032, -3.311684999999992, -5.794230000000001, -6.243119999999997, -7.002839999999994, -10.104314999999986, -8.594429999999996, -5.351384999999992, -7.1783399999999995, -9.989459999999998, -10.533899999999981, -3.6942749999999944, 0.5988450000000025, -1.407899999999993, -1.482584999999993, 0.6162000000000063, 2.919930000000007, 8.267025000000006, 9.681555000000014, 11.793405000000023, 13.525005000000021, 15.417090000000034, 15.550470000000015, 15.820935000000002, 16.93185000000001, 16.052400000000002, 15.839850000000027, 16.296735000000012, 15.504840000000016, 15.731820000000052, 14.714895000000002, 14.368965000000035, 17.216355000000053, 14.093040000000002, 12.661545000000007, 13.141050000000014, 12.706785000000016, 13.991249999999997, 14.183715000000014, 12.478830000000022, 12.23352000000001, 11.616930000000005, 10.548330000000002, 10.439715000000001, 8.681984999999994, 10.036260000000002, 7.655700000000019, 5.527470000000012, 7.318155000000013, 5.592990000000011, 6.575790000000005, 5.681325000000015, 5.365815000000007, 5.626725000000016, 4.803825000000011, 3.0515550000000067, 3.7773450000000155, 2.9004300000000125, 3.5536800000000195, 3.5195550000000075, 2.604615000000009, 2.1358350000000117, 2.5104300000000075, 1.3455000000000035, 1.3029900000000065, 0.8753550000000074, 0.21469500000000696, -0.5105099999999925, -0.11719499999999217, -0.8929049999999912, -2.5615199999999927, -2.4675299999999933, -2.954054999999994], [0.0, -1.3020149999999848, -1.1567399999999868, 0.14449500000000626, 1.2747149999999898, -0.8999249999999943, -0.2123549999999934, 3.604964999999983, 5.968169999999999, 7.478639999999988, 8.10673499999999, 8.95693499999999, 9.84281999999999, 5.665919999999991, -1.3031849999999832, -3.1796700000000104, -3.034979999999999, -2.3002199999999977, -3.9140399999999875, -2.0252700000000026, 2.2345049999999924, 4.583085000000001, 5.645639999999995, 6.041099999999991, 10.016174999999992, 12.211484999999993, 15.965039999999988, 17.431829999999994, 17.817929999999993, 17.199194999999996, 16.61575499999999, 17.463809999999995, 19.327035000000002, 19.211984999999988, 19.843394999999994, 19.34614499999999, 20.195564999999988, 21.31506000000002, 21.78247500000001, 20.613255000000006, 19.610370000000003, 19.272240000000004, 17.59796999999999, 16.113434999999996, 16.766684999999995, 18.893744999999996, 17.635215000000002, 16.174274999999998, 14.551679999999989, 15.805334999999985, 17.101694999999985, 17.163119999999992, 18.71532, 17.410574999999984, 15.779204999999987, 14.923154999999987, 14.025569999999984, 13.985789999999987, 13.732094999999994, 10.530779999999993, 11.68907999999999, 10.64543999999999, 8.72059499999999, 7.99441499999999, 7.013759999999989, 8.324939999999991, 9.224864999999992, 9.677459999999991, 10.93286999999999, 13.35691499999999, 13.255514999999988, 13.65526499999999, 13.127984999999992, 11.30200499999999, 10.13999999999999, 11.306684999999993, 12.439049999999988, 12.30605999999999, 13.050764999999995, 12.33082499999999, 12.28616999999999, 12.867854999999988], [0.0, -0.037244999999998196, 0.02788499999999594, -0.4502550000000012, -0.08151000000000197, 1.40478, 1.8794099999999987, 0.8546850000000021, -0.010919999999999153, 1.066260000000001, 3.0856799999999978, 4.234229999999997, 3.3577049999999984, -0.5181150000000039, -0.2911349999999997, 1.1842349999999986, 1.1074050000000002, 1.9232849999999986, 3.3555599999999974, 4.404074999999999, 2.225144999999998, 1.7403749999999985, 4.035915000000001, 5.642715, 2.838809999999998, 2.1149699999999987, 2.0459399999999985, 3.4052849999999975, 2.8655249999999977, 2.5806299999999975, 3.076904999999998, 3.373889999999998, 3.1276049999999973, 3.3194849999999976, 3.7929449999999987, 3.4017749999999976, 3.0800249999999973, 2.9427449999999973, 3.417959999999998, 2.8312049999999975, 2.4501749999999984, 2.7391649999999976, 3.884789999999999, 4.148429999999999, 4.1792399999999965, 2.6457599999999974, 2.626064999999998, 2.158064999999998, 2.196479999999999, 2.6502449999999973, 3.479969999999998, 4.65426, 4.585034999999997, 4.324319999999999, 4.3642949999999985, 4.992194999999999, 4.578405, 5.226585000000001, 4.6790249999999975, 5.467215000000002, 5.31804, 4.873829999999996, 3.7948949999999977, 3.3475649999999977, 5.104905, 4.777499999999999, 5.225414999999996, 5.518499999999996, 4.393739999999999, 3.9758549999999993, 3.3374249999999974, 3.145349999999998, 3.5917049999999975, 3.8194649999999988, 3.7170899999999976, 2.6139749999999973, 2.356184999999997, 2.388749999999998, 2.8817099999999973, 2.7582749999999985, 2.4178049999999973, 2.8058549999999975], [0.0, -1.7052750000000039, -0.9334649999999964, 0.596114999999994, 0.929759999999991, -1.5369900000000136, -2.0603700000000025, 1.3131300000000046, 2.913690000000008, 2.6812500000000075, 2.0810399999999944, 2.6280149999999924, 2.813460000000001, -1.9197750000000475, -5.655780000000025, -4.110210000000013, -1.66296, -2.630355000000014, -5.599620000000023, -6.448260000000051, -1.1682450000000006, 2.513745000000009, 3.5550450000000176, 3.330405000000016, 4.466474999999999, 5.739435000000004, 8.63557500000001, 10.489050000000013, 10.215465000000012, 10.810410000000013, 11.842545000000014, 12.151035000000014, 12.755145000000013, 13.652145000000015, 12.517245000000013, 12.454065000000012, 11.899290000000013, 12.634635000000014, 12.966135000000014, 12.663495000000013, 11.291670000000012, 10.280400000000014, 10.556520000000013, 10.929555000000013, 9.864660000000013, 9.857250000000013, 10.234965000000011, 9.809670000000015, 8.647470000000014, 8.881665000000014, 9.564165000000013, 10.185435000000012, 10.973625000000013, 10.219755000000013, 8.882445000000015, 9.298575000000014, 8.213010000000018, 6.6409200000000155, 6.333990000000017, 7.152795000000017, 6.978660000000021, 6.638580000000016, 6.222450000000017, 5.943600000000004, 6.484530000000021, 6.509490000000018, 7.300800000000025, 6.489015000000015, 7.63405500000002, 7.151040000000022, 5.405400000000008, 5.265975000000014, 5.812755000000018, 5.379660000000014, 5.08423500000001, 4.847505000000008, 4.834440000000002, 5.118945000000008, 4.034745000000015, 3.6131550000000052, 2.775045000000004, 3.5665499999999932], [0.0, -1.3636350000000075, -0.15015000000000533, 4.638074999999988, 5.561204999999976, 3.5835149999999825, 6.9152849999999955, 7.6508249999999745, 5.096909999999992, 2.24640000000001, -3.8639250000000294, -6.196710000000026, -7.313475000000025, -7.128225000000017, -8.062470000000028, -6.895395000000022, -3.135990000000019, -4.821570000000021, -9.031815000000027, -7.214415000000028, -5.232435000000018, -4.855695000000021, -2.405910000000011, 1.4494349999999763, 6.792434999999992, 12.97276499999998, 17.70287999999998, 21.84292499999995, 24.755054999999984, 27.057224999999995, 29.474444999999946, 31.771544999999932, 31.520384999999948, 31.20896999999998, 30.230850000000004, 29.031404999999992, 28.863900000000015, 29.505450000000025, 30.972629999999953, 32.922045000000004, 32.829225, 34.30088999999997, 36.50731500000002, 33.94442999999986, 34.10783999999993, 31.81619999999996, 30.14056499999996, 29.419454999999992, 29.583450000000006, 27.03090000000003, 25.394654999999986, 25.64347500000003, 24.599834999999985, 23.58154499999999, 28.454984999999972, 26.79280500000001, 23.83133999999997, 20.157149999999987, 20.284484999999975, 18.895500000000084, 16.48140000000005, 17.039685000000055, 17.70073500000003, 16.46053499999998, 13.957709999999972, 11.771564999999958, 11.66158499999999, 11.466780000000002, 11.225564999999987, 8.180249999999985, 7.897889999999988, 8.231534999999992, 6.245069999999982, 6.277634999999972, 4.29662999999997, 5.068244999999989, 1.939859999999987, -0.17940000000002776, -0.23673000000002276, -3.4743150000000202, -4.437420000000029, -5.976555000000024], [0.0, -0.46585499999998703, -0.503879999999997, 3.493229999999995, 4.237545000000024, 3.7984049999999936, 4.160325000000007, 9.420450000000011, 6.235710000000013, 2.9324099999999955, -2.3243999999999962, -5.2468649999999935, -6.167264999999989, -7.8038999999999925, -7.8265199999999915, -6.306884999999993, -0.2730000000000157, -1.843919999999999, -4.884360000000002, -2.5387050000000064, 6.5307450000000085, 4.300529999999988, 2.4100049999999946, 4.414214999999997, 4.448729999999992, 8.049210000000018, 14.50215000000002, 17.44177500000003, 21.286785000000066, 23.990265000000008, 27.039285000000028, 27.53985000000001, 27.998490000000018, 27.549014999999976, 26.489189999999944, 25.433850000000014, 25.00251000000005, 23.464740000000056, 24.251565000000006, 20.456279999999992, 22.16233500000007, 26.82595499999998, 26.57986500000007, 25.129455000000036, 26.856765000000024, 25.003875000000022, 21.592935000000054, 19.448715000000043, 17.242875000000048, 15.575625000000032, 15.598245000000064, 15.782715000000023, 14.938755000000041, 12.66408, 19.16830499999999, 14.379105000000012, 15.00642, 17.25769500000002, 14.70904499999999, 13.61392500000001, 14.089725000000024, 9.910680000000008, 9.717630000000016, 5.8129500000000185, 6.788535000000001, 6.137039999999983, 4.697744999999996, 6.961889999999995, 4.394325, 1.2764700000000069, 2.2869600000000148, 1.0413000000000068, 0.7975499999999975, -2.219489999999995, -3.208529999999998, -4.356884999999997, -5.773364999999994, -7.259459999999992, -8.285159999999996, -9.431564999999994, -10.797929999999994, -11.401064999999996], [0.0, -1.0426650000000386, -1.52295000000003, -5.01423000000004, -4.072380000000038, -1.3542750000000154, -3.2498700000000476, -6.225765000000006, -3.2783400000000036, -1.359734999999997, 8.364329999999944, 11.706629999999956, 9.833264999999962, 6.970664999999952, 5.468384999999943, 5.415149999999956, 5.268899999999935, 8.430434999999964, 14.771444999999957, 12.627419999999955, 8.256299999999959, 11.412179999999962, 11.015744999999955, 9.791534999999952, 7.025849999999949, 3.6188099999999714, 5.760494999999988, 4.768724999999959, 3.5341799999999637, 2.4347699999999293, 2.6330849999999657, 1.9919249999999842, 0.42529499999995224, 1.1276849999999534, 2.64361499999999, 1.7834699999999835, 2.4646049999999917, 1.8170099999999856, 1.1417250000000188, 0.079949999999954, -1.0102950000000348, -3.6386999999999965, -3.2375849999999993, -2.878395000000019, -1.2339600000000246, -1.7218499999999928, -4.444244999999995, -4.460039999999964, -4.602585000000005, -3.109860000000001, -2.1212099999999943, 0.8336249999999623, 3.6607349999999848, 3.183764999999976, -1.109160000000017, -1.179945000000032, 2.2415249999999496, 8.456369999999948, 7.693529999999946, 6.937124999999977, 5.293664999999969, 5.298539999999946, 2.8885349999999725, 2.5193999999999654, 4.527899999999963, 8.843444999999969, 6.94199999999997, 3.486989999999974, 4.235594999999979, 6.686939999999952, 6.496814999999966, 6.564479999999966, 6.516314999999965, 7.210319999999957, 7.593884999999974, 4.769504999999969, 5.8620899999999665, 6.123974999999975, 6.137819999999959, 7.635029999999965, 8.541584999999941, 8.765444999999971], [0.0, -9.237735000000002, -10.612094999999997, -7.956389999999997, -6.526260000000004, -6.332235000000008, -9.862514999999998, -10.33324499999999, -3.0782699999999994, 1.460745000000001, 5.329545000000003, 9.5238, 12.745200000000002, 8.975850000000017, -1.8413849999999987, -7.999485000000005, -6.363240000000003, -5.05869, -3.9306149999999986, -5.343, -5.391165000000003, 3.7026600000000047, 6.625515, 2.655119999999998, 3.41269499999999, 2.6391300000000038, 1.6097250000000014, 4.261529999999995, 4.567680000000005, 2.9253900000000033, 0.49959000000000175, -2.507504999999999, -1.9338149999999994, -1.3796249999999985, -0.9486749999999986, -0.40696499999999713, -0.777074999999998, 0.06454500000000163, -0.6526649999999987, -0.38570999999999644, 1.9037850000000085, 2.131740000000002, 1.4628899999999994, 0.808860000000001, 3.1599749999999944, 2.523105000000004, 1.9642349999999982, 2.1529949999999993, 1.9862699999999998, 2.336684999999999, 3.267810000000004, 4.179825000000005, 6.483749999999997, 8.659170000000007, 8.487569999999984, 10.706280000000012, 8.105955000000005, 10.38647999999999, 9.809475000000006, 8.081579999999999, 9.064379999999979, 9.973275000000001, 9.647819999999992, 9.490844999999995, 9.34205999999998, 10.379265, 11.54829, 10.430159999999997, 12.274860000000004, 11.635260000000004, 12.448214999999989, 14.457299999999998, 14.894684999999997, 14.089335, 14.076660000000006, 14.654054999999994, 14.476995000000011, 15.763215000000022, 15.786615000000017, 16.28835000000001, 16.480619999999995, 16.712085000000013], [0.0, -5.619510000000003, -6.407700000000005, -5.31804, -3.656640000000006, -4.4495100000000045, -6.249165, -7.784009999999991, -5.311605, -2.791230000000006, -2.516865000000005, 0.8622899999999984, 2.6923649999999926, 0.9219599999999986, -7.392450000000006, -7.6798800000000025, -5.447910000000006, -2.723370000000006, -3.6281700000000052, -5.794035000000001, -6.0299850000000035, -3.6543000000000063, 2.269020000000004, 1.7011799999999955, -0.22152000000000038, -2.950740000000005, -6.760260000000003, -7.42950000000001, -7.521930000000005, -8.993400000000012, -10.724610000000016, -12.575355000000034, -13.800930000000026, -11.305125000000018, -9.58210500000001, -9.846915000000008, -10.722465000000003, -10.311795000000004, -9.217845000000004, -9.591465000000012, -11.284455000000012, -10.071555000000005, -9.257235000000012, -8.692320000000011, -6.829094999999998, -7.99948500000001, -6.587685000000002, -7.66506000000001, -8.383245000000004, -9.072570000000002, -7.7510549999999965, -4.8853349999999995, -4.697940000000003, -4.792710000000005, -7.777965000000008, -7.172100000000004, -4.239885000000008, -3.735810000000005, -4.736355000000005, -4.048590000000006, -5.387460000000004, -4.750785000000005, -3.679845000000004, -6.009315000000004, -5.354115000000004, -5.177835000000005, -3.1045950000000038, -2.2428900000000045, -0.8248500000000043, -0.0707850000000052, -3.705780000000005, -2.863575000000005, -1.8638100000000055, -1.0715250000000034, -1.7458350000000042, -0.7257900000000042, 0.6240000000000006, 0.7220849999999999, 0.7745399999999929, 0.47794499999999474, 1.448069999999988, 1.574234999999991], [0.0, -0.5208450000000298, 0.03724500000002351, 1.8493800000000036, 3.216719999999995, 1.8661500000000615, 1.4818049999999943, 3.200924999999998, 8.89785000000002, 4.648604999999996, -0.4738499999999952, -6.514949999999978, -9.39509999999999, -7.155134999999996, -6.834750000000026, -3.837209999999981, 2.1607949999999505, 5.5358549999999696, 3.548024999999953, -1.5613650000000234, -1.2296700000000342, 4.797389999999947, 0.9416549999999688, -4.090319999999995, 0.0027299999999677027, 2.797469999999965, 4.453215, 0.8675550000000385, -1.0920000000000059, 1.1265150000000475, 5.567640000000058, 10.72831500000007, 12.447435000000052, 14.518335000000047, 16.28113500000006, 14.1833250000001, 13.193115000000073, 11.48238000000006, 12.726870000000059, 13.59774000000009, 7.589790000000061, 7.928505000000076, 10.084620000000033, 11.213670000000068, 15.485340000000019, 16.711890000000043, 14.968785000000093, 11.118899999999993, 12.925575000000013, 12.581595000000018, 12.754365000000004, 16.089645000000058, 16.934580000000036, 11.313315000000063, 7.097220000000075, 6.5791050000000375, 6.711900000000011, 9.303840000000022, 12.148305000000033, 14.849250000000008, 13.409955000000043, 13.364909999999998, 10.235160000000011, 12.23527500000004, 15.521025000000026, 14.81902500000005, 11.40594000000004, 10.351185000000061, 5.003895000000032, 0.2735850000000468, 0.0450450000000302, -1.459379999999971, -1.3022099999999703, 1.9404449999999969, -0.5715449999999684, -1.6849949999999723, -5.03177999999998, -6.5845649999999765, -7.079474999999977, -9.070424999999986, -10.522589999999965, -10.81450499999999], [0.0, 0.7940399999999972, 1.6436550000000025, -1.0436400000000177, -0.8478600000000167, 1.8509399999999987, 2.104440000000001, 1.8070649999999953, 0.5381999999999998, 2.010645000000009, 5.656170000000026, 10.02046500000002, 10.949445000000017, 7.194135000000018, 7.9189500000000175, 7.892625000000019, 5.527665000000024, 6.314685000000022, 8.307780000000019, 11.883495000000025, 13.238745000000021, 10.241790000000018, 9.96391500000002, 12.612405000000019, 12.006150000000023, 9.913410000000018, 9.355515000000018, 9.07315500000002, 8.931975000000019, 8.36569500000002, 11.20957500000002, 12.283050000000022, 11.74836000000003, 10.973235000000019, 9.359805000000017, 7.358130000000015, 6.740955000000022, 4.432155000000025, 5.159700000000017, 6.081270000000024, 2.624700000000022, 1.260675000000015, 4.4157750000000275, 7.945665000000021, 8.571615000000019, 10.84843500000002, 6.961695000000018, 4.136535000000013, 3.401385000000018, 3.6320700000000246, 4.308525000000019, 6.318000000000023, 9.39705000000002, 7.648485000000016, 3.5222850000000214, 5.103540000000017, 3.3692100000000185, 9.390810000000018, 15.789345000000004, 12.726675000000023, 10.905570000000019, 10.246275000000018, 6.817590000000017, 7.252245000000022, 6.982560000000019, 11.660025000000026, 11.783265000000021, 12.597000000000032, 10.009545000000017, 6.775665000000026, 9.148620000000019, 7.537335000000016, 6.577545000000025, 8.71045500000002, 8.464950000000021, 7.062705000000017, 5.046210000000021, 5.3506050000000185, 6.204120000000021, 5.715060000000028, 5.790915000000026, 6.362460000000022], ...]</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table><p>... and 3004 more rows.</p></details></details><div style=\"margin-left: 0px;\" class=\"container-fields\"><span class=\"field-key\" title=\".session_id\">session_id: </span><span class=\"field-value\">742951821</span></div><div style=\"margin-left: 0px;\" class=\"container-fields\"><span class=\"field-key\" title=\".institution\">institution: </span><span class=\"field-value\">Allen Institute for Brain Science</span></div><div style=\"margin-left: 0px;\" class=\"container-fields\"><span class=\"field-key\" title=\".stimulus_notes\">stimulus_notes: </span><span class=\"field-value\">brain_observatory_1.1</span></div></div>"
      ],
      "text/plain": [
       "root pynwb.file.NWBFile at 0x1601617772016\n",
       "Fields:\n",
       "  acquisition: {\n",
       "    raw_running_wheel_rotation <class 'pynwb.base.TimeSeries'>,\n",
       "    running_wheel_signal_voltage <class 'pynwb.base.TimeSeries'>,\n",
       "    running_wheel_supply_voltage <class 'pynwb.base.TimeSeries'>\n",
       "  }\n",
       "  devices: {\n",
       "    probeA <class 'abc.EcephysProbe'>,\n",
       "    probeB <class 'abc.EcephysProbe'>,\n",
       "    probeC <class 'abc.EcephysProbe'>,\n",
       "    probeD <class 'abc.EcephysProbe'>,\n",
       "    probeE <class 'abc.EcephysProbe'>,\n",
       "    probeF <class 'abc.EcephysProbe'>\n",
       "  }\n",
       "  electrode_groups: {\n",
       "    probeA <class 'abc.EcephysElectrodeGroup'>,\n",
       "    probeB <class 'abc.EcephysElectrodeGroup'>,\n",
       "    probeC <class 'abc.EcephysElectrodeGroup'>,\n",
       "    probeD <class 'abc.EcephysElectrodeGroup'>,\n",
       "    probeE <class 'abc.EcephysElectrodeGroup'>,\n",
       "    probeF <class 'abc.EcephysElectrodeGroup'>\n",
       "  }\n",
       "  electrodes: electrodes <class 'hdmf.common.table.DynamicTable'>\n",
       "  file_create_date: [datetime.datetime(2020, 5, 26, 0, 53, 26, 959556, tzinfo=tzoffset(None, -25200))]\n",
       "  identifier: 742951821\n",
       "  institution: Allen Institute for Brain Science\n",
       "  intervals: {\n",
       "    drifting_gratings_presentations <class 'pynwb.epoch.TimeIntervals'>,\n",
       "    flashes_presentations <class 'pynwb.epoch.TimeIntervals'>,\n",
       "    gabors_presentations <class 'pynwb.epoch.TimeIntervals'>,\n",
       "    invalid_times <class 'pynwb.epoch.TimeIntervals'>,\n",
       "    natural_movie_one_presentations <class 'pynwb.epoch.TimeIntervals'>,\n",
       "    natural_movie_three_presentations <class 'pynwb.epoch.TimeIntervals'>,\n",
       "    natural_scenes_presentations <class 'pynwb.epoch.TimeIntervals'>,\n",
       "    spontaneous_presentations <class 'pynwb.epoch.TimeIntervals'>,\n",
       "    static_gratings_presentations <class 'pynwb.epoch.TimeIntervals'>\n",
       "  }\n",
       "  invalid_times: invalid_times <class 'pynwb.epoch.TimeIntervals'>\n",
       "  processing: {\n",
       "    eye_tracking <class 'pynwb.base.ProcessingModule'>,\n",
       "    eye_tracking_rig_metadata <class 'pynwb.base.ProcessingModule'>,\n",
       "    filtered_gaze_mapping <class 'pynwb.base.ProcessingModule'>,\n",
       "    optotagging <class 'pynwb.base.ProcessingModule'>,\n",
       "    raw_gaze_mapping <class 'pynwb.base.ProcessingModule'>,\n",
       "    running <class 'pynwb.base.ProcessingModule'>,\n",
       "    stimulus <class 'pynwb.base.ProcessingModule'>\n",
       "  }\n",
       "  session_description: Data and metadata for an Ecephys session\n",
       "  session_id: 742951821\n",
       "  session_start_time: 2018-10-26 12:47:04-07:00\n",
       "  stimulus_notes: brain_observatory_1.1\n",
       "  subject: subject abc.EcephysSpecimen at 0x1601617798832\n",
       "Fields:\n",
       "  age: P120D\n",
       "  age_in_days: 120.0\n",
       "  genotype: wt/wt\n",
       "  sex: M\n",
       "  species: Mus musculus\n",
       "  specimen_name: C57BL/6J-404571\n",
       "  subject_id: 723627600\n",
       "\n",
       "  timestamps_reference_time: 2018-10-26 12:47:04-07:00\n",
       "  units: units <class 'pynwb.misc.Units'>"
      ]
     },
     "execution_count": 11,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "# takes relative or absolute filepath as first argument\n",
    "io = NWBHDF5IO(f\"{download_loc}/{filename}\", mode=\"r\", load_namespaces=True)\n",
    "nwb = io.read()\n",
    "nwb"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "id": "2598de2f",
   "metadata": {},
   "outputs": [],
   "source": [
    "### uncomment these to view aspects of the file\n",
    "\n",
    "### not all of these exist for all NWB files (Key Errors will arise if the fields don't exist for this file)\n",
    "\n",
    "# nwb.identifier\n",
    "# nwb.processing\n",
    "# nwb.acquisition[\"events\"]\n",
    "# nwb.intervals[\"trials\"]\n",
    "# nwb.stimulus[\"StimulusPresentation\"]\n",
    "# nwb.electrodes"
   ]
  },
  {
   "attachments": {},
   "cell_type": "markdown",
   "id": "6329ad90",
   "metadata": {},
   "source": [
    "### OpenScope's File Schemas\n",
    "OpenScope works with two main types of brain data files for different experiments. There's Extracellular Electrophysiology, *Ecephys*, which uses **Neuropixels** probes to gather electrical data, and Optical Physiology, *Ophys*, which uses **2-Photon** Calcium imaging to gather fluorescence data. Since the NWB Standard is very flexible, and these files are used for different needs, there are several differences between these data types. These table schemas were made as comprehensive descriptions of what goes in our NWB files. Below, **Pandas** is used to display a general outline for each file type where every field within the NWB file is described. Note that NWB files or files from other institutions could vary from these significantly. These tables are just meant to be used as a reference, don't be overwhelmed trying to understand all the fields!"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "id": "49f6a521",
   "metadata": {},
   "outputs": [],
   "source": [
    "# change pandas settings to show whole table\n",
    "pd.set_option('display.max_rows', None)\n",
    "pd.set_option('display.width', None)\n",
    "pd.set_option('display.max_colwidth', -1)"
   ]
  },
  {
   "attachments": {},
   "cell_type": "markdown",
   "id": "6dbe5f2c",
   "metadata": {},
   "source": [
    "#### Ecephys File"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 9,
   "id": "3d252ee4",
   "metadata": {
    "scrolled": true,
    "tags": [
     "output_scroll"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>Section</th>\n",
       "      <th>Field</th>\n",
       "      <th>Type</th>\n",
       "      <th>Path</th>\n",
       "      <th>Definition</th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>NaN</td>\n",
       "      <td>Session Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.session_description</td>\n",
       "      <td>Description of the Session</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>NaN</td>\n",
       "      <td>Session Identifier</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.identifier</td>\n",
       "      <td>Unique identifier of the session</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>NaN</td>\n",
       "      <td>Session Start Time</td>\n",
       "      <td>datetime</td>\n",
       "      <td>nwb.session_start_time</td>\n",
       "      <td>Datetime start of the session</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>NaN</td>\n",
       "      <td>Reference Time</td>\n",
       "      <td>datetime</td>\n",
       "      <td>nwb.timestamps_reference_time</td>\n",
       "      <td>Time that all timestamps are in reference to</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>4</th>\n",
       "      <td>NaN</td>\n",
       "      <td>Experiment Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.experiment_description</td>\n",
       "      <td>Description of the experiment</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>5</th>\n",
       "      <td>NaN</td>\n",
       "      <td>Institution</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.institution</td>\n",
       "      <td>Name of the institution that produced these data</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>6</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Comments</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.comments</td>\n",
       "      <td>Comments</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>7</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Conversion</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.conversion</td>\n",
       "      <td>Scalar to multiply each element in data to convert it to the specified unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>8</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.description</td>\n",
       "      <td>Description</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>9</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Interval</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.interval</td>\n",
       "      <td>Unexplained</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>10</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Offset</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.offset</td>\n",
       "      <td>Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>11</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Reference Frame</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.reference_frame</td>\n",
       "      <td>Unexplained</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>12</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Resolution</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.resolution</td>\n",
       "      <td>The smallest meaningful difference (in specified unit) between values in data</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>13</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.unit</td>\n",
       "      <td>Name of the unit for the data</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>14</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Angle</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.angle</td>\n",
       "      <td>Angle of the eye in degrees over time as calculated with corneal reflection tracking</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>15</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Height</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.height</td>\n",
       "      <td>Height of the cornea, in pixels, over time as calculated with corneal reflection tracking</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>16</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Width</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.width</td>\n",
       "      <td>Width of the cornea, in pixels, over time as calculated with corneal reflection tracking</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>17</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Area</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.area</td>\n",
       "      <td>Area of the cornea, in pixels, over time as calculated with corneal reflection tracking and with outliers removed. Should generally be equal to corneal reflection tracking height times corneal reflection tracking width</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>18</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Raw Area</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.area_raw</td>\n",
       "      <td>Area of the cornea, in pixels, over time as calculated with corneal reflection tracking. Should be equal to corneal reflection tracking height times corneal reflection tracking width.</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>19</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Data</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.data</td>\n",
       "      <td>2D array consisting of the X and Y locations of the eye, in pixels, over time as calculated by corneal reflection tracking</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>20</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.timestamps</td>\n",
       "      <td>Timestamps of the corneal reflection tracking arrays</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>21</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Tracking Comments</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].eye_tracking.comments</td>\n",
       "      <td>Comments</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>22</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Conversion</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].eye_tracking.conversion</td>\n",
       "      <td>Scalar to multiply each element in data to convert it to the specified unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>23</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].eye_tracking.description</td>\n",
       "      <td>Description</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>24</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Interval</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].eye_tracking.interval</td>\n",
       "      <td>Unexplained</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>25</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Offset</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].eye_tracking.offset</td>\n",
       "      <td>Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>26</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Reference Frame</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].eye_tracking.reference_frame</td>\n",
       "      <td>Unexplained</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>27</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Resolution</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].eye_tracking.resolution</td>\n",
       "      <td>The smallest meaningful difference (in specified unit) between values in data</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>28</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].eye_tracking.unit</td>\n",
       "      <td>Name of the unit for the data</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>29</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Angle</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].eye_tracking.angle</td>\n",
       "      <td>Angle of the eye in degrees over time as calculated with eye tracking</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>30</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Height</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].eye_tracking.height</td>\n",
       "      <td>Height of the eye, in pixels, over time as calculated with eye tracking</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>31</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Width</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].eye_tracking.width</td>\n",
       "      <td>Width of the eye, in pixels, over time as calculated with eye tracking</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>32</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Area</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].eye_tracking.area</td>\n",
       "      <td>Area of the eye, in pixels, over time as calculated with eye tracking with outliers removed. Should generally be equal to eye tracking height times eye tracking width</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>33</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Raw Area</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].eye_tracking.area_raw</td>\n",
       "      <td>Area of the eye, in pixels, over time as calculated with eye tracking. Should be equal to eye tracking height times eye tracking width</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>34</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Data</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].eye_tracking.data</td>\n",
       "      <td>2D array consisting of the X and Y locations of the eye, in pixels, over time as calculated by eye tracking</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>35</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].eye_tracking.timestamps</td>\n",
       "      <td>Timestamps of the eye tracking arrays</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>36</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Tracking Comments</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].pupil_tracking.comments</td>\n",
       "      <td>Comments</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>37</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Conversion</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].pupil_tracking.conversion</td>\n",
       "      <td>Scalar to multiply each element in data to convert it to the specified unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>38</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].pupil_tracking.description</td>\n",
       "      <td>Description</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>39</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Interval</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].pupil_tracking.interval</td>\n",
       "      <td>Unexplained</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>40</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Offset</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].pupil_tracking.offset</td>\n",
       "      <td>Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>41</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Reference Frame</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].pupil_tracking.reference_frame</td>\n",
       "      <td>Unexplained</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>42</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Resolution</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].pupil_tracking.resolution</td>\n",
       "      <td>The smallest meaningful difference (in specified unit) between values in data</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>43</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].pupil_tracking.unit</td>\n",
       "      <td>Name of the unit for the data</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>44</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Pupil Tracking Angle</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].pupil_tracking.angle</td>\n",
       "      <td>Angle of the pupil in degrees over time as calculated with pupil tracking</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>45</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Pupil Tracking Height</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].pupil_tracking.height</td>\n",
       "      <td>Height of the pupil, in pixels, over time as calculated with pupil tracking</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>46</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Pupil Tracking Width</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].pupil_tracking.width</td>\n",
       "      <td>Width of the pupil, in pixels, over time as calculated with pupil tracking</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>47</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Pupil Tracking Area</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].pupil_tracking.area</td>\n",
       "      <td>Area of the pupil, in pixels, over time as calculated with pupil tracking and with outliers removed. Should generally be equal to pupil tracking height times pupil tracking width</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>48</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Pupil Tracking Raw Area</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].pupil_tracking.area_raw</td>\n",
       "      <td>Area of the pupil, in pixels, over time as calculated with pupil tracking. Should be equal to pupil tracking height times pupil tracking width</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>49</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Pupil Tracking Data</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].pupil_tracking.data</td>\n",
       "      <td>2D array consisting of the X and Y locations of the pupil, in pixels, over time as calculated by eye tracking</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>50</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Pupil Tracking Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].pupil_tracking.timestamps</td>\n",
       "      <td>Timestamps of the pupil tracking arrays</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>51</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Blink Times</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].likely_blink.data</td>\n",
       "      <td>Array of booleans indicating probable blink times</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>52</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Blink Times Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"EyeTracking\"].likely_blink.timestamps</td>\n",
       "      <td>Timestamps of the blink times array</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>53</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Running Wheel Rotation Comments</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[\"raw_running_wheel_rotation\"].comments</td>\n",
       "      <td>Comments</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>54</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Running Wheel Rotation Conversion</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[\"raw_running_wheel_rotation\"].conversion</td>\n",
       "      <td>Scalar to multiply each element in data to convert it to the specified unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>55</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Running Wheel Rotation Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[\"raw_running_wheel_rotation\"].description</td>\n",
       "      <td>Description</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>56</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Running Wheel Rotation Interval</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[\"raw_running_wheel_rotation\"].interval</td>\n",
       "      <td>Unexplained</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>57</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Running Wheel Rotation Offset</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[\"raw_running_wheel_rotation\"].offset</td>\n",
       "      <td>Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>58</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Running Wheel Rotation Resolution</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[\"raw_running_wheel_rotation\"].resolution</td>\n",
       "      <td>The smallest meaningful difference (in specified unit) between values in data</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>59</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Running Wheel Rotation Timestamps Units</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[\"raw_running_wheel_rotation\"].timestamps_unit</td>\n",
       "      <td>Nameof the unit for the timestamps</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>60</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Running Wheel Rotation Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[\"raw_running_wheel_rotation\"].unit</td>\n",
       "      <td>Name of the unit for the data</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>61</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Raw Running Wheel Rotation Data</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"raw_running_wheel_rotation\"].data</td>\n",
       "      <td>Speed of the running wheel, measured at each timestamps. The data is raw (cm/s).</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>62</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Raw Running Wheel Rotation Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"raw_running_wheel_rotation\"].timestamps</td>\n",
       "      <td>Timestamps of the unfiltered running speed.</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>63</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Running Wheel Signal Voltage Conversion</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[\"running_wheel_signal_voltage\"].comments</td>\n",
       "      <td>Comments</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>64</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Running Wheel Signal Voltage Description</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[\"running_wheel_signal_voltage\"].conversion</td>\n",
       "      <td>Scalar to multiply each element in data to convert it to the specified unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>65</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Running Wheel Signal Voltage Interval</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[\"running_wheel_signal_voltage\"].description</td>\n",
       "      <td>Description</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>66</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Running Wheel Signal Voltage Offset</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[\"running_wheel_signal_voltage\"].interval</td>\n",
       "      <td>Unexplained</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>67</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Running Wheel Signal Voltage Resolution</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[\"running_wheel_signal_voltage\"].offset</td>\n",
       "      <td>Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>68</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Running Wheel Signal Voltage Timestamps Units</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[\"running_wheel_signal_voltage\"].resolution</td>\n",
       "      <td>The smallest meaningful difference (in specified unit) between values in data</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>69</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Running Wheel Signal Voltage Unit</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[\"running_wheel_signal_voltage\"].timestamps_unit</td>\n",
       "      <td>Nameof the unit for the timestamps</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>70</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Running Wheel Signal Voltage Comments</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[\"running_wheel_signal_voltage\"].unit</td>\n",
       "      <td>Name of the unit for the data</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>71</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Running Wheel Signal Voltage Data</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"running_wheel_signal_voltage\"].data</td>\n",
       "      <td>Unused</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>72</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Running Wheel Signal Voltage Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"running_wheel_signal_voltage\"].timestamps</td>\n",
       "      <td>Unused</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>73</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Running Wheel Supply Voltage Conversion</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[\"running_wheel_supply_voltage\"].comments</td>\n",
       "      <td>Comments</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>74</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Running Wheel Supply Voltage Description</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[\"running_wheel_supply_voltage\"].conversion</td>\n",
       "      <td>Scalar to multiply each element in data to convert it to the specified unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>75</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Running Wheel Supply Voltage Interval</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[\"running_wheel_supply_voltage\"].description</td>\n",
       "      <td>Description</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>76</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Running Wheel Supply Voltage Offset</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[\"running_wheel_supply_voltage\"].interval</td>\n",
       "      <td>Unexplained</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>77</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Running Wheel Supply Voltage Resolution</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[\"running_wheel_supply_voltage\"].offset</td>\n",
       "      <td>Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>78</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Running Wheel Supply Voltage Timestamps Units</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[\"running_wheel_supply_voltage\"].resolution</td>\n",
       "      <td>The smallest meaningful difference (in specified unit) between values in data</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>79</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Running Wheel Supply Voltage Unit</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[\"running_wheel_supply_voltage\"].timestamps_unit</td>\n",
       "      <td>Nameof the unit for the timestamps</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>80</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Running Wheel Supply Voltage Comments</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[\"running_wheel_supply_voltage\"].unit</td>\n",
       "      <td>Name of the unit for the data</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>81</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Running Wheel Supply Voltage Data</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"running_wheel_supply_voltage\"].data</td>\n",
       "      <td>Unused</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>82</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Running Wheel Supply Voltage Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"running_wheel_supply_voltage\"].timestamps</td>\n",
       "      <td>Unused</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>83</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>LFP Comments</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[\"probe_0_lfp\"].electrical_series.comments</td>\n",
       "      <td>Comments</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>84</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>LFP Conversion</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[\"probe_0_lfp\"].electrical_series.conversion</td>\n",
       "      <td>Scalar to multiply each element in data to convert it to the specified unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>85</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>LFP Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[\"probe_0_lfp\"].electrical_series.description</td>\n",
       "      <td>Description</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>86</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>LFP Interval</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[\"probe_0_lfp\"].electrical_series.interval</td>\n",
       "      <td>Unexplained</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>87</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>LFP Offset</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[\"probe_0_lfp\"].electrical_series.offset</td>\n",
       "      <td>Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>88</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>LFP Resolution</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[\"probe_0_lfp\"].electrical_series.resolution</td>\n",
       "      <td>The smallest meaningful difference (in specified unit) between values in data</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>89</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>LFP Timestamps Unit</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[\"probe_0_lfp\"].electrical_series.timestamps_unit</td>\n",
       "      <td>Nameof the unit for the timestamps</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>90</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>LFP Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[\"probe_0_lfp\"].electrical_series.unit</td>\n",
       "      <td>Name of the unit for the data</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>91</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Probe LFP Data</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"lfp\"].electrical_series[probe_name].data</td>\n",
       "      <td>n * t array of measured LFP values where n is the number of channels and t is the number of timestamps</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>92</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Probe LFP Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[\"lfp\"].electrical_series[probe_name].timestamps</td>\n",
       "      <td>array of timestamps for LFP data</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>93</th>\n",
       "      <td>devices</td>\n",
       "      <td>Probe Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.devices[probe_name].description</td>\n",
       "      <td>Description of this probe</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>94</th>\n",
       "      <td>devices</td>\n",
       "      <td>Probe Manufacturer</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.devices[probe_name].manufacturer</td>\n",
       "      <td>Manufacturer of this probe</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>95</th>\n",
       "      <td>devices</td>\n",
       "      <td>Probe ID</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.devices[probe_name].probe_id</td>\n",
       "      <td>Unique identifier of the probe</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>96</th>\n",
       "      <td>devices</td>\n",
       "      <td>Probe Sampling Rate</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.devices[probe_name].sampling_rate</td>\n",
       "      <td>Sampling rate of the recording session with this probe</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>97</th>\n",
       "      <td>electrodes</td>\n",
       "      <td>Electrode Column Names</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.electrodes.colnames</td>\n",
       "      <td>Column names of the electrodes table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>98</th>\n",
       "      <td>electrodes</td>\n",
       "      <td>Electrode IDs</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.electrodes.id</td>\n",
       "      <td>IDs column of the electrodes table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>99</th>\n",
       "      <td>electrodes</td>\n",
       "      <td>Electrode X Coordinates</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.electrodes.x</td>\n",
       "      <td>CCF X coordinates column of the electrodes table. Represents the X location of electrodes along a probe.</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>100</th>\n",
       "      <td>electrodes</td>\n",
       "      <td>Electrode Y Coordinates</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.electrodes.y</td>\n",
       "      <td>CCF Y coordinates column of the electrodes table. Represents the Y location of electrodes along a probe.</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>101</th>\n",
       "      <td>electrodes</td>\n",
       "      <td>Electrode Z Coordinates</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.electrodes.z</td>\n",
       "      <td>CCF Z coordinates column of the electrodes table. Represents the Z location of electrodes along a probe.</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>102</th>\n",
       "      <td>electrodes</td>\n",
       "      <td>Impedance</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.electrodes.imp</td>\n",
       "      <td>Impedance column of the electrodes table. Unused in our data.</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>103</th>\n",
       "      <td>electrodes</td>\n",
       "      <td>Electrode Locations</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.electrodes.location</td>\n",
       "      <td>Brain region acronyms column of the electrodes table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>104</th>\n",
       "      <td>electrodes</td>\n",
       "      <td>Electrode Filters</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.electrodes.filtering</td>\n",
       "      <td>Column of the electrodes table describing the list of filters applied to each electrode.</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>105</th>\n",
       "      <td>electrodes</td>\n",
       "      <td>Electrode Groups</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.electrodes.group</td>\n",
       "      <td>References to group object column of the electrodes table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>106</th>\n",
       "      <td>electrodes</td>\n",
       "      <td>Electrode Group Names</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.electrodes.group_name</td>\n",
       "      <td>Group names (probe names) column of the electrodes table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>107</th>\n",
       "      <td>electrodes</td>\n",
       "      <td>Electrode Probe Horizontal Position</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.electrodes.probe_vertical_position</td>\n",
       "      <td>Probe vertical positions column of the electrodes table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>108</th>\n",
       "      <td>electrodes</td>\n",
       "      <td>Electrode Probe Vertical Position</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.electrodes.probe_horizontal_position</td>\n",
       "      <td>Probe horizontal positions column of the electrodes table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>109</th>\n",
       "      <td>electrodes</td>\n",
       "      <td>Electrode Probe IDs</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.electrodes.probe_id</td>\n",
       "      <td>Probe IDs column of the electrodes table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>110</th>\n",
       "      <td>electrodes</td>\n",
       "      <td>Electrode Local Indices</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.electrodes.local_index</td>\n",
       "      <td>Column of the electrodes table that contains local indices of electrodes within their own probe</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>111</th>\n",
       "      <td>electrodes</td>\n",
       "      <td>Electrode Valid Data Flags</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.electrodes.valid_data</td>\n",
       "      <td>Valid data flags column of the electrodes table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>112</th>\n",
       "      <td>electrodes</td>\n",
       "      <td>Electrode Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.electrodes.description</td>\n",
       "      <td>Description of the electrodes table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>113</th>\n",
       "      <td>electrode_groups</td>\n",
       "      <td>Electrode Group Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.electrode_groups[probeX].description</td>\n",
       "      <td>Description of this electrode group</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>114</th>\n",
       "      <td>electrode_groups</td>\n",
       "      <td>Electrode Group Device</td>\n",
       "      <td>Device</td>\n",
       "      <td>nwb.electrode_groups[probeX].device</td>\n",
       "      <td>Reference to the device information for this electrode group</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>115</th>\n",
       "      <td>electrode_groups</td>\n",
       "      <td>Electrode Group Has LFP Flag</td>\n",
       "      <td>boolean</td>\n",
       "      <td>nwb.electrode_groups[probeX].has_lfp</td>\n",
       "      <td>Flag indicating if this electrode group has LFP data</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>116</th>\n",
       "      <td>electrode_groups</td>\n",
       "      <td>Electrode Group Sampling Rate</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.electrode_groups[probeX].lfp_sampling_rate</td>\n",
       "      <td>Sampling rate of this group's LFP data</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>117</th>\n",
       "      <td>electrode_groups</td>\n",
       "      <td>Electrode Group Location</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.electrode_groups[probeX].location</td>\n",
       "      <td>Brain location acronym of this electrode group</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>118</th>\n",
       "      <td>electrode_groups</td>\n",
       "      <td>Electrode Group Probe ID</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.electrode_groups[probeX].probe_id</td>\n",
       "      <td>Probe Identifier of this electrode group</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>119</th>\n",
       "      <td>file_create_date</td>\n",
       "      <td>File Creation Date</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.file_create_date</td>\n",
       "      <td>Datetime time this file was created</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>120</th>\n",
       "      <td>intervals</td>\n",
       "      <td>Stimulus Interval IDs</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.intervals[stimulus].id</td>\n",
       "      <td>IDs column of the stimulus table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>121</th>\n",
       "      <td>intervals</td>\n",
       "      <td>Stimulus Interval Start Times</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.intervals[stimulus].start_time</td>\n",
       "      <td>Column of start times of each interval in the stimulus table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>122</th>\n",
       "      <td>intervals</td>\n",
       "      <td>Stimulus Interval Stop Times</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.intervals[stimulus].stop_time</td>\n",
       "      <td>Column of stop times of each interval in the stimulus table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>123</th>\n",
       "      <td>intervals</td>\n",
       "      <td>Stimulus Interval Stimulus Names</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.intervals[stimulus].stimulus_name</td>\n",
       "      <td>Column of names of stimulus types for each interval of the stimulus table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>124</th>\n",
       "      <td>intervals</td>\n",
       "      <td>Stimulus Interval Stimulus Blocks</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.intervals[stimulus].stimulus_block</td>\n",
       "      <td>Numbers representing stimulus blocks column of the stimulus table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>125</th>\n",
       "      <td>intervals</td>\n",
       "      <td>Stimulus Interval Stimulus Frames</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.intervals[stimulus].frame</td>\n",
       "      <td>Column of the stimulus table consisting of frame numbers of the stimulus</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>126</th>\n",
       "      <td>intervals</td>\n",
       "      <td>Stimulus Interval Stimulus Indices</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.intervals[stimulus].stimulus_index</td>\n",
       "      <td>Column of the stimulus table which contains the stimulus index for each interval</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>127</th>\n",
       "      <td>intervals</td>\n",
       "      <td>Stimulus Interval Tags</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.intervals[stimulus].tags</td>\n",
       "      <td>Column of the stimulus table which contains a list of tags for each interval</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>128</th>\n",
       "      <td>intervals</td>\n",
       "      <td>Stimulus Interval Timeseries Link</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.intervals[stimulus].timeseries</td>\n",
       "      <td>Column of the stimulus table containing tuples of the form (i, c, r) where r is a reference to the complete timestamps array for the session, and i is the index within that array</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>129</th>\n",
       "      <td>intervals</td>\n",
       "      <td>Stimulus Intervals Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.intervals[stimulus].description</td>\n",
       "      <td>Description of the stimulus table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>130</th>\n",
       "      <td>invalid_times</td>\n",
       "      <td>Invalid Times IDs</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.invalid_times.id</td>\n",
       "      <td>IDs column of the invalid times table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>131</th>\n",
       "      <td>invalid_times</td>\n",
       "      <td>Invalid Times Start Times</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.invalid_times.start_time</td>\n",
       "      <td>Start times column of the invalid times table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>132</th>\n",
       "      <td>invalid_times</td>\n",
       "      <td>Invalid Times Stop Times</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.invalid_times.stop_time</td>\n",
       "      <td>Stop times column of the invalid times table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>133</th>\n",
       "      <td>invalid_times</td>\n",
       "      <td>Invalid Times Tags</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.invalid_times.tags</td>\n",
       "      <td>Tags column of the invalid times table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>134</th>\n",
       "      <td>invalid_times</td>\n",
       "      <td>Invalid Times Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.invalid_times.description</td>\n",
       "      <td>Description of the invalid times table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>135</th>\n",
       "      <td>processing</td>\n",
       "      <td>Optogenetic Stimulus Column Names</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[\"optotagging\"][\"optogenetic_stimulation\"].colname</td>\n",
       "      <td>Column names of the optogenetic stimulation table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>136</th>\n",
       "      <td>processing</td>\n",
       "      <td>Optogenetic Stimulus IDs</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[\"optotagging\"][\"optogenetic_stimulation\"].id</td>\n",
       "      <td>IDs column of the optogenetic stimulation table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>137</th>\n",
       "      <td>processing</td>\n",
       "      <td>Optogenetic Stimulus Start Times</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[\"optotagging\"][\"optogenetic_stimulation\"].start_time</td>\n",
       "      <td>Column of the stop times of the laser for each interval in the optogenetic stimulation table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>138</th>\n",
       "      <td>processing</td>\n",
       "      <td>Optogenetic Stimulus Stop Times</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[\"optotagging\"][\"optogenetic_stimulation\"].stop_time</td>\n",
       "      <td>Column of the start times of the laser for each interval in the optogenetic stimulation table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>139</th>\n",
       "      <td>processing</td>\n",
       "      <td>Optogenetic Stimulus Conditions</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[\"optotagging\"][\"optogenetic_stimulation\"].condition</td>\n",
       "      <td>Laser condition column of the optogenetic stimulation table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>140</th>\n",
       "      <td>processing</td>\n",
       "      <td>Optogenetic Stimulus Levels</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[\"optotagging\"][\"optogenetic_stimulation\"].level</td>\n",
       "      <td>Laser voltage level column of the optogenetic stimulation table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>141</th>\n",
       "      <td>processing</td>\n",
       "      <td>Optogenetic Stimulus Names</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[\"optotagging\"][\"optogenetic_stimulation\"].stimulus_name</td>\n",
       "      <td>Stimulus name column of the optogenetic stimulation table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>142</th>\n",
       "      <td>processing</td>\n",
       "      <td>Optogenetic Stimulus Duration</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[\"optotagging\"][\"optogenetic_stimulation\"].duration</td>\n",
       "      <td>Laser duration column of the optogenetic stimulation table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>143</th>\n",
       "      <td>processing</td>\n",
       "      <td>Optogenetic Stimulus Tags</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[\"optotagging\"][\"optogenetic_stimulation\"].tags</td>\n",
       "      <td>Tags column of the optogenetic stimulation table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>144</th>\n",
       "      <td>processing</td>\n",
       "      <td>Optogenetic Stimulus Timeseries Links</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[\"optotagging\"][\"optogenetic_stimulation\"].timeseries</td>\n",
       "      <td>Timeseries reference column of the optogenetic stimulation table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>145</th>\n",
       "      <td>processing</td>\n",
       "      <td>Optotagging Data</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[\"optotagging\"][\"optotagging\"].data</td>\n",
       "      <td>Period of the optotagging light oscilation (s)</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>146</th>\n",
       "      <td>processing</td>\n",
       "      <td>Optotagging Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[\"optotagging\"][\"optotagging\"].timestamps</td>\n",
       "      <td>Array of timestamps for the optotagging pulses</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>147</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed Comments</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_speed\"].comments</td>\n",
       "      <td>Comments</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>148</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed Conversion</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_speed\"].conversion</td>\n",
       "      <td>Scalar to multiply each element in data to convert it to the specified unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>149</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_speed\"].description</td>\n",
       "      <td>Description</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>150</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed Interval</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_speed\"].interval</td>\n",
       "      <td>Unexplained</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>151</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed Offset</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_speed\"].offset</td>\n",
       "      <td>Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>152</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed Resolution</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_speed\"].resolution</td>\n",
       "      <td>The smallest meaningful difference (in specified unit) between values in data</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>153</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed Timestamps Units</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_speed\"].timestamps_unit</td>\n",
       "      <td>Nameof the unit for the timestamps</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>154</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_speed\"].unit</td>\n",
       "      <td>Name of the unit for the data</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>155</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed Data</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_speed\"].data</td>\n",
       "      <td>Speed of the running wheel, measured at each timestamps. The data is filtered with a low-pass filter to remove noise artifacts (cm/s).</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>156</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_speed\"].timestamps</td>\n",
       "      <td>Array of timestamps for the running_speed array</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>157</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed End Times Comments</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_speed_end_times\"].comments</td>\n",
       "      <td>Comments</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>158</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed End Times Conversion</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_speed_end_times\"].conversion</td>\n",
       "      <td>Scalar to multiply each element in data to convert it to the specified unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>159</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed End Times Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_speed_end_times\"].description</td>\n",
       "      <td>Description</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>160</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed End Times Interval</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_speed_end_times\"].interval</td>\n",
       "      <td>Unexplained</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>161</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed End Times Offset</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_speed_end_times\"].offset</td>\n",
       "      <td>Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>162</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed End Times Resolution</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_speed_end_times\"].resolution</td>\n",
       "      <td>The smallest meaningful difference (in specified unit) between values in data</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>163</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed End Times Timestamps Units</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_speed_end_times\"].timestamps_unit</td>\n",
       "      <td>Nameof the unit for the timestamps</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>164</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed End Times Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_speed_end_times\"].unit</td>\n",
       "      <td>Name of the unit for the data</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>165</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed End Times Data</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_speed_end_times\"].data</td>\n",
       "      <td>The times that each measurement period for the running speed end. Should be the same as Running Speed Timestamps but with indices offset by 1.</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>166</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed End Times Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_speed_end_times\"].timestamps</td>\n",
       "      <td>Same as Running Speed End times Data</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>167</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Wheel Rotation Comments</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_wheel_rotation\"].comments</td>\n",
       "      <td>Comments</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>168</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Wheel Rotation Conversion</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_wheel_rotation\"].conversion</td>\n",
       "      <td>Scalar to multiply each element in data to convert it to the specified unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>169</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Wheel Rotation Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_wheel_rotation\"].description</td>\n",
       "      <td>Description</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>170</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Wheel Rotation Interval</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_wheel_rotation\"].interval</td>\n",
       "      <td>Unexplained</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>171</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Wheel Rotation Offset</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_wheel_rotation\"].offset</td>\n",
       "      <td>Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>172</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Wheel Rotation Resolution</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_wheel_rotation\"].resolution</td>\n",
       "      <td>The smallest meaningful difference (in specified unit) between values in data</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>173</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Wheel Rotation Timestamps Units</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_wheel_rotation\"].timestamps_unit</td>\n",
       "      <td>Nameof the unit for the timestamps</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>174</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Wheel Rotation Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_wheel_rotation\"].unit</td>\n",
       "      <td>Name of the unit for the data</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>175</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Wheel Rotation Data</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_wheel_rotation\"].data</td>\n",
       "      <td>Position of the running wheel, measured at each timestamps.</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>176</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Wheel Rotation Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[\"running\"][\"running_wheel_rotation\"].timestamps</td>\n",
       "      <td>Array of timestamps for the running_wheel_rotation array</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>177</th>\n",
       "      <td>processing</td>\n",
       "      <td>Stimulus Timestamps Data</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[\"stimulus\"][\"timestamps\"].data</td>\n",
       "      <td>Array of all the the stimulus timestamps during the session. Identical to Stimulus Timestamps Timestamps</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>178</th>\n",
       "      <td>processing</td>\n",
       "      <td>Stimulus Timestamps Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[\"stimulus\"][\"timestamps\"].timestamps</td>\n",
       "      <td>Array of all the the stimulus timestamps during the session. Identical to Stimulus Timestamps Data</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>179</th>\n",
       "      <td>subject</td>\n",
       "      <td>Subject Age</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.subject.age</td>\n",
       "      <td>Age of the subject</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>180</th>\n",
       "      <td>subject</td>\n",
       "      <td>Subject Age in Days</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.subject.age_in_days</td>\n",
       "      <td>Age of the subject, in days</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>181</th>\n",
       "      <td>subject</td>\n",
       "      <td>Subject Genotype</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.subject.genotype</td>\n",
       "      <td>Genotype of the subject</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>182</th>\n",
       "      <td>subject</td>\n",
       "      <td>Subject Sex</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.subject.sex</td>\n",
       "      <td>Sex of the subject, M or F</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>183</th>\n",
       "      <td>subject</td>\n",
       "      <td>Subject Species</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.subject.species</td>\n",
       "      <td>Species of the subject</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>184</th>\n",
       "      <td>subject</td>\n",
       "      <td>Subject Specimen Name</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.subject.specimen_name</td>\n",
       "      <td>Specimen name of the subject</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>185</th>\n",
       "      <td>subject</td>\n",
       "      <td>Subject Strain</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.subject.strain</td>\n",
       "      <td>Strain of the subject</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>186</th>\n",
       "      <td>subject</td>\n",
       "      <td>Subject ID</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.subject.subject_id</td>\n",
       "      <td>Unique identifier of the subject</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>187</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit Table Column Names</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.colnames</td>\n",
       "      <td>Column names of the units table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>188</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit IDs</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.id</td>\n",
       "      <td>IDs column of the units table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>189</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit Spreads</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.spread</td>\n",
       "      <td>Column of the units table consisting of the spread value for each unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>190</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit PT Ratios</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.PT_ratio</td>\n",
       "      <td>Column of the units table consisting of the pt ratio for each unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>191</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit Waveform Durations</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.waveform_duration</td>\n",
       "      <td>Column of the units table with the durations, in seconds, of a unit's waveform</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>192</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit D-Primes</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.d_prime</td>\n",
       "      <td>Column of the units table containing the d_prime values for units.</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>193</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit Cumulative Drifts</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.cumulative_drift</td>\n",
       "      <td>Column of the units table containing the cumulative drift values for units</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>194</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit Silhouette Scores</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.silhouette_score</td>\n",
       "      <td>Column of the units table containing the silhouette score for units</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>195</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit Cluster IDs</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.cluster_id</td>\n",
       "      <td>Column of the units table containing the cluster_id for units</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>196</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit L Ratios</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.l_ratio</td>\n",
       "      <td>Column of the units table containing the l ratio for units</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>197</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit Qualities</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.quality</td>\n",
       "      <td>Column of the units table with the quality, 'good' or 'noise' of each unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>198</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit NN Miss Rates</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.nn_miss_rate</td>\n",
       "      <td>Column of the units table containing the nearest-neighbors miss rate for each unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>199</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit Local Indices</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.local_index</td>\n",
       "      <td>Column of the units table containing the local index of each unit, where the local index is the order it was detected by kilosort</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>200</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit Amplitude Recovery Slopes</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.amplitude_recovery_slope</td>\n",
       "      <td>Column of the units table containing the amplitude recovery slope for each unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>201</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit SNRs</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.snr</td>\n",
       "      <td>Column of the units table containing the signal-to-noise ratio for each unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>202</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit Velocities Above</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.velocity_above</td>\n",
       "      <td>Column of the units table containing the velocity above value for each unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>203</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit Amplitude Cutoffs</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.amplitude_cutoff</td>\n",
       "      <td>Column  of the units table containing the amplitude cutoff for each unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>204</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit Isolation Distance</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.isolation_distance</td>\n",
       "      <td>Column of the units table containing the isolation distance for each unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>205</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit Peak Channel IDs</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.peak_channel_id</td>\n",
       "      <td>Column of the units table consisting of the unique ID of the unit's peak channel that can be found in the electrodes table</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>206</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit Velocities Below</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.velocity_below</td>\n",
       "      <td>Column of the units table containing the velocity below value for each unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>207</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit NN Hit Rates</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.nn_hit_rate</td>\n",
       "      <td>Column of the units table containing the nearest-neighbors hit rate for each unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>208</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit Firing Rates</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.firing_rate</td>\n",
       "      <td>Column of the units table containing the average firing rate for each unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>209</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit ISI Violations</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.isi_violations</td>\n",
       "      <td>Column of the units table containing the inter-spike-interval violations for each unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>210</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit Repolarization Slopes</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.repolarization_slope</td>\n",
       "      <td>Column of the units table containing the repolarization slope for each unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>211</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit Presence Ratios</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.presence_ratio</td>\n",
       "      <td>Column of the units table containing the presence ratio for each unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>212</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit Waveform Halfwidths</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.waveform_halfwidth</td>\n",
       "      <td>Column of the units table containing the average waveform halfwidth for each unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>213</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit Max Drifts</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.max_drift</td>\n",
       "      <td>Column of the units table containing the maximum drift for each unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>214</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit Spike Times</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.spike_times</td>\n",
       "      <td>Column of the units table consisting of the arrays of spike times for each unit. Should be same length as spikje amplitudes array</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>215</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit Spike Amplitudes</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.spike_amplitudes</td>\n",
       "      <td>Column of the units table consisting of arrays of spike amplitudes for each unit. Should be same length as spike times array</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>216</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit Waveform Means</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.waveform_mean</td>\n",
       "      <td>Column of mean waveforms for each unit. Each unit mean_waveform should be a 2D array with dimensions n*t where n is the number of channels and t is the time</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>217</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit Waveform Halfwidths</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.waveform_halfwidth</td>\n",
       "      <td>Column of the units table containing the average waveform halfwidth for each unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>218</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit Max Drifts</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.max_drift</td>\n",
       "      <td>Column of the units table containing the maximum drift for each unit</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>219</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit Spike Times</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.spike_times</td>\n",
       "      <td>Column of the units table consisting of the arrays of spike times for each unit. Should be same length as spikje amplitudes array</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>220</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit Spike Amplitudes</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.spike_amplitudes</td>\n",
       "      <td>Column of the units table consisting of arrays of spike amplitudes for each unit. Should be same length as spike times array</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>221</th>\n",
       "      <td>units</td>\n",
       "      <td>Unit Waveform Means</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.units.waveform_mean</td>\n",
       "      <td>Column of mean waveforms for each unit. Each unit mean_waveform should be a 2D array with dimensions n*t where n is the number of channels and t is the time</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "</div>"
      ],
      "text/plain": [
       "              Section                                          Field  \\\n",
       "0    NaN               Session Description                             \n",
       "1    NaN               Session Identifier                              \n",
       "2    NaN               Session Start Time                              \n",
       "3    NaN               Reference Time                                  \n",
       "4    NaN               Experiment Description                          \n",
       "5    NaN               Institution                                     \n",
       "6    acquisition       Corneal Reflection Tracking Comments            \n",
       "7    acquisition       Corneal Reflection Tracking Conversion          \n",
       "8    acquisition       Corneal Reflection Tracking Description         \n",
       "9    acquisition       Corneal Reflection Tracking Interval            \n",
       "10   acquisition       Corneal Reflection Tracking Offset              \n",
       "11   acquisition       Corneal Reflection Tracking Reference Frame     \n",
       "12   acquisition       Corneal Reflection Tracking Resolution          \n",
       "13   acquisition       Corneal Reflection Tracking Unit                \n",
       "14   acquisition       Corneal Reflection Tracking Angle               \n",
       "15   acquisition       Corneal Reflection Tracking Height              \n",
       "16   acquisition       Corneal Reflection Tracking Width               \n",
       "17   acquisition       Corneal Reflection Tracking Area                \n",
       "18   acquisition       Corneal Reflection Tracking Raw Area            \n",
       "19   acquisition       Corneal Reflection Tracking Data                \n",
       "20   acquisition       Corneal Reflection Tracking Timestamps          \n",
       "21   acquisition       Eye Tracking Tracking Comments                  \n",
       "22   acquisition       Eye Tracking Conversion                         \n",
       "23   acquisition       Eye Tracking Description                        \n",
       "24   acquisition       Eye Tracking Interval                           \n",
       "25   acquisition       Eye Tracking Offset                             \n",
       "26   acquisition       Eye Tracking Reference Frame                    \n",
       "27   acquisition       Eye Tracking Resolution                         \n",
       "28   acquisition       Eye Tracking Unit                               \n",
       "29   acquisition       Eye Tracking Angle                              \n",
       "30   acquisition       Eye Tracking Height                             \n",
       "31   acquisition       Eye Tracking Width                              \n",
       "32   acquisition       Eye Tracking Area                               \n",
       "33   acquisition       Eye Tracking Raw Area                           \n",
       "34   acquisition       Eye Tracking Data                               \n",
       "35   acquisition       Eye Tracking Timestamps                         \n",
       "36   acquisition       Eye Tracking Tracking Comments                  \n",
       "37   acquisition       Eye Tracking Conversion                         \n",
       "38   acquisition       Eye Tracking Description                        \n",
       "39   acquisition       Eye Tracking Interval                           \n",
       "40   acquisition       Eye Tracking Offset                             \n",
       "41   acquisition       Eye Tracking Reference Frame                    \n",
       "42   acquisition       Eye Tracking Resolution                         \n",
       "43   acquisition       Eye Tracking Unit                               \n",
       "44   acquisition       Pupil Tracking Angle                            \n",
       "45   acquisition       Pupil Tracking Height                           \n",
       "46   acquisition       Pupil Tracking Width                            \n",
       "47   acquisition       Pupil Tracking Area                             \n",
       "48   acquisition       Pupil Tracking Raw Area                         \n",
       "49   acquisition       Pupil Tracking Data                             \n",
       "50   acquisition       Pupil Tracking Timestamps                       \n",
       "51   acquisition       Blink Times                                     \n",
       "52   acquisition       Blink Times Timestamps                          \n",
       "53   acquisition       Running Wheel Rotation Comments                 \n",
       "54   acquisition       Running Wheel Rotation Conversion               \n",
       "55   acquisition       Running Wheel Rotation Description              \n",
       "56   acquisition       Running Wheel Rotation Interval                 \n",
       "57   acquisition       Running Wheel Rotation Offset                   \n",
       "58   acquisition       Running Wheel Rotation Resolution               \n",
       "59   acquisition       Running Wheel Rotation Timestamps Units         \n",
       "60   acquisition       Running Wheel Rotation Unit                     \n",
       "61   acquisition       Raw Running Wheel Rotation Data                 \n",
       "62   acquisition       Raw Running Wheel Rotation Timestamps           \n",
       "63   acquisition       Running Wheel Signal Voltage Conversion         \n",
       "64   acquisition       Running Wheel Signal Voltage Description        \n",
       "65   acquisition       Running Wheel Signal Voltage Interval           \n",
       "66   acquisition       Running Wheel Signal Voltage Offset             \n",
       "67   acquisition       Running Wheel Signal Voltage Resolution         \n",
       "68   acquisition       Running Wheel Signal Voltage Timestamps Units   \n",
       "69   acquisition       Running Wheel Signal Voltage Unit               \n",
       "70   acquisition       Running Wheel Signal Voltage Comments           \n",
       "71   acquisition       Running Wheel Signal Voltage Data               \n",
       "72   acquisition       Running Wheel Signal Voltage Timestamps         \n",
       "73   acquisition       Running Wheel Supply Voltage Conversion         \n",
       "74   acquisition       Running Wheel Supply Voltage Description        \n",
       "75   acquisition       Running Wheel Supply Voltage Interval           \n",
       "76   acquisition       Running Wheel Supply Voltage Offset             \n",
       "77   acquisition       Running Wheel Supply Voltage Resolution         \n",
       "78   acquisition       Running Wheel Supply Voltage Timestamps Units   \n",
       "79   acquisition       Running Wheel Supply Voltage Unit               \n",
       "80   acquisition       Running Wheel Supply Voltage Comments           \n",
       "81   acquisition       Running Wheel Supply Voltage Data               \n",
       "82   acquisition       Running Wheel Supply Voltage Timestamps         \n",
       "83   acquisition       LFP Comments                                    \n",
       "84   acquisition       LFP Conversion                                  \n",
       "85   acquisition       LFP Description                                 \n",
       "86   acquisition       LFP Interval                                    \n",
       "87   acquisition       LFP Offset                                      \n",
       "88   acquisition       LFP Resolution                                  \n",
       "89   acquisition       LFP Timestamps Unit                             \n",
       "90   acquisition       LFP Unit                                        \n",
       "91   acquisition       Probe LFP Data                                  \n",
       "92   acquisition       Probe LFP Timestamps                            \n",
       "93   devices           Probe Description                               \n",
       "94   devices           Probe Manufacturer                              \n",
       "95   devices           Probe ID                                        \n",
       "96   devices           Probe Sampling Rate                             \n",
       "97   electrodes        Electrode Column Names                          \n",
       "98   electrodes        Electrode IDs                                   \n",
       "99   electrodes        Electrode X Coordinates                         \n",
       "100  electrodes        Electrode Y Coordinates                         \n",
       "101  electrodes        Electrode Z Coordinates                         \n",
       "102  electrodes        Impedance                                       \n",
       "103  electrodes        Electrode Locations                             \n",
       "104  electrodes        Electrode Filters                               \n",
       "105  electrodes        Electrode Groups                                \n",
       "106  electrodes        Electrode Group Names                           \n",
       "107  electrodes        Electrode Probe Horizontal Position             \n",
       "108  electrodes        Electrode Probe Vertical Position               \n",
       "109  electrodes        Electrode Probe IDs                             \n",
       "110  electrodes        Electrode Local Indices                         \n",
       "111  electrodes        Electrode Valid Data Flags                      \n",
       "112  electrodes        Electrode Description                           \n",
       "113  electrode_groups  Electrode Group Description                     \n",
       "114  electrode_groups  Electrode Group Device                          \n",
       "115  electrode_groups  Electrode Group Has LFP Flag                    \n",
       "116  electrode_groups  Electrode Group Sampling Rate                   \n",
       "117  electrode_groups  Electrode Group Location                        \n",
       "118  electrode_groups  Electrode Group Probe ID                        \n",
       "119  file_create_date  File Creation Date                              \n",
       "120  intervals         Stimulus Interval IDs                           \n",
       "121  intervals         Stimulus Interval Start Times                   \n",
       "122  intervals         Stimulus Interval Stop Times                    \n",
       "123  intervals         Stimulus Interval Stimulus Names                \n",
       "124  intervals         Stimulus Interval Stimulus Blocks               \n",
       "125  intervals         Stimulus Interval Stimulus Frames               \n",
       "126  intervals         Stimulus Interval Stimulus Indices              \n",
       "127  intervals         Stimulus Interval Tags                          \n",
       "128  intervals         Stimulus Interval Timeseries Link               \n",
       "129  intervals         Stimulus Intervals Description                  \n",
       "130  invalid_times     Invalid Times IDs                               \n",
       "131  invalid_times     Invalid Times Start Times                       \n",
       "132  invalid_times     Invalid Times Stop Times                        \n",
       "133  invalid_times     Invalid Times Tags                              \n",
       "134  invalid_times     Invalid Times Description                       \n",
       "135  processing        Optogenetic Stimulus Column Names               \n",
       "136  processing        Optogenetic Stimulus IDs                        \n",
       "137  processing        Optogenetic Stimulus Start Times                \n",
       "138  processing        Optogenetic Stimulus Stop Times                 \n",
       "139  processing        Optogenetic Stimulus Conditions                 \n",
       "140  processing        Optogenetic Stimulus Levels                     \n",
       "141  processing        Optogenetic Stimulus Names                      \n",
       "142  processing        Optogenetic Stimulus Duration                   \n",
       "143  processing        Optogenetic Stimulus Tags                       \n",
       "144  processing        Optogenetic Stimulus Timeseries Links           \n",
       "145  processing        Optotagging Data                                \n",
       "146  processing        Optotagging Timestamps                          \n",
       "147  processing        Running Speed Comments                          \n",
       "148  processing        Running Speed Conversion                        \n",
       "149  processing        Running Speed Description                       \n",
       "150  processing        Running Speed Interval                          \n",
       "151  processing        Running Speed Offset                            \n",
       "152  processing        Running Speed Resolution                        \n",
       "153  processing        Running Speed Timestamps Units                  \n",
       "154  processing        Running Speed Unit                              \n",
       "155  processing        Running Speed Data                              \n",
       "156  processing        Running Speed Timestamps                        \n",
       "157  processing        Running Speed End Times Comments                \n",
       "158  processing        Running Speed End Times Conversion              \n",
       "159  processing        Running Speed End Times Description             \n",
       "160  processing        Running Speed End Times Interval                \n",
       "161  processing        Running Speed End Times Offset                  \n",
       "162  processing        Running Speed End Times Resolution              \n",
       "163  processing        Running Speed End Times Timestamps Units        \n",
       "164  processing        Running Speed End Times Unit                    \n",
       "165  processing        Running Speed End Times Data                    \n",
       "166  processing        Running Speed End Times Timestamps              \n",
       "167  processing        Running Wheel Rotation Comments                 \n",
       "168  processing        Running Wheel Rotation Conversion               \n",
       "169  processing        Running Wheel Rotation Description              \n",
       "170  processing        Running Wheel Rotation Interval                 \n",
       "171  processing        Running Wheel Rotation Offset                   \n",
       "172  processing        Running Wheel Rotation Resolution               \n",
       "173  processing        Running Wheel Rotation Timestamps Units         \n",
       "174  processing        Running Wheel Rotation Unit                     \n",
       "175  processing        Running Wheel Rotation Data                     \n",
       "176  processing        Running Wheel Rotation Timestamps               \n",
       "177  processing        Stimulus Timestamps Data                        \n",
       "178  processing        Stimulus Timestamps Timestamps                  \n",
       "179  subject           Subject Age                                     \n",
       "180  subject           Subject Age in Days                             \n",
       "181  subject           Subject Genotype                                \n",
       "182  subject           Subject Sex                                     \n",
       "183  subject           Subject Species                                 \n",
       "184  subject           Subject Specimen Name                           \n",
       "185  subject           Subject Strain                                  \n",
       "186  subject           Subject ID                                      \n",
       "187  units             Unit Table Column Names                         \n",
       "188  units             Unit IDs                                        \n",
       "189  units             Unit Spreads                                    \n",
       "190  units             Unit PT Ratios                                  \n",
       "191  units             Unit Waveform Durations                         \n",
       "192  units             Unit D-Primes                                   \n",
       "193  units             Unit Cumulative Drifts                          \n",
       "194  units             Unit Silhouette Scores                          \n",
       "195  units             Unit Cluster IDs                                \n",
       "196  units             Unit L Ratios                                   \n",
       "197  units             Unit Qualities                                  \n",
       "198  units             Unit NN Miss Rates                              \n",
       "199  units             Unit Local Indices                              \n",
       "200  units             Unit Amplitude Recovery Slopes                  \n",
       "201  units             Unit SNRs                                       \n",
       "202  units             Unit Velocities Above                           \n",
       "203  units             Unit Amplitude Cutoffs                          \n",
       "204  units             Unit Isolation Distance                         \n",
       "205  units             Unit Peak Channel IDs                           \n",
       "206  units             Unit Velocities Below                           \n",
       "207  units             Unit NN Hit Rates                               \n",
       "208  units             Unit Firing Rates                               \n",
       "209  units             Unit ISI Violations                             \n",
       "210  units             Unit Repolarization Slopes                      \n",
       "211  units             Unit Presence Ratios                            \n",
       "212  units             Unit Waveform Halfwidths                        \n",
       "213  units             Unit Max Drifts                                 \n",
       "214  units             Unit Spike Times                                \n",
       "215  units             Unit Spike Amplitudes                           \n",
       "216  units             Unit Waveform Means                             \n",
       "217  units             Unit Waveform Halfwidths                        \n",
       "218  units             Unit Max Drifts                                 \n",
       "219  units             Unit Spike Times                                \n",
       "220  units             Unit Spike Amplitudes                           \n",
       "221  units             Unit Waveform Means                             \n",
       "\n",
       "         Type  \\\n",
       "0    string     \n",
       "1    string     \n",
       "2    datetime   \n",
       "3    datetime   \n",
       "4    string     \n",
       "5    string     \n",
       "6    string     \n",
       "7    number     \n",
       "8    string     \n",
       "9    number     \n",
       "10   number     \n",
       "11   string     \n",
       "12   number     \n",
       "13   string     \n",
       "14   array      \n",
       "15   array      \n",
       "16   array      \n",
       "17   array      \n",
       "18   array      \n",
       "19   array      \n",
       "20   array      \n",
       "21   string     \n",
       "22   number     \n",
       "23   string     \n",
       "24   number     \n",
       "25   number     \n",
       "26   string     \n",
       "27   number     \n",
       "28   string     \n",
       "29   array      \n",
       "30   array      \n",
       "31   array      \n",
       "32   array      \n",
       "33   array      \n",
       "34   array      \n",
       "35   array      \n",
       "36   string     \n",
       "37   number     \n",
       "38   string     \n",
       "39   number     \n",
       "40   number     \n",
       "41   string     \n",
       "42   number     \n",
       "43   string     \n",
       "44   array      \n",
       "45   array      \n",
       "46   array      \n",
       "47   array      \n",
       "48   array      \n",
       "49   array      \n",
       "50   array      \n",
       "51   array      \n",
       "52   array      \n",
       "53   string     \n",
       "54   number     \n",
       "55   string     \n",
       "56   number     \n",
       "57   number     \n",
       "58   string     \n",
       "59   number     \n",
       "60   string     \n",
       "61   array      \n",
       "62   array      \n",
       "63   string     \n",
       "64   number     \n",
       "65   string     \n",
       "66   number     \n",
       "67   number     \n",
       "68   string     \n",
       "69   number     \n",
       "70   string     \n",
       "71   array      \n",
       "72   array      \n",
       "73   string     \n",
       "74   number     \n",
       "75   string     \n",
       "76   number     \n",
       "77   number     \n",
       "78   string     \n",
       "79   number     \n",
       "80   string     \n",
       "81   array      \n",
       "82   array      \n",
       "83   string     \n",
       "84   number     \n",
       "85   string     \n",
       "86   number     \n",
       "87   number     \n",
       "88   string     \n",
       "89   number     \n",
       "90   string     \n",
       "91   array      \n",
       "92   array      \n",
       "93   string     \n",
       "94   string     \n",
       "95   number     \n",
       "96   number     \n",
       "97   array      \n",
       "98   array      \n",
       "99   array      \n",
       "100  array      \n",
       "101  array      \n",
       "102  array      \n",
       "103  array      \n",
       "104  array      \n",
       "105  array      \n",
       "106  array      \n",
       "107  array      \n",
       "108  array      \n",
       "109  array      \n",
       "110  array      \n",
       "111  array      \n",
       "112  string     \n",
       "113  string     \n",
       "114  Device     \n",
       "115  boolean    \n",
       "116  number     \n",
       "117  string     \n",
       "118  number     \n",
       "119  number     \n",
       "120  array      \n",
       "121  array      \n",
       "122  array      \n",
       "123  array      \n",
       "124  array      \n",
       "125  array      \n",
       "126  array      \n",
       "127  array      \n",
       "128  array      \n",
       "129  string     \n",
       "130  array      \n",
       "131  array      \n",
       "132  array      \n",
       "133  array      \n",
       "134  string     \n",
       "135  array      \n",
       "136  array      \n",
       "137  array      \n",
       "138  array      \n",
       "139  array      \n",
       "140  array      \n",
       "141  array      \n",
       "142  array      \n",
       "143  array      \n",
       "144  array      \n",
       "145  array      \n",
       "146  array      \n",
       "147  string     \n",
       "148  number     \n",
       "149  string     \n",
       "150  number     \n",
       "151  number     \n",
       "152  string     \n",
       "153  number     \n",
       "154  string     \n",
       "155  array      \n",
       "156  array      \n",
       "157  string     \n",
       "158  number     \n",
       "159  string     \n",
       "160  number     \n",
       "161  number     \n",
       "162  string     \n",
       "163  number     \n",
       "164  string     \n",
       "165  array      \n",
       "166  array      \n",
       "167  string     \n",
       "168  number     \n",
       "169  string     \n",
       "170  number     \n",
       "171  number     \n",
       "172  string     \n",
       "173  number     \n",
       "174  string     \n",
       "175  array      \n",
       "176  array      \n",
       "177  array      \n",
       "178  array      \n",
       "179  number     \n",
       "180  number     \n",
       "181  string     \n",
       "182  string     \n",
       "183  string     \n",
       "184  string     \n",
       "185  string     \n",
       "186  string     \n",
       "187  array      \n",
       "188  array      \n",
       "189  array      \n",
       "190  array      \n",
       "191  array      \n",
       "192  array      \n",
       "193  array      \n",
       "194  array      \n",
       "195  array      \n",
       "196  array      \n",
       "197  array      \n",
       "198  array      \n",
       "199  array      \n",
       "200  array      \n",
       "201  array      \n",
       "202  array      \n",
       "203  array      \n",
       "204  array      \n",
       "205  array      \n",
       "206  array      \n",
       "207  array      \n",
       "208  array      \n",
       "209  array      \n",
       "210  array      \n",
       "211  array      \n",
       "212  array      \n",
       "213  array      \n",
       "214  array      \n",
       "215  array      \n",
       "216  array      \n",
       "217  array      \n",
       "218  array      \n",
       "219  array      \n",
       "220  array      \n",
       "221  array      \n",
       "\n",
       "                                                                           Path  \\\n",
       "0    nwb.session_description                                                      \n",
       "1    nwb.identifier                                                               \n",
       "2    nwb.session_start_time                                                       \n",
       "3    nwb.timestamps_reference_time                                                \n",
       "4    nwb.experiment_description                                                   \n",
       "5    nwb.institution                                                              \n",
       "6    nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.comments          \n",
       "7    nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.conversion        \n",
       "8    nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.description       \n",
       "9    nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.interval          \n",
       "10   nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.offset            \n",
       "11   nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.reference_frame   \n",
       "12   nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.resolution        \n",
       "13   nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.unit              \n",
       "14   nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.angle             \n",
       "15   nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.height            \n",
       "16   nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.width             \n",
       "17   nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.area              \n",
       "18   nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.area_raw          \n",
       "19   nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.data              \n",
       "20   nwb.acquisition[\"EyeTracking\"].corneal_reflection_tracking.timestamps        \n",
       "21   nwb.acquisition[\"EyeTracking\"].eye_tracking.comments                         \n",
       "22   nwb.acquisition[\"EyeTracking\"].eye_tracking.conversion                       \n",
       "23   nwb.acquisition[\"EyeTracking\"].eye_tracking.description                      \n",
       "24   nwb.acquisition[\"EyeTracking\"].eye_tracking.interval                         \n",
       "25   nwb.acquisition[\"EyeTracking\"].eye_tracking.offset                           \n",
       "26   nwb.acquisition[\"EyeTracking\"].eye_tracking.reference_frame                  \n",
       "27   nwb.acquisition[\"EyeTracking\"].eye_tracking.resolution                       \n",
       "28   nwb.acquisition[\"EyeTracking\"].eye_tracking.unit                             \n",
       "29   nwb.acquisition[\"EyeTracking\"].eye_tracking.angle                            \n",
       "30   nwb.acquisition[\"EyeTracking\"].eye_tracking.height                           \n",
       "31   nwb.acquisition[\"EyeTracking\"].eye_tracking.width                            \n",
       "32   nwb.acquisition[\"EyeTracking\"].eye_tracking.area                             \n",
       "33   nwb.acquisition[\"EyeTracking\"].eye_tracking.area_raw                         \n",
       "34   nwb.acquisition[\"EyeTracking\"].eye_tracking.data                             \n",
       "35   nwb.acquisition[\"EyeTracking\"].eye_tracking.timestamps                       \n",
       "36   nwb.acquisition[\"EyeTracking\"].pupil_tracking.comments                       \n",
       "37   nwb.acquisition[\"EyeTracking\"].pupil_tracking.conversion                     \n",
       "38   nwb.acquisition[\"EyeTracking\"].pupil_tracking.description                    \n",
       "39   nwb.acquisition[\"EyeTracking\"].pupil_tracking.interval                       \n",
       "40   nwb.acquisition[\"EyeTracking\"].pupil_tracking.offset                         \n",
       "41   nwb.acquisition[\"EyeTracking\"].pupil_tracking.reference_frame                \n",
       "42   nwb.acquisition[\"EyeTracking\"].pupil_tracking.resolution                     \n",
       "43   nwb.acquisition[\"EyeTracking\"].pupil_tracking.unit                           \n",
       "44   nwb.acquisition[\"EyeTracking\"].pupil_tracking.angle                          \n",
       "45   nwb.acquisition[\"EyeTracking\"].pupil_tracking.height                         \n",
       "46   nwb.acquisition[\"EyeTracking\"].pupil_tracking.width                          \n",
       "47   nwb.acquisition[\"EyeTracking\"].pupil_tracking.area                           \n",
       "48   nwb.acquisition[\"EyeTracking\"].pupil_tracking.area_raw                       \n",
       "49   nwb.acquisition[\"EyeTracking\"].pupil_tracking.data                           \n",
       "50   nwb.acquisition[\"EyeTracking\"].pupil_tracking.timestamps                     \n",
       "51   nwb.acquisition[\"EyeTracking\"].likely_blink.data                             \n",
       "52   nwb.acquisition[\"EyeTracking\"].likely_blink.timestamps                       \n",
       "53   nwb.acquisition[\"raw_running_wheel_rotation\"].comments                       \n",
       "54   nwb.acquisition[\"raw_running_wheel_rotation\"].conversion                     \n",
       "55   nwb.acquisition[\"raw_running_wheel_rotation\"].description                    \n",
       "56   nwb.acquisition[\"raw_running_wheel_rotation\"].interval                       \n",
       "57   nwb.acquisition[\"raw_running_wheel_rotation\"].offset                         \n",
       "58   nwb.acquisition[\"raw_running_wheel_rotation\"].resolution                     \n",
       "59   nwb.acquisition[\"raw_running_wheel_rotation\"].timestamps_unit                \n",
       "60   nwb.acquisition[\"raw_running_wheel_rotation\"].unit                           \n",
       "61   nwb.acquisition[\"raw_running_wheel_rotation\"].data                           \n",
       "62   nwb.acquisition[\"raw_running_wheel_rotation\"].timestamps                     \n",
       "63   nwb.acquisition[\"running_wheel_signal_voltage\"].comments                     \n",
       "64   nwb.acquisition[\"running_wheel_signal_voltage\"].conversion                   \n",
       "65   nwb.acquisition[\"running_wheel_signal_voltage\"].description                  \n",
       "66   nwb.acquisition[\"running_wheel_signal_voltage\"].interval                     \n",
       "67   nwb.acquisition[\"running_wheel_signal_voltage\"].offset                       \n",
       "68   nwb.acquisition[\"running_wheel_signal_voltage\"].resolution                   \n",
       "69   nwb.acquisition[\"running_wheel_signal_voltage\"].timestamps_unit              \n",
       "70   nwb.acquisition[\"running_wheel_signal_voltage\"].unit                         \n",
       "71   nwb.acquisition[\"running_wheel_signal_voltage\"].data                         \n",
       "72   nwb.acquisition[\"running_wheel_signal_voltage\"].timestamps                   \n",
       "73   nwb.acquisition[\"running_wheel_supply_voltage\"].comments                     \n",
       "74   nwb.acquisition[\"running_wheel_supply_voltage\"].conversion                   \n",
       "75   nwb.acquisition[\"running_wheel_supply_voltage\"].description                  \n",
       "76   nwb.acquisition[\"running_wheel_supply_voltage\"].interval                     \n",
       "77   nwb.acquisition[\"running_wheel_supply_voltage\"].offset                       \n",
       "78   nwb.acquisition[\"running_wheel_supply_voltage\"].resolution                   \n",
       "79   nwb.acquisition[\"running_wheel_supply_voltage\"].timestamps_unit              \n",
       "80   nwb.acquisition[\"running_wheel_supply_voltage\"].unit                         \n",
       "81   nwb.acquisition[\"running_wheel_supply_voltage\"].data                         \n",
       "82   nwb.acquisition[\"running_wheel_supply_voltage\"].timestamps                   \n",
       "83   nwb.acquisition[\"probe_0_lfp\"].electrical_series.comments                    \n",
       "84   nwb.acquisition[\"probe_0_lfp\"].electrical_series.conversion                  \n",
       "85   nwb.acquisition[\"probe_0_lfp\"].electrical_series.description                 \n",
       "86   nwb.acquisition[\"probe_0_lfp\"].electrical_series.interval                    \n",
       "87   nwb.acquisition[\"probe_0_lfp\"].electrical_series.offset                      \n",
       "88   nwb.acquisition[\"probe_0_lfp\"].electrical_series.resolution                  \n",
       "89   nwb.acquisition[\"probe_0_lfp\"].electrical_series.timestamps_unit             \n",
       "90   nwb.acquisition[\"probe_0_lfp\"].electrical_series.unit                        \n",
       "91   nwb.acquisition[\"lfp\"].electrical_series[probe_name].data                    \n",
       "92   nwb.acquisition[\"lfp\"].electrical_series[probe_name].timestamps              \n",
       "93   nwb.devices[probe_name].description                                          \n",
       "94   nwb.devices[probe_name].manufacturer                                         \n",
       "95   nwb.devices[probe_name].probe_id                                             \n",
       "96   nwb.devices[probe_name].sampling_rate                                        \n",
       "97   nwb.electrodes.colnames                                                      \n",
       "98   nwb.electrodes.id                                                            \n",
       "99   nwb.electrodes.x                                                             \n",
       "100  nwb.electrodes.y                                                             \n",
       "101  nwb.electrodes.z                                                             \n",
       "102  nwb.electrodes.imp                                                           \n",
       "103  nwb.electrodes.location                                                      \n",
       "104  nwb.electrodes.filtering                                                     \n",
       "105  nwb.electrodes.group                                                         \n",
       "106  nwb.electrodes.group_name                                                    \n",
       "107  nwb.electrodes.probe_vertical_position                                       \n",
       "108  nwb.electrodes.probe_horizontal_position                                     \n",
       "109  nwb.electrodes.probe_id                                                      \n",
       "110  nwb.electrodes.local_index                                                   \n",
       "111  nwb.electrodes.valid_data                                                    \n",
       "112  nwb.electrodes.description                                                   \n",
       "113  nwb.electrode_groups[probeX].description                                     \n",
       "114  nwb.electrode_groups[probeX].device                                          \n",
       "115  nwb.electrode_groups[probeX].has_lfp                                         \n",
       "116  nwb.electrode_groups[probeX].lfp_sampling_rate                               \n",
       "117  nwb.electrode_groups[probeX].location                                        \n",
       "118  nwb.electrode_groups[probeX].probe_id                                        \n",
       "119  nwb.file_create_date                                                         \n",
       "120  nwb.intervals[stimulus].id                                                   \n",
       "121  nwb.intervals[stimulus].start_time                                           \n",
       "122  nwb.intervals[stimulus].stop_time                                            \n",
       "123  nwb.intervals[stimulus].stimulus_name                                        \n",
       "124  nwb.intervals[stimulus].stimulus_block                                       \n",
       "125  nwb.intervals[stimulus].frame                                                \n",
       "126  nwb.intervals[stimulus].stimulus_index                                       \n",
       "127  nwb.intervals[stimulus].tags                                                 \n",
       "128  nwb.intervals[stimulus].timeseries                                           \n",
       "129  nwb.intervals[stimulus].description                                          \n",
       "130  nwb.invalid_times.id                                                         \n",
       "131  nwb.invalid_times.start_time                                                 \n",
       "132  nwb.invalid_times.stop_time                                                  \n",
       "133  nwb.invalid_times.tags                                                       \n",
       "134  nwb.invalid_times.description                                                \n",
       "135  nwb.processing[\"optotagging\"][\"optogenetic_stimulation\"].colname             \n",
       "136  nwb.processing[\"optotagging\"][\"optogenetic_stimulation\"].id                  \n",
       "137  nwb.processing[\"optotagging\"][\"optogenetic_stimulation\"].start_time          \n",
       "138  nwb.processing[\"optotagging\"][\"optogenetic_stimulation\"].stop_time           \n",
       "139  nwb.processing[\"optotagging\"][\"optogenetic_stimulation\"].condition           \n",
       "140  nwb.processing[\"optotagging\"][\"optogenetic_stimulation\"].level               \n",
       "141  nwb.processing[\"optotagging\"][\"optogenetic_stimulation\"].stimulus_name       \n",
       "142  nwb.processing[\"optotagging\"][\"optogenetic_stimulation\"].duration            \n",
       "143  nwb.processing[\"optotagging\"][\"optogenetic_stimulation\"].tags                \n",
       "144  nwb.processing[\"optotagging\"][\"optogenetic_stimulation\"].timeseries          \n",
       "145  nwb.processing[\"optotagging\"][\"optotagging\"].data                            \n",
       "146  nwb.processing[\"optotagging\"][\"optotagging\"].timestamps                      \n",
       "147  nwb.processing[\"running\"][\"running_speed\"].comments                          \n",
       "148  nwb.processing[\"running\"][\"running_speed\"].conversion                        \n",
       "149  nwb.processing[\"running\"][\"running_speed\"].description                       \n",
       "150  nwb.processing[\"running\"][\"running_speed\"].interval                          \n",
       "151  nwb.processing[\"running\"][\"running_speed\"].offset                            \n",
       "152  nwb.processing[\"running\"][\"running_speed\"].resolution                        \n",
       "153  nwb.processing[\"running\"][\"running_speed\"].timestamps_unit                   \n",
       "154  nwb.processing[\"running\"][\"running_speed\"].unit                              \n",
       "155  nwb.processing[\"running\"][\"running_speed\"].data                              \n",
       "156  nwb.processing[\"running\"][\"running_speed\"].timestamps                        \n",
       "157  nwb.processing[\"running\"][\"running_speed_end_times\"].comments                \n",
       "158  nwb.processing[\"running\"][\"running_speed_end_times\"].conversion              \n",
       "159  nwb.processing[\"running\"][\"running_speed_end_times\"].description             \n",
       "160  nwb.processing[\"running\"][\"running_speed_end_times\"].interval                \n",
       "161  nwb.processing[\"running\"][\"running_speed_end_times\"].offset                  \n",
       "162  nwb.processing[\"running\"][\"running_speed_end_times\"].resolution              \n",
       "163  nwb.processing[\"running\"][\"running_speed_end_times\"].timestamps_unit         \n",
       "164  nwb.processing[\"running\"][\"running_speed_end_times\"].unit                    \n",
       "165  nwb.processing[\"running\"][\"running_speed_end_times\"].data                    \n",
       "166  nwb.processing[\"running\"][\"running_speed_end_times\"].timestamps              \n",
       "167  nwb.processing[\"running\"][\"running_wheel_rotation\"].comments                 \n",
       "168  nwb.processing[\"running\"][\"running_wheel_rotation\"].conversion               \n",
       "169  nwb.processing[\"running\"][\"running_wheel_rotation\"].description              \n",
       "170  nwb.processing[\"running\"][\"running_wheel_rotation\"].interval                 \n",
       "171  nwb.processing[\"running\"][\"running_wheel_rotation\"].offset                   \n",
       "172  nwb.processing[\"running\"][\"running_wheel_rotation\"].resolution               \n",
       "173  nwb.processing[\"running\"][\"running_wheel_rotation\"].timestamps_unit          \n",
       "174  nwb.processing[\"running\"][\"running_wheel_rotation\"].unit                     \n",
       "175  nwb.processing[\"running\"][\"running_wheel_rotation\"].data                     \n",
       "176  nwb.processing[\"running\"][\"running_wheel_rotation\"].timestamps               \n",
       "177  nwb.processing[\"stimulus\"][\"timestamps\"].data                                \n",
       "178  nwb.processing[\"stimulus\"][\"timestamps\"].timestamps                          \n",
       "179  nwb.subject.age                                                              \n",
       "180  nwb.subject.age_in_days                                                      \n",
       "181  nwb.subject.genotype                                                         \n",
       "182  nwb.subject.sex                                                              \n",
       "183  nwb.subject.species                                                          \n",
       "184  nwb.subject.specimen_name                                                    \n",
       "185  nwb.subject.strain                                                           \n",
       "186  nwb.subject.subject_id                                                       \n",
       "187  nwb.units.colnames                                                           \n",
       "188  nwb.units.id                                                                 \n",
       "189  nwb.units.spread                                                             \n",
       "190  nwb.units.PT_ratio                                                           \n",
       "191  nwb.units.waveform_duration                                                  \n",
       "192  nwb.units.d_prime                                                            \n",
       "193  nwb.units.cumulative_drift                                                   \n",
       "194  nwb.units.silhouette_score                                                   \n",
       "195  nwb.units.cluster_id                                                         \n",
       "196  nwb.units.l_ratio                                                            \n",
       "197  nwb.units.quality                                                            \n",
       "198  nwb.units.nn_miss_rate                                                       \n",
       "199  nwb.units.local_index                                                        \n",
       "200  nwb.units.amplitude_recovery_slope                                           \n",
       "201  nwb.units.snr                                                                \n",
       "202  nwb.units.velocity_above                                                     \n",
       "203  nwb.units.amplitude_cutoff                                                   \n",
       "204  nwb.units.isolation_distance                                                 \n",
       "205  nwb.units.peak_channel_id                                                    \n",
       "206  nwb.units.velocity_below                                                     \n",
       "207  nwb.units.nn_hit_rate                                                        \n",
       "208  nwb.units.firing_rate                                                        \n",
       "209  nwb.units.isi_violations                                                     \n",
       "210  nwb.units.repolarization_slope                                               \n",
       "211  nwb.units.presence_ratio                                                     \n",
       "212  nwb.units.waveform_halfwidth                                                 \n",
       "213  nwb.units.max_drift                                                          \n",
       "214  nwb.units.spike_times                                                        \n",
       "215  nwb.units.spike_amplitudes                                                   \n",
       "216  nwb.units.waveform_mean                                                      \n",
       "217  nwb.units.waveform_halfwidth                                                 \n",
       "218  nwb.units.max_drift                                                          \n",
       "219  nwb.units.spike_times                                                        \n",
       "220  nwb.units.spike_amplitudes                                                   \n",
       "221  nwb.units.waveform_mean                                                      \n",
       "\n",
       "                                                                                                                                                                                                                     Definition  \n",
       "0    Description of the Session                                                                                                                                                                                                  \n",
       "1    Unique identifier of the session                                                                                                                                                                                            \n",
       "2    Datetime start of the session                                                                                                                                                                                               \n",
       "3    Time that all timestamps are in reference to                                                                                                                                                                                \n",
       "4    Description of the experiment                                                                                                                                                                                               \n",
       "5    Name of the institution that produced these data                                                                                                                                                                            \n",
       "6    Comments                                                                                                                                                                                                                    \n",
       "7    Scalar to multiply each element in data to convert it to the specified unit                                                                                                                                                 \n",
       "8    Description                                                                                                                                                                                                                 \n",
       "9    Unexplained                                                                                                                                                                                                                 \n",
       "10   Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.                                                                                                             \n",
       "11   Unexplained                                                                                                                                                                                                                 \n",
       "12   The smallest meaningful difference (in specified unit) between values in data                                                                                                                                               \n",
       "13   Name of the unit for the data                                                                                                                                                                                               \n",
       "14   Angle of the eye in degrees over time as calculated with corneal reflection tracking                                                                                                                                        \n",
       "15   Height of the cornea, in pixels, over time as calculated with corneal reflection tracking                                                                                                                                   \n",
       "16   Width of the cornea, in pixels, over time as calculated with corneal reflection tracking                                                                                                                                    \n",
       "17   Area of the cornea, in pixels, over time as calculated with corneal reflection tracking and with outliers removed. Should generally be equal to corneal reflection tracking height times corneal reflection tracking width  \n",
       "18   Area of the cornea, in pixels, over time as calculated with corneal reflection tracking. Should be equal to corneal reflection tracking height times corneal reflection tracking width.                                     \n",
       "19   2D array consisting of the X and Y locations of the eye, in pixels, over time as calculated by corneal reflection tracking                                                                                                  \n",
       "20   Timestamps of the corneal reflection tracking arrays                                                                                                                                                                        \n",
       "21   Comments                                                                                                                                                                                                                    \n",
       "22   Scalar to multiply each element in data to convert it to the specified unit                                                                                                                                                 \n",
       "23   Description                                                                                                                                                                                                                 \n",
       "24   Unexplained                                                                                                                                                                                                                 \n",
       "25   Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.                                                                                                             \n",
       "26   Unexplained                                                                                                                                                                                                                 \n",
       "27   The smallest meaningful difference (in specified unit) between values in data                                                                                                                                               \n",
       "28   Name of the unit for the data                                                                                                                                                                                               \n",
       "29   Angle of the eye in degrees over time as calculated with eye tracking                                                                                                                                                       \n",
       "30   Height of the eye, in pixels, over time as calculated with eye tracking                                                                                                                                                     \n",
       "31   Width of the eye, in pixels, over time as calculated with eye tracking                                                                                                                                                      \n",
       "32   Area of the eye, in pixels, over time as calculated with eye tracking with outliers removed. Should generally be equal to eye tracking height times eye tracking width                                                      \n",
       "33   Area of the eye, in pixels, over time as calculated with eye tracking. Should be equal to eye tracking height times eye tracking width                                                                                      \n",
       "34   2D array consisting of the X and Y locations of the eye, in pixels, over time as calculated by eye tracking                                                                                                                 \n",
       "35   Timestamps of the eye tracking arrays                                                                                                                                                                                       \n",
       "36   Comments                                                                                                                                                                                                                    \n",
       "37   Scalar to multiply each element in data to convert it to the specified unit                                                                                                                                                 \n",
       "38   Description                                                                                                                                                                                                                 \n",
       "39   Unexplained                                                                                                                                                                                                                 \n",
       "40   Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.                                                                                                             \n",
       "41   Unexplained                                                                                                                                                                                                                 \n",
       "42   The smallest meaningful difference (in specified unit) between values in data                                                                                                                                               \n",
       "43   Name of the unit for the data                                                                                                                                                                                               \n",
       "44   Angle of the pupil in degrees over time as calculated with pupil tracking                                                                                                                                                   \n",
       "45   Height of the pupil, in pixels, over time as calculated with pupil tracking                                                                                                                                                 \n",
       "46   Width of the pupil, in pixels, over time as calculated with pupil tracking                                                                                                                                                  \n",
       "47   Area of the pupil, in pixels, over time as calculated with pupil tracking and with outliers removed. Should generally be equal to pupil tracking height times pupil tracking width                                          \n",
       "48   Area of the pupil, in pixels, over time as calculated with pupil tracking. Should be equal to pupil tracking height times pupil tracking width                                                                              \n",
       "49   2D array consisting of the X and Y locations of the pupil, in pixels, over time as calculated by eye tracking                                                                                                               \n",
       "50   Timestamps of the pupil tracking arrays                                                                                                                                                                                     \n",
       "51   Array of booleans indicating probable blink times                                                                                                                                                                           \n",
       "52   Timestamps of the blink times array                                                                                                                                                                                         \n",
       "53   Comments                                                                                                                                                                                                                    \n",
       "54   Scalar to multiply each element in data to convert it to the specified unit                                                                                                                                                 \n",
       "55   Description                                                                                                                                                                                                                 \n",
       "56   Unexplained                                                                                                                                                                                                                 \n",
       "57   Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.                                                                                                             \n",
       "58   The smallest meaningful difference (in specified unit) between values in data                                                                                                                                               \n",
       "59   Nameof the unit for the timestamps                                                                                                                                                                                          \n",
       "60   Name of the unit for the data                                                                                                                                                                                               \n",
       "61   Speed of the running wheel, measured at each timestamps. The data is raw (cm/s).                                                                                                                                            \n",
       "62   Timestamps of the unfiltered running speed.                                                                                                                                                                                 \n",
       "63   Comments                                                                                                                                                                                                                    \n",
       "64   Scalar to multiply each element in data to convert it to the specified unit                                                                                                                                                 \n",
       "65   Description                                                                                                                                                                                                                 \n",
       "66   Unexplained                                                                                                                                                                                                                 \n",
       "67   Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.                                                                                                             \n",
       "68   The smallest meaningful difference (in specified unit) between values in data                                                                                                                                               \n",
       "69   Nameof the unit for the timestamps                                                                                                                                                                                          \n",
       "70   Name of the unit for the data                                                                                                                                                                                               \n",
       "71   Unused                                                                                                                                                                                                                      \n",
       "72   Unused                                                                                                                                                                                                                      \n",
       "73   Comments                                                                                                                                                                                                                    \n",
       "74   Scalar to multiply each element in data to convert it to the specified unit                                                                                                                                                 \n",
       "75   Description                                                                                                                                                                                                                 \n",
       "76   Unexplained                                                                                                                                                                                                                 \n",
       "77   Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.                                                                                                             \n",
       "78   The smallest meaningful difference (in specified unit) between values in data                                                                                                                                               \n",
       "79   Nameof the unit for the timestamps                                                                                                                                                                                          \n",
       "80   Name of the unit for the data                                                                                                                                                                                               \n",
       "81   Unused                                                                                                                                                                                                                      \n",
       "82   Unused                                                                                                                                                                                                                      \n",
       "83   Comments                                                                                                                                                                                                                    \n",
       "84   Scalar to multiply each element in data to convert it to the specified unit                                                                                                                                                 \n",
       "85   Description                                                                                                                                                                                                                 \n",
       "86   Unexplained                                                                                                                                                                                                                 \n",
       "87   Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.                                                                                                             \n",
       "88   The smallest meaningful difference (in specified unit) between values in data                                                                                                                                               \n",
       "89   Nameof the unit for the timestamps                                                                                                                                                                                          \n",
       "90   Name of the unit for the data                                                                                                                                                                                               \n",
       "91   n * t array of measured LFP values where n is the number of channels and t is the number of timestamps                                                                                                                      \n",
       "92   array of timestamps for LFP data                                                                                                                                                                                            \n",
       "93   Description of this probe                                                                                                                                                                                                   \n",
       "94   Manufacturer of this probe                                                                                                                                                                                                  \n",
       "95   Unique identifier of the probe                                                                                                                                                                                              \n",
       "96   Sampling rate of the recording session with this probe                                                                                                                                                                      \n",
       "97   Column names of the electrodes table                                                                                                                                                                                        \n",
       "98   IDs column of the electrodes table                                                                                                                                                                                          \n",
       "99   CCF X coordinates column of the electrodes table. Represents the X location of electrodes along a probe.                                                                                                                    \n",
       "100  CCF Y coordinates column of the electrodes table. Represents the Y location of electrodes along a probe.                                                                                                                    \n",
       "101  CCF Z coordinates column of the electrodes table. Represents the Z location of electrodes along a probe.                                                                                                                    \n",
       "102  Impedance column of the electrodes table. Unused in our data.                                                                                                                                                               \n",
       "103  Brain region acronyms column of the electrodes table                                                                                                                                                                        \n",
       "104  Column of the electrodes table describing the list of filters applied to each electrode.                                                                                                                                    \n",
       "105  References to group object column of the electrodes table                                                                                                                                                                   \n",
       "106  Group names (probe names) column of the electrodes table                                                                                                                                                                    \n",
       "107  Probe vertical positions column of the electrodes table                                                                                                                                                                     \n",
       "108  Probe horizontal positions column of the electrodes table                                                                                                                                                                   \n",
       "109  Probe IDs column of the electrodes table                                                                                                                                                                                    \n",
       "110  Column of the electrodes table that contains local indices of electrodes within their own probe                                                                                                                             \n",
       "111  Valid data flags column of the electrodes table                                                                                                                                                                             \n",
       "112  Description of the electrodes table                                                                                                                                                                                         \n",
       "113  Description of this electrode group                                                                                                                                                                                         \n",
       "114  Reference to the device information for this electrode group                                                                                                                                                                \n",
       "115  Flag indicating if this electrode group has LFP data                                                                                                                                                                        \n",
       "116  Sampling rate of this group's LFP data                                                                                                                                                                                      \n",
       "117  Brain location acronym of this electrode group                                                                                                                                                                              \n",
       "118  Probe Identifier of this electrode group                                                                                                                                                                                    \n",
       "119  Datetime time this file was created                                                                                                                                                                                         \n",
       "120  IDs column of the stimulus table                                                                                                                                                                                            \n",
       "121  Column of start times of each interval in the stimulus table                                                                                                                                                                \n",
       "122  Column of stop times of each interval in the stimulus table                                                                                                                                                                 \n",
       "123  Column of names of stimulus types for each interval of the stimulus table                                                                                                                                                   \n",
       "124  Numbers representing stimulus blocks column of the stimulus table                                                                                                                                                           \n",
       "125  Column of the stimulus table consisting of frame numbers of the stimulus                                                                                                                                                    \n",
       "126  Column of the stimulus table which contains the stimulus index for each interval                                                                                                                                            \n",
       "127  Column of the stimulus table which contains a list of tags for each interval                                                                                                                                                \n",
       "128  Column of the stimulus table containing tuples of the form (i, c, r) where r is a reference to the complete timestamps array for the session, and i is the index within that array                                          \n",
       "129  Description of the stimulus table                                                                                                                                                                                           \n",
       "130  IDs column of the invalid times table                                                                                                                                                                                       \n",
       "131  Start times column of the invalid times table                                                                                                                                                                               \n",
       "132  Stop times column of the invalid times table                                                                                                                                                                                \n",
       "133  Tags column of the invalid times table                                                                                                                                                                                      \n",
       "134  Description of the invalid times table                                                                                                                                                                                      \n",
       "135  Column names of the optogenetic stimulation table                                                                                                                                                                           \n",
       "136  IDs column of the optogenetic stimulation table                                                                                                                                                                             \n",
       "137  Column of the stop times of the laser for each interval in the optogenetic stimulation table                                                                                                                                \n",
       "138  Column of the start times of the laser for each interval in the optogenetic stimulation table                                                                                                                               \n",
       "139  Laser condition column of the optogenetic stimulation table                                                                                                                                                                 \n",
       "140  Laser voltage level column of the optogenetic stimulation table                                                                                                                                                             \n",
       "141  Stimulus name column of the optogenetic stimulation table                                                                                                                                                                   \n",
       "142  Laser duration column of the optogenetic stimulation table                                                                                                                                                                  \n",
       "143  Tags column of the optogenetic stimulation table                                                                                                                                                                            \n",
       "144  Timeseries reference column of the optogenetic stimulation table                                                                                                                                                            \n",
       "145  Period of the optotagging light oscilation (s)                                                                                                                                                                              \n",
       "146  Array of timestamps for the optotagging pulses                                                                                                                                                                              \n",
       "147  Comments                                                                                                                                                                                                                    \n",
       "148  Scalar to multiply each element in data to convert it to the specified unit                                                                                                                                                 \n",
       "149  Description                                                                                                                                                                                                                 \n",
       "150  Unexplained                                                                                                                                                                                                                 \n",
       "151  Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.                                                                                                             \n",
       "152  The smallest meaningful difference (in specified unit) between values in data                                                                                                                                               \n",
       "153  Nameof the unit for the timestamps                                                                                                                                                                                          \n",
       "154  Name of the unit for the data                                                                                                                                                                                               \n",
       "155  Speed of the running wheel, measured at each timestamps. The data is filtered with a low-pass filter to remove noise artifacts (cm/s).                                                                                      \n",
       "156  Array of timestamps for the running_speed array                                                                                                                                                                             \n",
       "157  Comments                                                                                                                                                                                                                    \n",
       "158  Scalar to multiply each element in data to convert it to the specified unit                                                                                                                                                 \n",
       "159  Description                                                                                                                                                                                                                 \n",
       "160  Unexplained                                                                                                                                                                                                                 \n",
       "161  Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.                                                                                                             \n",
       "162  The smallest meaningful difference (in specified unit) between values in data                                                                                                                                               \n",
       "163  Nameof the unit for the timestamps                                                                                                                                                                                          \n",
       "164  Name of the unit for the data                                                                                                                                                                                               \n",
       "165  The times that each measurement period for the running speed end. Should be the same as Running Speed Timestamps but with indices offset by 1.                                                                              \n",
       "166  Same as Running Speed End times Data                                                                                                                                                                                        \n",
       "167  Comments                                                                                                                                                                                                                    \n",
       "168  Scalar to multiply each element in data to convert it to the specified unit                                                                                                                                                 \n",
       "169  Description                                                                                                                                                                                                                 \n",
       "170  Unexplained                                                                                                                                                                                                                 \n",
       "171  Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.                                                                                                             \n",
       "172  The smallest meaningful difference (in specified unit) between values in data                                                                                                                                               \n",
       "173  Nameof the unit for the timestamps                                                                                                                                                                                          \n",
       "174  Name of the unit for the data                                                                                                                                                                                               \n",
       "175  Position of the running wheel, measured at each timestamps.                                                                                                                                                                 \n",
       "176  Array of timestamps for the running_wheel_rotation array                                                                                                                                                                    \n",
       "177  Array of all the the stimulus timestamps during the session. Identical to Stimulus Timestamps Timestamps                                                                                                                    \n",
       "178  Array of all the the stimulus timestamps during the session. Identical to Stimulus Timestamps Data                                                                                                                          \n",
       "179  Age of the subject                                                                                                                                                                                                          \n",
       "180  Age of the subject, in days                                                                                                                                                                                                 \n",
       "181  Genotype of the subject                                                                                                                                                                                                     \n",
       "182  Sex of the subject, M or F                                                                                                                                                                                                  \n",
       "183  Species of the subject                                                                                                                                                                                                      \n",
       "184  Specimen name of the subject                                                                                                                                                                                                \n",
       "185  Strain of the subject                                                                                                                                                                                                       \n",
       "186  Unique identifier of the subject                                                                                                                                                                                            \n",
       "187  Column names of the units table                                                                                                                                                                                             \n",
       "188  IDs column of the units table                                                                                                                                                                                               \n",
       "189  Column of the units table consisting of the spread value for each unit                                                                                                                                                      \n",
       "190  Column of the units table consisting of the pt ratio for each unit                                                                                                                                                          \n",
       "191  Column of the units table with the durations, in seconds, of a unit's waveform                                                                                                                                              \n",
       "192  Column of the units table containing the d_prime values for units.                                                                                                                                                          \n",
       "193  Column of the units table containing the cumulative drift values for units                                                                                                                                                  \n",
       "194  Column of the units table containing the silhouette score for units                                                                                                                                                         \n",
       "195  Column of the units table containing the cluster_id for units                                                                                                                                                               \n",
       "196  Column of the units table containing the l ratio for units                                                                                                                                                                  \n",
       "197  Column of the units table with the quality, 'good' or 'noise' of each unit                                                                                                                                                  \n",
       "198  Column of the units table containing the nearest-neighbors miss rate for each unit                                                                                                                                          \n",
       "199  Column of the units table containing the local index of each unit, where the local index is the order it was detected by kilosort                                                                                           \n",
       "200  Column of the units table containing the amplitude recovery slope for each unit                                                                                                                                             \n",
       "201  Column of the units table containing the signal-to-noise ratio for each unit                                                                                                                                                \n",
       "202  Column of the units table containing the velocity above value for each unit                                                                                                                                                 \n",
       "203  Column  of the units table containing the amplitude cutoff for each unit                                                                                                                                                    \n",
       "204  Column of the units table containing the isolation distance for each unit                                                                                                                                                   \n",
       "205  Column of the units table consisting of the unique ID of the unit's peak channel that can be found in the electrodes table                                                                                                  \n",
       "206  Column of the units table containing the velocity below value for each unit                                                                                                                                                 \n",
       "207  Column of the units table containing the nearest-neighbors hit rate for each unit                                                                                                                                           \n",
       "208  Column of the units table containing the average firing rate for each unit                                                                                                                                                  \n",
       "209  Column of the units table containing the inter-spike-interval violations for each unit                                                                                                                                      \n",
       "210  Column of the units table containing the repolarization slope for each unit                                                                                                                                                 \n",
       "211  Column of the units table containing the presence ratio for each unit                                                                                                                                                       \n",
       "212  Column of the units table containing the average waveform halfwidth for each unit                                                                                                                                           \n",
       "213  Column of the units table containing the maximum drift for each unit                                                                                                                                                        \n",
       "214  Column of the units table consisting of the arrays of spike times for each unit. Should be same length as spikje amplitudes array                                                                                           \n",
       "215  Column of the units table consisting of arrays of spike amplitudes for each unit. Should be same length as spike times array                                                                                                \n",
       "216  Column of mean waveforms for each unit. Each unit mean_waveform should be a 2D array with dimensions n*t where n is the number of channels and t is the time                                                                \n",
       "217  Column of the units table containing the average waveform halfwidth for each unit                                                                                                                                           \n",
       "218  Column of the units table containing the maximum drift for each unit                                                                                                                                                        \n",
       "219  Column of the units table consisting of the arrays of spike times for each unit. Should be same length as spikje amplitudes array                                                                                           \n",
       "220  Column of the units table consisting of arrays of spike amplitudes for each unit. Should be same length as spike times array                                                                                                \n",
       "221  Column of mean waveforms for each unit. Each unit mean_waveform should be a 2D array with dimensions n*t where n is the number of channels and t is the time                                                                "
      ]
     },
     "execution_count": 9,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "pd.read_csv(\"../../data/ecephys_schema.csv\")"
   ]
  },
  {
   "attachments": {},
   "cell_type": "markdown",
   "id": "059f169c",
   "metadata": {},
   "source": [
    "#### Ophys File"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 10,
   "id": "8dca71a4",
   "metadata": {
    "tags": [
     "output_scroll"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>Section</th>\n",
       "      <th>Field</th>\n",
       "      <th>Type</th>\n",
       "      <th>Path</th>\n",
       "      <th>Definition</th>\n",
       "      <th>Unnamed: 5</th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>NaN</td>\n",
       "      <td>Session Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.session_description</td>\n",
       "      <td>Description of the Session</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>NaN</td>\n",
       "      <td>Session Identifier</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.identifier</td>\n",
       "      <td>Unique identifier of the session</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>NaN</td>\n",
       "      <td>Session Start Time</td>\n",
       "      <td>datetime</td>\n",
       "      <td>nwb.session_start_time</td>\n",
       "      <td>Datetime start of the session</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>NaN</td>\n",
       "      <td>Reference Time</td>\n",
       "      <td>datetime</td>\n",
       "      <td>nwb.timestamps_reference_time</td>\n",
       "      <td>Time that all timestamps are in reference to</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>4</th>\n",
       "      <td>NaN</td>\n",
       "      <td>Experiment Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.experiment_description</td>\n",
       "      <td>Description of the experiment</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>5</th>\n",
       "      <td>NaN</td>\n",
       "      <td>Institution</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.institution</td>\n",
       "      <td>Name of the institution that produced these data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>6</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Comments</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.comments\"</td>\n",
       "      <td>Comments</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>7</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Conversion</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.conversion\"</td>\n",
       "      <td>Scalar to multiply each element in data to convert it to the specified unit</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>8</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.description\"</td>\n",
       "      <td>Description</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>9</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Interval</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.interval\"</td>\n",
       "      <td>Unexplained</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>10</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Offset</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.offset\"</td>\n",
       "      <td>Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>11</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Reference Frame</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.reference_frame\"</td>\n",
       "      <td>Unexplained</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>12</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Resolution</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.resolution\"</td>\n",
       "      <td>The smallest meaningful difference (in specified unit) between values in data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>13</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.unit\"</td>\n",
       "      <td>Name of the unit for the data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>14</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Angle</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.angle\"</td>\n",
       "      <td>Angle of the eye in degrees over time as calculated with corneal reflection tracking</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>15</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Height</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.height\"</td>\n",
       "      <td>Height of the cornea, in pixels, over time as calculated with corneal reflection tracking</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>16</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Width</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.width\"</td>\n",
       "      <td>Width of the cornea, in pixels, over time as calculated with corneal reflection tracking</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>17</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Area</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.area\"</td>\n",
       "      <td>Area of the cornea, in pixels, over time as calculated with corneal reflection tracking and with outliers removed. Should generally be equal to corneal reflection tracking height times corneal reflection tracking width</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>18</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Raw Area</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.area_raw\"</td>\n",
       "      <td>Area of the cornea, in pixels, over time as calculated with corneal reflection tracking. Should be equal to corneal reflection tracking height times corneal reflection tracking width.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>19</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Data</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.data\"</td>\n",
       "      <td>2D array consisting of the X and Y locations of the eye, in pixels, over time as calculated by corneal reflection tracking</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>20</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Corneal Reflection Tracking Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.timestamps\"</td>\n",
       "      <td>Timestamps of the corneal reflection tracking arrays</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>21</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Tracking Comments</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].eye_tracking.comments\"</td>\n",
       "      <td>Comments</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>22</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Conversion</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].eye_tracking.conversion\"</td>\n",
       "      <td>Scalar to multiply each element in data to convert it to the specified unit</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>23</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].eye_tracking.description\"</td>\n",
       "      <td>Description</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>24</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Interval</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].eye_tracking.interval\"</td>\n",
       "      <td>Unexplained</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>25</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Offset</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].eye_tracking.offset\"</td>\n",
       "      <td>Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>26</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Reference Frame</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].eye_tracking.reference_frame\"</td>\n",
       "      <td>Unexplained</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>27</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Resolution</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].eye_tracking.resolution\"</td>\n",
       "      <td>The smallest meaningful difference (in specified unit) between values in data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>28</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].eye_tracking.unit\"</td>\n",
       "      <td>Name of the unit for the data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>29</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Angle</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].eye_tracking.angle\"</td>\n",
       "      <td>Angle of the eye in degrees over time as calculated with eye tracking</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>30</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Height</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].eye_tracking.height\"</td>\n",
       "      <td>Height of the eye, in pixels, over time as calculated with eye tracking</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>31</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Width</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].eye_tracking.width\"</td>\n",
       "      <td>Width of the eye, in pixels, over time as calculated with eye tracking</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>32</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Area</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].eye_tracking.area\"</td>\n",
       "      <td>Area of the eye, in pixels, over time as calculated with eye tracking with outliers removed. Should generally be equal to eye tracking height times eye tracking width</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>33</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Raw Area</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].eye_tracking.area_raw\"</td>\n",
       "      <td>Area of the eye, in pixels, over time as calculated with eye tracking. Should be equal to eye tracking height times eye tracking width</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>34</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Data</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].eye_tracking.data\"</td>\n",
       "      <td>2D array consisting of the X and Y locations of the eye, in pixels, over time as calculated by eye tracking</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>35</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].eye_tracking.timestamps\"</td>\n",
       "      <td>Timestamps of the eye tracking arrays</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>36</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Tracking Comments</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].pupil_tracking.comments\"</td>\n",
       "      <td>Comments</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>37</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Conversion</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].pupil_tracking.conversion\"</td>\n",
       "      <td>Scalar to multiply each element in data to convert it to the specified unit</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>38</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].pupil_tracking.description\"</td>\n",
       "      <td>Description</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>39</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Interval</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].pupil_tracking.interval\"</td>\n",
       "      <td>Unexplained</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>40</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Offset</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].pupil_tracking.offset\"</td>\n",
       "      <td>Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>41</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Reference Frame</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].pupil_tracking.reference_frame\"</td>\n",
       "      <td>Unexplained</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>42</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Resolution</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].pupil_tracking.resolution\"</td>\n",
       "      <td>The smallest meaningful difference (in specified unit) between values in data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>43</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Eye Tracking Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].pupil_tracking.unit\"</td>\n",
       "      <td>Name of the unit for the data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>44</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Pupil Tracking Angle</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].pupil_tracking.angle\"</td>\n",
       "      <td>Angle of the pupil in degrees over time as calculated with pupil tracking</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>45</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Pupil Tracking Height</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].pupil_tracking.height\"</td>\n",
       "      <td>Height of the pupil, in pixels, over time as calculated with pupil tracking</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>46</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Pupil Tracking Width</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].pupil_tracking.width\"</td>\n",
       "      <td>Width of the pupil, in pixels, over time as calculated with pupil tracking</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>47</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Pupil Tracking Area</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].pupil_tracking.area\"</td>\n",
       "      <td>Area of the pupil, in pixels, over time as calculated with pupil tracking and with outliers removed. Should generally be equal to pupil tracking height times pupil tracking width</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>48</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Pupil Tracking Raw Area</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].pupil_tracking.area_raw\"</td>\n",
       "      <td>Area of the pupil, in pixels, over time as calculated with pupil tracking. Should be equal to pupil tracking height times pupil tracking width</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>49</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Pupil Tracking Data</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].pupil_tracking.data\"</td>\n",
       "      <td>2D array consisting of the X and Y locations of the pupil, in pixels, over time as calculated by eye tracking</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>50</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Pupil Tracking Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].pupil_tracking.timestamps\"</td>\n",
       "      <td>Timestamps of the pupil tracking arrays</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>51</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Blink Times</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].likely_blink.data\"</td>\n",
       "      <td>Array of booleans indicating probable blink times</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>52</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Blink Times Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[EyeTracking\"].likely_blink.timestamps\"</td>\n",
       "      <td>Timestamps of the blink times array</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>53</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>2P Movie Data</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[raw_suite2p_motion_corrected\"].data\"</td>\n",
       "      <td>3D array of the raw 2P movie where the dimensions are pixels height * pixels width * frame time</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>54</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>2P Movie Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[raw_suite2p_motion_corrected\"].timestamps\"</td>\n",
       "      <td>Timestamps of the frames in the 2P movie</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>55</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>2P Movie Rate</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[raw_suite2p_motion_corrected\"].rate\"</td>\n",
       "      <td>Framerate of the 2P movie</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>56</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>2P Movie Device</td>\n",
       "      <td>Device</td>\n",
       "      <td>nwb.acquisition[raw_suite2p_motion_corrected\"].device\"</td>\n",
       "      <td>Device that produced the 2P movie data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>57</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>2P Movie Imaging Plane</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[raw_suite2p_motion_corrected\"].imaging_plane\"</td>\n",
       "      <td>Imaging Plane of the 2P movie</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>58</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Input Voltage Comments</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[v_in\"].comments\"</td>\n",
       "      <td>Comments</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>59</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Input Voltage Conversion</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[v_in\"].conversion\"</td>\n",
       "      <td>Scalar to multiply each element in data to convert it to the specified unit</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>60</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Input Voltage Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[v_in\"].description\"</td>\n",
       "      <td>Description</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>61</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Input Voltage Interval</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[v_in\"].interval\"</td>\n",
       "      <td>Unexplained</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>62</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Input Voltage Offset</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[v_in\"].offset\"</td>\n",
       "      <td>Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>63</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Input Voltage Resolution</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[v_in\"].resolution\"</td>\n",
       "      <td>The smallest meaningful difference (in specified unit) between values in data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>64</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Input Voltage Timestamps Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[v_in\"].timestamps_unit\"</td>\n",
       "      <td>Name of the unit for the timestamps</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>65</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Input Voltage Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[v_in\"].unit\"</td>\n",
       "      <td>Name of the unit for the data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>66</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Input Voltage Data</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[v_in\"].data\"</td>\n",
       "      <td>Unused</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>67</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Input Voltage Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[v_in\"].timestamps\"</td>\n",
       "      <td>Unused</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>68</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Signal Voltage Comments</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[v_sig\"].comments\"</td>\n",
       "      <td>Comments</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>69</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Signal Voltage Conversion</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[v_sig\"].conversion\"</td>\n",
       "      <td>Scalar to multiply each element in data to convert it to the specified unit</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>70</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Signal Voltage Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[v_sig\"].description\"</td>\n",
       "      <td>Description</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>71</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Signal Voltage Interval</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[v_sig\"].interval\"</td>\n",
       "      <td>Unexplained</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>72</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Signal Voltage Offset</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[v_sig\"].offset\"</td>\n",
       "      <td>Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>73</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Signal Voltage Resolution</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.acquisition[v_sig\"].resolution\"</td>\n",
       "      <td>The smallest meaningful difference (in specified unit) between values in data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>74</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Signal Voltage Timestamps Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[v_sig\"].timestamps_unit\"</td>\n",
       "      <td>Name of the unit for the timestamps</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>75</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Signal Voltage Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.acquisition[v_sig\"].unit\"</td>\n",
       "      <td>Name of the unit for the data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>76</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Signal Voltage Data</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[v_sig\"].dat\"</td>\n",
       "      <td>Unused</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>77</th>\n",
       "      <td>acquisition</td>\n",
       "      <td>Signal Voltage Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.acquisition[v_sig\"].timestamps\"</td>\n",
       "      <td>Unused</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>78</th>\n",
       "      <td>devices</td>\n",
       "      <td>Device description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.devices[device_name].description</td>\n",
       "      <td>Description of the device</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>79</th>\n",
       "      <td>file_create_date</td>\n",
       "      <td>File Creation Date</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.file_create_date</td>\n",
       "      <td>Datetime time this file was created</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>80</th>\n",
       "      <td>imaging_planes</td>\n",
       "      <td>Imaging Plane Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.imaging_planes[imaging_plane_name].description</td>\n",
       "      <td>Description of the instrument used.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>81</th>\n",
       "      <td>imaging_planes</td>\n",
       "      <td>Imaging Plane Excitation Lambda</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.imaging_planes[imaging_plane_name].excitation_lambda</td>\n",
       "      <td>Peak wavelength of the light excitation given by the pulsed Ti:Sa laser (nm).</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>82</th>\n",
       "      <td>imaging_planes</td>\n",
       "      <td>Imaging Plane Imaging Rate</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.imaging_planes[imaging_plane_name].imaging_rate</td>\n",
       "      <td>Frame rate to record each imaged plane.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>83</th>\n",
       "      <td>imaging_planes</td>\n",
       "      <td>Imaging Plane Indicator</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.imaging_planes[imaging_plane_name].indicator</td>\n",
       "      <td>Calcium indicator used to record neuronal activity.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>84</th>\n",
       "      <td>imaging_planes</td>\n",
       "      <td>Imaging Plane Location</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.imaging_planes[imaging_plane_name].location</td>\n",
       "      <td>Brain area imaged during the experiemnt.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>85</th>\n",
       "      <td>imaging_planes</td>\n",
       "      <td>Imaging Plane Optical Channel</td>\n",
       "      <td>OpticalChannel</td>\n",
       "      <td>nwb.imaging_planes[imaging_plane_name].optical_channel</td>\n",
       "      <td>Optical channel associated with this imaging plane. This provides a description of the fluorescence emission wavelength.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>86</th>\n",
       "      <td>imaging_planes</td>\n",
       "      <td>Imaging Plane Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.imaging_planes[imaging_plane_name].unit</td>\n",
       "      <td>Unit of this imaging plane</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>87</th>\n",
       "      <td>intervals</td>\n",
       "      <td>Stimulus Intervals Column Names</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.intervals[stimulus].colnames</td>\n",
       "      <td>Column names of the stimulus table</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>88</th>\n",
       "      <td>intervals</td>\n",
       "      <td>Stimulus Interval IDs</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.intervals[stimulus].id</td>\n",
       "      <td>IDs column of the stimulus table</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>89</th>\n",
       "      <td>intervals</td>\n",
       "      <td>Stimulus Interval Start Times</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.intervals[stimulus].start_time</td>\n",
       "      <td>Start times of the stimulus table</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>90</th>\n",
       "      <td>intervals</td>\n",
       "      <td>Stimulus Interval Stop Times</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.intervals[stimulus].stop_time</td>\n",
       "      <td>Stop times of the stimulus table</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>91</th>\n",
       "      <td>intervals</td>\n",
       "      <td>Stimulus Interval Stimulus Names</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.intervals[stimulus].stimulus_name</td>\n",
       "      <td>Names of stimulus types column of the stimulus table</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>92</th>\n",
       "      <td>intervals</td>\n",
       "      <td>Stimulus Interval Stimulus Blocks</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.intervals[stimulus].stimulus_block</td>\n",
       "      <td>Numbers representing stimulus blocks column of the stimulus table</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>93</th>\n",
       "      <td>intervals</td>\n",
       "      <td>Stimulus Interval Stimulus Frames</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.intervals[stimulus].frame</td>\n",
       "      <td>Column of the stimulus table consisting of frame numbers of the stimulus</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>94</th>\n",
       "      <td>intervals</td>\n",
       "      <td>Stimulus Interval Stimulus Indices</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.intervals[stimulus].stimulus_index</td>\n",
       "      <td>Column of the stimulus table which contains the stimulus index for each interval</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>95</th>\n",
       "      <td>intervals</td>\n",
       "      <td>Stimulus Interval Tags</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.intervals[stimulus].tags</td>\n",
       "      <td>Column of the stimulus table which contains a list of tags for each interval</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>96</th>\n",
       "      <td>intervals</td>\n",
       "      <td>Stimulus Interval Timeseries Link</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.intervals[stimulus].timeseries</td>\n",
       "      <td>Column of the stimulus table contain tuples of the form (i, c, r) where r is a reference to the complete timestamps array for the session, and i is the index within that array</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>97</th>\n",
       "      <td>intervals</td>\n",
       "      <td>Stimulus Intervals Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.intervals[stimulus].description</td>\n",
       "      <td>Description of the stimulus table</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>98</th>\n",
       "      <td>lab_meta_data</td>\n",
       "      <td>Experiment Container ID</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.lab_meta_data[metadata\"].experiment_container_id\"</td>\n",
       "      <td>unique id associated with all experiments that were cell-matched</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>99</th>\n",
       "      <td>lab_meta_data</td>\n",
       "      <td>FOV Width</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.lab_meta_data[metadata\"].field_of_view_width\"</td>\n",
       "      <td>Number of pixels in the horizontal direction</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>100</th>\n",
       "      <td>lab_meta_data</td>\n",
       "      <td>FOV Height</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.lab_meta_data[metadata\"].field_of_view_height\"</td>\n",
       "      <td>Number of pixels in the vertical direction</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>101</th>\n",
       "      <td>lab_meta_data</td>\n",
       "      <td>Imaging Depth</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.lab_meta_data[metadata\"].imaging_depth\"</td>\n",
       "      <td>Imaging depth from the surface of the brain in microns</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>102</th>\n",
       "      <td>lab_meta_data</td>\n",
       "      <td>Imaging Plane Group</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.lab_meta_data[metadata\"].imaging_plane_group\"</td>\n",
       "      <td>The Allen Institute mesoscope simultaneously acquire planes in pair.  This number indicate which plane this experiment is associated with.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>103</th>\n",
       "      <td>lab_meta_data</td>\n",
       "      <td>Imaging Plane Group Count</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.lab_meta_data[metadata\"].imaging_plane_group_count\"</td>\n",
       "      <td>Id of the imaging plane within the pair of simultateneously acquired planes.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>104</th>\n",
       "      <td>lab_meta_data</td>\n",
       "      <td>Ophys Experiment ID</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.lab_meta_data[metadata\"].ophys_experiment_id\"</td>\n",
       "      <td>Unique id given to each imaging plane</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>105</th>\n",
       "      <td>lab_meta_data</td>\n",
       "      <td>Ophys Session ID</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.lab_meta_data[metadata\"].ophys_session_id\"</td>\n",
       "      <td>Unique id given to each experimental session. Multiple experiemntal ids can have the same session id.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>106</th>\n",
       "      <td>processing</td>\n",
       "      <td>Fluorescence Trace Comments</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[ophys\"][\"corrected_fluorescence\"].roi_response_series[\"traces\"].comments\"</td>\n",
       "      <td>Comments</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>107</th>\n",
       "      <td>processing</td>\n",
       "      <td>Fluorescence Trace Conversion</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[ophys\"][\"corrected_fluorescence\"].roi_response_series[\"traces\"].conversion\"</td>\n",
       "      <td>Scalar to multiply each element in data to convert it to the specified unit</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>108</th>\n",
       "      <td>processing</td>\n",
       "      <td>Fluorescence Trace Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[ophys\"][\"corrected_fluorescence\"].roi_response_series[\"traces\"].description\"</td>\n",
       "      <td>Description</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>109</th>\n",
       "      <td>processing</td>\n",
       "      <td>Fluorescence Trace Interval</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[ophys\"][\"corrected_fluorescence\"].roi_response_series[\"traces\"].interval\"</td>\n",
       "      <td>Unexplained</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>110</th>\n",
       "      <td>processing</td>\n",
       "      <td>Fluorescence Trace Offset</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[ophys\"][\"corrected_fluorescence\"].roi_response_series[\"traces\"]</td>\n",
       "      <td>Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>111</th>\n",
       "      <td>processing</td>\n",
       "      <td>Fluorescence Trace Resolution</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[ophys\"][\"corrected_fluorescence\"].roi_response_series[\"traces\"].resolution\"</td>\n",
       "      <td>The smallest meaningful difference (in specified unit) between values in data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>112</th>\n",
       "      <td>processing</td>\n",
       "      <td>Fluorescence Trace Timestamps Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[ophys\"][\"corrected_fluorescence\"].roi_response_series[\"traces\"].timestamps_unit\"</td>\n",
       "      <td>Name of the unit for the timestamps</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>113</th>\n",
       "      <td>processing</td>\n",
       "      <td>Fluorescence Trace Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[ophys\"][\"corrected_fluorescence\"].roi_response_series[\"traces\"].unit\"</td>\n",
       "      <td>Name of the unit for the data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>114</th>\n",
       "      <td>processing</td>\n",
       "      <td>Fluorescence Trace Data</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[ophys\"][\"corrected_fluorescence\"].roi_response_series.data\"</td>\n",
       "      <td>Traces extracted from individual ROI, neuropil subtracted and demixed, but not normalized</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>115</th>\n",
       "      <td>processing</td>\n",
       "      <td>Fluorescence Trace Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[ophys\"][\"corrected_fluorescence\"].roi_response_series.timestamps\"</td>\n",
       "      <td>Timestamps of the corrected_fluorescence arrays</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>116</th>\n",
       "      <td>processing</td>\n",
       "      <td>DFF Trace Comments</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[ophys\"][\"dff\"].roi_response_series.comments\"</td>\n",
       "      <td>Comments</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>117</th>\n",
       "      <td>processing</td>\n",
       "      <td>DFF Trace Conversion</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[ophys\"][\"dff\"].roi_response_series.conversion\"</td>\n",
       "      <td>Scalar to multiply each element in data to convert it to the specified unit</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>118</th>\n",
       "      <td>processing</td>\n",
       "      <td>DFF Trace Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[ophys\"][\"dff\"].roi_response_series.description\"</td>\n",
       "      <td>Description</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>119</th>\n",
       "      <td>processing</td>\n",
       "      <td>DFF Trace Interval</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[ophys\"][\"dff\"].roi_response_series.interval\"</td>\n",
       "      <td>Unexplained</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>120</th>\n",
       "      <td>processing</td>\n",
       "      <td>DFF Trace Offset</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[ophys\"][\"dff\"].roi_response_series.offset\"</td>\n",
       "      <td>Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>121</th>\n",
       "      <td>processing</td>\n",
       "      <td>DFF Trace Resolution</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[ophys\"][\"dff\"].roi_response_series.resolution\"</td>\n",
       "      <td>The smallest meaningful difference (in specified unit) between values in data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>122</th>\n",
       "      <td>processing</td>\n",
       "      <td>DFF Trace Timestamps Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[ophys\"][\"dff\"].roi_response_series.timestamps_unit\"</td>\n",
       "      <td>Name of the unit for the timestamps</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>123</th>\n",
       "      <td>processing</td>\n",
       "      <td>DFF Trace Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[ophys\"][\"dff\"].roi_response_series.unit\"</td>\n",
       "      <td>Name of the unit for the data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>124</th>\n",
       "      <td>processing</td>\n",
       "      <td>DFF Trace Data</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[ophys\"][\"dff\"].roi_response_series.data\"</td>\n",
       "      <td>Traces extracted from individual ROI, baseline corrected, normalized fluorescence traces</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>125</th>\n",
       "      <td>processing</td>\n",
       "      <td>DFF Trace Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[ophys\"][\"dff\"].roi_response_series.timestamps\"</td>\n",
       "      <td>Timestamps of the dff arrays</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>126</th>\n",
       "      <td>processing</td>\n",
       "      <td>Event Detection Comments</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[ophys\"][\"event_detection\"].comments\"</td>\n",
       "      <td>Comments</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>127</th>\n",
       "      <td>processing</td>\n",
       "      <td>Event Detection Conversion</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[ophys\"][\"event_detection\"].conversion\"</td>\n",
       "      <td>Scalar to multiply each element in data to convert it to the specified unit</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>128</th>\n",
       "      <td>processing</td>\n",
       "      <td>Event Detection Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[ophys\"][\"event_detection\"].description\"</td>\n",
       "      <td>Description</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>129</th>\n",
       "      <td>processing</td>\n",
       "      <td>Event Detection Interval</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[ophys\"][\"event_detection\"].interval\"</td>\n",
       "      <td>Unexplained</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>130</th>\n",
       "      <td>processing</td>\n",
       "      <td>Event Detection Offset</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[ophys\"][\"event_detection\"].offset\"</td>\n",
       "      <td>Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>131</th>\n",
       "      <td>processing</td>\n",
       "      <td>Event Detection Resolution</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[ophys\"][\"event_detection\"].resolution\"</td>\n",
       "      <td>The smallest meaningful difference (in specified unit) between values in data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>132</th>\n",
       "      <td>processing</td>\n",
       "      <td>Event Detection Timestamps Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[ophys\"][\"event_detection\"].timestamps_unit\"</td>\n",
       "      <td>Name of the unit for the timestamps</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>133</th>\n",
       "      <td>processing</td>\n",
       "      <td>Event Detection Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[ophys\"][\"event_detection\"].unit\"</td>\n",
       "      <td>Name of the unit for the data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>134</th>\n",
       "      <td>processing</td>\n",
       "      <td>Event Detection Data</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[ophys\"][\"event_detection\"].data\"</td>\n",
       "      <td>Calcium events (detected with an L0 event detection algorithm)</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>135</th>\n",
       "      <td>processing</td>\n",
       "      <td>Event Detection Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[ophys\"][\"event_detection\"].timestamps\"</td>\n",
       "      <td>Timestamps of the events_detection arrays</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>136</th>\n",
       "      <td>processing</td>\n",
       "      <td>Event Detection Lambdas</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[ophys\"][\"event_detection\"].lambdas\"</td>\n",
       "      <td>Lambda used in the event detection algorithm. lambda is chosen by finding smallest lambda such that the size of the smallest detected event is greater or equal to event_min_size*robust std of noise.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>137</th>\n",
       "      <td>processing</td>\n",
       "      <td>Event Detection Standard Deviation</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[ophys\"][\"event_detection\"].noise_stds\"</td>\n",
       "      <td>Estimates of the std of the noise for each trace</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>138</th>\n",
       "      <td>processing</td>\n",
       "      <td>ROI Table Column Names</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[ophys\"][\"image_segmentation\"][\"cell_specimen_table\"].colnames\"</td>\n",
       "      <td>Column names of the ROI table</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>139</th>\n",
       "      <td>processing</td>\n",
       "      <td>ROI IDs</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[ophys\"][\"image_segmentation\"][\"cell_specimen_table\"].id\"</td>\n",
       "      <td>Column of IDs in the ROI table</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>140</th>\n",
       "      <td>processing</td>\n",
       "      <td>ROI Cell Specimen IDs</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[ophys\"][\"image_segmentation\"][\"cell_specimen_table\"].cell_specimen_id\"</td>\n",
       "      <td>Column of the ROI table consisting of the cell ID within a container for each ROI</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>141</th>\n",
       "      <td>processing</td>\n",
       "      <td>ROI Heights</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[ophys\"][\"image_segmentation\"][\"cell_specimen_table\"].height\"</td>\n",
       "      <td>ROI heights, in pixels, column of the ROIs table</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>142</th>\n",
       "      <td>processing</td>\n",
       "      <td>ROI Mask Image Planes</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[ophys\"][\"image_segmentation\"][\"cell_specimen_table\"].mask_image_plane\"</td>\n",
       "      <td>Column of the ROI table consisting of the index of ROIs that overlap</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>143</th>\n",
       "      <td>processing</td>\n",
       "      <td>ROI Max Corrections Down</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[ophys\"][\"image_segmentation\"][\"cell_specimen_table\"].max_correction_down\"</td>\n",
       "      <td>Column of the ROI table consisting of the maximum motion correction downward for each ROI</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>144</th>\n",
       "      <td>processing</td>\n",
       "      <td>ROI Max Corrections Left</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[ophys\"][\"image_segmentation\"][\"cell_specimen_table\"].max_correction_left\"</td>\n",
       "      <td>Column of the ROI table consisting of the maximum motion correction to the left for each ROI</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>145</th>\n",
       "      <td>processing</td>\n",
       "      <td>ROI Max Corrections Up</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[ophys\"][\"image_segmentation\"][\"cell_specimen_table\"].max_correction_up\"</td>\n",
       "      <td>Maximum motion correction upward</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>146</th>\n",
       "      <td>processing</td>\n",
       "      <td>ROI Max Corrections Right</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[ophys\"][\"image_segmentation\"][\"cell_specimen_table\"].max_correction_right\"</td>\n",
       "      <td>Maximum motion correction to the right</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>147</th>\n",
       "      <td>processing</td>\n",
       "      <td>ROI Valid Flags</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[ophys\"][\"image_segmentation\"][\"cell_specimen_table\"].valid_roi\"</td>\n",
       "      <td>ROI validity flags column of the ROIs table, indicating if the ROI is classified as a cell</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>148</th>\n",
       "      <td>processing</td>\n",
       "      <td>ROI Widths</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[ophys\"][\"image_segmentation\"][\"cell_specimen_table\"].width\"</td>\n",
       "      <td>ROI widths, in pixels, column of the ROI table</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>149</th>\n",
       "      <td>processing</td>\n",
       "      <td>ROI X Coordinates</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[ophys\"][\"image_segmentation\"][\"cell_specimen_table\"].x\"</td>\n",
       "      <td>ROI X coordinates, in pixels, column of the ROI table</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>150</th>\n",
       "      <td>processing</td>\n",
       "      <td>ROI Y Coordinates</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[ophys\"][\"image_segmentation\"][\"cell_specimen_table\"].y\"</td>\n",
       "      <td>ROI Y coordinates, in pixels, column of the ROI table</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>151</th>\n",
       "      <td>processing</td>\n",
       "      <td>ROI Image Masks</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[ophys\"][\"image_segmentation\"][\"cell_specimen_table\"].image_mask\"</td>\n",
       "      <td>Column of the ROIs table consisting of the black/white segmentation mask image of each individual ROI</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>152</th>\n",
       "      <td>processing</td>\n",
       "      <td>2P Image Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[ophys\"][\"images\"].description\"</td>\n",
       "      <td>Description of the Images</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>153</th>\n",
       "      <td>processing</td>\n",
       "      <td>2P Average Image</td>\n",
       "      <td>GrayscaleImage</td>\n",
       "      <td>nwb.processing[ophys\"][\"images\"][\"average_image\"]\"</td>\n",
       "      <td>Average Image of the movie from the session</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>154</th>\n",
       "      <td>processing</td>\n",
       "      <td>2P Max Projection</td>\n",
       "      <td>GrayscaleImage</td>\n",
       "      <td>nwb.processing[ophys\"][\"images\"][\"max_projection\"]\"</td>\n",
       "      <td>Maximum projection image of the movie from the session</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>155</th>\n",
       "      <td>processing</td>\n",
       "      <td>2P Segmentation Mask</td>\n",
       "      <td>GrayscaleImage</td>\n",
       "      <td>nwb.processing[ophys\"][\"images\"][\"segmentation_mask\"]\"</td>\n",
       "      <td>Black/white Segmentation mask image of all ROIs in the movie</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>156</th>\n",
       "      <td>processing</td>\n",
       "      <td>Ophys Motion Correction X Comments</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[ophys\"][\"ophys_motion_correction_x\"].comments\"</td>\n",
       "      <td>Comments</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>157</th>\n",
       "      <td>processing</td>\n",
       "      <td>Ophys Motion Correction X Conversion</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[ophys\"][\"ophys_motion_correction_x\"].conversion\"</td>\n",
       "      <td>Scalar to multiply each element in data to convert it to the specified unit</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>158</th>\n",
       "      <td>processing</td>\n",
       "      <td>Ophys Motion Correction X Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[ophys\"][\"ophys_motion_correction_x\"].description\"</td>\n",
       "      <td>Description</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>159</th>\n",
       "      <td>processing</td>\n",
       "      <td>Ophys Motion Correction X Interval</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[ophys\"][\"ophys_motion_correction_x\"].interval\"</td>\n",
       "      <td>Unexplained</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>160</th>\n",
       "      <td>processing</td>\n",
       "      <td>Ophys Motion Correction X Offset</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[ophys\"][\"ophys_motion_correction_x\"].offset\"</td>\n",
       "      <td>Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>161</th>\n",
       "      <td>processing</td>\n",
       "      <td>Ophys Motion Correction X Resolution</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[ophys\"][\"ophys_motion_correction_x\"].resolution\"</td>\n",
       "      <td>The smallest meaningful difference (in specified unit) between values in data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>162</th>\n",
       "      <td>processing</td>\n",
       "      <td>Ophys Motion Correction X Timestamps Unit</td>\n",
       "      <td>unit</td>\n",
       "      <td>nwb.processing[ophys\"][\"ophys_motion_correction_x\"].timestamps_unit\"</td>\n",
       "      <td>Name of the unit for the timestamps</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>163</th>\n",
       "      <td>processing</td>\n",
       "      <td>Ophys Motion Correction X Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[ophys\"][\"ophys_motion_correction_x\"].unit\"</td>\n",
       "      <td>Name of the unit for the data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>164</th>\n",
       "      <td>processing</td>\n",
       "      <td>Motion Correction X Data</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[ophys\"][\"ophys_motion_correction_x\"].data\"</td>\n",
       "      <td>horizontal correction applied to each frame of the two-photon raw movie using rigid-body motion correction</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>165</th>\n",
       "      <td>processing</td>\n",
       "      <td>Motion Correction X Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[ophys\"][\"ophys_motion_correction_x\"].timestamps\"</td>\n",
       "      <td>Array of timestamps for the motion correction arrays</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>166</th>\n",
       "      <td>processing</td>\n",
       "      <td>Ophys Motion Correction Y Comments</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[ophys\"][\"ophys_motion_correction_y\"].comments\"</td>\n",
       "      <td>Comments</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>167</th>\n",
       "      <td>processing</td>\n",
       "      <td>Ophys Motion Correction Y Conversion</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[ophys\"][\"ophys_motion_correction_y\"].conversion\"</td>\n",
       "      <td>Scalar to multiply each element in data to convert it to the specified unit</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>168</th>\n",
       "      <td>processing</td>\n",
       "      <td>Ophys Motion Correction Y Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[ophys\"][\"ophys_motion_correction_y\"].description\"</td>\n",
       "      <td>Description</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>169</th>\n",
       "      <td>processing</td>\n",
       "      <td>Ophys Motion Correction Y Interval</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[ophys\"][\"ophys_motion_correction_y\"].interval\"</td>\n",
       "      <td>Unexplained</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>170</th>\n",
       "      <td>processing</td>\n",
       "      <td>Ophys Motion Correction Y Offset</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[ophys\"][\"ophys_motion_correction_y\"].offset\"</td>\n",
       "      <td>Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>171</th>\n",
       "      <td>processing</td>\n",
       "      <td>Ophys Motion Correction Y Resolution</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[ophys\"][\"ophys_motion_correction_y\"].resolution\"</td>\n",
       "      <td>The smallest meaningful difference (in specified unit) between values in data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>172</th>\n",
       "      <td>processing</td>\n",
       "      <td>Ophys Motion Correction Y Timestamps Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[ophys\"][\"ophys_motion_correction_y\"].timestamps_unit\"</td>\n",
       "      <td>Name of the unit for the timestamps</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>173</th>\n",
       "      <td>processing</td>\n",
       "      <td>Ophys Motion Correction Y Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[ophys\"][\"ophys_motion_correction_y\"].unit\"</td>\n",
       "      <td>Name of the unit for the data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>174</th>\n",
       "      <td>processing</td>\n",
       "      <td>Motion Correction Y Data</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[ophys\"][\"ophys_motion_correction_y\"].data\"</td>\n",
       "      <td>Vertical correction applied to each frame of the two-photon raw movie using rigid-body motion correction</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>175</th>\n",
       "      <td>processing</td>\n",
       "      <td>Motion Correction Y Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[ophys\"][\"ophys_motion_correction_y\"].timestamps\"</td>\n",
       "      <td>Array of timestamps for the motion correction arrays</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>176</th>\n",
       "      <td>processing</td>\n",
       "      <td>Stimulus Timestamps Comments</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[stimulus\"][\"timestamps\"].comments\"</td>\n",
       "      <td>Comments</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>177</th>\n",
       "      <td>processing</td>\n",
       "      <td>Stimulus Timestamps Conversion</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[stimulus\"][\"timestamps\"].conversion\"</td>\n",
       "      <td>Scalar to multiply each element in data to convert it to the specified unit</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>178</th>\n",
       "      <td>processing</td>\n",
       "      <td>Stimulus Timestamps Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[stimulus\"][\"timestamps\"].description\"</td>\n",
       "      <td>Description</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>179</th>\n",
       "      <td>processing</td>\n",
       "      <td>Stimulus Timestamps Interval</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[stimulus\"][\"timestamps\"].interval\"</td>\n",
       "      <td>Unexplained</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>180</th>\n",
       "      <td>processing</td>\n",
       "      <td>Stimulus Timestamps Offset</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[stimulus\"][\"timestamps\"].offset\"</td>\n",
       "      <td>Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>181</th>\n",
       "      <td>processing</td>\n",
       "      <td>Stimulus Timestamps Resolution</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[stimulus\"][\"timestamps\"].resolution\"</td>\n",
       "      <td>The smallest meaningful difference (in specified unit) between values in data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>182</th>\n",
       "      <td>processing</td>\n",
       "      <td>Stimulus Timestamps Timestamps Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[stimulus\"][\"timestamps\"].timestamps_unit\"</td>\n",
       "      <td>Name of the unit for the timestamps</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>183</th>\n",
       "      <td>processing</td>\n",
       "      <td>Stimulus Timestamps Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[stimulus\"][\"timestamps\"].unit\"</td>\n",
       "      <td>Name of the unit for the data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>184</th>\n",
       "      <td>processing</td>\n",
       "      <td>Stimulus Timestamps Data</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[stimulus\"][\"timestamps\"].data\"</td>\n",
       "      <td>Array of all the screen refresh timestamps during the session. Identical to Stimulus Timestamps</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>185</th>\n",
       "      <td>processing</td>\n",
       "      <td>Stimulus Timestamps Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[stimulus\"][\"timestamps\"].timestamps\"</td>\n",
       "      <td>Array of all the screen refresh timestamps during the session. Identical to Stimulus Timestamps</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>186</th>\n",
       "      <td>processing</td>\n",
       "      <td>Ophys Stimulus Timestamps Comments</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[ophys_stimulus\"][\"timestamps\"].comments\"</td>\n",
       "      <td>Comments</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>187</th>\n",
       "      <td>processing</td>\n",
       "      <td>Ophys Stimulus Timestamps Conversion</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[ophys_stimulus\"][\"timestamps\"].conversion\"</td>\n",
       "      <td>Scalar to multiply each element in data to convert it to the specified unit</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>188</th>\n",
       "      <td>processing</td>\n",
       "      <td>Ophys Stimulus Timestamps Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[ophys_stimulus\"][\"timestamps\"].description\"</td>\n",
       "      <td>Description</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>189</th>\n",
       "      <td>processing</td>\n",
       "      <td>Ophys Stimulus Timestamps Interval</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[ophys_stimulus\"][\"timestamps\"].interval\"</td>\n",
       "      <td>Unexplained</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>190</th>\n",
       "      <td>processing</td>\n",
       "      <td>Ophys Stimulus Timestamps Offset</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[ophys_stimulus\"][\"timestamps\"].offset\"</td>\n",
       "      <td>Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>191</th>\n",
       "      <td>processing</td>\n",
       "      <td>Ophys Stimulus Timestamps Resolution</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[ophys_stimulus\"][\"timestamps\"].resolution\"</td>\n",
       "      <td>The smallest meaningful difference (in specified unit) between values in data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>192</th>\n",
       "      <td>processing</td>\n",
       "      <td>Ophys Stimulus Timestamps Timestamps Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[ophys_stimulus\"][\"timestamps\"].timestamps_unit\"</td>\n",
       "      <td>Name of the unit for the timestamps</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>193</th>\n",
       "      <td>processing</td>\n",
       "      <td>Ophys Stimulus Timestamps Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[ophys_stimulus\"][\"timestamps\"].unit\"</td>\n",
       "      <td>Name of the unit for the data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>194</th>\n",
       "      <td>processing</td>\n",
       "      <td>Ophys Stimulus Timestamps Data</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[stimulus_ophys\"][\"timestamps\"].data\"</td>\n",
       "      <td>Timestamps associated with all visual stimuli presented on the strimulation screen.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>195</th>\n",
       "      <td>processing</td>\n",
       "      <td>Ophys Stimulus Timestamps Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[stimulus_ophys\"][\"timestamps\"].timestamps\"</td>\n",
       "      <td>Timestamps associated with all visual stimuli presented on the strimulation screen.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>196</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running DX Comments</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[running\"][\"dx\"].comments\"</td>\n",
       "      <td>Comments</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>197</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running DX Conversion</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[running\"][\"dx\"].conversion\"</td>\n",
       "      <td>Scalar to multiply each element in data to convert it to the specified unit</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>198</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running DX Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[running\"][\"dx\"].description\"</td>\n",
       "      <td>Description</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>199</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running DX Interval</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[running\"][\"dx\"].interval\"</td>\n",
       "      <td>Unexplained</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>200</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running DX Offset</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[running\"][\"dx\"].offset\"</td>\n",
       "      <td>Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>201</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running DX Resolution</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[running\"][\"dx\"].resolution\"</td>\n",
       "      <td>The smallest meaningful difference (in specified unit) between values in data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>202</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running DX Timestamps Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[running\"][\"dx\"].timestamps_unit\"</td>\n",
       "      <td>Name of the unit for the timestamps</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>203</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running DX Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[running\"][\"dx\"].unit\"</td>\n",
       "      <td>Name of the unit for the data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>204</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running DX Data</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[running\"][\"dx\"].data\"</td>\n",
       "      <td>Array of differences, in degrees, between current and last wheel position</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>205</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running DX Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[running\"][\"dx\"].timestamps\"</td>\n",
       "      <td>Array of timestamps for the dx array</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>206</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed Comments</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[running\"][\"speed\"].comments\"</td>\n",
       "      <td>Comments</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>207</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed Conversion</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[running\"][\"speed\"].conversion\"</td>\n",
       "      <td>Scalar to multiply each element in data to convert it to the specified unit</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>208</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[running\"][\"speed\"].description\"</td>\n",
       "      <td>Description</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>209</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed Interval</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[running\"][\"speed\"].interval\"</td>\n",
       "      <td>Unexplained</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>210</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed Offset</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[running\"][\"speed\"].offset\"</td>\n",
       "      <td>Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>211</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed Resolution</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[running\"][\"speed\"].resolution\"</td>\n",
       "      <td>The smallest meaningful difference (in specified unit) between values in data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>212</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed Timestamps Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[running\"][\"speed\"].timestamps_unit\"</td>\n",
       "      <td>Name of the unit for the timestamps</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>213</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[running\"][\"speed\"].unit\"</td>\n",
       "      <td>Name of the unit for the data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>214</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed Data</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[running\"][\"speed\"].data\"</td>\n",
       "      <td>Speed of the running wheel, measured at each timestamps. The data is filtered with a low-pass filter to remove noise artifacts (cm/s).</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>215</th>\n",
       "      <td>processing</td>\n",
       "      <td>Running Speed Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[running\"][\"speed\"].timestamps\"</td>\n",
       "      <td>Timestamps of the running speed.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>216</th>\n",
       "      <td>processing</td>\n",
       "      <td>Unfiltered Running Speed Comments</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[running\"][\"speed_unfiltered\"].comments\"</td>\n",
       "      <td>Comments</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>217</th>\n",
       "      <td>processing</td>\n",
       "      <td>Unfiltered Running Speed Conversion</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[running\"][\"speed_unfiltered\"].conversion\"</td>\n",
       "      <td>Scalar to multiply each element in data to convert it to the specified unit</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>218</th>\n",
       "      <td>processing</td>\n",
       "      <td>Unfiltered Running Speed Description</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[running\"][\"speed_unfiltered\"].description\"</td>\n",
       "      <td>Description</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>219</th>\n",
       "      <td>processing</td>\n",
       "      <td>Unfiltered Running Speed Interval</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[running\"][\"speed_unfiltered\"].interval\"</td>\n",
       "      <td>Unexplained</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>220</th>\n",
       "      <td>processing</td>\n",
       "      <td>Unfiltered Running Speed Offset</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[running\"][\"speed_unfiltered\"].offset\"</td>\n",
       "      <td>Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>221</th>\n",
       "      <td>processing</td>\n",
       "      <td>Unfiltered Running Speed Resolution</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.processing[running\"][\"speed_unfiltered\"].resolution\"</td>\n",
       "      <td>The smallest meaningful difference (in specified unit) between values in data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>222</th>\n",
       "      <td>processing</td>\n",
       "      <td>Unfiltered Running Speed Timestamps Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[running\"][\"speed_unfiltered\"].timestamps_unit\"</td>\n",
       "      <td>Name of the unit for the timestamps</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>223</th>\n",
       "      <td>processing</td>\n",
       "      <td>Unfiltered Running Speed Unit</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.processing[running\"][\"speed_unfiltered\"].unit\"</td>\n",
       "      <td>Name of the unit for the data</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>224</th>\n",
       "      <td>processing</td>\n",
       "      <td>Unfiltered Running Speed Data</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[running\"][\"speed_unfiltered\"].data\"</td>\n",
       "      <td>Speed of the running wheel, measured at each timestamps. The data is raw (cm/s).</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>225</th>\n",
       "      <td>processing</td>\n",
       "      <td>Unfiltered Running Speed Timestamps</td>\n",
       "      <td>array</td>\n",
       "      <td>nwb.processing[running\"][\"speed_unfiltered\"].timestamps\"</td>\n",
       "      <td>Timestamps of the unfiltered running speed.</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>226</th>\n",
       "      <td>subject</td>\n",
       "      <td>Subject Age</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.subject.age</td>\n",
       "      <td>Age of the subject</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>227</th>\n",
       "      <td>subject</td>\n",
       "      <td>Subject Age in Days</td>\n",
       "      <td>number</td>\n",
       "      <td>nwb.subject.age_in_days</td>\n",
       "      <td>Age of the subject, in days</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>228</th>\n",
       "      <td>subject</td>\n",
       "      <td>Subject Genotype</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.subject.genotype</td>\n",
       "      <td>Genotype of the subject</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>229</th>\n",
       "      <td>subject</td>\n",
       "      <td>Subject Sex</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.subject.sex</td>\n",
       "      <td>Sex of the subject, M or F</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>230</th>\n",
       "      <td>subject</td>\n",
       "      <td>Subject Species</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.subject.species</td>\n",
       "      <td>Species of the subject</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>231</th>\n",
       "      <td>subject</td>\n",
       "      <td>Subject Specimen Name</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.subject.specimen_name</td>\n",
       "      <td>Specimen name of the subject</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>232</th>\n",
       "      <td>subject</td>\n",
       "      <td>Subject Strain</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.subject.strain</td>\n",
       "      <td>Strain of the subject</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>233</th>\n",
       "      <td>subject</td>\n",
       "      <td>Subject ID</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.subject.subject_id</td>\n",
       "      <td>Unique identifier of the subject</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>234</th>\n",
       "      <td>subject</td>\n",
       "      <td>Subject Strain</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.subject.strain</td>\n",
       "      <td>Strain of the subject</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>235</th>\n",
       "      <td>subject</td>\n",
       "      <td>Subject ID</td>\n",
       "      <td>string</td>\n",
       "      <td>nwb.subject.subject_id</td>\n",
       "      <td>Unique identifier of the subject</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "</div>"
      ],
      "text/plain": [
       "              Section                                        Field  \\\n",
       "0    NaN               Session Description                           \n",
       "1    NaN               Session Identifier                            \n",
       "2    NaN               Session Start Time                            \n",
       "3    NaN               Reference Time                                \n",
       "4    NaN               Experiment Description                        \n",
       "5    NaN               Institution                                   \n",
       "6    acquisition       Corneal Reflection Tracking Comments          \n",
       "7    acquisition       Corneal Reflection Tracking Conversion        \n",
       "8    acquisition       Corneal Reflection Tracking Description       \n",
       "9    acquisition       Corneal Reflection Tracking Interval          \n",
       "10   acquisition       Corneal Reflection Tracking Offset            \n",
       "11   acquisition       Corneal Reflection Tracking Reference Frame   \n",
       "12   acquisition       Corneal Reflection Tracking Resolution        \n",
       "13   acquisition       Corneal Reflection Tracking Unit              \n",
       "14   acquisition       Corneal Reflection Tracking Angle             \n",
       "15   acquisition       Corneal Reflection Tracking Height            \n",
       "16   acquisition       Corneal Reflection Tracking Width             \n",
       "17   acquisition       Corneal Reflection Tracking Area              \n",
       "18   acquisition       Corneal Reflection Tracking Raw Area          \n",
       "19   acquisition       Corneal Reflection Tracking Data              \n",
       "20   acquisition       Corneal Reflection Tracking Timestamps        \n",
       "21   acquisition       Eye Tracking Tracking Comments                \n",
       "22   acquisition       Eye Tracking Conversion                       \n",
       "23   acquisition       Eye Tracking Description                      \n",
       "24   acquisition       Eye Tracking Interval                         \n",
       "25   acquisition       Eye Tracking Offset                           \n",
       "26   acquisition       Eye Tracking Reference Frame                  \n",
       "27   acquisition       Eye Tracking Resolution                       \n",
       "28   acquisition       Eye Tracking Unit                             \n",
       "29   acquisition       Eye Tracking Angle                            \n",
       "30   acquisition       Eye Tracking Height                           \n",
       "31   acquisition       Eye Tracking Width                            \n",
       "32   acquisition       Eye Tracking Area                             \n",
       "33   acquisition       Eye Tracking Raw Area                         \n",
       "34   acquisition       Eye Tracking Data                             \n",
       "35   acquisition       Eye Tracking Timestamps                       \n",
       "36   acquisition       Eye Tracking Tracking Comments                \n",
       "37   acquisition       Eye Tracking Conversion                       \n",
       "38   acquisition       Eye Tracking Description                      \n",
       "39   acquisition       Eye Tracking Interval                         \n",
       "40   acquisition       Eye Tracking Offset                           \n",
       "41   acquisition       Eye Tracking Reference Frame                  \n",
       "42   acquisition       Eye Tracking Resolution                       \n",
       "43   acquisition       Eye Tracking Unit                             \n",
       "44   acquisition       Pupil Tracking Angle                          \n",
       "45   acquisition       Pupil Tracking Height                         \n",
       "46   acquisition       Pupil Tracking Width                          \n",
       "47   acquisition       Pupil Tracking Area                           \n",
       "48   acquisition       Pupil Tracking Raw Area                       \n",
       "49   acquisition       Pupil Tracking Data                           \n",
       "50   acquisition       Pupil Tracking Timestamps                     \n",
       "51   acquisition       Blink Times                                   \n",
       "52   acquisition       Blink Times Timestamps                        \n",
       "53   acquisition       2P Movie Data                                 \n",
       "54   acquisition       2P Movie Timestamps                           \n",
       "55   acquisition       2P Movie Rate                                 \n",
       "56   acquisition       2P Movie Device                               \n",
       "57   acquisition       2P Movie Imaging Plane                        \n",
       "58   acquisition       Input Voltage Comments                        \n",
       "59   acquisition       Input Voltage Conversion                      \n",
       "60   acquisition       Input Voltage Description                     \n",
       "61   acquisition       Input Voltage Interval                        \n",
       "62   acquisition       Input Voltage Offset                          \n",
       "63   acquisition       Input Voltage Resolution                      \n",
       "64   acquisition       Input Voltage Timestamps Unit                 \n",
       "65   acquisition       Input Voltage Unit                            \n",
       "66   acquisition       Input Voltage Data                            \n",
       "67   acquisition       Input Voltage Timestamps                      \n",
       "68   acquisition       Signal Voltage Comments                       \n",
       "69   acquisition       Signal Voltage Conversion                     \n",
       "70   acquisition       Signal Voltage Description                    \n",
       "71   acquisition       Signal Voltage Interval                       \n",
       "72   acquisition       Signal Voltage Offset                         \n",
       "73   acquisition       Signal Voltage Resolution                     \n",
       "74   acquisition       Signal Voltage Timestamps Unit                \n",
       "75   acquisition       Signal Voltage Unit                           \n",
       "76   acquisition       Signal Voltage Data                           \n",
       "77   acquisition       Signal Voltage Timestamps                     \n",
       "78   devices           Device description                            \n",
       "79   file_create_date  File Creation Date                            \n",
       "80   imaging_planes    Imaging Plane Description                     \n",
       "81   imaging_planes    Imaging Plane Excitation Lambda               \n",
       "82   imaging_planes    Imaging Plane Imaging Rate                    \n",
       "83   imaging_planes    Imaging Plane Indicator                       \n",
       "84   imaging_planes    Imaging Plane Location                        \n",
       "85   imaging_planes    Imaging Plane Optical Channel                 \n",
       "86   imaging_planes    Imaging Plane Unit                            \n",
       "87   intervals         Stimulus Intervals Column Names               \n",
       "88   intervals         Stimulus Interval IDs                         \n",
       "89   intervals         Stimulus Interval Start Times                 \n",
       "90   intervals         Stimulus Interval Stop Times                  \n",
       "91   intervals         Stimulus Interval Stimulus Names              \n",
       "92   intervals         Stimulus Interval Stimulus Blocks             \n",
       "93   intervals         Stimulus Interval Stimulus Frames             \n",
       "94   intervals         Stimulus Interval Stimulus Indices            \n",
       "95   intervals         Stimulus Interval Tags                        \n",
       "96   intervals         Stimulus Interval Timeseries Link             \n",
       "97   intervals         Stimulus Intervals Description                \n",
       "98   lab_meta_data     Experiment Container ID                       \n",
       "99   lab_meta_data     FOV Width                                     \n",
       "100  lab_meta_data     FOV Height                                    \n",
       "101  lab_meta_data     Imaging Depth                                 \n",
       "102  lab_meta_data     Imaging Plane Group                           \n",
       "103  lab_meta_data     Imaging Plane Group Count                     \n",
       "104  lab_meta_data     Ophys Experiment ID                           \n",
       "105  lab_meta_data     Ophys Session ID                              \n",
       "106  processing        Fluorescence Trace Comments                   \n",
       "107  processing        Fluorescence Trace Conversion                 \n",
       "108  processing        Fluorescence Trace Description                \n",
       "109  processing        Fluorescence Trace Interval                   \n",
       "110  processing        Fluorescence Trace Offset                     \n",
       "111  processing        Fluorescence Trace Resolution                 \n",
       "112  processing        Fluorescence Trace Timestamps Unit            \n",
       "113  processing        Fluorescence Trace Unit                       \n",
       "114  processing        Fluorescence Trace Data                       \n",
       "115  processing        Fluorescence Trace Timestamps                 \n",
       "116  processing        DFF Trace Comments                            \n",
       "117  processing        DFF Trace Conversion                          \n",
       "118  processing        DFF Trace Description                         \n",
       "119  processing        DFF Trace Interval                            \n",
       "120  processing        DFF Trace Offset                              \n",
       "121  processing        DFF Trace Resolution                          \n",
       "122  processing        DFF Trace Timestamps Unit                     \n",
       "123  processing        DFF Trace Unit                                \n",
       "124  processing        DFF Trace Data                                \n",
       "125  processing        DFF Trace Timestamps                          \n",
       "126  processing        Event Detection Comments                      \n",
       "127  processing        Event Detection Conversion                    \n",
       "128  processing        Event Detection Description                   \n",
       "129  processing        Event Detection Interval                      \n",
       "130  processing        Event Detection Offset                        \n",
       "131  processing        Event Detection Resolution                    \n",
       "132  processing        Event Detection Timestamps Unit               \n",
       "133  processing        Event Detection Unit                          \n",
       "134  processing        Event Detection Data                          \n",
       "135  processing        Event Detection Timestamps                    \n",
       "136  processing        Event Detection Lambdas                       \n",
       "137  processing        Event Detection Standard Deviation            \n",
       "138  processing        ROI Table Column Names                        \n",
       "139  processing        ROI IDs                                       \n",
       "140  processing        ROI Cell Specimen IDs                         \n",
       "141  processing        ROI Heights                                   \n",
       "142  processing        ROI Mask Image Planes                         \n",
       "143  processing        ROI Max Corrections Down                      \n",
       "144  processing        ROI Max Corrections Left                      \n",
       "145  processing        ROI Max Corrections Up                        \n",
       "146  processing        ROI Max Corrections Right                     \n",
       "147  processing        ROI Valid Flags                               \n",
       "148  processing        ROI Widths                                    \n",
       "149  processing        ROI X Coordinates                             \n",
       "150  processing        ROI Y Coordinates                             \n",
       "151  processing        ROI Image Masks                               \n",
       "152  processing        2P Image Description                          \n",
       "153  processing        2P Average Image                              \n",
       "154  processing        2P Max Projection                             \n",
       "155  processing        2P Segmentation Mask                          \n",
       "156  processing        Ophys Motion Correction X Comments            \n",
       "157  processing        Ophys Motion Correction X Conversion          \n",
       "158  processing        Ophys Motion Correction X Description         \n",
       "159  processing        Ophys Motion Correction X Interval            \n",
       "160  processing        Ophys Motion Correction X Offset              \n",
       "161  processing        Ophys Motion Correction X Resolution          \n",
       "162  processing        Ophys Motion Correction X Timestamps Unit     \n",
       "163  processing        Ophys Motion Correction X Unit                \n",
       "164  processing        Motion Correction X Data                      \n",
       "165  processing        Motion Correction X Timestamps                \n",
       "166  processing        Ophys Motion Correction Y Comments            \n",
       "167  processing        Ophys Motion Correction Y Conversion          \n",
       "168  processing        Ophys Motion Correction Y Description         \n",
       "169  processing        Ophys Motion Correction Y Interval            \n",
       "170  processing        Ophys Motion Correction Y Offset              \n",
       "171  processing        Ophys Motion Correction Y Resolution          \n",
       "172  processing        Ophys Motion Correction Y Timestamps Unit     \n",
       "173  processing        Ophys Motion Correction Y Unit                \n",
       "174  processing        Motion Correction Y Data                      \n",
       "175  processing        Motion Correction Y Timestamps                \n",
       "176  processing        Stimulus Timestamps Comments                  \n",
       "177  processing        Stimulus Timestamps Conversion                \n",
       "178  processing        Stimulus Timestamps Description               \n",
       "179  processing        Stimulus Timestamps Interval                  \n",
       "180  processing        Stimulus Timestamps Offset                    \n",
       "181  processing        Stimulus Timestamps Resolution                \n",
       "182  processing        Stimulus Timestamps Timestamps Unit           \n",
       "183  processing        Stimulus Timestamps Unit                      \n",
       "184  processing        Stimulus Timestamps Data                      \n",
       "185  processing        Stimulus Timestamps Timestamps                \n",
       "186  processing        Ophys Stimulus Timestamps Comments            \n",
       "187  processing        Ophys Stimulus Timestamps Conversion          \n",
       "188  processing        Ophys Stimulus Timestamps Description         \n",
       "189  processing        Ophys Stimulus Timestamps Interval            \n",
       "190  processing        Ophys Stimulus Timestamps Offset              \n",
       "191  processing        Ophys Stimulus Timestamps Resolution          \n",
       "192  processing        Ophys Stimulus Timestamps Timestamps Unit     \n",
       "193  processing        Ophys Stimulus Timestamps Unit                \n",
       "194  processing        Ophys Stimulus Timestamps Data                \n",
       "195  processing        Ophys Stimulus Timestamps Timestamps          \n",
       "196  processing        Running DX Comments                           \n",
       "197  processing        Running DX Conversion                         \n",
       "198  processing        Running DX Description                        \n",
       "199  processing        Running DX Interval                           \n",
       "200  processing        Running DX Offset                             \n",
       "201  processing        Running DX Resolution                         \n",
       "202  processing        Running DX Timestamps Unit                    \n",
       "203  processing        Running DX Unit                               \n",
       "204  processing        Running DX Data                               \n",
       "205  processing        Running DX Timestamps                         \n",
       "206  processing        Running Speed Comments                        \n",
       "207  processing        Running Speed Conversion                      \n",
       "208  processing        Running Speed Description                     \n",
       "209  processing        Running Speed Interval                        \n",
       "210  processing        Running Speed Offset                          \n",
       "211  processing        Running Speed Resolution                      \n",
       "212  processing        Running Speed Timestamps Unit                 \n",
       "213  processing        Running Speed Unit                            \n",
       "214  processing        Running Speed Data                            \n",
       "215  processing        Running Speed Timestamps                      \n",
       "216  processing        Unfiltered Running Speed Comments             \n",
       "217  processing        Unfiltered Running Speed Conversion           \n",
       "218  processing        Unfiltered Running Speed Description          \n",
       "219  processing        Unfiltered Running Speed Interval             \n",
       "220  processing        Unfiltered Running Speed Offset               \n",
       "221  processing        Unfiltered Running Speed Resolution           \n",
       "222  processing        Unfiltered Running Speed Timestamps Unit      \n",
       "223  processing        Unfiltered Running Speed Unit                 \n",
       "224  processing        Unfiltered Running Speed Data                 \n",
       "225  processing        Unfiltered Running Speed Timestamps           \n",
       "226  subject           Subject Age                                   \n",
       "227  subject           Subject Age in Days                           \n",
       "228  subject           Subject Genotype                              \n",
       "229  subject           Subject Sex                                   \n",
       "230  subject           Subject Species                               \n",
       "231  subject           Subject Specimen Name                         \n",
       "232  subject           Subject Strain                                \n",
       "233  subject           Subject ID                                    \n",
       "234  subject           Subject Strain                                \n",
       "235  subject           Subject ID                                    \n",
       "\n",
       "               Type  \\\n",
       "0    string           \n",
       "1    string           \n",
       "2    datetime         \n",
       "3    datetime         \n",
       "4    string           \n",
       "5    string           \n",
       "6    string           \n",
       "7    number           \n",
       "8    string           \n",
       "9    number           \n",
       "10   number           \n",
       "11   string           \n",
       "12   number           \n",
       "13   string           \n",
       "14   array            \n",
       "15   array            \n",
       "16   array            \n",
       "17   array            \n",
       "18   array            \n",
       "19   array            \n",
       "20   array            \n",
       "21   string           \n",
       "22   number           \n",
       "23   string           \n",
       "24   number           \n",
       "25   number           \n",
       "26   string           \n",
       "27   number           \n",
       "28   string           \n",
       "29   array            \n",
       "30   array            \n",
       "31   array            \n",
       "32   array            \n",
       "33   array            \n",
       "34   array            \n",
       "35   array            \n",
       "36   string           \n",
       "37   number           \n",
       "38   string           \n",
       "39   number           \n",
       "40   number           \n",
       "41   string           \n",
       "42   number           \n",
       "43   string           \n",
       "44   array            \n",
       "45   array            \n",
       "46   array            \n",
       "47   array            \n",
       "48   array            \n",
       "49   array            \n",
       "50   array            \n",
       "51   array            \n",
       "52   array            \n",
       "53   array            \n",
       "54   array            \n",
       "55   number           \n",
       "56   Device           \n",
       "57   number           \n",
       "58   string           \n",
       "59   number           \n",
       "60   string           \n",
       "61   number           \n",
       "62   number           \n",
       "63   number           \n",
       "64   string           \n",
       "65   string           \n",
       "66   array            \n",
       "67   array            \n",
       "68   string           \n",
       "69   number           \n",
       "70   string           \n",
       "71   number           \n",
       "72   number           \n",
       "73   number           \n",
       "74   string           \n",
       "75   string           \n",
       "76   array            \n",
       "77   array            \n",
       "78   string           \n",
       "79   number           \n",
       "80   string           \n",
       "81   number           \n",
       "82   number           \n",
       "83   string           \n",
       "84   string           \n",
       "85   OpticalChannel   \n",
       "86   string           \n",
       "87   array            \n",
       "88   array            \n",
       "89   array            \n",
       "90   array            \n",
       "91   array            \n",
       "92   array            \n",
       "93   array            \n",
       "94   array            \n",
       "95   array            \n",
       "96   array            \n",
       "97   string           \n",
       "98   number           \n",
       "99   number           \n",
       "100  number           \n",
       "101  number           \n",
       "102  number           \n",
       "103  number           \n",
       "104  number           \n",
       "105  number           \n",
       "106  string           \n",
       "107  number           \n",
       "108  string           \n",
       "109  number           \n",
       "110  number           \n",
       "111  number           \n",
       "112  string           \n",
       "113  string           \n",
       "114  array            \n",
       "115  array            \n",
       "116  string           \n",
       "117  number           \n",
       "118  string           \n",
       "119  number           \n",
       "120  number           \n",
       "121  number           \n",
       "122  string           \n",
       "123  string           \n",
       "124  array            \n",
       "125  array            \n",
       "126  string           \n",
       "127  number           \n",
       "128  string           \n",
       "129  number           \n",
       "130  number           \n",
       "131  number           \n",
       "132  string           \n",
       "133  string           \n",
       "134  array            \n",
       "135  array            \n",
       "136  array            \n",
       "137  array            \n",
       "138  array            \n",
       "139  array            \n",
       "140  array            \n",
       "141  array            \n",
       "142  array            \n",
       "143  array            \n",
       "144  array            \n",
       "145  array            \n",
       "146  array            \n",
       "147  array            \n",
       "148  array            \n",
       "149  array            \n",
       "150  array            \n",
       "151  array            \n",
       "152  string           \n",
       "153  GrayscaleImage   \n",
       "154  GrayscaleImage   \n",
       "155  GrayscaleImage   \n",
       "156  string           \n",
       "157  number           \n",
       "158  string           \n",
       "159  number           \n",
       "160  number           \n",
       "161  number           \n",
       "162  unit             \n",
       "163  string           \n",
       "164  array            \n",
       "165  array            \n",
       "166  string           \n",
       "167  number           \n",
       "168  string           \n",
       "169  number           \n",
       "170  number           \n",
       "171  number           \n",
       "172  string           \n",
       "173  string           \n",
       "174  array            \n",
       "175  array            \n",
       "176  string           \n",
       "177  number           \n",
       "178  string           \n",
       "179  number           \n",
       "180  number           \n",
       "181  number           \n",
       "182  string           \n",
       "183  string           \n",
       "184  array            \n",
       "185  array            \n",
       "186  string           \n",
       "187  number           \n",
       "188  string           \n",
       "189  number           \n",
       "190  number           \n",
       "191  number           \n",
       "192  string           \n",
       "193  string           \n",
       "194  array            \n",
       "195  array            \n",
       "196  string           \n",
       "197  number           \n",
       "198  string           \n",
       "199  number           \n",
       "200  number           \n",
       "201  number           \n",
       "202  string           \n",
       "203  string           \n",
       "204  array            \n",
       "205  array            \n",
       "206  string           \n",
       "207  number           \n",
       "208  string           \n",
       "209  number           \n",
       "210  number           \n",
       "211  number           \n",
       "212  string           \n",
       "213  string           \n",
       "214  array            \n",
       "215  array            \n",
       "216  string           \n",
       "217  number           \n",
       "218  string           \n",
       "219  number           \n",
       "220  number           \n",
       "221  number           \n",
       "222  string           \n",
       "223  string           \n",
       "224  array            \n",
       "225  array            \n",
       "226  number           \n",
       "227  number           \n",
       "228  string           \n",
       "229  string           \n",
       "230  string           \n",
       "231  string           \n",
       "232  string           \n",
       "233  string           \n",
       "234  string           \n",
       "235  string           \n",
       "\n",
       "                                                                                                Path  \\\n",
       "0    nwb.session_description                                                                           \n",
       "1    nwb.identifier                                                                                    \n",
       "2    nwb.session_start_time                                                                            \n",
       "3    nwb.timestamps_reference_time                                                                     \n",
       "4    nwb.experiment_description                                                                        \n",
       "5    nwb.institution                                                                                   \n",
       "6    nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.comments\"                               \n",
       "7    nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.conversion\"                             \n",
       "8    nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.description\"                            \n",
       "9    nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.interval\"                               \n",
       "10   nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.offset\"                                 \n",
       "11   nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.reference_frame\"                        \n",
       "12   nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.resolution\"                             \n",
       "13   nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.unit\"                                   \n",
       "14   nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.angle\"                                  \n",
       "15   nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.height\"                                 \n",
       "16   nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.width\"                                  \n",
       "17   nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.area\"                                   \n",
       "18   nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.area_raw\"                               \n",
       "19   nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.data\"                                   \n",
       "20   nwb.acquisition[EyeTracking\"].corneal_reflection_tracking.timestamps\"                             \n",
       "21   nwb.acquisition[EyeTracking\"].eye_tracking.comments\"                                              \n",
       "22   nwb.acquisition[EyeTracking\"].eye_tracking.conversion\"                                            \n",
       "23   nwb.acquisition[EyeTracking\"].eye_tracking.description\"                                           \n",
       "24   nwb.acquisition[EyeTracking\"].eye_tracking.interval\"                                              \n",
       "25   nwb.acquisition[EyeTracking\"].eye_tracking.offset\"                                                \n",
       "26   nwb.acquisition[EyeTracking\"].eye_tracking.reference_frame\"                                       \n",
       "27   nwb.acquisition[EyeTracking\"].eye_tracking.resolution\"                                            \n",
       "28   nwb.acquisition[EyeTracking\"].eye_tracking.unit\"                                                  \n",
       "29   nwb.acquisition[EyeTracking\"].eye_tracking.angle\"                                                 \n",
       "30   nwb.acquisition[EyeTracking\"].eye_tracking.height\"                                                \n",
       "31   nwb.acquisition[EyeTracking\"].eye_tracking.width\"                                                 \n",
       "32   nwb.acquisition[EyeTracking\"].eye_tracking.area\"                                                  \n",
       "33   nwb.acquisition[EyeTracking\"].eye_tracking.area_raw\"                                              \n",
       "34   nwb.acquisition[EyeTracking\"].eye_tracking.data\"                                                  \n",
       "35   nwb.acquisition[EyeTracking\"].eye_tracking.timestamps\"                                            \n",
       "36   nwb.acquisition[EyeTracking\"].pupil_tracking.comments\"                                            \n",
       "37   nwb.acquisition[EyeTracking\"].pupil_tracking.conversion\"                                          \n",
       "38   nwb.acquisition[EyeTracking\"].pupil_tracking.description\"                                         \n",
       "39   nwb.acquisition[EyeTracking\"].pupil_tracking.interval\"                                            \n",
       "40   nwb.acquisition[EyeTracking\"].pupil_tracking.offset\"                                              \n",
       "41   nwb.acquisition[EyeTracking\"].pupil_tracking.reference_frame\"                                     \n",
       "42   nwb.acquisition[EyeTracking\"].pupil_tracking.resolution\"                                          \n",
       "43   nwb.acquisition[EyeTracking\"].pupil_tracking.unit\"                                                \n",
       "44   nwb.acquisition[EyeTracking\"].pupil_tracking.angle\"                                               \n",
       "45   nwb.acquisition[EyeTracking\"].pupil_tracking.height\"                                              \n",
       "46   nwb.acquisition[EyeTracking\"].pupil_tracking.width\"                                               \n",
       "47   nwb.acquisition[EyeTracking\"].pupil_tracking.area\"                                                \n",
       "48   nwb.acquisition[EyeTracking\"].pupil_tracking.area_raw\"                                            \n",
       "49   nwb.acquisition[EyeTracking\"].pupil_tracking.data\"                                                \n",
       "50   nwb.acquisition[EyeTracking\"].pupil_tracking.timestamps\"                                          \n",
       "51   nwb.acquisition[EyeTracking\"].likely_blink.data\"                                                  \n",
       "52   nwb.acquisition[EyeTracking\"].likely_blink.timestamps\"                                            \n",
       "53   nwb.acquisition[raw_suite2p_motion_corrected\"].data\"                                              \n",
       "54   nwb.acquisition[raw_suite2p_motion_corrected\"].timestamps\"                                        \n",
       "55   nwb.acquisition[raw_suite2p_motion_corrected\"].rate\"                                              \n",
       "56   nwb.acquisition[raw_suite2p_motion_corrected\"].device\"                                            \n",
       "57   nwb.acquisition[raw_suite2p_motion_corrected\"].imaging_plane\"                                     \n",
       "58   nwb.acquisition[v_in\"].comments\"                                                                  \n",
       "59   nwb.acquisition[v_in\"].conversion\"                                                                \n",
       "60   nwb.acquisition[v_in\"].description\"                                                               \n",
       "61   nwb.acquisition[v_in\"].interval\"                                                                  \n",
       "62   nwb.acquisition[v_in\"].offset\"                                                                    \n",
       "63   nwb.acquisition[v_in\"].resolution\"                                                                \n",
       "64   nwb.acquisition[v_in\"].timestamps_unit\"                                                           \n",
       "65   nwb.acquisition[v_in\"].unit\"                                                                      \n",
       "66   nwb.acquisition[v_in\"].data\"                                                                      \n",
       "67   nwb.acquisition[v_in\"].timestamps\"                                                                \n",
       "68   nwb.acquisition[v_sig\"].comments\"                                                                 \n",
       "69   nwb.acquisition[v_sig\"].conversion\"                                                               \n",
       "70   nwb.acquisition[v_sig\"].description\"                                                              \n",
       "71   nwb.acquisition[v_sig\"].interval\"                                                                 \n",
       "72   nwb.acquisition[v_sig\"].offset\"                                                                   \n",
       "73   nwb.acquisition[v_sig\"].resolution\"                                                               \n",
       "74   nwb.acquisition[v_sig\"].timestamps_unit\"                                                          \n",
       "75   nwb.acquisition[v_sig\"].unit\"                                                                     \n",
       "76   nwb.acquisition[v_sig\"].dat\"                                                                      \n",
       "77   nwb.acquisition[v_sig\"].timestamps\"                                                               \n",
       "78   nwb.devices[device_name].description                                                              \n",
       "79   nwb.file_create_date                                                                              \n",
       "80   nwb.imaging_planes[imaging_plane_name].description                                                \n",
       "81   nwb.imaging_planes[imaging_plane_name].excitation_lambda                                          \n",
       "82   nwb.imaging_planes[imaging_plane_name].imaging_rate                                               \n",
       "83   nwb.imaging_planes[imaging_plane_name].indicator                                                  \n",
       "84   nwb.imaging_planes[imaging_plane_name].location                                                   \n",
       "85   nwb.imaging_planes[imaging_plane_name].optical_channel                                            \n",
       "86   nwb.imaging_planes[imaging_plane_name].unit                                                       \n",
       "87   nwb.intervals[stimulus].colnames                                                                  \n",
       "88   nwb.intervals[stimulus].id                                                                        \n",
       "89   nwb.intervals[stimulus].start_time                                                                \n",
       "90   nwb.intervals[stimulus].stop_time                                                                 \n",
       "91   nwb.intervals[stimulus].stimulus_name                                                             \n",
       "92   nwb.intervals[stimulus].stimulus_block                                                            \n",
       "93   nwb.intervals[stimulus].frame                                                                     \n",
       "94   nwb.intervals[stimulus].stimulus_index                                                            \n",
       "95   nwb.intervals[stimulus].tags                                                                      \n",
       "96   nwb.intervals[stimulus].timeseries                                                                \n",
       "97   nwb.intervals[stimulus].description                                                               \n",
       "98   nwb.lab_meta_data[metadata\"].experiment_container_id\"                                             \n",
       "99   nwb.lab_meta_data[metadata\"].field_of_view_width\"                                                 \n",
       "100  nwb.lab_meta_data[metadata\"].field_of_view_height\"                                                \n",
       "101  nwb.lab_meta_data[metadata\"].imaging_depth\"                                                       \n",
       "102  nwb.lab_meta_data[metadata\"].imaging_plane_group\"                                                 \n",
       "103  nwb.lab_meta_data[metadata\"].imaging_plane_group_count\"                                           \n",
       "104  nwb.lab_meta_data[metadata\"].ophys_experiment_id\"                                                 \n",
       "105  nwb.lab_meta_data[metadata\"].ophys_session_id\"                                                    \n",
       "106  nwb.processing[ophys\"][\"corrected_fluorescence\"].roi_response_series[\"traces\"].comments\"          \n",
       "107  nwb.processing[ophys\"][\"corrected_fluorescence\"].roi_response_series[\"traces\"].conversion\"        \n",
       "108  nwb.processing[ophys\"][\"corrected_fluorescence\"].roi_response_series[\"traces\"].description\"       \n",
       "109  nwb.processing[ophys\"][\"corrected_fluorescence\"].roi_response_series[\"traces\"].interval\"          \n",
       "110  nwb.processing[ophys\"][\"corrected_fluorescence\"].roi_response_series[\"traces\"]                    \n",
       "111  nwb.processing[ophys\"][\"corrected_fluorescence\"].roi_response_series[\"traces\"].resolution\"        \n",
       "112  nwb.processing[ophys\"][\"corrected_fluorescence\"].roi_response_series[\"traces\"].timestamps_unit\"   \n",
       "113  nwb.processing[ophys\"][\"corrected_fluorescence\"].roi_response_series[\"traces\"].unit\"              \n",
       "114  nwb.processing[ophys\"][\"corrected_fluorescence\"].roi_response_series.data\"                        \n",
       "115  nwb.processing[ophys\"][\"corrected_fluorescence\"].roi_response_series.timestamps\"                  \n",
       "116  nwb.processing[ophys\"][\"dff\"].roi_response_series.comments\"                                       \n",
       "117  nwb.processing[ophys\"][\"dff\"].roi_response_series.conversion\"                                     \n",
       "118  nwb.processing[ophys\"][\"dff\"].roi_response_series.description\"                                    \n",
       "119  nwb.processing[ophys\"][\"dff\"].roi_response_series.interval\"                                       \n",
       "120  nwb.processing[ophys\"][\"dff\"].roi_response_series.offset\"                                         \n",
       "121  nwb.processing[ophys\"][\"dff\"].roi_response_series.resolution\"                                     \n",
       "122  nwb.processing[ophys\"][\"dff\"].roi_response_series.timestamps_unit\"                                \n",
       "123  nwb.processing[ophys\"][\"dff\"].roi_response_series.unit\"                                           \n",
       "124  nwb.processing[ophys\"][\"dff\"].roi_response_series.data\"                                           \n",
       "125  nwb.processing[ophys\"][\"dff\"].roi_response_series.timestamps\"                                     \n",
       "126  nwb.processing[ophys\"][\"event_detection\"].comments\"                                               \n",
       "127  nwb.processing[ophys\"][\"event_detection\"].conversion\"                                             \n",
       "128  nwb.processing[ophys\"][\"event_detection\"].description\"                                            \n",
       "129  nwb.processing[ophys\"][\"event_detection\"].interval\"                                               \n",
       "130  nwb.processing[ophys\"][\"event_detection\"].offset\"                                                 \n",
       "131  nwb.processing[ophys\"][\"event_detection\"].resolution\"                                             \n",
       "132  nwb.processing[ophys\"][\"event_detection\"].timestamps_unit\"                                        \n",
       "133  nwb.processing[ophys\"][\"event_detection\"].unit\"                                                   \n",
       "134  nwb.processing[ophys\"][\"event_detection\"].data\"                                                   \n",
       "135  nwb.processing[ophys\"][\"event_detection\"].timestamps\"                                             \n",
       "136  nwb.processing[ophys\"][\"event_detection\"].lambdas\"                                                \n",
       "137  nwb.processing[ophys\"][\"event_detection\"].noise_stds\"                                             \n",
       "138  nwb.processing[ophys\"][\"image_segmentation\"][\"cell_specimen_table\"].colnames\"                     \n",
       "139  nwb.processing[ophys\"][\"image_segmentation\"][\"cell_specimen_table\"].id\"                           \n",
       "140  nwb.processing[ophys\"][\"image_segmentation\"][\"cell_specimen_table\"].cell_specimen_id\"             \n",
       "141  nwb.processing[ophys\"][\"image_segmentation\"][\"cell_specimen_table\"].height\"                       \n",
       "142  nwb.processing[ophys\"][\"image_segmentation\"][\"cell_specimen_table\"].mask_image_plane\"             \n",
       "143  nwb.processing[ophys\"][\"image_segmentation\"][\"cell_specimen_table\"].max_correction_down\"          \n",
       "144  nwb.processing[ophys\"][\"image_segmentation\"][\"cell_specimen_table\"].max_correction_left\"          \n",
       "145  nwb.processing[ophys\"][\"image_segmentation\"][\"cell_specimen_table\"].max_correction_up\"            \n",
       "146  nwb.processing[ophys\"][\"image_segmentation\"][\"cell_specimen_table\"].max_correction_right\"         \n",
       "147  nwb.processing[ophys\"][\"image_segmentation\"][\"cell_specimen_table\"].valid_roi\"                    \n",
       "148  nwb.processing[ophys\"][\"image_segmentation\"][\"cell_specimen_table\"].width\"                        \n",
       "149  nwb.processing[ophys\"][\"image_segmentation\"][\"cell_specimen_table\"].x\"                            \n",
       "150  nwb.processing[ophys\"][\"image_segmentation\"][\"cell_specimen_table\"].y\"                            \n",
       "151  nwb.processing[ophys\"][\"image_segmentation\"][\"cell_specimen_table\"].image_mask\"                   \n",
       "152  nwb.processing[ophys\"][\"images\"].description\"                                                     \n",
       "153  nwb.processing[ophys\"][\"images\"][\"average_image\"]\"                                                \n",
       "154  nwb.processing[ophys\"][\"images\"][\"max_projection\"]\"                                               \n",
       "155  nwb.processing[ophys\"][\"images\"][\"segmentation_mask\"]\"                                            \n",
       "156  nwb.processing[ophys\"][\"ophys_motion_correction_x\"].comments\"                                     \n",
       "157  nwb.processing[ophys\"][\"ophys_motion_correction_x\"].conversion\"                                   \n",
       "158  nwb.processing[ophys\"][\"ophys_motion_correction_x\"].description\"                                  \n",
       "159  nwb.processing[ophys\"][\"ophys_motion_correction_x\"].interval\"                                     \n",
       "160  nwb.processing[ophys\"][\"ophys_motion_correction_x\"].offset\"                                       \n",
       "161  nwb.processing[ophys\"][\"ophys_motion_correction_x\"].resolution\"                                   \n",
       "162  nwb.processing[ophys\"][\"ophys_motion_correction_x\"].timestamps_unit\"                              \n",
       "163  nwb.processing[ophys\"][\"ophys_motion_correction_x\"].unit\"                                         \n",
       "164  nwb.processing[ophys\"][\"ophys_motion_correction_x\"].data\"                                         \n",
       "165  nwb.processing[ophys\"][\"ophys_motion_correction_x\"].timestamps\"                                   \n",
       "166  nwb.processing[ophys\"][\"ophys_motion_correction_y\"].comments\"                                     \n",
       "167  nwb.processing[ophys\"][\"ophys_motion_correction_y\"].conversion\"                                   \n",
       "168  nwb.processing[ophys\"][\"ophys_motion_correction_y\"].description\"                                  \n",
       "169  nwb.processing[ophys\"][\"ophys_motion_correction_y\"].interval\"                                     \n",
       "170  nwb.processing[ophys\"][\"ophys_motion_correction_y\"].offset\"                                       \n",
       "171  nwb.processing[ophys\"][\"ophys_motion_correction_y\"].resolution\"                                   \n",
       "172  nwb.processing[ophys\"][\"ophys_motion_correction_y\"].timestamps_unit\"                              \n",
       "173  nwb.processing[ophys\"][\"ophys_motion_correction_y\"].unit\"                                         \n",
       "174  nwb.processing[ophys\"][\"ophys_motion_correction_y\"].data\"                                         \n",
       "175  nwb.processing[ophys\"][\"ophys_motion_correction_y\"].timestamps\"                                   \n",
       "176  nwb.processing[stimulus\"][\"timestamps\"].comments\"                                                 \n",
       "177  nwb.processing[stimulus\"][\"timestamps\"].conversion\"                                               \n",
       "178  nwb.processing[stimulus\"][\"timestamps\"].description\"                                              \n",
       "179  nwb.processing[stimulus\"][\"timestamps\"].interval\"                                                 \n",
       "180  nwb.processing[stimulus\"][\"timestamps\"].offset\"                                                   \n",
       "181  nwb.processing[stimulus\"][\"timestamps\"].resolution\"                                               \n",
       "182  nwb.processing[stimulus\"][\"timestamps\"].timestamps_unit\"                                          \n",
       "183  nwb.processing[stimulus\"][\"timestamps\"].unit\"                                                     \n",
       "184  nwb.processing[stimulus\"][\"timestamps\"].data\"                                                     \n",
       "185  nwb.processing[stimulus\"][\"timestamps\"].timestamps\"                                               \n",
       "186  nwb.processing[ophys_stimulus\"][\"timestamps\"].comments\"                                           \n",
       "187  nwb.processing[ophys_stimulus\"][\"timestamps\"].conversion\"                                         \n",
       "188  nwb.processing[ophys_stimulus\"][\"timestamps\"].description\"                                        \n",
       "189  nwb.processing[ophys_stimulus\"][\"timestamps\"].interval\"                                           \n",
       "190  nwb.processing[ophys_stimulus\"][\"timestamps\"].offset\"                                             \n",
       "191  nwb.processing[ophys_stimulus\"][\"timestamps\"].resolution\"                                         \n",
       "192  nwb.processing[ophys_stimulus\"][\"timestamps\"].timestamps_unit\"                                    \n",
       "193  nwb.processing[ophys_stimulus\"][\"timestamps\"].unit\"                                               \n",
       "194  nwb.processing[stimulus_ophys\"][\"timestamps\"].data\"                                               \n",
       "195  nwb.processing[stimulus_ophys\"][\"timestamps\"].timestamps\"                                         \n",
       "196  nwb.processing[running\"][\"dx\"].comments\"                                                          \n",
       "197  nwb.processing[running\"][\"dx\"].conversion\"                                                        \n",
       "198  nwb.processing[running\"][\"dx\"].description\"                                                       \n",
       "199  nwb.processing[running\"][\"dx\"].interval\"                                                          \n",
       "200  nwb.processing[running\"][\"dx\"].offset\"                                                            \n",
       "201  nwb.processing[running\"][\"dx\"].resolution\"                                                        \n",
       "202  nwb.processing[running\"][\"dx\"].timestamps_unit\"                                                   \n",
       "203  nwb.processing[running\"][\"dx\"].unit\"                                                              \n",
       "204  nwb.processing[running\"][\"dx\"].data\"                                                              \n",
       "205  nwb.processing[running\"][\"dx\"].timestamps\"                                                        \n",
       "206  nwb.processing[running\"][\"speed\"].comments\"                                                       \n",
       "207  nwb.processing[running\"][\"speed\"].conversion\"                                                     \n",
       "208  nwb.processing[running\"][\"speed\"].description\"                                                    \n",
       "209  nwb.processing[running\"][\"speed\"].interval\"                                                       \n",
       "210  nwb.processing[running\"][\"speed\"].offset\"                                                         \n",
       "211  nwb.processing[running\"][\"speed\"].resolution\"                                                     \n",
       "212  nwb.processing[running\"][\"speed\"].timestamps_unit\"                                                \n",
       "213  nwb.processing[running\"][\"speed\"].unit\"                                                           \n",
       "214  nwb.processing[running\"][\"speed\"].data\"                                                           \n",
       "215  nwb.processing[running\"][\"speed\"].timestamps\"                                                     \n",
       "216  nwb.processing[running\"][\"speed_unfiltered\"].comments\"                                            \n",
       "217  nwb.processing[running\"][\"speed_unfiltered\"].conversion\"                                          \n",
       "218  nwb.processing[running\"][\"speed_unfiltered\"].description\"                                         \n",
       "219  nwb.processing[running\"][\"speed_unfiltered\"].interval\"                                            \n",
       "220  nwb.processing[running\"][\"speed_unfiltered\"].offset\"                                              \n",
       "221  nwb.processing[running\"][\"speed_unfiltered\"].resolution\"                                          \n",
       "222  nwb.processing[running\"][\"speed_unfiltered\"].timestamps_unit\"                                     \n",
       "223  nwb.processing[running\"][\"speed_unfiltered\"].unit\"                                                \n",
       "224  nwb.processing[running\"][\"speed_unfiltered\"].data\"                                                \n",
       "225  nwb.processing[running\"][\"speed_unfiltered\"].timestamps\"                                          \n",
       "226  nwb.subject.age                                                                                   \n",
       "227  nwb.subject.age_in_days                                                                           \n",
       "228  nwb.subject.genotype                                                                              \n",
       "229  nwb.subject.sex                                                                                   \n",
       "230  nwb.subject.species                                                                               \n",
       "231  nwb.subject.specimen_name                                                                         \n",
       "232  nwb.subject.strain                                                                                \n",
       "233  nwb.subject.subject_id                                                                            \n",
       "234  nwb.subject.strain                                                                                \n",
       "235  nwb.subject.subject_id                                                                            \n",
       "\n",
       "                                                                                                                                                                                                                     Definition  \\\n",
       "0    Description of the Session                                                                                                                                                                                                   \n",
       "1    Unique identifier of the session                                                                                                                                                                                             \n",
       "2    Datetime start of the session                                                                                                                                                                                                \n",
       "3    Time that all timestamps are in reference to                                                                                                                                                                                 \n",
       "4    Description of the experiment                                                                                                                                                                                                \n",
       "5    Name of the institution that produced these data                                                                                                                                                                             \n",
       "6    Comments                                                                                                                                                                                                                     \n",
       "7    Scalar to multiply each element in data to convert it to the specified unit                                                                                                                                                  \n",
       "8    Description                                                                                                                                                                                                                  \n",
       "9    Unexplained                                                                                                                                                                                                                  \n",
       "10   Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.                                                                                                              \n",
       "11   Unexplained                                                                                                                                                                                                                  \n",
       "12   The smallest meaningful difference (in specified unit) between values in data                                                                                                                                                \n",
       "13   Name of the unit for the data                                                                                                                                                                                                \n",
       "14   Angle of the eye in degrees over time as calculated with corneal reflection tracking                                                                                                                                         \n",
       "15   Height of the cornea, in pixels, over time as calculated with corneal reflection tracking                                                                                                                                    \n",
       "16   Width of the cornea, in pixels, over time as calculated with corneal reflection tracking                                                                                                                                     \n",
       "17   Area of the cornea, in pixels, over time as calculated with corneal reflection tracking and with outliers removed. Should generally be equal to corneal reflection tracking height times corneal reflection tracking width   \n",
       "18   Area of the cornea, in pixels, over time as calculated with corneal reflection tracking. Should be equal to corneal reflection tracking height times corneal reflection tracking width.                                      \n",
       "19   2D array consisting of the X and Y locations of the eye, in pixels, over time as calculated by corneal reflection tracking                                                                                                   \n",
       "20   Timestamps of the corneal reflection tracking arrays                                                                                                                                                                         \n",
       "21   Comments                                                                                                                                                                                                                     \n",
       "22   Scalar to multiply each element in data to convert it to the specified unit                                                                                                                                                  \n",
       "23   Description                                                                                                                                                                                                                  \n",
       "24   Unexplained                                                                                                                                                                                                                  \n",
       "25   Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.                                                                                                              \n",
       "26   Unexplained                                                                                                                                                                                                                  \n",
       "27   The smallest meaningful difference (in specified unit) between values in data                                                                                                                                                \n",
       "28   Name of the unit for the data                                                                                                                                                                                                \n",
       "29   Angle of the eye in degrees over time as calculated with eye tracking                                                                                                                                                        \n",
       "30   Height of the eye, in pixels, over time as calculated with eye tracking                                                                                                                                                      \n",
       "31   Width of the eye, in pixels, over time as calculated with eye tracking                                                                                                                                                       \n",
       "32   Area of the eye, in pixels, over time as calculated with eye tracking with outliers removed. Should generally be equal to eye tracking height times eye tracking width                                                       \n",
       "33   Area of the eye, in pixels, over time as calculated with eye tracking. Should be equal to eye tracking height times eye tracking width                                                                                       \n",
       "34   2D array consisting of the X and Y locations of the eye, in pixels, over time as calculated by eye tracking                                                                                                                  \n",
       "35   Timestamps of the eye tracking arrays                                                                                                                                                                                        \n",
       "36   Comments                                                                                                                                                                                                                     \n",
       "37   Scalar to multiply each element in data to convert it to the specified unit                                                                                                                                                  \n",
       "38   Description                                                                                                                                                                                                                  \n",
       "39   Unexplained                                                                                                                                                                                                                  \n",
       "40   Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.                                                                                                              \n",
       "41   Unexplained                                                                                                                                                                                                                  \n",
       "42   The smallest meaningful difference (in specified unit) between values in data                                                                                                                                                \n",
       "43   Name of the unit for the data                                                                                                                                                                                                \n",
       "44   Angle of the pupil in degrees over time as calculated with pupil tracking                                                                                                                                                    \n",
       "45   Height of the pupil, in pixels, over time as calculated with pupil tracking                                                                                                                                                  \n",
       "46   Width of the pupil, in pixels, over time as calculated with pupil tracking                                                                                                                                                   \n",
       "47   Area of the pupil, in pixels, over time as calculated with pupil tracking and with outliers removed. Should generally be equal to pupil tracking height times pupil tracking width                                           \n",
       "48   Area of the pupil, in pixels, over time as calculated with pupil tracking. Should be equal to pupil tracking height times pupil tracking width                                                                               \n",
       "49   2D array consisting of the X and Y locations of the pupil, in pixels, over time as calculated by eye tracking                                                                                                                \n",
       "50   Timestamps of the pupil tracking arrays                                                                                                                                                                                      \n",
       "51   Array of booleans indicating probable blink times                                                                                                                                                                            \n",
       "52   Timestamps of the blink times array                                                                                                                                                                                          \n",
       "53   3D array of the raw 2P movie where the dimensions are pixels height * pixels width * frame time                                                                                                                              \n",
       "54   Timestamps of the frames in the 2P movie                                                                                                                                                                                     \n",
       "55   Framerate of the 2P movie                                                                                                                                                                                                    \n",
       "56   Device that produced the 2P movie data                                                                                                                                                                                       \n",
       "57   Imaging Plane of the 2P movie                                                                                                                                                                                                \n",
       "58   Comments                                                                                                                                                                                                                     \n",
       "59   Scalar to multiply each element in data to convert it to the specified unit                                                                                                                                                  \n",
       "60   Description                                                                                                                                                                                                                  \n",
       "61   Unexplained                                                                                                                                                                                                                  \n",
       "62   Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.                                                                                                              \n",
       "63   The smallest meaningful difference (in specified unit) between values in data                                                                                                                                                \n",
       "64   Name of the unit for the timestamps                                                                                                                                                                                          \n",
       "65   Name of the unit for the data                                                                                                                                                                                                \n",
       "66   Unused                                                                                                                                                                                                                       \n",
       "67   Unused                                                                                                                                                                                                                       \n",
       "68   Comments                                                                                                                                                                                                                     \n",
       "69   Scalar to multiply each element in data to convert it to the specified unit                                                                                                                                                  \n",
       "70   Description                                                                                                                                                                                                                  \n",
       "71   Unexplained                                                                                                                                                                                                                  \n",
       "72   Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.                                                                                                              \n",
       "73   The smallest meaningful difference (in specified unit) between values in data                                                                                                                                                \n",
       "74   Name of the unit for the timestamps                                                                                                                                                                                          \n",
       "75   Name of the unit for the data                                                                                                                                                                                                \n",
       "76   Unused                                                                                                                                                                                                                       \n",
       "77   Unused                                                                                                                                                                                                                       \n",
       "78   Description of the device                                                                                                                                                                                                    \n",
       "79   Datetime time this file was created                                                                                                                                                                                          \n",
       "80   Description of the instrument used.                                                                                                                                                                                          \n",
       "81   Peak wavelength of the light excitation given by the pulsed Ti:Sa laser (nm).                                                                                                                                                \n",
       "82   Frame rate to record each imaged plane.                                                                                                                                                                                      \n",
       "83   Calcium indicator used to record neuronal activity.                                                                                                                                                                          \n",
       "84   Brain area imaged during the experiemnt.                                                                                                                                                                                     \n",
       "85   Optical channel associated with this imaging plane. This provides a description of the fluorescence emission wavelength.                                                                                                     \n",
       "86   Unit of this imaging plane                                                                                                                                                                                                   \n",
       "87   Column names of the stimulus table                                                                                                                                                                                           \n",
       "88   IDs column of the stimulus table                                                                                                                                                                                             \n",
       "89   Start times of the stimulus table                                                                                                                                                                                            \n",
       "90   Stop times of the stimulus table                                                                                                                                                                                             \n",
       "91   Names of stimulus types column of the stimulus table                                                                                                                                                                         \n",
       "92   Numbers representing stimulus blocks column of the stimulus table                                                                                                                                                            \n",
       "93   Column of the stimulus table consisting of frame numbers of the stimulus                                                                                                                                                     \n",
       "94   Column of the stimulus table which contains the stimulus index for each interval                                                                                                                                             \n",
       "95   Column of the stimulus table which contains a list of tags for each interval                                                                                                                                                 \n",
       "96   Column of the stimulus table contain tuples of the form (i, c, r) where r is a reference to the complete timestamps array for the session, and i is the index within that array                                              \n",
       "97   Description of the stimulus table                                                                                                                                                                                            \n",
       "98   unique id associated with all experiments that were cell-matched                                                                                                                                                             \n",
       "99   Number of pixels in the horizontal direction                                                                                                                                                                                 \n",
       "100  Number of pixels in the vertical direction                                                                                                                                                                                   \n",
       "101  Imaging depth from the surface of the brain in microns                                                                                                                                                                       \n",
       "102  The Allen Institute mesoscope simultaneously acquire planes in pair.  This number indicate which plane this experiment is associated with.                                                                                   \n",
       "103  Id of the imaging plane within the pair of simultateneously acquired planes.                                                                                                                                                 \n",
       "104  Unique id given to each imaging plane                                                                                                                                                                                        \n",
       "105  Unique id given to each experimental session. Multiple experiemntal ids can have the same session id.                                                                                                                        \n",
       "106  Comments                                                                                                                                                                                                                     \n",
       "107  Scalar to multiply each element in data to convert it to the specified unit                                                                                                                                                  \n",
       "108  Description                                                                                                                                                                                                                  \n",
       "109  Unexplained                                                                                                                                                                                                                  \n",
       "110  Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.                                                                                                              \n",
       "111  The smallest meaningful difference (in specified unit) between values in data                                                                                                                                                \n",
       "112  Name of the unit for the timestamps                                                                                                                                                                                          \n",
       "113  Name of the unit for the data                                                                                                                                                                                                \n",
       "114  Traces extracted from individual ROI, neuropil subtracted and demixed, but not normalized                                                                                                                                    \n",
       "115  Timestamps of the corrected_fluorescence arrays                                                                                                                                                                              \n",
       "116  Comments                                                                                                                                                                                                                     \n",
       "117  Scalar to multiply each element in data to convert it to the specified unit                                                                                                                                                  \n",
       "118  Description                                                                                                                                                                                                                  \n",
       "119  Unexplained                                                                                                                                                                                                                  \n",
       "120  Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.                                                                                                              \n",
       "121  The smallest meaningful difference (in specified unit) between values in data                                                                                                                                                \n",
       "122  Name of the unit for the timestamps                                                                                                                                                                                          \n",
       "123  Name of the unit for the data                                                                                                                                                                                                \n",
       "124  Traces extracted from individual ROI, baseline corrected, normalized fluorescence traces                                                                                                                                     \n",
       "125  Timestamps of the dff arrays                                                                                                                                                                                                 \n",
       "126  Comments                                                                                                                                                                                                                     \n",
       "127  Scalar to multiply each element in data to convert it to the specified unit                                                                                                                                                  \n",
       "128  Description                                                                                                                                                                                                                  \n",
       "129  Unexplained                                                                                                                                                                                                                  \n",
       "130  Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.                                                                                                              \n",
       "131  The smallest meaningful difference (in specified unit) between values in data                                                                                                                                                \n",
       "132  Name of the unit for the timestamps                                                                                                                                                                                          \n",
       "133  Name of the unit for the data                                                                                                                                                                                                \n",
       "134  Calcium events (detected with an L0 event detection algorithm)                                                                                                                                                               \n",
       "135  Timestamps of the events_detection arrays                                                                                                                                                                                    \n",
       "136  Lambda used in the event detection algorithm. lambda is chosen by finding smallest lambda such that the size of the smallest detected event is greater or equal to event_min_size*robust std of noise.                       \n",
       "137  Estimates of the std of the noise for each trace                                                                                                                                                                             \n",
       "138  Column names of the ROI table                                                                                                                                                                                                \n",
       "139  Column of IDs in the ROI table                                                                                                                                                                                               \n",
       "140  Column of the ROI table consisting of the cell ID within a container for each ROI                                                                                                                                            \n",
       "141  ROI heights, in pixels, column of the ROIs table                                                                                                                                                                             \n",
       "142  Column of the ROI table consisting of the index of ROIs that overlap                                                                                                                                                         \n",
       "143  Column of the ROI table consisting of the maximum motion correction downward for each ROI                                                                                                                                    \n",
       "144  Column of the ROI table consisting of the maximum motion correction to the left for each ROI                                                                                                                                 \n",
       "145  Maximum motion correction upward                                                                                                                                                                                             \n",
       "146  Maximum motion correction to the right                                                                                                                                                                                       \n",
       "147  ROI validity flags column of the ROIs table, indicating if the ROI is classified as a cell                                                                                                                                   \n",
       "148  ROI widths, in pixels, column of the ROI table                                                                                                                                                                               \n",
       "149  ROI X coordinates, in pixels, column of the ROI table                                                                                                                                                                        \n",
       "150  ROI Y coordinates, in pixels, column of the ROI table                                                                                                                                                                        \n",
       "151  Column of the ROIs table consisting of the black/white segmentation mask image of each individual ROI                                                                                                                        \n",
       "152  Description of the Images                                                                                                                                                                                                    \n",
       "153  Average Image of the movie from the session                                                                                                                                                                                  \n",
       "154  Maximum projection image of the movie from the session                                                                                                                                                                       \n",
       "155  Black/white Segmentation mask image of all ROIs in the movie                                                                                                                                                                 \n",
       "156  Comments                                                                                                                                                                                                                     \n",
       "157  Scalar to multiply each element in data to convert it to the specified unit                                                                                                                                                  \n",
       "158  Description                                                                                                                                                                                                                  \n",
       "159  Unexplained                                                                                                                                                                                                                  \n",
       "160  Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.                                                                                                              \n",
       "161  The smallest meaningful difference (in specified unit) between values in data                                                                                                                                                \n",
       "162  Name of the unit for the timestamps                                                                                                                                                                                          \n",
       "163  Name of the unit for the data                                                                                                                                                                                                \n",
       "164  horizontal correction applied to each frame of the two-photon raw movie using rigid-body motion correction                                                                                                                   \n",
       "165  Array of timestamps for the motion correction arrays                                                                                                                                                                         \n",
       "166  Comments                                                                                                                                                                                                                     \n",
       "167  Scalar to multiply each element in data to convert it to the specified unit                                                                                                                                                  \n",
       "168  Description                                                                                                                                                                                                                  \n",
       "169  Unexplained                                                                                                                                                                                                                  \n",
       "170  Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.                                                                                                              \n",
       "171  The smallest meaningful difference (in specified unit) between values in data                                                                                                                                                \n",
       "172  Name of the unit for the timestamps                                                                                                                                                                                          \n",
       "173  Name of the unit for the data                                                                                                                                                                                                \n",
       "174  Vertical correction applied to each frame of the two-photon raw movie using rigid-body motion correction                                                                                                                     \n",
       "175  Array of timestamps for the motion correction arrays                                                                                                                                                                         \n",
       "176  Comments                                                                                                                                                                                                                     \n",
       "177  Scalar to multiply each element in data to convert it to the specified unit                                                                                                                                                  \n",
       "178  Description                                                                                                                                                                                                                  \n",
       "179  Unexplained                                                                                                                                                                                                                  \n",
       "180  Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.                                                                                                              \n",
       "181  The smallest meaningful difference (in specified unit) between values in data                                                                                                                                                \n",
       "182  Name of the unit for the timestamps                                                                                                                                                                                          \n",
       "183  Name of the unit for the data                                                                                                                                                                                                \n",
       "184  Array of all the screen refresh timestamps during the session. Identical to Stimulus Timestamps                                                                                                                              \n",
       "185  Array of all the screen refresh timestamps during the session. Identical to Stimulus Timestamps                                                                                                                              \n",
       "186  Comments                                                                                                                                                                                                                     \n",
       "187  Scalar to multiply each element in data to convert it to the specified unit                                                                                                                                                  \n",
       "188  Description                                                                                                                                                                                                                  \n",
       "189  Unexplained                                                                                                                                                                                                                  \n",
       "190  Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.                                                                                                              \n",
       "191  The smallest meaningful difference (in specified unit) between values in data                                                                                                                                                \n",
       "192  Name of the unit for the timestamps                                                                                                                                                                                          \n",
       "193  Name of the unit for the data                                                                                                                                                                                                \n",
       "194  Timestamps associated with all visual stimuli presented on the strimulation screen.                                                                                                                                          \n",
       "195  Timestamps associated with all visual stimuli presented on the strimulation screen.                                                                                                                                          \n",
       "196  Comments                                                                                                                                                                                                                     \n",
       "197  Scalar to multiply each element in data to convert it to the specified unit                                                                                                                                                  \n",
       "198  Description                                                                                                                                                                                                                  \n",
       "199  Unexplained                                                                                                                                                                                                                  \n",
       "200  Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.                                                                                                              \n",
       "201  The smallest meaningful difference (in specified unit) between values in data                                                                                                                                                \n",
       "202  Name of the unit for the timestamps                                                                                                                                                                                          \n",
       "203  Name of the unit for the data                                                                                                                                                                                                \n",
       "204  Array of differences, in degrees, between current and last wheel position                                                                                                                                                    \n",
       "205  Array of timestamps for the dx array                                                                                                                                                                                         \n",
       "206  Comments                                                                                                                                                                                                                     \n",
       "207  Scalar to multiply each element in data to convert it to the specified unit                                                                                                                                                  \n",
       "208  Description                                                                                                                                                                                                                  \n",
       "209  Unexplained                                                                                                                                                                                                                  \n",
       "210  Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.                                                                                                              \n",
       "211  The smallest meaningful difference (in specified unit) between values in data                                                                                                                                                \n",
       "212  Name of the unit for the timestamps                                                                                                                                                                                          \n",
       "213  Name of the unit for the data                                                                                                                                                                                                \n",
       "214  Speed of the running wheel, measured at each timestamps. The data is filtered with a low-pass filter to remove noise artifacts (cm/s).                                                                                       \n",
       "215  Timestamps of the running speed.                                                                                                                                                                                             \n",
       "216  Comments                                                                                                                                                                                                                     \n",
       "217  Scalar to multiply each element in data to convert it to the specified unit                                                                                                                                                  \n",
       "218  Description                                                                                                                                                                                                                  \n",
       "219  Unexplained                                                                                                                                                                                                                  \n",
       "220  Scalar to add to each element in the data scaled by ‘conversion’ to finish converting it to the specified unit.                                                                                                              \n",
       "221  The smallest meaningful difference (in specified unit) between values in data                                                                                                                                                \n",
       "222  Name of the unit for the timestamps                                                                                                                                                                                          \n",
       "223  Name of the unit for the data                                                                                                                                                                                                \n",
       "224  Speed of the running wheel, measured at each timestamps. The data is raw (cm/s).                                                                                                                                             \n",
       "225  Timestamps of the unfiltered running speed.                                                                                                                                                                                  \n",
       "226  Age of the subject                                                                                                                                                                                                           \n",
       "227  Age of the subject, in days                                                                                                                                                                                                  \n",
       "228  Genotype of the subject                                                                                                                                                                                                      \n",
       "229  Sex of the subject, M or F                                                                                                                                                                                                   \n",
       "230  Species of the subject                                                                                                                                                                                                       \n",
       "231  Specimen name of the subject                                                                                                                                                                                                 \n",
       "232  Strain of the subject                                                                                                                                                                                                        \n",
       "233  Unique identifier of the subject                                                                                                                                                                                             \n",
       "234  Strain of the subject                                                                                                                                                                                                        \n",
       "235  Unique identifier of the subject                                                                                                                                                                                             \n",
       "\n",
       "     Unnamed: 5  \n",
       "0   NaN          \n",
       "1   NaN          \n",
       "2   NaN          \n",
       "3   NaN          \n",
       "4   NaN          \n",
       "5   NaN          \n",
       "6   NaN          \n",
       "7   NaN          \n",
       "8   NaN          \n",
       "9   NaN          \n",
       "10  NaN          \n",
       "11  NaN          \n",
       "12  NaN          \n",
       "13  NaN          \n",
       "14  NaN          \n",
       "15  NaN          \n",
       "16  NaN          \n",
       "17  NaN          \n",
       "18  NaN          \n",
       "19  NaN          \n",
       "20  NaN          \n",
       "21  NaN          \n",
       "22  NaN          \n",
       "23  NaN          \n",
       "24  NaN          \n",
       "25  NaN          \n",
       "26  NaN          \n",
       "27  NaN          \n",
       "28  NaN          \n",
       "29  NaN          \n",
       "30  NaN          \n",
       "31  NaN          \n",
       "32  NaN          \n",
       "33  NaN          \n",
       "34  NaN          \n",
       "35  NaN          \n",
       "36  NaN          \n",
       "37  NaN          \n",
       "38  NaN          \n",
       "39  NaN          \n",
       "40  NaN          \n",
       "41  NaN          \n",
       "42  NaN          \n",
       "43  NaN          \n",
       "44  NaN          \n",
       "45  NaN          \n",
       "46  NaN          \n",
       "47  NaN          \n",
       "48  NaN          \n",
       "49  NaN          \n",
       "50  NaN          \n",
       "51  NaN          \n",
       "52  NaN          \n",
       "53  NaN          \n",
       "54  NaN          \n",
       "55  NaN          \n",
       "56  NaN          \n",
       "57  NaN          \n",
       "58  NaN          \n",
       "59  NaN          \n",
       "60  NaN          \n",
       "61  NaN          \n",
       "62  NaN          \n",
       "63  NaN          \n",
       "64  NaN          \n",
       "65  NaN          \n",
       "66  NaN          \n",
       "67  NaN          \n",
       "68  NaN          \n",
       "69  NaN          \n",
       "70  NaN          \n",
       "71  NaN          \n",
       "72  NaN          \n",
       "73  NaN          \n",
       "74  NaN          \n",
       "75  NaN          \n",
       "76  NaN          \n",
       "77  NaN          \n",
       "78  NaN          \n",
       "79  NaN          \n",
       "80  NaN          \n",
       "81  NaN          \n",
       "82  NaN          \n",
       "83  NaN          \n",
       "84  NaN          \n",
       "85  NaN          \n",
       "86  NaN          \n",
       "87  NaN          \n",
       "88  NaN          \n",
       "89  NaN          \n",
       "90  NaN          \n",
       "91  NaN          \n",
       "92  NaN          \n",
       "93  NaN          \n",
       "94  NaN          \n",
       "95  NaN          \n",
       "96  NaN          \n",
       "97  NaN          \n",
       "98  NaN          \n",
       "99  NaN          \n",
       "100 NaN          \n",
       "101 NaN          \n",
       "102 NaN          \n",
       "103 NaN          \n",
       "104 NaN          \n",
       "105 NaN          \n",
       "106 NaN          \n",
       "107 NaN          \n",
       "108 NaN          \n",
       "109 NaN          \n",
       "110 NaN          \n",
       "111 NaN          \n",
       "112 NaN          \n",
       "113 NaN          \n",
       "114 NaN          \n",
       "115 NaN          \n",
       "116 NaN          \n",
       "117 NaN          \n",
       "118 NaN          \n",
       "119 NaN          \n",
       "120 NaN          \n",
       "121 NaN          \n",
       "122 NaN          \n",
       "123 NaN          \n",
       "124 NaN          \n",
       "125 NaN          \n",
       "126 NaN          \n",
       "127 NaN          \n",
       "128 NaN          \n",
       "129 NaN          \n",
       "130 NaN          \n",
       "131 NaN          \n",
       "132 NaN          \n",
       "133 NaN          \n",
       "134 NaN          \n",
       "135 NaN          \n",
       "136 NaN          \n",
       "137 NaN          \n",
       "138 NaN          \n",
       "139 NaN          \n",
       "140 NaN          \n",
       "141 NaN          \n",
       "142 NaN          \n",
       "143 NaN          \n",
       "144 NaN          \n",
       "145 NaN          \n",
       "146 NaN          \n",
       "147 NaN          \n",
       "148 NaN          \n",
       "149 NaN          \n",
       "150 NaN          \n",
       "151 NaN          \n",
       "152 NaN          \n",
       "153 NaN          \n",
       "154 NaN          \n",
       "155 NaN          \n",
       "156 NaN          \n",
       "157 NaN          \n",
       "158 NaN          \n",
       "159 NaN          \n",
       "160 NaN          \n",
       "161 NaN          \n",
       "162 NaN          \n",
       "163 NaN          \n",
       "164 NaN          \n",
       "165 NaN          \n",
       "166 NaN          \n",
       "167 NaN          \n",
       "168 NaN          \n",
       "169 NaN          \n",
       "170 NaN          \n",
       "171 NaN          \n",
       "172 NaN          \n",
       "173 NaN          \n",
       "174 NaN          \n",
       "175 NaN          \n",
       "176 NaN          \n",
       "177 NaN          \n",
       "178 NaN          \n",
       "179 NaN          \n",
       "180 NaN          \n",
       "181 NaN          \n",
       "182 NaN          \n",
       "183 NaN          \n",
       "184 NaN          \n",
       "185 NaN          \n",
       "186 NaN          \n",
       "187 NaN          \n",
       "188 NaN          \n",
       "189 NaN          \n",
       "190 NaN          \n",
       "191 NaN          \n",
       "192 NaN          \n",
       "193 NaN          \n",
       "194 NaN          \n",
       "195 NaN          \n",
       "196 NaN          \n",
       "197 NaN          \n",
       "198 NaN          \n",
       "199 NaN          \n",
       "200 NaN          \n",
       "201 NaN          \n",
       "202 NaN          \n",
       "203 NaN          \n",
       "204 NaN          \n",
       "205 NaN          \n",
       "206 NaN          \n",
       "207 NaN          \n",
       "208 NaN          \n",
       "209 NaN          \n",
       "210 NaN          \n",
       "211 NaN          \n",
       "212 NaN          \n",
       "213 NaN          \n",
       "214 NaN          \n",
       "215 NaN          \n",
       "216 NaN          \n",
       "217 NaN          \n",
       "218 NaN          \n",
       "219 NaN          \n",
       "220 NaN          \n",
       "221 NaN          \n",
       "222 NaN          \n",
       "223 NaN          \n",
       "224 NaN          \n",
       "225 NaN          \n",
       "226 NaN          \n",
       "227 NaN          \n",
       "228 NaN          \n",
       "229 NaN          \n",
       "230 NaN          \n",
       "231 NaN          \n",
       "232 NaN          \n",
       "233 NaN          \n",
       "234 NaN          \n",
       "235 NaN          "
      ]
     },
     "execution_count": 10,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "pd.read_csv(\"../../data/ophys_schema.csv\")"
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3 (ipykernel)",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.10.8"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 5
}
